@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2018 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2018 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric.
 
@@ -22,17 +22,13 @@ except ImportError:
 from eric7.Globals import getConfig
 
 
-def main(argv):
+def main():
     """
     Create Desktop and Start Menu links.
-
-    @param argv list of command line arguments
-    @type list of str
     """
     if sys.platform.startswith(("win", "cygwin")):
         regPath = (
-            "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer"
-            + "\\User Shell Folders"
+            "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\User Shell Folders"
         )
 
         # 1. create desktop shortcuts
@@ -73,7 +69,7 @@ def getWinregEntry(name, path):
     @param path registry path of the variable
     @type str
     @return value of requested registry variable
-    @rtype any
+    @rtype Any
     """
     try:
         registryKey = winreg.OpenKey(winreg.HKEY_CURRENT_USER, path)
@@ -132,6 +128,11 @@ def windowsDesktopEntries():
             os.path.join(getConfig("bindir"), "eric7_ide.cmd"),
             os.path.join(getConfig("ericPixDir"), "eric7.ico"),
         ),
+        (
+            "eric7 MicroPython (Python {0}.{1}).lnk",
+            os.path.join(getConfig("bindir"), "eric7_mpy.cmd"),
+            os.path.join(getConfig("ericPixDir"), "ericMPy48.ico"),
+        ),
         (
             "eric7 Browser (Python {0}.{1}).lnk",
             os.path.join(getConfig("bindir"), "eric7_browser.cmd"),
@@ -157,7 +158,7 @@ def windowsProgramsEntry():
 
 if __name__ == "__main__":
     try:
-        main(sys.argv)
+        main()
     except SystemExit:
         raise
     except Exception:
