@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2022 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2022 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -480,7 +480,9 @@ class BlackFormattingDialog(QDialog, Ui_BlackFormattingDialog):
         @param relSrc name of the file relative to the project (defaults to "")
         @type str (optional)
         """
-        then = datetime.datetime.utcfromtimestamp(src.stat().st_mtime)
+        then = datetime.datetime.fromtimestamp(
+            src.stat().st_mtime, tz=datetime.timezone.utc
+        )
         with open(src, "rb") as buf:
             srcContents, _, _ = black.decode_bytes(buf.read())
         try:
@@ -491,7 +493,7 @@ class BlackFormattingDialog(QDialog, Ui_BlackFormattingDialog):
 
         fileName = relSrc if bool(relSrc) else str(src)
 
-        now = datetime.datetime.utcnow()
+        now = datetime.datetime.now(tz=datetime.timezone.utc)
         srcName = f"{fileName}\t{then} +0000"
         dstName = f"{fileName}\t{now} +0000"
         diffContents = black.diff(srcContents, dstContents, srcName, dstName)
@@ -661,7 +663,7 @@ class BlackReport(QObject, black.Report):
         """
         self.result.emit("failed", str(src), message)
 
-    def path_ignored(self, src, message=""):
+    def path_ignored(self, src, message=""):  # noqa: U100
         """
         Public method handling an ignored path.
 
@@ -739,7 +741,7 @@ class BlackMultiprocessingReport(black.Report):
             BlackMultiprocessingResult(status="failed", filename=str(src), data=message)
         )
 
-    def path_ignored(self, src, message=""):
+    def path_ignored(self, src, message=""):  # noqa: U100
         """
         Public method handling an ignored path.
 
