@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,6 +25,7 @@ from eric7.EricGui import EricPixmapCache
 from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 from eric7.EricWidgets import EricFileDialog, EricMessageBox, EricTextInputDialog
 from eric7.EricWidgets.EricApplication import ericApp
+from eric7.VirtualEnv.VirtualenvMeta import VirtualenvMetaData
 
 from .Ui_CondaPackagesWidget import Ui_CondaPackagesWidget
 
@@ -667,9 +668,13 @@ class CondaPackagesWidget(QWidget, Ui_CondaPackagesWidget):
                 ]
                 ok, prefix, interpreter = self.__conda.createCondaEnvironment(args)
                 if ok:
-                    ericApp().getObject("VirtualEnvManager").addVirtualEnv(
-                        virtEnvName, prefix, interpreter, isConda=True
+                    metadata = VirtualenvMetaData(
+                        name=virtEnvName,
+                        path=prefix,
+                        interpreter=interpreter,
+                        is_conda=True,
                     )
+                    ericApp().getObject("VirtualEnvManager").addVirtualEnv(metadata)
 
     @pyqtSlot()
     def __createEnvironment(self):
@@ -689,9 +694,13 @@ class CondaPackagesWidget(QWidget, Ui_CondaPackagesWidget):
             ]
             ok, prefix, interpreter = self.__conda.createCondaEnvironment(args)
             if ok:
-                ericApp().getObject("VirtualEnvManager").addVirtualEnv(
-                    virtEnvName, prefix, interpreter, isConda=True
+                metadata = VirtualenvMetaData(
+                    name=virtEnvName,
+                    path=prefix,
+                    interpreter=interpreter,
+                    is_conda=True,
                 )
+                ericApp().getObject("VirtualEnvManager").addVirtualEnv(metadata)
 
     @pyqtSlot()
     def __deleteEnvironment(self):
