@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -49,9 +49,12 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Constructor
 
-        @param ui reference to the user interface object (UserInterface)
-        @param port port to be used for the cooperation server (integer)
-        @param parent reference to the parent widget (QWidget)
+        @param ui reference to the user interface object
+        @type UserInterface
+        @param port port to be used for the cooperation server
+        @type int
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -118,7 +121,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private method to remember the given host as the most recent entry.
 
-        @param host host entry to remember (string)
+        @param host host entry to remember
+        @type str
         """
         if host in self.__recent:
             self.__recent.remove(host)
@@ -158,7 +162,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot handling a new participant joining.
 
-        @param nick nick name of the new participant (string)
+        @param nick nick name of the new participant
+        @type str
         """
         if nick == "":
             return
@@ -194,7 +199,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot handling a participant leaving the session.
 
-        @param nick nick name of the participant (string)
+        @param nick nick name of the participant
+        @type str
         """
         if nick == "":
             return
@@ -227,8 +233,10 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Public slot to append a message to the display.
 
-        @param from_ originator of the message (string)
-        @param message message to be appended (string)
+        @param from_ originator of the message
+        @type str
+        @param message message to be appended
+        @type str
         """
         if from_ == "" or message == "":
             return
@@ -255,7 +263,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot handling the entry of a host to connect to.
 
-        @param host host to connect to (string)
+        @param host host to connect to
+        @type str
         """
         if not self.__connected:
             self.connectButton.setEnabled(host != "")
@@ -264,7 +273,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private method to determine the connection parameters.
 
-        @return tuple with hostname and port (string, integer)
+        @return tuple with hostname and port
+        @rtype tuple of (str, int)
         """
         hostEntry = self.hostEdit.currentText()
         if "@" in hostEntry:
@@ -332,7 +342,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to set the connected state.
 
-        @param connected new connected state (boolean)
+        @param connected new connected state
+        @type bool
         """
         if connected:
             self.connectButton.setText(self.tr("Disconnect"))
@@ -360,7 +371,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to show an error message.
 
-        @param message error message to show (string)
+        @param message error message to show
+        @type str
         """
         color = self.chatEdit.textColor()
         self.chatEdit.setTextColor(Qt.GlobalColor.red)
@@ -390,7 +402,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Public method to get a reference to the cooperation client.
 
-        @return reference to the cooperation client (CooperationClient)
+        @return reference to the cooperation client
+        @rtype CooperationClient
         """
         return self.__client
 
@@ -398,9 +411,12 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to handle editor command messages from the client.
 
-        @param hashStr hash of the project (string)
-        @param fileName project relative file name of the editor (string)
-        @param message command message (string)
+        @param hashStr hash of the project
+        @type str
+        @param fileName project relative file name of the editor
+        @type str
+        @param message command message
+        @type str
         """
         from eric7.QScintilla.Editor import Editor
 
@@ -419,7 +435,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to share the current editor.
 
-        @param checked flag indicating the button state (boolean)
+        @param checked flag indicating the button state
+        @type bool
         """
         if checked:
             self.shareButton.setIcon(EricPixmapCache.getIcon("sharedEditConnected"))
@@ -434,7 +451,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to start a shared edit session.
 
-        @param checked flag indicating the button state (boolean)
+        @param checked flag indicating the button state
+        @type bool
         """
         if checked:
             self.sendEditButton.setEnabled(True)
@@ -474,7 +492,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Public slot to set action according to an editor's state.
 
-        @param editor reference to the editor (Editor)
+        @param editor reference to the editor
+        @type Editor
         """
         shareable, sharing, editing, remoteEditing = editor.getSharingStatus()
 
@@ -521,7 +540,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to react to text selection/deselection of the chat edit.
 
-        @param yes flag signaling the availability of selected text (boolean)
+        @param yes flag signaling the availability of selected text
+        @type bool
         """
         self.__copyChatAct.setEnabled(yes)
 
@@ -530,7 +550,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to show the context menu for the chat.
 
-        @param pos the position of the mouse pointer (QPoint)
+        @param pos the position of the mouse pointer
+        @type QPoint
         """
         enable = self.chatEdit.toPlainText() != ""
         self.__saveChatAct.setEnabled(enable)
@@ -640,7 +661,8 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         Private slot to show the context menu for the users list.
 
-        @param pos the position of the mouse pointer (QPoint)
+        @param pos the position of the mouse pointer
+        @type QPoint
         """
         itm = self.usersList.itemAt(pos)
         self.__kickUserAct.setEnabled(itm is not None)
