@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,6 +37,7 @@ def printerr(s):
     Module function used for debugging the debug client.
 
     @param s data to be printed
+    @type str
     """
     sys.__stderr__.write("{0!s}\n".format(s))
     sys.__stderr__.flush()
@@ -46,7 +47,8 @@ def setRecursionLimit(limit):
     """
     Module function to set the recursion limit.
 
-    @param limit recursion limit (integer)
+    @param limit recursion limit
+    @type int
     """
     global gRecursionLimit
     gRecursionLimit = limit
@@ -75,6 +77,7 @@ class DebugBase:
         Constructor
 
         @param dbgClient the owning client
+        @type DebugClient
         """
         self._dbgClient = dbgClient
 
@@ -114,8 +117,7 @@ class DebugBase:
         # Use it like this:
         # if hasattr(sys, 'breakpoint): sys.breakpoint()
         sys.breakpoint = self.set_trace
-        if sys.version_info >= (3, 7):
-            sys.breakpointhook = self.set_trace
+        sys.breakpointhook = self.set_trace
 
     def __eventPollTimer(self):
         """
@@ -152,8 +154,10 @@ class DebugBase:
         or a frame below.
 
         @param frmnr distance of frame to get locals dictionary of. 0 is
-            the current frame (int)
+            the current frame
+        @type int
         @return locals dictionary of the frame
+        @rtype dict
         """
         try:
             f = self.frameList[frmnr]
@@ -167,18 +171,20 @@ class DebugBase:
         frame.f_locals returns the last data.
 
         @param frmnr distance of frame to store locals dictionary to. 0 is
-            the current frame (int)
+            the current frame
+        @type int
         """
-        cf = self.frameList[frmnr]
+        with contextlib.suppress(IndexError):
+            cf = self.frameList[frmnr]
 
-        with contextlib.suppress(ImportError, AttributeError):
-            if "__pypy__" in sys.builtin_module_names:
-                import __pypy__  # __IGNORE_WARNING_I10__
+            with contextlib.suppress(ImportError, AttributeError):
+                if "__pypy__" in sys.builtin_module_names:
+                    import __pypy__  # __IGNORE_WARNING_I10__
 
-                __pypy__.locals_to_fast(cf)
-                return
+                    __pypy__.locals_to_fast(cf)
+                    return
 
-        ctypes.pythonapi.PyFrame_LocalsToFast(ctypes.py_object(cf), ctypes.c_int(0))
+            ctypes.pythonapi.PyFrame_LocalsToFast(ctypes.py_object(cf), ctypes.c_int(0))
 
     def step(self, traceMode):
         """
@@ -186,6 +192,7 @@ class DebugBase:
 
         @param traceMode If it is True, then the step is a step into,
               otherwise it is a step over.
+        @type bool
         """
         if traceMode:
             self.set_step()
@@ -205,6 +212,7 @@ class DebugBase:
         It resumes the thread stopping only at breakpoints or exceptions.
 
         @param special flag indicating a special continue operation
+        @type bool
         """
         self.set_continue(special)
 
@@ -213,13 +221,14 @@ class DebugBase:
         Public method to determine the current recursion depth.
 
         @param frame The current stack frame.
+        @type frame object
         """
         self.__recursionDepth = 0
         while frame is not None:
             self.__recursionDepth += 1
             frame = frame.f_back
 
-    def profileWithRecursion(self, frame, event, arg):
+    def profileWithRecursion(self, frame, event, arg):  # noqa: U100
         """
         Public method used to trace some stuff independent of the debugger
         trace function.
@@ -248,7 +257,7 @@ class DebugBase:
                     "(offending frame is two down the stack)"
                 )
 
-    def profile(self, frame, event, arg):
+    def profile(self, frame, event, arg):  # noqa: U100
         """
         Public method used to trace some stuff independent of the debugger
         trace function.
@@ -315,6 +324,9 @@ class DebugBase:
             if self.quitting:
                 raise SystemExit
 
+        # check if we are still managing all exceptions
+        self._dbgClient.checkExceptionHook()
+
         if event == "line":
             if self.stop_here(frame) or self.break_here(frame):
                 if (
@@ -331,6 +343,7 @@ class DebugBase:
         if event == "call":
             if (
                 self.stop_here(frame)
+                or not self._dbgClient.callTraceOptimization
                 or self.__checkBreakInFrame(frame)
                 or Watch.watches != []
             ) or (
@@ -678,18 +691,25 @@ class DebugBase:
                     frame.f_globals.get("__file__"), frame.f_code.co_firstlineno
                 ] = False
                 return False
-            lineNo = frame.f_code.co_firstlineno
-            lineNumbers = [lineNo]
 
-            co_lnotab = frame.f_code.co_lnotab[1::2]
+            try:
+                lineNumbers = [
+                    line for _, _, line in frame.f_code.co_lines() if line is not None
+                ]
+            except AttributeError:
+                # backward compatibility code for Python 3.10 and below
+                lineNo = frame.f_code.co_firstlineno
+                lineNumbers = [lineNo]
 
-            # No need to handle special case if a lot of lines between
-            # (e.g. closure), because the additional lines won't cause a bp
-            for co_lno in co_lnotab:
-                if co_lno >= 0x80:
-                    lineNo -= 0x100
-                lineNo += co_lno
-                lineNumbers.append(lineNo)
+                co_lnotab = frame.f_code.co_lnotab[1::2]
+
+                # No need to handle special case if a lot of lines between
+                # (e.g. closure), because the additional lines won't cause a bp
+                for co_lno in co_lnotab:
+                    if co_lno >= 0x80:
+                        lineNo -= 0x100
+                    lineNo += co_lno
+                    lineNumbers.append(lineNo)
 
             for bp in Breakpoint.breakInFile[filename]:
                 if bp in lineNumbers:
@@ -763,13 +783,14 @@ class DebugBase:
         @type frame object or list
         @param applyTrace flag to assign trace function to fr.f_trace
         @type bool
-        @return list of lists with file name (string), line number (integer)
-            and function name (string)
+        @return list of lists with file name, line number, function name
+            and function arguments
+        @rtype list of list of [str, int, str, str]
         """
         tb_lineno = None
         if frame is None:
             fr = self.getFrame()
-        elif type(frame) == list:
+        elif isinstance(frame, list):
             fr, tb_lineno = frame.pop(0)
         else:
             fr = frame
@@ -818,7 +839,7 @@ class DebugBase:
             stack.append([fname, fline, ffunc, fargs])
 
             # is it a stack frame or exception list?
-            if type(frame) == list:
+            if isinstance(frame, list):
                 if frame != []:
                     fr, tb_lineno = frame.pop(0)
                 else:
@@ -833,7 +854,8 @@ class DebugBase:
         Public method reimplemented to handle the program about to execute a
         particular line.
 
-        @param frame the frame object
+        @param frame reference to the frame object
+        @type frame object
         """
         # We never stop on line 0.
         if frame.f_lineno == 0:
@@ -869,14 +891,18 @@ class DebugBase:
         exctype, excval, exctb = excinfo
 
         if (
-            exctype in [GeneratorExit, StopIteration] and unhandled is False
+            not unhandled
+            and (
+                exctype in [GeneratorExit, StopIteration]
+                or not self._dbgClient.reportAllExceptions
+            )
         ) or exctype == SystemExit:
             # ignore these
             return
 
         if exctype in [SyntaxError, IndentationError]:
             try:
-                if type(excval) == tuple:
+                if type(excval) is tuple:
                     message, details = excval
                     filename, lineno, charno, text = details
                 else:
@@ -990,7 +1016,9 @@ class DebugBase:
         type object.
 
         @param exctype type of the exception
-        @return exception name (string)
+        @type type
+        @return exception name
+        @rtype str
         """
         return str(exctype).replace("<class '", "").replace("'>", "")
 
@@ -999,7 +1027,9 @@ class DebugBase:
         Private member to return a list of stack frames.
 
         @param exctb exception traceback
+        @type traceback
         @return list of stack frames
+        @rtype list of frame
         """
         tb = exctb
         stack = []
