@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,6 +12,7 @@ import codecs
 import codeop
 import contextlib
 import fnmatch
+import importlib.util
 import json
 import os
 import re
@@ -33,7 +34,7 @@ import DebugVariables
 
 from AsyncFile import AsyncFile, AsyncPendingWrite
 from BreakpointWatch import Breakpoint, Watch
-from DebugBase import printerr, setRecursionLimit  # __IGNORE_WARNING__
+from DebugBase import printerr, setRecursionLimit
 from DebugConfig import NonExpandableTypes, SpecialAttributes
 from DebugUtilities import formatargvalues, getargvalues, prepareJsonCommand
 from FlexCompleter import Completer
@@ -80,7 +81,8 @@ def DebugClientClose(fd):
     """
     Replacement for the standard os.close(fd).
 
-    @param fd open file descriptor to be closed (integer)
+    @param fd open file descriptor to be closed
+    @type int
     """
     if DebugClientInstance is None:
         DebugClientOrigClose(fd)
@@ -100,7 +102,8 @@ def DebugClientSetRecursionLimit(limit):
     """
     Replacement for the standard sys.setrecursionlimit(limit).
 
-    @param limit recursion limit (integer)
+    @param limit recursion limit
+    @type int
     """
     rl = max(limit, 64)
     setRecursionLimit(rl)
@@ -179,6 +182,7 @@ class DebugClientBase:
         self.test = None
         self.debugging = False
         self.multiprocessSupport = False
+        self.reportAllExceptions = False
         self.noDebugList = []
 
         self.readstream = None
@@ -199,11 +203,16 @@ class DebugClientBase:
 
         self.startOptions = None
 
+        self.callTraceOptimization = False
+
+        self.__debugeeExceptHook = None
+
     def getCoding(self):
         """
         Public method to return the current coding.
 
-        @return codec name (string)
+        @return codec name
+        @rtype str
         """
         return self.__coding
 
@@ -211,7 +220,8 @@ class DebugClientBase:
         """
         Private method to set the coding used by a python file.
 
-        @param filename name of the file to inspect (string)
+        @param filename name of the file to inspect
+        @type str
         """
         if self.noencoding:
             self.__coding = sys.getdefaultencoding()
@@ -259,13 +269,15 @@ class DebugClientBase:
         Public method to close the session with the debugger and optionally
         terminate.
 
-        @param terminate flag indicating to terminate (boolean)
+        @param terminate flag indicating to terminate
+        @type bool
         """
         with contextlib.suppress(Exception):  # secok
             self.set_quit()
 
         self.debugging = False
         self.multiprocessSupport = False
+        self.reportAllExceptions = False
         self.noDebugList = []
 
         # make sure we close down our end of the socket
@@ -288,6 +300,7 @@ class DebugClientBase:
         @param mode kind of code to be generated (exec or eval)
         @type str
         @return compiled code object (None in case of errors)
+        @rtype Code
         """
         with codecs.open(filename, encoding=self.__coding) as fp:
             statement = fp.read()
@@ -305,6 +318,7 @@ class DebugClientBase:
         @param mode kind of code to be generated (exec or eval)
         @type str
         @return compiled code object (None in case of errors)
+        @rtype Code
         """
         try:
             code = compile(statement + "\n", filename, mode)
@@ -336,7 +350,7 @@ class DebugClientBase:
         @param jsonStr string containing the command received from the IDE
         @type str
         """
-        ##        printerr(jsonStr)          ## debug       # __IGNORE_WARNING_M891__
+        ##        printerr(jsonStr)          ## debug       # noqa: M891
 
         try:
             commandDict = json.loads(jsonStr.strip())
@@ -468,6 +482,7 @@ class DebugClientBase:
             self.running = sys.argv[0]
             self.debugging = True
             self.multiprocessSupport = params["multiprocess"]
+            self.reportAllExceptions = params["reportAllExceptions"]
 
             self.threads.clear()
             self.attachThread(mainThread=True)
@@ -875,9 +890,9 @@ class DebugClientBase:
         if "debuggerId" not in params:
             params["debuggerId"] = self.__debuggerId
 
-        cmd = prepareJsonCommand(method, params)
+        jsonCommand = prepareJsonCommand(method, params)
 
-        self.writestream.write_p(cmd)
+        self.writestream.write_p(jsonCommand)
         self.writestream.flush()
 
     def sendClearTemporaryBreakpoint(self, filename, lineno):
@@ -886,7 +901,7 @@ class DebugClientBase:
 
         @param filename name of the file the bp belongs to
         @type str
-        @param lineno linenumber of the bp
+        @param lineno line number of the bp
         @type int
         """
         self.sendJsonCommand(
@@ -995,30 +1010,26 @@ class DebugClientBase:
             },
         )
 
-    def sendPassiveStartup(self, filename, exceptions):
+    def sendPassiveStartup(self, filename, reportAllExceptions):
         """
         Public method to send the passive start information.
 
         @param filename name of the script
         @type str
-        @param exceptions flag to enable exception reporting of the IDE
+        @param reportAllExceptions flag to enable reporting of all exceptions
         @type bool
         """
         self.sendJsonCommand(
             "PassiveStartup",
             {
                 "filename": filename,
-                "exceptions": exceptions,
+                "reportAllExceptions": reportAllExceptions,
             },
         )
 
-    def sendDebuggerId(self, debuggerId):
+    def sendDebuggerId(self):
         """
         Public method to send the debug client id.
-
-        @param debuggerId id of this debug client instance (made up of
-            hostname and process ID)
-        @type str
         """
         # debugger ID is added automatically by sendJsonCommand
         self.sendJsonCommand("DebuggerId", {})
@@ -1027,22 +1038,20 @@ class DebugClientBase:
         """
         Private method to determine the clients capabilities.
 
-        @return client capabilities (integer)
+        @return client capabilities
+        @rtype int
         """
-        try:
-            import PyProfile  # __IGNORE_WARNING__
-
-            with contextlib.suppress(KeyError):
-                del sys.modules["PyProfile"]
-            return self.clientCapabilities
-        except ImportError:
+        if importlib.util.find_spec("PyProfile") is None:
             return self.clientCapabilities & ~DebugClientCapabilities.HasProfiler
+        else:
+            return self.clientCapabilities
 
     def readReady(self, stream):
         """
         Public method called when there is data ready to be read.
 
         @param stream file like object that has data to be read
+        @type file like
         @return flag indicating an error condition
         @rtype bool
         """
@@ -1068,6 +1077,7 @@ class DebugClientBase:
         Public method called when we are ready to write data.
 
         @param stream file like object that has data to be written
+        @type file like
         """
         stream.write_p("")
         stream.flush()
@@ -1090,7 +1100,8 @@ class DebugClientBase:
         Public method implementing our event loop.
 
         @param disablePolling flag indicating to enter an event loop with
-            polling disabled (boolean)
+            polling disabled
+        @type bool
         """
         self.eventExit = False
         self.pollingDisabled = disablePolling
@@ -1216,18 +1227,37 @@ class DebugClientBase:
             socket.gethostname(), os.getpid(), name
         )
 
-        self.sendDebuggerId(self.__debuggerId)
+        self.sendDebuggerId()
 
     def __unhandled_exception(self, exctype, excval, exctb):
         """
         Private method called to report an uncaught exception.
 
-        @param exctype the type of the exception
-        @param excval data about the exception
+        @param exctype class of the exception
+        @type type
+        @param excval exception instance
+        @type Exception
         @param exctb traceback for the exception
+        @type traceback
         """
         self.mainThread.user_exception((exctype, excval, exctb), True)
 
+        if self.__debugeeExceptHook is not None:
+            # call the exception hook of the program being debugged
+            self.__debugeeExceptHook(exctype, excval, exctb)
+
+    def checkExceptionHook(self):
+        """
+        Public method to check, that 'sys.excepthook' is still our hook.
+
+        If the exception hook has been changed by the program being debugger, save
+        that hook and set it to ours again. The program's hook is called in our
+        '__unhandled_exception()' method.
+        """
+        if sys.excepthook != self.__unhandled_exception:
+            self.__debugeeExceptHook = sys.excepthook
+            sys.excepthook = self.__unhandled_exception
+
     def __interceptSignals(self):
         """
         Private method to intercept common signals.
@@ -1297,8 +1327,10 @@ class DebugClientBase:
         sys.path is used as a set of possible prefixes. The name stays
         relative if a file could not be found.
 
-        @param fn filename (string)
-        @return the converted filename (string)
+        @param fn filename
+        @type str
+        @return the converted filename
+        @rtype str
         """
         if os.path.isabs(fn):
             return fn
@@ -1335,7 +1367,8 @@ class DebugClientBase:
         """
         Public method to return the main script we are currently running.
 
-        @return flag indicating a running debug session (boolean)
+        @return flag indicating a running debug session
+        @rtype bool
         """
         return self.running
 
@@ -1677,8 +1710,10 @@ class DebugClientBase:
         Private slot to convert a filter string to a list of filter objects.
 
         @param scope 1 to generate filter for global variables, 0 for local
-            variables (int)
+            variables
+        @type int
         @param filterString string of filter patterns separated by ';'
+        @type str
         """
         patternFilterObjects = None
         filterString = filterString.strip()
@@ -1705,7 +1740,8 @@ class DebugClientBase:
         """
         Private slot to handle the request for a commandline completion list.
 
-        @param text the text to be completed (string)
+        @param text the text to be completed
+        @type str
         """
         completerDelims = " \t\n`~!@#$%^&*()-=+[{]}\\|;:'\",<>/?"
 
@@ -1744,9 +1780,12 @@ class DebugClientBase:
         """
         Private method to create a completions list.
 
-        @param text text to complete (string)
+        @param text text to complete
+        @type str
         @param completer completer method
-        @param completions set where to add new completions strings (set)
+        @type function
+        @param completions set where to add new completions strings
+        @type set
         """
         state = 0
         try:
@@ -1767,11 +1806,11 @@ class DebugClientBase:
         host=None,
         port=None,
         enableTrace=True,
-        exceptions=True,
+        reportAllExceptions=False,
         tracePython=False,
         redirect=True,
         passive=True,
-        multiprocessSupport=False,
+        multiprocessSupport=False,  # noqa: U100
     ):
         """
         Public method used to start the remote debugger.
@@ -1784,7 +1823,8 @@ class DebugClientBase:
         @type int
         @param enableTrace flag to enable the tracing function
         @type bool
-        @param exceptions flag to enable exception reporting of the IDE
+        @param reportAllExceptions flag indicating to report all exceptions
+            instead of unhandled exceptions only
         @type bool
         @param tracePython flag to enable tracing into the Python library
         @type bool
@@ -1822,6 +1862,9 @@ class DebugClientBase:
         self.dircache = []
         self.debugging = True
 
+        # all exceptions reporting
+        self.reportAllExceptions = reportAllExceptions
+
         self.attachThread(mainThread=True)
         self.mainThread.tracePythonLibs(tracePython)
 
@@ -1840,11 +1883,12 @@ class DebugClientBase:
         wd="",
         host=None,
         port=None,
-        exceptions=True,
         tracePython=False,
         redirect=True,
         passive=True,
         multiprocessSupport=False,
+        reportAllExceptions=False,
+        callTraceOptimization=False,
         codeStr="",
         scriptModule="",
     ):
@@ -1852,21 +1896,29 @@ class DebugClientBase:
         Public method used to start the remote debugger.
 
         @param progargs commandline for the program to be debugged
-            (list of strings)
-        @param wd working directory for the program execution (string)
-        @param host hostname of the debug server (string)
-        @param port portnumber of the debug server (int)
-        @param exceptions flag to enable exception reporting of the IDE
-            (boolean)
+        @type list of str
+        @param wd working directory for the program execution
+        @type str
+        @param host hostname of the debug server
+        @type str
+        @param port portnumber of the debug server
+        @type int
         @param tracePython flag to enable tracing into the Python library
-            (boolean)
+        @type bool
         @param redirect flag indicating redirection of stdin, stdout and
-            stderr (boolean)
+            stderr
+        @type bool
         @param passive flag indicating a passive debugging session
         @type bool
         @param multiprocessSupport flag indicating to enable multiprocess
             debugging support
         @type bool
+        @param reportAllExceptions flag indicating to report all exceptions instead
+            of unhandled exceptions only
+        @type bool
+        @param callTraceOptimization flag indicating to speed up function/method
+            call tracing
+        @type bool
         @param codeStr string containing Python code to execute
         @type str
         @param scriptModule name of a module to be executed as a script
@@ -1908,10 +1960,12 @@ class DebugClientBase:
             self.__setCoding(self.running)
         self.debugging = True
         self.multiprocessSupport = multiprocessSupport
+        self.reportAllExceptions = reportAllExceptions
+        self.callTraceOptimization = callTraceOptimization
 
         self.passive = passive
         if passive:
-            self.sendPassiveStartup(self.running, exceptions)
+            self.sendPassiveStartup(self.running, reportAllExceptions)
 
         self.attachThread(mainThread=True)
         self.mainThread.tracePythonLibs(tracePython)
@@ -1953,10 +2007,14 @@ class DebugClientBase:
         """
         Public method used to start the remote debugger and call a function.
 
-        @param scriptname name of the script to be debugged (string)
+        @param scriptname name of the script to be debugged
+        @type str
         @param func function to be called
+        @type function
         @param *args arguments being passed to func
+        @type list
         @return result of the function call
+        @rtype Any
         """
         self.startDebugger(scriptname, enableTrace=False)
         res = self.mainThread.runcall(func, *args)
@@ -1967,8 +2025,10 @@ class DebugClientBase:
         """
         Private method to resolve a hostname to an IP address.
 
-        @param host hostname of the debug server (string)
-        @return IP address (string)
+        @param host hostname of the debug server
+        @type str
+        @return IP address
+        @rtype str
         """
         try:
             host, version = host.split("@@")
@@ -1997,10 +2057,11 @@ class DebugClientBase:
             port = None
             wd = ""
             tracePython = False
-            exceptions = True
             redirect = True
             passive = True
             multiprocess = False
+            reportAllExceptions = False
+            callTraceOptimization = False
             codeStr = ""
             scriptModule = ""
             while args[0]:
@@ -2019,9 +2080,6 @@ class DebugClientBase:
                 elif args[0] == "-t":
                     tracePython = True
                     del args[0]
-                elif args[0] == "-e":
-                    exceptions = False
-                    del args[0]
                 elif args[0] == "-n":
                     redirect = False
                     del args[0]
@@ -2034,6 +2092,12 @@ class DebugClientBase:
                 elif args[0] == "--multiprocess":
                     multiprocess = True
                     del args[0]
+                elif args[0] == "--report-exceptions":
+                    reportAllExceptions = True
+                    del args[0]
+                elif args[0] == "--call-trace-optimization":
+                    callTraceOptimization = True
+                    del args[0]
                 elif args[0] in ("-c", "--code"):
                     codeStr = args[1]
                     del args[0]
@@ -2059,7 +2123,7 @@ class DebugClientBase:
                     wd,
                     host,
                     port,
-                    exceptions,
+                    reportAllExceptions,
                     tracePython,
                     redirect,
                     self.noencoding,
@@ -2072,11 +2136,12 @@ class DebugClientBase:
                     wd,
                     host,
                     port,
-                    exceptions=exceptions,
                     tracePython=tracePython,
                     redirect=redirect,
                     passive=passive,
                     multiprocessSupport=multiprocess,
+                    reportAllExceptions=reportAllExceptions,
+                    callTraceOptimization=callTraceOptimization,
                     codeStr=codeStr,
                     scriptModule=scriptModule,
                 )
@@ -2090,12 +2155,16 @@ class DebugClientBase:
                 self.multiprocessSupport = True
                 del sys.argv[1]
 
+            if sys.argv[1] == "--call-trace-optimization":
+                self.callTraceOptimization = True
+                del sys.argv[1]
+
             if sys.argv[1] == "":
                 del sys.argv[1]
 
             try:
                 port = int(sys.argv[1])
-            except (ValueError, IndexError):
+            except (IndexError, ValueError):
                 port = -1
 
             if sys.argv[2] == "True":
@@ -2105,7 +2174,7 @@ class DebugClientBase:
             else:
                 try:
                     redirect = int(sys.argv[2])
-                except (ValueError, IndexError):
+                except (IndexError, ValueError):
                     redirect = True
 
             ipOrHost = sys.argv[3]
@@ -2125,7 +2194,7 @@ class DebugClientBase:
                     "",
                     remoteAddress,
                     port,
-                    True,
+                    False,
                     False,
                     redirect,
                     self.noencoding,
@@ -2146,7 +2215,8 @@ class DebugClientBase:
 
         It prevents the debugger connections from being closed.
 
-        @param fd file descriptor to be closed (integer)
+        @param fd file descriptor to be closed
+        @type int
         """
         if fd in [
             self.readstream.fileno(),
@@ -2162,8 +2232,10 @@ class DebugClientBase:
         Private slot to calculate a path list including the PYTHONPATH
         environment variable.
 
-        @param firstEntry entry to be put first in sys.path (string)
-        @return path list for use as sys.path (list of strings)
+        @param firstEntry entry to be put first in sys.path
+        @type str
+        @return path list for use as sys.path
+        @rtype list of str
         """
         sysPath = [
             path
