@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -33,7 +33,8 @@ class BreakPointViewer(QTreeView):
         """
         Constructor
 
-        @param parent the parent (QWidget)
+        @param parent the parent
+        @type QWidget
         """
         super().__init__(parent)
         self.setObjectName("BreakPointViewer")
