@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -426,7 +426,7 @@ class DebugServer(QTcpServer):
         @return list of supported languages
         @rtype list of str
         """
-        languages = list(self.__debuggerInterfaceRegistry.keys())
+        languages = list(self.__debuggerInterfaceRegistry)
         with contextlib.suppress(ValueError):
             languages.remove("None")
 
@@ -918,9 +918,9 @@ class DebugServer(QTcpServer):
             # the peer is not allowed to connect
             res = EricMessageBox.yesNo(
                 None,
-                self.tr("Connection from illegal host"),
+                self.tr("Connection from unknown host"),
                 self.tr(
-                    """<p>A connection was attempted by the illegal host"""
+                    """<p>A connection was attempted by the unknown host"""
                     """ <b>{0}</b>. Accept this connection?</p>"""
                 ).format(peerAddress),
                 icon=EricMessageBox.Warning,
@@ -938,9 +938,9 @@ class DebugServer(QTcpServer):
 
         self.debuggerInterface.newConnection(sock)
 
-    def masterClientConnected(self):
+    def mainClientConnected(self):
         """
-        Public method to perform actions after the master client has finally
+        Public method to perform actions after the main client has finally
         established the connection.
         """
         # Perform actions necessary, if client type has changed
@@ -963,21 +963,32 @@ class DebugServer(QTcpServer):
         if self.debuggerInterface is not None:
             self.debuggerInterface.shutdown()
 
+        if self.clientProcess is not None:
+            self.clientProcess.terminate()
+            if not self.clientProcess.waitForFinished(10000):
+                self.clientProcess.kill()
+
     def remoteEnvironment(self, env):
         """
         Public method to set the environment for a program to debug, run, ...
 
         @param env environment settings
-        @type str
+        @type str or dict
+        @exception TypeError taised to indicate an unsupported parameter type
         """
-        envlist = shlex.split(env)
-        envdict = {}
-        for el in envlist:
-            if "=" in el:
-                key, value = el.split("=", 1)
-                envdict[key] = value
-            else:
-                envdict[el] = ""
+        if not isinstance(env, (dict, str)):
+            raise TypeError("'env' must be of type str or list of str")
+        elif isinstance(env, str):
+            envlist = shlex.split(env)
+            envdict = {}
+            for el in envlist:
+                if "=" in el:
+                    key, value = el.split("=", 1)
+                    envdict[key] = value
+                else:
+                    envdict[el] = ""
+        else:
+            envdict = env
         self.debuggerInterface.remoteEnvironment(envdict)
 
     def remoteLoad(
@@ -997,20 +1008,21 @@ class DebugServer(QTcpServer):
         enableMultiprocess=False,
         multiprocessNoDebug="",
         configOverride=None,
+        reportAllExceptions=False,
     ):
         """
         Public method to load a new program to debug.
 
         @param venvName name of the virtual environment to be used
         @type str
-        @param fn the filename to debug
+        @param fn filename to debug
         @type str
-        @param argv the command line arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param env environment parameter settings
-        @type str
+        @type str or dict
         @param autoClearShell flag indicating, that the interpreter window
             should be cleared
         @type bool
@@ -1039,6 +1051,9 @@ class DebugServer(QTcpServer):
         @param configOverride dictionary containing the global config override
             data
         @type dict
+        @param reportAllExceptions flag indicating to report all exceptions
+            instead of unhandled exceptions only
+        @type bool
         """
         self.__autoClearShell = autoClearShell
         self.__multiprocessNoDebugList = [
@@ -1085,6 +1100,7 @@ class DebugServer(QTcpServer):
             tracePython,
             autoContinue,
             enableMultiprocess=enableMultiprocess,
+            reportAllExceptions=reportAllExceptions,
         )
         self.debugging = True
         self.running = True
@@ -1110,14 +1126,14 @@ class DebugServer(QTcpServer):
 
         @param venvName name of the virtual environment to be used
         @type str
-        @param fn the filename to debug
+        @param fn filename to debug
         @type str
-        @param argv the command line arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list str
+        @param wd  working directory for the program
         @type str
         @param env environment parameter settings
-        @type str
+        @type str or dict
         @param autoClearShell flag indicating, that the interpreter window
             should be cleared
         @type bool
@@ -1189,14 +1205,14 @@ class DebugServer(QTcpServer):
 
         @param venvName name of the virtual environment to be used
         @type str
-        @param fn the filename to debug
+        @param fn filename to debug
         @type str
-        @param argv the command line arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param env environment parameter settings
-        @type str
+        @type str or dict
         @param autoClearShell flag indicating, that the interpreter window
             should be cleared
         @type bool
@@ -1271,14 +1287,14 @@ class DebugServer(QTcpServer):
 
         @param venvName name of the virtual environment to be used
         @type str
-        @param fn the filename to debug
+        @param fn filename to debug
         @type str
-        @param argv the command line arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param env environment parameter settings
-        @type str
+        @type str or dict
         @param autoClearShell flag indicating, that the interpreter window
             should be cleared
         @type bool
@@ -1340,7 +1356,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param stmt the Python statement to execute.
+        @param stmt Python statement to execute.
         @type str
         """
         self.debuggerInterface.remoteStatement(debuggerId, stmt.rstrip())
@@ -1388,6 +1404,7 @@ class DebugServer(QTcpServer):
         @param debuggerId ID of the debugger backend
         @type str
         @param special flag indicating a special continue operation
+        @type bool
         """
         self.debuggerInterface.remoteContinue(debuggerId, special)
 
@@ -1398,7 +1415,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param line the new line, where execution should be continued to
+        @param line new line, where execution should be continued to
         @type int
         """
         self.debuggerInterface.remoteContinueUntil(debuggerId, line)
@@ -1409,7 +1426,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param line the new line, where execution should be continued
+        @param line new line, where execution should be continued
         @type int
         """
         self.debuggerInterface.remoteMoveIP(debuggerId, line)
@@ -1424,7 +1441,7 @@ class DebugServer(QTcpServer):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param setBreakpoint flag indicating setting or resetting a breakpoint
         @type bool
@@ -1445,7 +1462,7 @@ class DebugServer(QTcpServer):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param enable flag indicating enabling or disabling a breakpoint
         @type bool
@@ -1460,7 +1477,7 @@ class DebugServer(QTcpServer):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param count number of occurrences to ignore
         @type int
@@ -1518,7 +1535,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param inputString the raw input
+        @param inputString raw input
         @type str
         """
         self.debuggerInterface.remoteRawInput(debuggerId, inputString)
@@ -1559,7 +1576,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterList list of variable types to filter out
         @type list of str
@@ -1571,14 +1588,14 @@ class DebugServer(QTcpServer):
         )
 
     def remoteClientVariable(
-        self, debuggerId, scope, filterList, var, framenr=0, maxSize=0
+        self, debuggerId, scope, filterList, var, framenr=0, maxSize=0  # noqa: U100
     ):
         """
         Public method to request the variables of the debugged program.
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterList list of variable types to filter out
         @type list of str
@@ -1611,7 +1628,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterStr regexp string for variable names to filter out
         @type str
@@ -1648,7 +1665,7 @@ class DebugServer(QTcpServer):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param text the text to be completed
+        @param text text to be completed
         @type str
         """
         self.debuggerInterface.remoteCompletion(debuggerId, text)
@@ -1987,7 +2004,9 @@ class DebugServer(QTcpServer):
             self.__debuggerInterfaceRegistry[clientType][0] = capabilities
             self.clientCapabilities.emit(capabilities, clientType, venvName)
 
-    def signalClientCompletionList(self, completionList, text, debuggerId):
+    def signalClientCompletionList(
+        self, completionList, text, debuggerId  # noqa: U100
+    ):
         """
         Public method to process the client auto completion info.
 
@@ -2042,13 +2061,13 @@ class DebugServer(QTcpServer):
             debuggerId,
         )
 
-    def passiveStartUp(self, fn, exc, debuggerId):
+    def passiveStartUp(self, fn, reportAllExceptions, debuggerId):
         """
         Public method to handle a passive debug connection.
 
         @param fn filename of the debugged script
         @type str
-        @param exc flag to enable exception reporting of the IDE
+        @param reportAllExceptions flag to enable reporting of all exceptions
         @type bool
         @param debuggerId ID of the debugger backend
         @type str
@@ -2059,7 +2078,7 @@ class DebugServer(QTcpServer):
         self.running = True
         self.__restoreBreakpoints(debuggerId)
         self.__restoreWatchpoints(debuggerId)
-        self.passiveDebugStarted.emit(fn, exc)
+        self.passiveDebugStarted.emit(fn, reportAllExceptions)
 
     def __passiveShutDown(self):
         """
@@ -2196,7 +2215,8 @@ class DebugServer(QTcpServer):
         @rtype str
         """
         try:
-            if ericApp().getObject("Project").isOpen():
+            project = ericApp().getObject("Project")
+            if project.isOpen() and project.getProjectVenv(resolveDebugger=False):
                 return self.tr("<project>")
             else:
                 return ""
