@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -534,7 +534,7 @@ class DebugViewer(QWidget):
                 self.lvvStackComboBox.addItem("{0}:{1}:{2}".format(*s))
             self.lvvStackComboBox.blockSignals(block)
 
-    def __clientLine(self, fn, line, debuggerId, threadName):
+    def __clientLine(self, fn, line, debuggerId, threadName):  # noqa: U100
         """
         Private method to handle a change to the current line.
 
@@ -583,7 +583,13 @@ class DebugViewer(QWidget):
             self.__removeDebugger(debuggerId)
 
     def __clientSyntaxError(
-        self, message, filename, lineNo, characterNo, debuggerId, threadName
+        self,
+        message,  # noqa: U100
+        filename,  # noqa: U100
+        lineNo,  # noqa: U100
+        characterNo,  # noqa: U100
+        debuggerId,
+        threadName,
     ):
         """
         Private method to handle a syntax error in the debugged program.
@@ -605,7 +611,12 @@ class DebugViewer(QWidget):
         self.__setThreadIconAndState(debuggerId, threadName, "syntax")
 
     def __clientException(
-        self, exceptionType, exceptionMessage, stackTrace, debuggerId, threadName
+        self,
+        exceptionType,  # noqa: U100
+        exceptionMessage,  # noqa: U100
+        stackTrace,  # noqa: U100
+        debuggerId,
+        threadName,
     ):
         """
         Private method to handle an exception of the debugged program.
@@ -753,7 +764,7 @@ class DebugViewer(QWidget):
         if frameNo >= 0:
             self.lvvStackComboBox.setCurrentIndex(frameNo)
 
-    def __debuggerSelected(self, current, previous):
+    def __debuggerSelected(self, current, previous):  # noqa: U100
         """
         Private slot to handle the selection of a debugger backend in the
         debuggers list.
@@ -950,7 +961,7 @@ class DebugViewer(QWidget):
             debuggerItem = debuggerItems[0]
 
             currentItem = self.__debuggersList.currentItem()
-            if currentItem.parent() is debuggerItem:
+            if currentItem is not None and currentItem.parent() is debuggerItem:
                 currentChild = currentItem.text(0)
             else:
                 currentChild = ""
