@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -34,7 +34,7 @@ class DebuggerInterfaceNone(QObject):
         self.passive = passive
 
         self.qsock = None
-        self.queue = []
+        self.__commandQueue = []
         # set default values for capabilities of clients
         self.clientCapabilities = ClientDefaultCapabilities
 
@@ -139,7 +139,7 @@ class DebuggerInterfaceNone(QObject):
         (Needed on Win OS)
         """
         self.qsock = None
-        self.queue = []
+        self.__commandQueue.clear()
 
     def isConnected(self):
         """
@@ -167,15 +167,16 @@ class DebuggerInterfaceNone(QObject):
         traceInterpreter=False,
         autoContinue=True,
         enableMultiprocess=False,
+        reportAllExceptions=False,
     ):
         """
         Public method to load a new program to debug.
 
-        @param fn the filename to debug
+        @param fn filename to debug
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param traceInterpreter flag indicating if the interpreter library
             should be traced as well
@@ -186,6 +187,9 @@ class DebuggerInterfaceNone(QObject):
         @param enableMultiprocess flag indicating to perform multiprocess
             debugging
         @type bool
+        @param reportAllExceptions flag indicating to report all exceptions
+            instead of unhandled exceptions only
+        @type bool
         """
         return
 
@@ -193,11 +197,11 @@ class DebuggerInterfaceNone(QObject):
         """
         Public method to load a new program to run.
 
-        @param fn the filename to run
+        @param fn filename to run
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         """
         return
@@ -206,11 +210,11 @@ class DebuggerInterfaceNone(QObject):
         """
         Public method to load a new program to collect coverage data.
 
-        @param fn the filename to run
+        @param fn filename to run
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param erase flag indicating that coverage info should be
             cleared first
@@ -222,11 +226,11 @@ class DebuggerInterfaceNone(QObject):
         """
         Public method to load a new program to collect profiling data.
 
-        @param fn the filename to run
+        @param fn filename to run
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param erase flag indicating that timing info should be cleared
             first
@@ -240,7 +244,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param stmt the Python statement to execute.
+        @param stmt Python statement to execute.
         @type str
         """
         self.debugServer.signalClientStatement(False, "")
@@ -300,7 +304,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param line the new line, where execution should be continued to
+        @param line new line, where execution should be continued to
         @type int
         """
         return
@@ -311,7 +315,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param line the new line, where execution should be continued
+        @param line new line, where execution should be continued
         @type int
         """
         return
@@ -326,7 +330,7 @@ class DebuggerInterfaceNone(QObject):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param setBreakpoint flag indicating setting or resetting a breakpoint
         @type bool
@@ -345,7 +349,7 @@ class DebuggerInterfaceNone(QObject):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param enable flag indicating enabling or disabling a breakpoint
         @type bool
@@ -360,7 +364,7 @@ class DebuggerInterfaceNone(QObject):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param count number of occurrences to ignore
         @type int
@@ -415,7 +419,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param inputString the raw input
+        @param inputString raw input
         @type str
         """
         return
@@ -457,7 +461,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterList list of variable types to filter out
         @type list of str
@@ -478,7 +482,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterList list of variable types to filter out
         @type list of str
@@ -508,7 +512,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterStr regexp string for variable names to filter out
         @type str
@@ -562,7 +566,7 @@ class DebuggerInterfaceNone(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param text the text to be completed
+        @param text text to be completed
         @type str
         """
         return
@@ -600,3 +604,7 @@ def getRegistryData():
             createDebuggerInterfaceNone,
         )
     ]
+
+
+#
+# eflag: noqa = U100
