@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,6 +12,8 @@ import json
 import logging
 import os
 import shlex
+import struct
+import zlib
 
 from PyQt6.QtCore import QObject, QProcess, QProcessEnvironment, QTimer
 
@@ -53,8 +55,8 @@ class DebuggerInterfacePython(QObject):
         self.process = None
         self.__startedVenv = ""
 
-        self.queue = []
-        self.__master = None
+        self.__commandQueue = []
+        self.__mainDebugger = None
         self.__connections = {}
         self.__pendingConnections = []
         self.__inShutdown = False
@@ -79,7 +81,7 @@ class DebuggerInterfacePython(QObject):
         # attribute to remember the name of the executed script
         self.__scriptName = ""
 
-    def __identityTranslation(self, fn, remote2local=True):
+    def __identityTranslation(self, fn, remote2local=True):  # noqa: U100
         """
         Private method to perform the identity path translation.
 
@@ -134,7 +136,7 @@ class DebuggerInterfacePython(QObject):
         proc = QProcess(self)
         if environment is not None:
             env = QProcessEnvironment()
-            for key, value in list(environment.items()):
+            for key, value in environment.items():
                 env.insert(key, value)
             proc.setProcessEnvironment(env)
         args = arguments[:]
@@ -202,36 +204,46 @@ class DebuggerInterfacePython(QObject):
 
         self.__inShutdown = False
 
-        debugClient = self.__determineDebugClient()
-
         redirect = (
             str(configOverride["redirect"])
             if configOverride and configOverride["enable"]
             else str(Preferences.getDebugger("Python3Redirect"))
         )
         noencoding = (
-            Preferences.getDebugger("Python3NoEncoding") and "--no-encoding" or ""
+            "--no-encoding" if Preferences.getDebugger("Python3NoEncoding") else ""
         )
         multiprocessEnabled = (
             "--multiprocess" if Preferences.getDebugger("MultiProcessEnabled") else ""
         )
+        callTraceOptimization = (
+            "--call-trace-optimization"
+            if Preferences.getDebugger("PythonCallTraceOptimization")
+            else ""
+        )
 
         if Preferences.getDebugger("RemoteDbgEnabled"):
+            # remote debugging code
             ipaddr = self.debugServer.getHostAddress(False)
             rexec = Preferences.getDebugger("RemoteExecution")
             rhost = Preferences.getDebugger("RemoteHost")
             if rhost == "":
                 rhost = "localhost"
             if rexec:
+                rdebugClient = Preferences.getDebugger("RemoteDebugClient")
+                if not rdebugClient and rhost == "localhost":
+                    # it is a remote debugging session on the same host
+                    rdebugClient = self.__determineDebugClient()
                 args = Utilities.parseOptionString(rexec) + [
                     rhost,
                     interpreter,
-                    debugClient,
+                    rdebugClient,
                 ]
                 if noencoding:
                     args.append(noencoding)
                 if multiprocessEnabled:
                     args.append(multiprocessEnabled)
+                if callTraceOptimization:
+                    args.append(callTraceOptimization)
                 args.extend([str(port), redirect, ipaddr])
                 if OSUtilities.isWindowsPlatform():
                     if not os.path.splitext(args[0])[1]:
@@ -267,76 +279,94 @@ class DebuggerInterfacePython(QObject):
                 else:
                     self.translate = self.__identityTranslation
                 return process, self.__isNetworked, ""
-
-        # set translation function
-        self.translate = self.__identityTranslation
-
-        # setup the environment for the debugger
-        if Preferences.getDebugger("DebugEnvironmentReplace"):
-            clientEnv = {}
-        else:
-            clientEnv = os.environ.copy()
-            if originalPathString:
-                clientEnv["PATH"] = originalPathString
-        envlist = shlex.split(Preferences.getDebugger("DebugEnvironment"))
-        for el in envlist:
-            with contextlib.suppress(ValueError):
-                key, value = el.split("=", 1)
-                clientEnv[str(key)] = str(value)
-        if execPath:
-            if "PATH" in clientEnv:
-                clientEnv["PATH"] = os.pathsep.join([execPath, clientEnv["PATH"]])
             else:
-                clientEnv["PATH"] = execPath
-
-        ipaddr = self.debugServer.getHostAddress(True)
-        if runInConsole or Preferences.getDebugger("ConsoleDbgEnabled"):
-            ccmd = Preferences.getDebugger("ConsoleDbgCommand")
-            if ccmd:
-                args = Utilities.parseOptionString(ccmd) + [
-                    interpreter,
-                    os.path.abspath(debugClient),
-                ]
-                if noencoding:
-                    args.append(noencoding)
-                if multiprocessEnabled:
-                    args.append(multiprocessEnabled)
-                args.extend([str(port), "0", ipaddr])
-                args[0] = FileSystemUtilities.getExecutablePath(args[0])
-                process = self.__startProcess(
-                    args[0], args[1:], clientEnv, workingDir=workingDir
+                EricMessageBox.critical(
+                    None,
+                    self.tr("Start Debugger"),
+                    self.tr(
+                        "<p>Remote debugging is configured but no command for remote"
+                        " login was given.</p>"
+                    ),
                 )
-                if process is None:
-                    EricMessageBox.critical(
-                        None,
-                        self.tr("Start Debugger"),
-                        self.tr(
-                            """<p>The debugger backend could not be"""
-                            """ started.</p>"""
-                        ),
-                    )
-                return process, self.__isNetworked, interpreter
+                return None, False, ""
 
-        args = [debugClient]
-        if noencoding:
-            args.append(noencoding)
-        if multiprocessEnabled:
-            args.append(multiprocessEnabled)
-        args.extend([str(port), redirect, ipaddr])
-        process = self.__startProcess(
-            interpreter, args, clientEnv, workingDir=workingDir
-        )
-        if process is None:
-            self.__startedVenv = ""
-            EricMessageBox.critical(
-                None,
-                self.tr("Start Debugger"),
-                self.tr("""<p>The debugger backend could not be started.</p>"""),
-            )
         else:
-            self.__startedVenv = venvName
+            # local debugging code below
+            debugClient = self.__determineDebugClient()
 
-        return process, self.__isNetworked, interpreter
+            # set translation function
+            self.translate = self.__identityTranslation
+
+            # setup the environment for the debugger
+            if Preferences.getDebugger("DebugEnvironmentReplace"):
+                clientEnv = {}
+            else:
+                clientEnv = os.environ.copy()
+                if originalPathString:
+                    clientEnv["PATH"] = originalPathString
+            envlist = shlex.split(Preferences.getDebugger("DebugEnvironment"))
+            for el in envlist:
+                with contextlib.suppress(ValueError):
+                    key, value = el.split("=", 1)
+                    clientEnv[str(key)] = str(value)
+            if execPath:
+                if "PATH" in clientEnv:
+                    clientEnv["PATH"] = os.pathsep.join([execPath, clientEnv["PATH"]])
+                else:
+                    clientEnv["PATH"] = execPath
+
+            ipaddr = self.debugServer.getHostAddress(True)
+            if runInConsole or Preferences.getDebugger("ConsoleDbgEnabled"):
+                ccmd = Preferences.getDebugger("ConsoleDbgCommand")
+                if ccmd:
+                    args = Utilities.parseOptionString(ccmd) + [
+                        interpreter,
+                        os.path.abspath(debugClient),
+                    ]
+                    if noencoding:
+                        args.append(noencoding)
+                    if multiprocessEnabled:
+                        args.append(multiprocessEnabled)
+                    if callTraceOptimization:
+                        args.append(callTraceOptimization)
+                    args.extend([str(port), "0", ipaddr])
+                    args[0] = FileSystemUtilities.getExecutablePath(args[0])
+                    process = self.__startProcess(
+                        args[0], args[1:], clientEnv, workingDir=workingDir
+                    )
+                    if process is None:
+                        EricMessageBox.critical(
+                            None,
+                            self.tr("Start Debugger"),
+                            self.tr(
+                                """<p>The debugger backend could not be"""
+                                """ started.</p>"""
+                            ),
+                        )
+                    return process, self.__isNetworked, interpreter
+
+            args = [debugClient]
+            if noencoding:
+                args.append(noencoding)
+            if multiprocessEnabled:
+                args.append(multiprocessEnabled)
+            if callTraceOptimization:
+                args.append(callTraceOptimization)
+            args.extend([str(port), redirect, ipaddr])
+            process = self.__startProcess(
+                interpreter, args, clientEnv, workingDir=workingDir
+            )
+            if process is None:
+                self.__startedVenv = ""
+                EricMessageBox.critical(
+                    None,
+                    self.tr("Start Debugger"),
+                    self.tr("""<p>The debugger backend could not be started.</p>"""),
+                )
+            else:
+                self.__startedVenv = venvName
+
+            return process, self.__isNetworked, interpreter
 
     def __determineDebugClient(self):
         """
@@ -397,10 +427,6 @@ class DebuggerInterfacePython(QObject):
             return None, self.__isNetworked, ""
 
         # start debugger with project specific settings
-        debugClient = project.getDebugProperty("DEBUGCLIENT")
-        if not bool(debugClient) or not os.path.exists(debugClient):
-            debugClient = self.__determineDebugClient()
-
         redirect = (
             str(configOverride["redirect"])
             if configOverride and configOverride["enable"]
@@ -410,6 +436,11 @@ class DebuggerInterfacePython(QObject):
         multiprocessEnabled = (
             "--multiprocess" if Preferences.getDebugger("MultiProcessEnabled") else ""
         )
+        callTraceOptimization = (
+            "--call-trace-optimization"
+            if Preferences.getDebugger("PythonCallTraceOptimization")
+            else ""
+        )
 
         if venvName and venvName != self.debugServer.getProjectEnvironmentString():
             venvManager = ericApp().getObject("VirtualEnvManager")
@@ -430,21 +461,28 @@ class DebuggerInterfacePython(QObject):
         self.__inShutdown = False
 
         if project.getDebugProperty("REMOTEDEBUGGER"):
+            # remote debugging code
             ipaddr = self.debugServer.getHostAddress(False)
             rexec = project.getDebugProperty("REMOTECOMMAND")
             rhost = project.getDebugProperty("REMOTEHOST")
             if rhost == "":
                 rhost = "localhost"
             if rexec:
+                rdebugClient = project.getDebugProperty("REMOTEDEBUGCLIENT")
+                if not rdebugClient and rhost == "localhost":
+                    # it is a remote debugging session on the same host
+                    rdebugClient = self.__determineDebugClient()
                 args = Utilities.parseOptionString(rexec) + [
                     rhost,
                     interpreter,
-                    debugClient,
+                    rdebugClient,
                 ]
                 if noencoding:
                     args.append(noencoding)
                 if multiprocessEnabled:
                     args.append(multiprocessEnabled)
+                if callTraceOptimization:
+                    args.append(callTraceOptimization)
                 args.extend([str(port), redirect, ipaddr])
                 if OSUtilities.isWindowsPlatform():
                     if not os.path.splitext(args[0])[1]:
@@ -479,77 +517,87 @@ class DebuggerInterfacePython(QObject):
                 # remote shell command is missing
                 return None, self.__isNetworked, ""
 
-        # set translation function
-        self.translate = self.__identityTranslation
-
-        # setup the environment for the debugger
-        if project.getDebugProperty("ENVIRONMENTOVERRIDE"):
-            clientEnv = {}
         else:
-            clientEnv = os.environ.copy()
-            if originalPathString:
-                clientEnv["PATH"] = originalPathString
-        envlist = shlex.split(project.getDebugProperty("ENVIRONMENTSTRING"))
-        for el in envlist:
-            with contextlib.suppress(ValueError):
-                key, value = el.split("=", 1)
-                clientEnv[str(key)] = str(value)
-        if execPath:
-            if "PATH" in clientEnv:
-                clientEnv["PATH"] = os.pathsep.join([execPath, clientEnv["PATH"]])
+            # local debugging code below
+            debugClient = project.getDebugProperty("DEBUGCLIENT")
+            if not bool(debugClient) or not os.path.exists(debugClient):
+                debugClient = self.__determineDebugClient()
+
+            # set translation function
+            self.translate = self.__identityTranslation
+
+            # setup the environment for the debugger
+            if project.getDebugProperty("ENVIRONMENTOVERRIDE"):
+                clientEnv = {}
             else:
-                clientEnv["PATH"] = execPath
+                clientEnv = os.environ.copy()
+                if originalPathString:
+                    clientEnv["PATH"] = originalPathString
+            envlist = shlex.split(project.getDebugProperty("ENVIRONMENTSTRING"))
+            for el in envlist:
+                with contextlib.suppress(ValueError):
+                    key, value = el.split("=", 1)
+                    clientEnv[str(key)] = str(value)
+            if execPath:
+                if "PATH" in clientEnv:
+                    clientEnv["PATH"] = os.pathsep.join([execPath, clientEnv["PATH"]])
+                else:
+                    clientEnv["PATH"] = execPath
 
-        ipaddr = self.debugServer.getHostAddress(True)
-        if runInConsole or project.getDebugProperty("CONSOLEDEBUGGER"):
-            ccmd = project.getDebugProperty(
-                "CONSOLECOMMAND"
-            ) or Preferences.getDebugger("ConsoleDbgCommand")
-            if ccmd:
-                args = Utilities.parseOptionString(ccmd) + [
-                    interpreter,
-                    os.path.abspath(debugClient),
-                ]
-                if noencoding:
-                    args.append(noencoding)
-                if multiprocessEnabled:
-                    args.append(multiprocessEnabled)
-                args.extend([str(port), "0", ipaddr])
-                args[0] = FileSystemUtilities.getExecutablePath(args[0])
-                process = self.__startProcess(
-                    args[0], args[1:], clientEnv, workingDir=workingDir
-                )
-                if process is None:
-                    EricMessageBox.critical(
-                        None,
-                        self.tr("Start Debugger"),
-                        self.tr(
-                            """<p>The debugger backend could not be"""
-                            """ started.</p>"""
-                        ),
+            ipaddr = self.debugServer.getHostAddress(True)
+            if runInConsole or project.getDebugProperty("CONSOLEDEBUGGER"):
+                ccmd = project.getDebugProperty(
+                    "CONSOLECOMMAND"
+                ) or Preferences.getDebugger("ConsoleDbgCommand")
+                if ccmd:
+                    args = Utilities.parseOptionString(ccmd) + [
+                        interpreter,
+                        os.path.abspath(debugClient),
+                    ]
+                    if noencoding:
+                        args.append(noencoding)
+                    if multiprocessEnabled:
+                        args.append(multiprocessEnabled)
+                    if callTraceOptimization:
+                        args.append(callTraceOptimization)
+                    args.extend([str(port), "0", ipaddr])
+                    args[0] = FileSystemUtilities.getExecutablePath(args[0])
+                    process = self.__startProcess(
+                        args[0], args[1:], clientEnv, workingDir=workingDir
                     )
-                return process, self.__isNetworked, interpreter
+                    if process is None:
+                        EricMessageBox.critical(
+                            None,
+                            self.tr("Start Debugger"),
+                            self.tr(
+                                """<p>The debugger backend could not be"""
+                                """ started.</p>"""
+                            ),
+                        )
+                    return process, self.__isNetworked, interpreter
 
-        args = [debugClient]
-        if noencoding:
-            args.append(noencoding)
-        if multiprocessEnabled:
-            args.append(multiprocessEnabled)
-        args.extend([str(port), redirect, ipaddr])
-        process = self.__startProcess(
-            interpreter, args, clientEnv, workingDir=workingDir
-        )
-        if process is None:
-            self.__startedVenv = ""
-            EricMessageBox.critical(
-                None,
-                self.tr("Start Debugger"),
-                self.tr("""<p>The debugger backend could not be started.</p>"""),
+            args = [debugClient]
+            if noencoding:
+                args.append(noencoding)
+            if multiprocessEnabled:
+                args.append(multiprocessEnabled)
+            if callTraceOptimization:
+                args.append(callTraceOptimization)
+            args.extend([str(port), redirect, ipaddr])
+            process = self.__startProcess(
+                interpreter, args, clientEnv, workingDir=workingDir
             )
-        else:
-            self.__startedVenv = venvName
+            if process is None:
+                self.__startedVenv = ""
+                EricMessageBox.critical(
+                    None,
+                    self.tr("Start Debugger"),
+                    self.tr("""<p>The debugger backend could not be started.</p>"""),
+                )
+            else:
+                self.__startedVenv = venvName
 
-        return process, self.__isNetworked, interpreter
+            return process, self.__isNetworked, interpreter
 
     def getClientCapabilities(self):
         """
@@ -590,26 +638,25 @@ class DebuggerInterfacePython(QObject):
             self.__connections[debuggerId] = sock
             self.__pendingConnections.remove(sock)
 
-            if self.__master is None:
-                self.__master = debuggerId
+            if self.__mainDebugger is None:
+                self.__mainDebugger = debuggerId
                 # Get the remote clients capabilities
                 self.remoteCapabilities(debuggerId)
 
             self.debugServer.signalClientDebuggerId(debuggerId)
 
-            if debuggerId == self.__master:
+            if debuggerId == self.__mainDebugger:
                 self.__flush()
-                self.debugServer.masterClientConnected()
+                self.debugServer.mainClientConnected()
 
             self.debugServer.initializeClient(debuggerId)
 
-            # perform auto-continue except for master
+            # perform auto-continue except for main
             if (
-                debuggerId != self.__master
+                debuggerId != self.__mainDebugger
                 and self.__autoContinue
                 and not self.__isStepCommand
             ):
-                self.__autoContinued.append(debuggerId)
                 QTimer.singleShot(0, lambda: self.remoteContinue(debuggerId))
 
     def __socketDisconnected(self, sock):
@@ -619,11 +666,11 @@ class DebuggerInterfacePython(QObject):
         @param sock reference to the disconnected socket
         @type QTcpSocket
         """
-        for debuggerId in self.__connections:
+        for debuggerId in list(self.__connections):
             if self.__connections[debuggerId] is sock:
                 del self.__connections[debuggerId]
-                if debuggerId == self.__master:
-                    self.__master = None
+                if debuggerId == self.__mainDebugger:
+                    self.__mainDebugger = None
                 if debuggerId in self.__autoContinued:
                     self.__autoContinued.remove(debuggerId)
                 if not self.__inShutdown:
@@ -652,18 +699,19 @@ class DebuggerInterfacePython(QObject):
         @return list of connected debugger backend IDs
         @rtype list of str
         """
-        return sorted(self.__connections.keys())
+        return sorted(self.__connections)
 
     def __flush(self):
         """
         Private slot to flush the queue.
         """
-        if self.__master:
+        if self.__mainDebugger:
             # Send commands that were waiting for the connection.
-            for cmd in self.queue:
-                self.__writeJsonCommandToSocket(cmd, self.__connections[self.__master])
+            conn = self.__connections[self.__mainDebugger]
+            for jsonStr in self.__commandQueue:
+                self.__writeJsonCommandToSocket(jsonStr, conn)
 
-        self.queue = []
+        self.__commandQueue.clear()
 
     def shutdown(self):
         """
@@ -672,7 +720,7 @@ class DebuggerInterfacePython(QObject):
         It closes our sockets and shuts down the debug clients.
         (Needed on Win OS)
         """
-        if not self.__master:
+        if not self.__mainDebugger:
             return
 
         self.__inShutdown = True
@@ -686,9 +734,9 @@ class DebuggerInterfacePython(QObject):
             self.__shutdownSocket(sock)
 
         # reinitialize
-        self.queue = []
+        self.__commandQueue.clear()
 
-        self.__master = None
+        self.__mainDebugger = None
 
     def __shutdownSocket(self, sock):
         """
@@ -727,7 +775,7 @@ class DebuggerInterfacePython(QObject):
         @type dict
         """
         self.__sendJsonCommand(
-            "RequestEnvironment", {"environment": env}, self.__master
+            "RequestEnvironment", {"environment": env}, self.__mainDebugger
         )
 
     def remoteLoad(
@@ -738,15 +786,16 @@ class DebuggerInterfacePython(QObject):
         traceInterpreter=False,
         autoContinue=True,
         enableMultiprocess=False,
+        reportAllExceptions=False,
     ):
         """
         Public method to load a new program to debug.
 
-        @param fn the filename to debug
+        @param fn filename to debug
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param traceInterpreter flag indicating if the interpreter library
             should be traced as well
@@ -757,6 +806,9 @@ class DebuggerInterfacePython(QObject):
         @param enableMultiprocess flag indicating to perform multiprocess
             debugging
         @type bool
+        @param reportAllExceptions flag indicating to report all exceptions
+            instead of unhandled exceptions only
+        @type bool
         """
         self.__autoContinue = autoContinue
         self.__scriptName = os.path.abspath(fn)
@@ -769,22 +821,23 @@ class DebuggerInterfacePython(QObject):
             {
                 "workdir": wd,
                 "filename": fn,
-                "argv": Utilities.parseOptionString(argv),
+                "argv": argv,
                 "traceInterpreter": traceInterpreter,
                 "multiprocess": enableMultiprocess,
+                "reportAllExceptions": reportAllExceptions,
             },
-            self.__master,
+            self.__mainDebugger,
         )
 
     def remoteRun(self, fn, argv, wd):
         """
         Public method to load a new program to run.
 
-        @param fn the filename to run
+        @param fn filename to run
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         """
         self.__scriptName = os.path.abspath(fn)
@@ -796,20 +849,20 @@ class DebuggerInterfacePython(QObject):
             {
                 "workdir": wd,
                 "filename": fn,
-                "argv": Utilities.parseOptionString(argv),
+                "argv": argv,
             },
-            self.__master,
+            self.__mainDebugger,
         )
 
     def remoteCoverage(self, fn, argv, wd, erase=False):
         """
         Public method to load a new program to collect coverage data.
 
-        @param fn the filename to run
+        @param fn filename to run
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param erase flag indicating that coverage info should be
             cleared first
@@ -824,21 +877,21 @@ class DebuggerInterfacePython(QObject):
             {
                 "workdir": wd,
                 "filename": fn,
-                "argv": Utilities.parseOptionString(argv),
+                "argv": argv,
                 "erase": erase,
             },
-            self.__master,
+            self.__mainDebugger,
         )
 
     def remoteProfile(self, fn, argv, wd, erase=False):
         """
         Public method to load a new program to collect profiling data.
 
-        @param fn the filename to run
+        @param fn filename to run
         @type str
-        @param argv the commandline arguments to pass to the program
-        @type str
-        @param wd the working directory for the program
+        @param argv list of command line arguments to pass to the program
+        @type list of str
+        @param wd working directory for the program
         @type str
         @param erase flag indicating that timing info should be cleared
             first
@@ -853,10 +906,10 @@ class DebuggerInterfacePython(QObject):
             {
                 "workdir": wd,
                 "filename": fn,
-                "argv": Utilities.parseOptionString(argv),
+                "argv": argv,
                 "erase": erase,
             },
-            self.__master,
+            self.__mainDebugger,
         )
 
     def remoteStatement(self, debuggerId, stmt):
@@ -865,7 +918,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param stmt the Python statement to execute.
+        @param stmt Python statement to execute.
         @type str
         """
         self.__sendJsonCommand(
@@ -941,7 +994,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param line the new line, where execution should be continued to
+        @param line new line, where execution should be continued to
         @type int
         """
         self.__isStepCommand = False
@@ -959,7 +1012,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param line the new line, where execution should be continued
+        @param line new line, where execution should be continued
         @type int
         """
         self.__sendJsonCommand(
@@ -980,7 +1033,7 @@ class DebuggerInterfacePython(QObject):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param setBreakpoint flag indicating setting or resetting a breakpoint
         @type bool
@@ -989,7 +1042,7 @@ class DebuggerInterfacePython(QObject):
         @param temp flag indicating a temporary breakpoint
         @type bool
         """
-        debuggerList = [debuggerId] if debuggerId else list(self.__connections.keys())
+        debuggerList = [debuggerId] if debuggerId else list(self.__connections)
         for debuggerId in debuggerList:
             self.__sendJsonCommand(
                 "RequestBreakpoint",
@@ -1011,12 +1064,12 @@ class DebuggerInterfacePython(QObject):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param enable flag indicating enabling or disabling a breakpoint
         @type bool
         """
-        debuggerList = [debuggerId] if debuggerId else list(self.__connections.keys())
+        debuggerList = [debuggerId] if debuggerId else list(self.__connections)
         for debuggerId in debuggerList:
             self.__sendJsonCommand(
                 "RequestBreakpointEnable",
@@ -1036,12 +1089,12 @@ class DebuggerInterfacePython(QObject):
         @type str
         @param fn filename the breakpoint belongs to
         @type str
-        @param line linenumber of the breakpoint
+        @param line line number of the breakpoint
         @type int
         @param count number of occurrences to ignore
         @type int
         """
-        debuggerList = [debuggerId] if debuggerId else list(self.__connections.keys())
+        debuggerList = [debuggerId] if debuggerId else list(self.__connections)
         for debuggerId in debuggerList:
             self.__sendJsonCommand(
                 "RequestBreakpointIgnore",
@@ -1066,7 +1119,7 @@ class DebuggerInterfacePython(QObject):
         @param temp flag indicating a temporary watch expression
         @type bool
         """
-        debuggerList = [debuggerId] if debuggerId else list(self.__connections.keys())
+        debuggerList = [debuggerId] if debuggerId else list(self.__connections)
         for debuggerId in debuggerList:
             # cond is combination of cond and special (s. watch expression
             # viewer)
@@ -1091,7 +1144,7 @@ class DebuggerInterfacePython(QObject):
         @param enable flag indicating enabling or disabling a watch expression
         @type bool
         """
-        debuggerList = [debuggerId] if debuggerId else list(self.__connections.keys())
+        debuggerList = [debuggerId] if debuggerId else list(self.__connections)
         for debuggerId in debuggerList:
             # cond is combination of cond and special (s. watch expression
             # viewer)
@@ -1116,7 +1169,7 @@ class DebuggerInterfacePython(QObject):
         @param count number of occurrences to ignore
         @type int
         """
-        debuggerList = [debuggerId] if debuggerId else list(self.__connections.keys())
+        debuggerList = [debuggerId] if debuggerId else list(self.__connections)
         for debuggerId in debuggerList:
             # cond is combination of cond and special (s. watch expression
             # viewer)
@@ -1135,7 +1188,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param inputString the raw input
+        @param inputString raw input
         @type str
         """
         self.__sendJsonCommand(
@@ -1189,7 +1242,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterList list of variable types to filter out
         @type list of str
@@ -1219,7 +1272,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterList list of variable types to filter out
         @type list of str
@@ -1259,7 +1312,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param scope the scope of the variables (0 = local, 1 = global)
+        @param scope scope of the variables (0 = local, 1 = global)
         @type int
         @param filterStr regexp string for variable names to filter out
         @type str
@@ -1332,7 +1385,7 @@ class DebuggerInterfacePython(QObject):
 
         @param debuggerId ID of the debugger backend
         @type str
-        @param text the text to be completed
+        @param text text to be completed
         @type str
         """
         self.__sendJsonCommand(
@@ -1350,14 +1403,27 @@ class DebuggerInterfacePython(QObject):
         @param sock reference to the socket to read data from
         @type QTcpSocket
         """
-        while sock and sock.canReadLine():
-            qs = sock.readLine()
-            line = bytes(qs).decode(encoding=Preferences.getSystem("StringEncoding"))
+        while sock and sock.bytesAvailable():
+            header = sock.read(struct.calcsize(b"!II"))
+            length, datahash = struct.unpack(b"!II", header)
 
-            logging.debug("<Debug-Server> %s", line)
-            ##print("Server: ", line)    ## debug       # __IGNORE_WARNING_M891__
+            data = bytearray()
+            while len(data) < length:
+                maxSize = length - len(data)
+                if sock.bytesAvailable() < maxSize:
+                    sock.waitForReadyRead(50)
+                data += sock.read(maxSize)
 
-            self.__handleJsonCommand(line, sock)
+            if zlib.adler32(data) & 0xFFFFFFFF != datahash:
+                # corrupted data -> discard and continue
+                continue
+
+            jsonStr = data.decode("utf-8", "backslashreplace")
+
+            logging.debug("<Debug-Server> %s", jsonStr)
+            ##print("Server: ", jsonStr)    ## debug       # __IGNORE_WARNING_M891__
+
+            self.__handleJsonCommand(jsonStr, sock)
 
     def __handleJsonCommand(self, jsonStr, sock):
         """
@@ -1460,8 +1526,8 @@ class DebuggerInterfacePython(QObject):
 
         elif method == "ResponseCapabilities":
             self.clientCapabilities = params["capabilities"]
-            if params["debuggerId"] == self.__master:
-                # signal only for the master connection
+            if params["debuggerId"] == self.__mainDebugger:
+                # signal only for the main connection
                 self.debugServer.signalClientCapabilities(
                     params["capabilities"],
                     params["clientType"],
@@ -1469,8 +1535,8 @@ class DebuggerInterfacePython(QObject):
                 )
 
         elif method == "ResponseBanner":
-            if params["debuggerId"] == self.__master:
-                # signal only for the master connection
+            if params["debuggerId"] == self.__mainDebugger:
+                # signal only for the main connection
                 self.debugServer.signalClientBanner(
                     params["version"],
                     params["platform"],
@@ -1561,13 +1627,13 @@ class DebuggerInterfacePython(QObject):
                 params["message"],
                 params["debuggerId"],
             )
-            if params["debuggerId"] == self.__master:
+            if params["debuggerId"] == self.__mainDebugger:
                 self.debugServer.signalMainClientExit()
 
         elif method == "PassiveStartup":
             self.debugServer.passiveStartUp(
                 self.translate(params["filename"], True),
-                params["exceptions"],
+                params["reportAllExceptions"],
                 params["debuggerId"],
             )
 
@@ -1595,29 +1661,30 @@ class DebuggerInterfacePython(QObject):
             "method": command,
             "params": params,
         }
-        cmd = json.dumps(commandDict) + "\n"
+        jsonStr = json.dumps(commandDict)
 
         if debuggerId and debuggerId in self.__connections:
             sock = self.__connections[debuggerId]
-        elif sock is None and self.__master is not None:
-            sock = self.__connections[self.__master]
+        elif sock is None and self.__mainDebugger is not None:
+            sock = self.__connections[self.__mainDebugger]
         if sock is not None:
-            self.__writeJsonCommandToSocket(cmd, sock)
+            self.__writeJsonCommandToSocket(jsonStr, sock)
         else:
-            self.queue.append(cmd)
+            self.__commandQueue.append(jsonStr)
 
-    def __writeJsonCommandToSocket(self, cmd, sock):
+    def __writeJsonCommandToSocket(self, jsonCommand, sock):
         """
         Private method to write a JSON command to the socket.
 
-        @param cmd JSON command to be sent
+        @param jsonCommand JSON encoded command to be sent
         @type str
         @param sock reference to the socket to write to
         @type QTcpSocket
         """
-        data = cmd.encode("utf8", "backslashreplace")
-        length = "{0:09d}".format(len(data))
-        sock.write(length.encode() + data)
+        data = jsonCommand.encode("utf8", "backslashreplace")
+        header = struct.pack(b"!II", len(data), zlib.adler32(data) & 0xFFFFFFFF)
+        sock.write(header)
+        sock.write(data)
         sock.flush()
 
 
