@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,9 +25,12 @@ class VariableDetailDialog(QDialog, Ui_VariableDetailDialog):
         """
         Constructor
 
-        @param var the variables name (string)
-        @param vtype the variables type (string)
-        @param value the variables value (string)
+        @param var the variables name
+        @type str
+        @param vtype the variables type
+        @type str
+        @param value the variables value
+        @type str
         """
         super().__init__()
         self.setupUi(self)
