@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -18,7 +18,7 @@ def initSSL():
         # no SSL available, so there is nothing to initialize
         return
 
-    blacklist = [
+    blocklist = [
         "SRP-AES-256-CBC-SHA",  # open to MitM
         "SRP-AES-128-CBC-SHA",  # open to MitM
     ]
@@ -26,7 +26,7 @@ def initSSL():
     strongCiphers = [
         c
         for c in QSslConfiguration.supportedCiphers()
-        if c.name() not in blacklist and c.usedBits() >= 128
+        if c.name() not in blocklist and c.usedBits() >= 128
     ]
     defaultSslConfiguration = QSslConfiguration.defaultConfiguration()
     defaultSslConfiguration.setCiphers(strongCiphers)
