@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -33,12 +33,12 @@ class EricIconBar(QWidget):
 
     BarSizes = {
         # tuples with (icon size, border size, translated size string)
-        "xs": (16, 1, QCoreApplication.translate("EricIconBar", "extra small")),
-        "sm": (22, 1, QCoreApplication.translate("EricIconBar", "small")),
-        "md": (32, 2, QCoreApplication.translate("EricIconBar", "medium")),
-        "lg": (48, 2, QCoreApplication.translate("EricIconBar", "large")),
-        "xl": (64, 3, QCoreApplication.translate("EricIconBar", "extra large")),
-        "xxl": (96, 3, QCoreApplication.translate("EricIconBar", "very large")),
+        "xs": (16, 1, QCoreApplication.translate("EricIconBar", "extra small (16 px)")),
+        "sm": (22, 1, QCoreApplication.translate("EricIconBar", "small (22 px)")),
+        "md": (32, 2, QCoreApplication.translate("EricIconBar", "medium (32 px)")),
+        "lg": (48, 2, QCoreApplication.translate("EricIconBar", "large (48 px)")),
+        "xl": (64, 3, QCoreApplication.translate("EricIconBar", "extra large (64 px)")),
+        "xxl": (96, 3, QCoreApplication.translate("EricIconBar", "very large (96 px)")),
     }
     DefaultBarSize = "md"
 
@@ -218,9 +218,13 @@ class EricIconBar(QWidget):
 
         label = self.__layout.itemAt(self.__currentIndex)
         if label:
-            label.widget().setStyleSheet(
-                EricIconBar.LabelStyleSheetTemplate.format(self.__highlightColor.name())
-            )
+            widget = label.widget()
+            if widget:
+                widget.setStyleSheet(
+                    EricIconBar.LabelStyleSheetTemplate.format(
+                        self.__highlightColor.name()
+                    )
+                )
 
     def color(self):
         """
@@ -338,6 +342,19 @@ class EricIconBar(QWidget):
 
             self.__adjustIconLabels()
 
+    def setIcon(self, index, icon):
+        """
+        Public method to set the icon at the given index.
+
+        @param index icon index
+        @type int
+        @param icon reference to the icon
+        @type QIcon
+        """
+        labelItem = self.__layout.itemAt(index)
+        if labelItem:
+            labelItem.widget().setPixmap(icon.pixmap(self.__barSize, self.__barSize))
+
     @pyqtSlot()
     def __iconClicked(self, label):
         """
