@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,6 +10,7 @@ Module implementing a main window class with styling support.
 from PyQt6.QtWidgets import QApplication, QMainWindow, QStyleFactory
 
 from .EricApplication import ericApp
+from .EricProxyStyle import EricProxyStyle
 
 
 class EricMainWindow(QMainWindow):
@@ -40,13 +41,15 @@ class EricMainWindow(QMainWindow):
         """
         # step 1: set the style
         style = None
-        if styleName != "System" and styleName in QStyleFactory.keys():
-            # __IGNORE_WARNING_Y118__
+        if styleName != "System" and styleName in QStyleFactory.keys():  # noqa: Y118
             style = QStyleFactory.create(styleName)
         if style is None:
             style = QStyleFactory.create(self.defaultStyleName)
-        if style is not None:
-            QApplication.setStyle(style)
+
+        if style is None:
+            QApplication.setStyle(EricProxyStyle())
+        else:
+            QApplication.setStyle(EricProxyStyle(style))
 
         # step 2: set a style sheet
         ericApp().setStyleSheetFile(styleSheetFile)
