@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,6 +23,7 @@ from PyQt6.QtWidgets import (
 
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets import EricMessageBox
+from eric7.EricWidgets.EricApplication import ericApp
 
 from .Ui_EricToolBarDialog import Ui_EricToolBarDialog
 
@@ -53,8 +54,9 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         Constructor
 
         @param toolBarManager reference to a toolbar manager object
-            (EricToolBarManager)
-        @param parent reference to the parent widget (QWidget)
+        @type EricToolBarManager
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -102,12 +104,16 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
                 if self.__manager.isWidgetAction(action):
                     item.setData(0, EricToolBarDialog.WidgetActionRole, True)
                     item.setData(
-                        0, Qt.ItemDataRole.ForegroundRole, QColor(Qt.GlobalColor.blue)
+                        0,
+                        Qt.ItemDataRole.ForegroundRole,
+                        QColor("#8b8bff")
+                        if ericApp().usesDarkPalette()
+                        else QColor(Qt.GlobalColor.blue),
                     )
                     self.__widgetActionToToolBarItemID[id(action)] = None
             categoryItem.setExpanded(True)
 
-        for tbID, actions in list(self.__manager.toolBarsActions().items()):
+        for tbID, actions in self.__manager.toolBarsActions().items():
             tb = self.__manager.toolBarById(tbID)
             default = self.__manager.isDefaultToolBar(tb)
             tbItem = EricToolBarItem(
@@ -268,7 +274,8 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         """
         Private slot called upon a selection of the current toolbar.
 
-        @param index index of the new current toolbar (integer)
+        @param index index of the new current toolbar
+        @type int
         """
         itemID = self.toolbarComboBox.itemData(index)
         self.__currentToolBarItem = self.__toolbarItems[itemID]
@@ -300,9 +307,10 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         """
         Private slot called, when the currently selected action changes.
 
-        @param current reference to the current item (QTreeWidgetItem)
+        @param current reference to the current item
+        @type QTreeWidgetItem
         @param previous reference to the previous current item
-            (QTreeWidgetItem)
+        @type QTreeWidgetItem
         """
         self.__setupButtons()
 
@@ -311,9 +319,10 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         """
         Private slot to handle a change of the current item.
 
-        @param current reference to the current item (QListWidgetItem)
+        @param current reference to the current item
+        @type QListWidgetItem
         @param previous reference to the previous current item
-            (QListWidgetItem)
+        @type QListWidgetItem
         """
         self.__setupButtons()
 
@@ -421,7 +430,8 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         """
         Private slot called, when a button of the button box was clicked.
 
-        @param button reference to the button clicked (QAbstractButton)
+        @param button reference to the button clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Cancel):
             self.reject()
@@ -453,7 +463,7 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         self.__removedToolBarIDs = []
 
         # step 2: save configured toolbars
-        for tbItem in list(self.__toolbarItems.values()):
+        for tbItem in self.__toolbarItems.values():
             if not tbItem.isChanged:
                 continue
 
@@ -486,7 +496,7 @@ class EricToolBarDialog(QDialog, Ui_EricToolBarDialog):
         actions.
 
         @param actions list of actions to set for the current toolbar
-        (list of QAction)
+        @type list of QAction
         """
         tbItemID = id(self.__currentToolBarItem)
         for widgetActionID in self.__toolBarItemToWidgetActionID[tbItemID]:
