@@ -1,16 +1,26 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a toolbar manager class.
 """
 
-from PyQt6.QtCore import QByteArray, QDataStream, QIODevice, QObject
-from PyQt6.QtWidgets import QToolBar
+import contextlib
 
-from eric7 import Utilities
+from PyQt6.QtCore import (
+    QByteArray,
+    QCoreApplication,
+    QDataStream,
+    QIODevice,
+    QObject,
+    QSize,
+    pyqtSlot,
+)
+from PyQt6.QtWidgets import QStyle, QToolBar
+
+from eric7 import Preferences, Utilities
 
 
 class EricToolBarManager(QObject):
@@ -22,12 +32,35 @@ class EricToolBarManager(QObject):
     ToolBarMarker = 0xFEFE
     CustomToolBarMarker = 0xFDFD
 
+    IconSizes = {
+        # tuples with (icon size, translated size string)
+        "": (
+            0,
+            QCoreApplication.translate(
+                "EricToolBarManager", "default (style dependent)"
+            ),
+        ),
+        "xs": (
+            16,
+            QCoreApplication.translate("EricToolBarManager", "extra small (16 px)"),
+        ),
+        "sm": (22, QCoreApplication.translate("EricToolBarManager", "small (22 px)")),
+        "md": (32, QCoreApplication.translate("EricToolBarManager", "medium (32 px)")),
+        "lg": (48, QCoreApplication.translate("EricToolBarManager", "large (48 px)")),
+        "xl": (
+            64,
+            QCoreApplication.translate("EricToolBarManager", "extra large (64 px)"),
+        ),
+    }
+
     def __init__(self, ui=None, parent=None):
         """
         Constructor
 
-        @param ui reference to the user interface object (UI.UserInterface)
-        @param parent reference to the parent object (QObject)
+        @param ui reference to the user interface object
+        @type UI.UserInterface
+        @param parent reference to the parent object
+        @type QObject
         """
         super().__init__(parent)
 
@@ -67,10 +100,12 @@ class EricToolBarManager(QObject):
         """
         Private slot to get a toolbar by its object name.
 
-        @param name object name of the toolbar (string)
-        @return reference to the toolbar (QToolBar)
+        @param name object name of the toolbar
+        @type str
+        @return reference to the toolbar
+        @rtype QToolBar
         """
-        for toolBar in list(self.__allToolBars.values()):
+        for toolBar in self.__allToolBars.values():
             if toolBar.objectName() == name:
                 return toolBar
         return None
@@ -79,16 +114,18 @@ class EricToolBarManager(QObject):
         """
         Private method to find an action by name.
 
-        @param name name of the action to search for (string)
-        @return reference to the action (QAction)
+        @param name name of the action to search for
+        @type str
+        @return reference to the action
+        @rtype QAction
         """
         # check objectName() first
-        for action in list(self.__allActions.values()):
+        for action in self.__allActions.values():
             if action.objectName() == name:
                 return action
 
         # check text() next
-        for action in list(self.__allActions.values()):
+        for action in self.__allActions.values():
             if action.text() == name:
                 return action
 
@@ -98,8 +135,10 @@ class EricToolBarManager(QObject):
         """
         Private method to find a default toolbar by name.
 
-        @param name name of the default toolbar to search for (string)
-        @return reference to the default toolbar (QToolBar)
+        @param name name of the default toolbar to search for
+        @type str
+        @return reference to the default toolbar
+        @rtype QToolBar
         """
         # check objectName() first
         for tbID in self.__defaultToolBars:
@@ -123,7 +162,8 @@ class EricToolBarManager(QObject):
         """
         Public method to set the reference to the main window.
 
-        @param mainWindow reference to the main window (QMainWindow)
+        @param mainWindow reference to the main window
+        @type QMainWindow
         """
         self.__mainWindow = mainWindow
 
@@ -131,7 +171,8 @@ class EricToolBarManager(QObject):
         """
         Public method to get the reference to the main window.
 
-        @return reference to the main window (QMainWindow)
+        @return reference to the main window
+        @rtype QMainWindow
         """
         return self.__mainWindow
 
@@ -139,12 +180,20 @@ class EricToolBarManager(QObject):
         """
         Public method to add a toolbar to be managed.
 
-        @param toolBar reference to the toolbar to be managed (QToolBar)
-        @param category category for the toolbar (string)
+        @param toolBar reference to the toolbar to be managed
+        @type QToolBar
+        @param category category for the toolbar
+        @type str
         """
         if toolBar is None:
             return
 
+        iconSizeStr = Preferences.getIcons("IconSize")
+        if iconSizeStr:
+            with contextlib.suppress(KeyError):
+                iconSize = EricToolBarManager.IconSizes[iconSizeStr][0]
+                toolBar.setIconSize(QSize(iconSize, iconSize))
+
         newActions = []
         newActionsWithSeparators = []
         actions = toolBar.actions()
@@ -170,7 +219,8 @@ class EricToolBarManager(QObject):
         """
         Public method to remove a toolbar added with addToolBar().
 
-        @param toolBar reference to the toolbar to be removed (QToolBar)
+        @param toolBar reference to the toolbar to be removed
+        @type QToolBar
         """
         if toolBar is None:
             return
@@ -202,8 +252,9 @@ class EricToolBarManager(QObject):
 
         @param toolBars dictionary with toolbar id as key and
             a list of actions as value
+        @type dict
         """
-        for key, actions in list(toolBars.items()):
+        for key, actions in toolBars.items():
             tb = self.__allToolBars[key]
             self.setToolBar(tb, actions)
 
@@ -211,8 +262,10 @@ class EricToolBarManager(QObject):
         """
         Public method to set the actions of a toolbar.
 
-        @param toolBar reference to the toolbar to configure (QToolBar)
-        @param actions list of actions to be set (list of QAction)
+        @param toolBar reference to the toolbar to configure
+        @type QToolBar
+        @param actions list of actions to be set
+        @type list of QAction
         """
         if toolBar is None:
             return
@@ -274,7 +327,8 @@ class EricToolBarManager(QObject):
         """
         Public method to reset a toolbar to its default state.
 
-        @param toolBar reference to the toolbar to configure (QToolBar)
+        @param toolBar reference to the toolbar to configure
+        @type QToolBar
         """
         if not self.isDefaultToolBar():
             return
@@ -292,7 +346,8 @@ class EricToolBarManager(QObject):
         """
         Public method to get all toolbars added with addToolBar().
 
-        @return list of all default toolbars (list of QToolBar)
+        @return list of all default toolbars
+        @rtype list of QToolBar
         """
         return list(self.__defaultToolBars.values())
 
@@ -300,8 +355,10 @@ class EricToolBarManager(QObject):
         """
         Public method to check, if a toolbar was added with addToolBar().
 
-        @param toolBar reference to the toolbar to be checked (QToolBar)
-        @return flag indicating an added toolbar (boolean)
+        @param toolBar reference to the toolbar to be checked
+        @type QToolBar
+        @return flag indicating an added toolbar
+        @rtype bool
         """
         return toolBar is not None and id(toolBar) in self.__defaultToolBars
 
@@ -309,9 +366,12 @@ class EricToolBarManager(QObject):
         """
         Public method to create a custom toolbar.
 
-        @param title title to be used for the toolbar (string)
-        @param name optional name for the new toolbar (string)
-        @return reference to the created toolbar (QToolBar)
+        @param title title to be used for the toolbar
+        @type str
+        @param name optional name for the new toolbar
+        @type str
+        @return reference to the created toolbar
+        @rtype QToolBar
         """
         if self.__mainWindow is None:
             return None
@@ -343,7 +403,8 @@ class EricToolBarManager(QObject):
         """
         Public method to remove a custom toolbar created with createToolBar().
 
-        @param toolBar reference to the toolbar to be managed (QToolBar)
+        @param toolBar reference to the toolbar to be managed
+        @type QToolBar
         """
         if toolBar is None:
             return
@@ -370,8 +431,10 @@ class EricToolBarManager(QObject):
         """
         Public method to give a toolbar a new title.
 
-        @param toolBar reference to the toolbar to be managed (QToolBar)
-        @param title title to be used for the toolbar (string)
+        @param toolBar reference to the toolbar to be managed
+        @type QToolBar
+        @param title title to be used for the toolbar
+        @type str
         """
         if toolBar is None:
             return
@@ -385,7 +448,8 @@ class EricToolBarManager(QObject):
         """
         Public method to get all toolbars.
 
-        @return list of all toolbars (list of QToolBar)
+        @return list of all toolbars
+        @rtype list of QToolBar
         """
         return list(self.__allToolBars.values())
 
@@ -393,8 +457,10 @@ class EricToolBarManager(QObject):
         """
         Public method to add an action to be managed.
 
-        @param action reference to the action to be managed (QAction)
-        @param category category for the toolbar (string)
+        @param action reference to the action to be managed
+        @type QAction
+        @param category category for the toolbar
+        @type str
         """
         if action is None:
             return
@@ -429,7 +495,8 @@ class EricToolBarManager(QObject):
         """
         Public method to remove an action from the manager.
 
-        @param action reference to the action to be removed (QAction)
+        @param action reference to the action to be removed
+        @type QAction
         """
         aID = id(action)
 
@@ -465,7 +532,8 @@ class EricToolBarManager(QObject):
         """
         Public method to remove the actions belonging to a category.
 
-        @param category category for the actions (string)
+        @param category category for the actions
+        @type str
         """
         for action in self.categoryActions(category):
             self.removeAction(action)
@@ -474,8 +542,10 @@ class EricToolBarManager(QObject):
         """
         Public method to save the state of the toolbar manager.
 
-        @param version version number stored with the data (integer)
-        @return saved state as a byte array (QByteArray)
+        @param version version number stored with the data
+        @type int
+        @return saved state as a byte array
+        @rtype QByteArray
         """
         data = QByteArray()
         stream = QDataStream(data, QIODevice.OpenModeFlag.WriteOnly)
@@ -526,9 +596,12 @@ class EricToolBarManager(QObject):
         """
         Public method to restore the state of the toolbar manager.
 
-        @param state byte array containing the saved state (QByteArray)
-        @param version version number stored with the data (integer)
-        @return flag indicating success (boolean)
+        @param state byte array containing the saved state
+        @type QByteArray
+        @param version version number stored with the data
+        @type int
+        @return flag indicating success
+        @rtype bool
         """
         if state.isEmpty():
             return False
@@ -601,8 +674,10 @@ class EricToolBarManager(QObject):
         """
         Public method to get the toolbar for a widget action.
 
-        @param action widget action to check for (QAction)
-        @return reference to the toolbar containing action (QToolBar)
+        @param action widget action to check for
+        @type QAction
+        @return reference to the toolbar containing action
+        @rtype QToolBar
         """
         aID = id(action)
         if aID in self.__widgetActions:
@@ -615,8 +690,9 @@ class EricToolBarManager(QObject):
 
         @param actions dictionary with toolbar id as key and
             a list of widget actions as value
+        @type dict
         """
-        for tbID in list(actions.keys())[:]:
+        for tbID in list(actions):
             toolBar = self.__allToolBars[tbID]
             newActions = self.__toolBars[tbID][:]
             newActionsWithSeparators = self.__toolBarsWithSeparators[tbID][:]
@@ -640,8 +716,10 @@ class EricToolBarManager(QObject):
         """
         Public method to check, if action is a widget action.
 
-        @param action reference to the action to be checked (QAction)
-        @return flag indicating a widget action (boolean)
+        @param action reference to the action to be checked
+        @type QAction
+        @return flag indicating a widget action
+        @rtype bool
         """
         return id(action) in self.__allWidgetActions
 
@@ -649,16 +727,19 @@ class EricToolBarManager(QObject):
         """
         Public method to get the list of categories.
 
-        @return list of categories (list of string)
+        @return list of categories
+        @rtype list of str
         """
-        return list(self.__categoryToActions.keys())
+        return list(self.__categoryToActions)
 
     def categoryActions(self, category):
         """
         Public method to get the actions belonging to a category.
 
-        @param category category for the actions (string)
-        @return list of actions (list of QAction)
+        @param category category for the actions
+        @type str
+        @return list of actions
+        @rtype list of QAction
         """
         if category not in self.__categoryToActions:
             return []
@@ -669,8 +750,10 @@ class EricToolBarManager(QObject):
         """
         Public method to get an action given its id.
 
-        @param aID id of the action object (integer)
-        @return reference to the action (QAction)
+        @param aID id of the action object
+        @type int
+        @return reference to the action
+        @rtype QAction
         """
         if aID not in self.__allActions:
             return None
@@ -680,8 +763,10 @@ class EricToolBarManager(QObject):
         """
         Public method to get a toolbar given its id.
 
-        @param tbID id of the toolbar object (integer)
-        @return reference to the toolbar (QToolBar)
+        @param tbID id of the toolbar object
+        @type int
+        @return reference to the toolbar
+        @rtype QToolBar
         """
         if tbID not in self.__allToolBars:
             return None
@@ -691,8 +776,10 @@ class EricToolBarManager(QObject):
         """
         Public method to get a toolbar's actions given its id.
 
-        @param tbID id of the toolbar object (integer)
-        @return list of actions (list of QAction)
+        @param tbID id of the toolbar object
+        @type int
+        @return list of actions
+        @rtype list of QAction
         """
         if tbID not in self.__toolBars:
             return []
@@ -704,6 +791,7 @@ class EricToolBarManager(QObject):
 
         @return reference to dictionary of toolbar IDs as key and list
             of actions as values
+        @rtype dict
         """
         return self.__toolBars
 
@@ -711,9 +799,38 @@ class EricToolBarManager(QObject):
         """
         Public method to get a default toolbar's actions given its id.
 
-        @param tbID id of the default toolbar object (integer)
-        @return list of actions (list of QAction)
+        @param tbID id of the default toolbar object
+        @type int
+        @return list of actions
+        @rtype list of QAction
         """
         if tbID not in self.__defaultToolBars:
             return []
         return self.__defaultToolBars[tbID][:]
+
+    @pyqtSlot()
+    def preferencesChanged(self):
+        """
+        Public slot to handle a change of preferences.
+        """
+        iconSizeStr = Preferences.getIcons("IconSize")
+        if iconSizeStr:
+            try:
+                iconSize = EricToolBarManager.IconSizes[iconSizeStr][0]
+            except KeyError:
+                # determine icon size through the style
+                iconSize = (
+                    list(self.__allToolBars.items()[0])
+                    .style()
+                    .pixelMetric(QStyle.PixelMetric.PM_ToolBarIconSize)
+                )
+        else:
+            # determine icon size through the style
+            iconSize = (
+                list(self.__allToolBars.values())[0]
+                .style()
+                .pixelMetric(QStyle.PixelMetric.PM_ToolBarIconSize)
+            )
+
+        for tbID in self.__allToolBars:
+            self.__allToolBars[tbID].setIconSize(QSize(iconSize, iconSize))
