@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -180,7 +180,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
         modules = self.__buildModulesDict()
 
         # step 1: build a dictionary of packages
-        for module in sorted(modules.keys()):
+        for module in sorted(modules):
             if "." in module:
                 packageName, moduleName = module.rsplit(".", 1)
             else:
@@ -191,7 +191,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
                 packages[packageName] = ([moduleName], [])
 
         # step 2: assign modules to dictionaries and update import relationship
-        for module in sorted(modules.keys()):
+        for module in sorted(modules):
             package = module.rsplit(".", 1)[0]
             impLst = []
             for moduleImport in modules[module].imports:
@@ -213,7 +213,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
                         n = "{0}.{1}".format(root, moduleImport)
                         if n in modules:
                             impLst.append(n)
-            for moduleImport in list(modules[module].from_imports.keys()):
+            for moduleImport in modules[module].from_imports:
                 if moduleImport.startswith("."):
                     dots = len(moduleImport) - len(moduleImport.lstrip("."))
                     if dots == 1:
@@ -263,7 +263,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
                 except KeyError:
                     continue
 
-        for package in sorted(packages.keys()):
+        for package in sorted(packages):
             if package:
                 relPackage = package.replace(root, "")
                 if relPackage and relPackage[0] == ".":
@@ -413,7 +413,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
             )
             self.scene.addItem(assoc)
 
-    def parsePersistenceData(self, version, data):
+    def parsePersistenceData(self, version, data):  # noqa: U100
         """
         Public method to parse persisted data.
 
@@ -463,7 +463,7 @@ class ApplicationDiagramBuilder(UMLDiagramBuilder):
             "no_modules": self.noModules,
         }
 
-    def fromDict(self, version, data):
+    def fromDict(self, version, data):  # noqa: U100
         """
         Public method to populate the class with data persisted by 'toDict()'.
 
