@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -255,9 +255,9 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         # step 1: build all classes found in the modules
         classesFound = False
 
-        for modName in list(modules.keys()):
+        for modName in modules:
             module = modules[modName]
-            for cls in list(module.classes.keys()):
+            for cls in module.classes:
                 classesFound = True
                 self.__addLocalClass(cls, module.classes[cls], 0, 0)
         if not classesFound and not subpackages:
@@ -277,7 +277,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         routes = []
         nodes = []
 
-        for modName in list(modules.keys()):
+        for modName in modules:
             module = modules[modName]
             todo = [module.createHierarchy()]
             while todo:
@@ -313,15 +313,14 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
 
                     if hierarchy.get(className):
                         todo.append(hierarchy.get(className))
-                        children = list(hierarchy.get(className).keys())
-                        for child in children:
+                        for child in hierarchy.get(className, []):
                             if (className, child) not in routes:
                                 routes.append((className, child))
 
                 del todo[0]
 
         # step 3: build the subpackages
-        for subpackage in sorted(subpackages.keys()):
+        for subpackage in sorted(subpackages):
             self.__addPackage(subpackage, subpackages[subpackage], 0, 0)
             nodes.append(subpackage)
 
@@ -427,9 +426,9 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
             name = "{0} (Module)".format(name)
         cl = ClassModel(
             name,
-            sorted(_class.methods.keys())[:],
-            sorted(_class.attributes.keys())[:],
-            sorted(_class.globals.keys())[:],
+            sorted(_class.methods),
+            sorted(_class.attributes),
+            sorted(_class.globals),
         )
         cw = ClassItem(
             cl,
@@ -514,7 +513,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
                 )
                 self.scene.addItem(assoc)
 
-    def parsePersistenceData(self, version, data):
+    def parsePersistenceData(self, version, data):  # noqa: U100
         """
         Public method to parse persisted data.
 
@@ -559,7 +558,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
 
         return data
 
-    def fromDict(self, version, data):
+    def fromDict(self, version, data):  # noqa: U100
         """
         Public method to populate the class with data persisted by 'toDict()'.
 
