@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,15 @@ Module implementing a subclass of EricGraphicsView for our diagrams.
 
 import pathlib
 
-from PyQt6.QtCore import QEvent, QMarginsF, QRectF, QSignalMapper, Qt, pyqtSignal
+from PyQt6.QtCore import (
+    QEvent,
+    QMarginsF,
+    QRectF,
+    QSignalMapper,
+    Qt,
+    pyqtSignal,
+    pyqtSlot,
+)
 from PyQt6.QtGui import QAction, QPageLayout
 from PyQt6.QtPrintSupport import QPrintDialog, QPrinter, QPrintPreviewDialog
 from PyQt6.QtWidgets import QDialog, QGraphicsView, QToolBar
@@ -80,11 +88,7 @@ class UMLGraphicsView(EricGraphicsView):
         Private method to initialize the view actions.
         """
         self.alignMapper = QSignalMapper(self)
-        try:
-            self.alignMapper.mappedInt.connect(self.__alignShapes)
-        except AttributeError:
-            # pre Qt 5.15
-            self.alignMapper.mapped[int].connect(self.__alignShapes)
+        self.alignMapper.mappedInt.connect(self.__alignShapes)
 
         self.deleteShapeAct = QAction(
             EricPixmapCache.getIcon("deleteShape"), self.tr("Delete shapes"), self
@@ -199,6 +203,7 @@ class UMLGraphicsView(EricGraphicsView):
         else:
             self.decHeightAct.setEnabled(True)
 
+    @pyqtSlot("QList<QRectF>")
     def __sceneChanged(self, areas):
         """
         Private slot called when the scene changes.
@@ -826,7 +831,7 @@ class UMLGraphicsView(EricGraphicsView):
 
         return data
 
-    def fromDict(self, version, data):
+    def fromDict(self, version, data):  # noqa: U100
         """
         Public method to populate the class with data persisted by 'toDict()'.
 
