@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2022 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2022 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -429,7 +429,7 @@ class HelpBookmarksWidget(QListWidget):
             bookmarksDict = {
                 "creator": "eric7",
                 "version": 1,
-                "created": datetime.datetime.now().isoformat(
+                "created": datetime.datetime.now(tz=datetime.timezone.utc).isoformat(
                     sep=" ", timespec="seconds"
                 ),
                 "bookmarks": [],
