@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -69,7 +69,7 @@ class HelpViewerWidget(QWidget):
         """      color: #000000;\n"""
         """      margin: 10px 10px 10px 10px;\n"""
         """}\n"""
-        """</style"""
+        """</style>\n"""
         """</head>\n"""
         """<body>\n"""
         """</body>\n"""
@@ -85,7 +85,7 @@ class HelpViewerWidget(QWidget):
         """      color: #ffffff;\n"""
         """      margin: 10px 10px 10px 10px;\n"""
         """}\n"""
-        """</style"""
+        """</style>\n"""
         """</head>\n"""
         """<body>\n"""
         """</body>\n"""
@@ -339,6 +339,8 @@ class HelpViewerWidget(QWidget):
 
         self.__centerSplitter.setSizes([900, 150])
 
+        self.__helpInstaller = None
+
         if Preferences.getHelp("QtHelpSearchNewOnStart"):
             QTimer.singleShot(50, self.__lookForNewDocumentation)
 
@@ -494,7 +496,7 @@ class HelpViewerWidget(QWidget):
         self.__helpSearchEngine.cancelIndexing()
         self.__helpSearchEngine.cancelSearching()
 
-        self.__helpInstaller.stop()
+        self.__helpInstaller and self.__helpInstaller.stop()
 
     @pyqtSlot()
     def __openFile(self):
@@ -683,7 +685,7 @@ class HelpViewerWidget(QWidget):
         """
         qthelpDir = os.path.join(Globals.getConfigDir(), "qthelp")
         if not os.path.exists(qthelpDir):
-            os.makedirs(qthelpDir)
+            os.makedirs(qthelpDir, exist_ok=True)
         return os.path.join(qthelpDir, "eric7help.qhc")
 
     @pyqtSlot(str)
