@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,9 +39,9 @@ from .HexEditWidget import HexEditWidget
 
 class HexEditMainWindow(EricMainWindow):
     """
-    Class implementing the web browser main window.
+    Class implementing the hex editor main window.
 
-    @signal editorClosed() emitted after the window was requested to close down
+    @signal editorClosed() emitted after the window was requested to close
     """
 
     editorClosed = pyqtSignal()
@@ -54,11 +54,15 @@ class HexEditMainWindow(EricMainWindow):
         """
         Constructor
 
-        @param fileName name of a file to load on startup (string)
-        @param parent parent widget of this window (QWidget)
+        @param fileName name of a file to load on startup
+        @type str
+        @param parent parent widget of this window
+        @type QWidget
         @param fromEric flag indicating whether it was called from within
-            eric (boolean)
-        @param project reference to the project object (Project)
+            eric
+        @type bool
+        @param project reference to the project object
+        @type Project
         """
         super().__init__(parent)
         self.setObjectName("eric7_hex_editor")
@@ -108,7 +112,7 @@ class HexEditMainWindow(EricMainWindow):
         self.__initToolbars()
         self.__createStatusBar()
 
-        self.__class__.windows.append(self)
+        HexEditMainWindow.windows.append(self)
 
         state = Preferences.getHexEditor("HexEditorState")
         self.restoreState(state)
@@ -1028,8 +1032,8 @@ class HexEditMainWindow(EricMainWindow):
             Preferences.setGeometry("HexEditorGeometry", self.saveGeometry())
 
             with contextlib.suppress(ValueError):
-                if self.__fromEric or len(self.__class__.windows) > 1:
-                    del self.__class__.windows[self.__class__.windows.index(self)]
+                if self.__fromEric or len(HexEditMainWindow.windows) > 1:
+                    HexEditMainWindow.windows.remove(self)
 
             if not self.__fromEric:
                 Preferences.syncPreferences()
@@ -1191,7 +1195,7 @@ class HexEditMainWindow(EricMainWindow):
             self.tr("Save binary file"),
             self.__lastSavePath,
             self.tr("All Files (*)"),
-            EricFileDialog.DontConfirmOverwrite,
+            options=EricFileDialog.DontConfirmOverwrite,
         )
         if not fileName:
             return False
@@ -1323,7 +1327,7 @@ class HexEditMainWindow(EricMainWindow):
         """
         Private slot to close all other windows.
         """
-        for win in self.__class__.windows[:]:
+        for win in HexEditMainWindow.windows[:]:
             if win != self:
                 win.close()
 
@@ -1552,7 +1556,8 @@ class HexEditMainWindow(EricMainWindow):
         """
         Private method to open a file from the list of recently opened files.
 
-        @param act reference to the action that triggered (QAction)
+        @param act reference to the action that triggered
+        @type QAction
         """
         fileName = act.data()
         if fileName and self.__maybeSave():
@@ -1591,6 +1596,7 @@ class HexEditMainWindow(EricMainWindow):
         Private method to add a file name to the list of recently opened files.
 
         @param fileName name of the file to be added
+        @type str
         """
         if fileName:
             for recent in self.__recent[:]:
