@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -108,11 +108,13 @@ class HexEditSearchReplaceWidget(QWidget):
         self.__ui.findtextCombo.lineEdit().returnPressed.connect(
             self.__findByReturnPressed
         )
+        self.__ui.findtextCombo.lineEdit().setClearButtonEnabled(True)
         if replace:
             self.__ui.replacetextCombo.setCompleter(None)
             self.__ui.replacetextCombo.lineEdit().returnPressed.connect(
                 self.on_replaceButton_clicked
             )
+            self.__ui.replacetextCombo.lineEdit().setClearButtonEnabled(True)
 
         self.findNextAct = EricAction(
             self.tr("Find Next"),
@@ -575,7 +577,7 @@ class HexEditSearchReplaceWidget(QWidget):
         @exception ValueError raised to indicate an invalid dataFormat
             parameter
         """
-        if dataFormat not in self.__formatAndValidators.keys():
+        if dataFormat not in self.__formatAndValidators:
             raise ValueError("Bad value for 'dataFormat' parameter.")
 
         if dataFormat == "hex":  # hex format
@@ -606,7 +608,7 @@ class HexEditSearchReplaceWidget(QWidget):
         @exception ValueError raised to indicate an invalid dataFormat
             parameter
         """
-        if dataFormat not in self.__formatAndValidators.keys():
+        if dataFormat not in self.__formatAndValidators:
             raise ValueError("Bad value for 'dataFormat' parameter.")
 
         if dataFormat == "hex":  # hex format
