@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -106,7 +106,7 @@ class JediClient(EricJsonClient):
         projectPath = params["ProjectPath"]
         self.__project = jedi.Project(projectPath)
 
-    def __closeProject(self, params):
+    def __closeProject(self, params):  # noqa: U100
         """
         Private method to save a jedi project's data.
 
