@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -18,7 +18,7 @@ from eric7 import Preferences
 from eric7.EricNetwork.EricJsonServer import EricJsonServer
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
-from eric7.QScintilla.Editor import Editor, ReferenceItem
+from eric7.QScintilla.Editor import EditorIconId, ReferenceItem
 from eric7.SystemUtilities import PythonUtilities
 
 from .RefactoringPreviewDialog import RefactoringPreviewDialog
@@ -32,24 +32,24 @@ class JediServer(EricJsonServer):
     IdProject = "Project"
 
     PictureIDs = {
-        "class": "?{0}".format(Editor.ClassID),
-        "_class": "?{0}".format(Editor.ClassProtectedID),
-        "__class": "?{0}".format(Editor.ClassPrivateID),
-        "instance": "?{0}".format(Editor.ClassID),
-        "_instance": "?{0}".format(Editor.ClassProtectedID),
-        "__instance": "?{0}".format(Editor.ClassPrivateID),
-        "function": "?{0}".format(Editor.MethodID),
-        "_function": "?{0}".format(Editor.MethodProtectedID),
-        "__function": "?{0}".format(Editor.MethodPrivateID),
-        "module": "?{0}".format(Editor.ModuleID),
-        "_module": "?{0}".format(Editor.ModuleID),
-        "__module": "?{0}".format(Editor.ModuleID),
-        "param": "?{0}".format(Editor.AttributeID),
-        "_param": "?{0}".format(Editor.AttributeProtectedID),
-        "__param": "?{0}".format(Editor.AttributePrivateID),
-        "statement": "?{0}".format(Editor.AttributeID),
-        "_statement": "?{0}".format(Editor.AttributeProtectedID),
-        "__statement": "?{0}".format(Editor.AttributePrivateID),
+        "class": "?{0}".format(EditorIconId.Class),
+        "_class": "?{0}".format(EditorIconId.ClassProtected),
+        "__class": "?{0}".format(EditorIconId.ClassPrivate),
+        "instance": "?{0}".format(EditorIconId.Class),
+        "_instance": "?{0}".format(EditorIconId.ClassProtected),
+        "__instance": "?{0}".format(EditorIconId.ClassPrivate),
+        "function": "?{0}".format(EditorIconId.Method),
+        "_function": "?{0}".format(EditorIconId.MethodProtected),
+        "__function": "?{0}".format(EditorIconId.MethodPrivate),
+        "module": "?{0}".format(EditorIconId.Module),
+        "_module": "?{0}".format(EditorIconId.Module),
+        "__module": "?{0}".format(EditorIconId.Module),
+        "param": "?{0}".format(EditorIconId.Attribute),
+        "_param": "?{0}".format(EditorIconId.AttributeProtected),
+        "__param": "?{0}".format(EditorIconId.AttributePrivate),
+        "statement": "?{0}".format(EditorIconId.Attribute),
+        "_statement": "?{0}".format(EditorIconId.AttributeProtected),
+        "__statement": "?{0}".format(EditorIconId.AttributePrivate),
         "import": "",
         "None": "",
     }
@@ -91,7 +91,7 @@ class JediServer(EricJsonServer):
             "ClientException": self.__processClientException,
         }
 
-        # temporary store for editor references indexed by Uuid
+        # temporary store for editor references indexed by UUID
         self.__editors = {}
 
         # Python 3
@@ -165,7 +165,7 @@ class JediServer(EricJsonServer):
         source = editor.text()
         return filename, line, index, source
 
-    def requestCompletions(self, editor, context, acText):
+    def requestCompletions(self, editor, context, acText):  # noqa: U100
         """
         Public method to request a list of possible completions.
 
@@ -225,7 +225,7 @@ class JediServer(EricJsonServer):
             if editor is not None:
                 editor.completionsListReady(names, result["CompletionText"])
 
-    def getCallTips(self, editor, pos, commas):
+    def getCallTips(self, editor, pos, commas):  # noqa: U100
         """
         Public method to calculate calltips.
 
@@ -985,3 +985,16 @@ class JediServer(EricJsonServer):
         self.sendJson("closeProject", {}, idString=JediServer.IdProject)
 
         self.stopClient(idString=JediServer.IdProject)
+
+    def forgetEditor(self, editor):
+        """
+        Public method to forget about the given editor.
+
+        @param editor reference to the editor to forget about
+        @type Editor
+        """
+        for uid in list(self.__editors):
+            if self.__editors[uid] is editor:
+                with contextlib.suppress(KeyError):
+                    del self.__editors[uid]
+                break
