@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -38,6 +38,8 @@ class MicroPythonFileManager(QObject):
         copied to the connected device
     @signal deleteFileDone(deviceFile) emitted after the file has been deleted
         on the connected device
+    @signal putDataDone(deviceFile) emitted after data has been save to a file
+        on the connected device
     @signal rsyncDone(localName, deviceName) emitted after the rsync operation
         has been completed
     @signal rsyncProgressMessage(msg) emitted to send a message about what
@@ -57,6 +59,7 @@ class MicroPythonFileManager(QObject):
     getFileDone = pyqtSignal(str, str)
     putFileDone = pyqtSignal(str, str)
     deleteFileDone = pyqtSignal(str)
+    putDataDone = pyqtSignal(str)
     rsyncDone = pyqtSignal(str, str)
     rsyncProgressMessage = pyqtSignal(str)
     removeDirectoryDone = pyqtSignal()
@@ -65,18 +68,33 @@ class MicroPythonFileManager(QObject):
 
     error = pyqtSignal(str, str)
 
-    def __init__(self, commandsInterface, parent=None):
+    def __init__(self, device, parent=None):
         """
         Constructor
 
-        @param commandsInterface reference to the commands interface object
-        @type MicroPythonCommandsInterface
+        @param device MicroPython device object
+        @type BaseDevice
         @param parent reference to the parent object
         @type QObject
         """
         super().__init__(parent)
 
-        self.__commandsInterface = commandsInterface
+        self.__device = device
+
+    def exists(self, pathname):
+        """
+        Public method to check the existence of a file or directory.
+
+        @param pathname name of the path to check
+        @type str
+        @return flag indicating the existence
+        @rtype bool
+        """
+        try:
+            return self.__device.exists(pathname)
+        except Exception as exc:
+            self.error.emit("exists", str(exc))
+            return False
 
     @pyqtSlot(str)
     def lls(self, dirname, showHidden=False):
@@ -89,13 +107,20 @@ class MicroPythonFileManager(QObject):
         @type bool
         """
         try:
-            filesList = self.__commandsInterface.lls(dirname, showHidden=showHidden)
+            filesList = self.__device.lls(dirname, showHidden=showHidden)
+            adjustEpoch = (
+                not self.__device.hasCircuitPython()
+                and self.__device.getDeviceData(key="epoch_year") == 2000
+            )
             result = [
                 (
                     decoratedName(name, mode),
                     mode2string(mode),
                     str(size),
-                    mtime2string(mtime, adjustEpoch=True),
+                    mtime2string(mtime, adjustEpoch=adjustEpoch),
+                    f"{dirname}{name}"
+                    if dirname.endswith("/")
+                    else f"{dirname}/{name}",
                 )
                 for name, (mode, size, mtime) in filesList
             ]
@@ -109,7 +134,7 @@ class MicroPythonFileManager(QObject):
         Public slot to get the current directory of the device.
         """
         try:
-            pwd = self.__commandsInterface.pwd()
+            pwd = self.__device.pwd()
             self.currentDir.emit(pwd)
         except Exception as exc:
             self.error.emit("pwd", str(exc))
@@ -123,7 +148,7 @@ class MicroPythonFileManager(QObject):
         @type str
         """
         try:
-            self.__commandsInterface.cd(dirname)
+            self.__device.cd(dirname)
             self.currentDirChanged.emit(dirname)
         except Exception as exc:
             self.error.emit("cd", str(exc))
@@ -143,11 +168,27 @@ class MicroPythonFileManager(QObject):
             # only a local directory was given
             hostFileName = os.path.join(hostFileName, os.path.basename(deviceFileName))
         try:
-            self.__commandsInterface.get(deviceFileName, hostFileName)
+            self.__device.get(deviceFileName, hostFileName)
             self.getFileDone.emit(deviceFileName, hostFileName)
         except Exception as exc:
             self.error.emit("get", str(exc))
 
+    def getData(self, deviceFileName):
+        """
+        Public method to read data from the connected device.
+
+        @param deviceFileName name of the file to read from
+        @type str
+        @return data read from the device
+        @rtype bytes
+        """
+        try:
+            data = self.__device.getData(deviceFileName)
+            return data
+        except Exception as exc:
+            self.error.emit("getData", str(exc))
+            return b""
+
     @pyqtSlot(str)
     @pyqtSlot(str, str)
     def put(self, hostFileName, deviceFileName=""):
@@ -160,11 +201,72 @@ class MicroPythonFileManager(QObject):
         @type str
         """
         try:
-            self.__commandsInterface.put(hostFileName, deviceFileName)
+            self.__device.put(hostFileName, deviceFileName)
             self.putFileDone.emit(hostFileName, deviceFileName)
         except Exception as exc:
             self.error.emit("put", str(exc))
 
+    def putData(self, deviceFileName, data):
+        """
+        Public method to write data to the connected device.
+
+        @param deviceFileName name of the file to write to
+        @type str
+        @param data data to write
+        @type bytes
+        """
+        try:
+            self.__device.putData(deviceFileName, data)
+            self.putDataDone.emit(deviceFileName)
+        except Exception as exc:
+            self.error.emit("putData", str(exc))
+
+    def writeFile(self, filename, text):
+        """
+        Public method to write some text to a file on the connected device.
+
+        @param filename name of the file on the connected device
+        @type str
+        @param text text to be written
+        @type str
+        @return flag indicating success
+        @rtype bool
+        """
+        if self.__device.supportsLocalFileAccess():
+            try:
+                with open(filename, "w") as f:
+                    f.write(text)
+                return True
+            except OSError as exc:
+                self.error.emit("writeFile", str(exc))
+                return False
+        else:
+            try:
+                self.__device.putData(filename, text.encode("utf-8"))
+                self.putDataDone.emit(filename)
+                return True
+            except Exception as exc:
+                self.error.emit("writeFile", str(exc))
+                return False
+
+    def rename(self, oldname, newname):
+        """
+        Public method to rename a file on the device.
+
+        @param oldname current name of the file
+        @type str
+        @param newname new name for the file
+        @type str
+        @return flag indicating success
+        @rtype bool
+        """
+        try:
+            self.__device.rename(oldname, newname)
+            return True
+        except Exception as exc:
+            self.error.emit("rename", str(exc))
+            return False
+
     @pyqtSlot(str)
     def delete(self, deviceFileName):
         """
@@ -174,7 +276,7 @@ class MicroPythonFileManager(QObject):
         @type str
         """
         try:
-            self.__commandsInterface.rm(deviceFileName)
+            self.__device.rm(deviceFileName)
             self.deleteFileDone.emit(deviceFileName)
         except Exception as exc:
             self.error.emit("delete", str(exc))
@@ -241,23 +343,23 @@ class MicroPythonFileManager(QObject):
                     destinationDict[name] = nstat
         else:
             try:
-                destinationFiles = self.__commandsInterface.lls(
-                    deviceDirectory, fullstat=True
-                )
+                if not self.__device.exists(deviceDirectory):
+                    self.__device.mkdir(deviceDirectory)
+                destinationFiles = self.__device.lls(deviceDirectory, fullstat=True)
             except Exception as exc:
                 return [str(exc)]
             if destinationFiles is None:
                 # the destination directory does not exist
                 try:
-                    self.__commandsInterface.mkdir(deviceDirectory)
+                    self.__device.mkdir(deviceDirectory)
                 except Exception as exc:
                     return [str(exc)]
             else:
                 for name, nstat in destinationFiles:
                     destinationDict[name] = nstat
 
-        destinationSet = set(destinationDict.keys())
-        sourceSet = set(sourceDict.keys())
+        destinationSet = set(destinationDict)
+        sourceSet = set(sourceDict)
         toAdd = sourceSet - destinationSet  # add to dev
         toDelete = destinationSet - sourceSet  # delete from dev
         toUpdate = destinationSet.intersection(sourceSet)  # update files
@@ -353,7 +455,7 @@ class MicroPythonFileManager(QObject):
                 )
                 if os.path.isfile(sourceFilename):
                     try:
-                        self.__commandsInterface.put(sourceFilename, destFilename)
+                        self.__device.put(sourceFilename, destFilename)
                     except Exception as exc:
                         # just note issues but ignore them otherwise
                         errors.append(str(exc))
@@ -382,9 +484,7 @@ class MicroPythonFileManager(QObject):
                         )
                     )
                     try:
-                        self.__commandsInterface.rmrf(
-                            destFilename, recursive=True, force=True
-                        )
+                        self.__device.rmrf(destFilename, recursive=True, force=True)
                     except Exception as exc:
                         # just note issues but ignore them otherwise
                         errors.append(str(exc))
@@ -436,9 +536,7 @@ class MicroPythonFileManager(QObject):
                                 )
                             )
                             try:
-                                self.__commandsInterface.put(
-                                    sourceFilename, destFilename
-                                )
+                                self.__device.put(sourceFilename, destFilename)
                             except Exception as exc:
                                 errors.append(str(exc))
 
@@ -480,11 +578,30 @@ class MicroPythonFileManager(QObject):
         @type str
         """
         try:
-            self.__commandsInterface.mkdir(dirname)
+            self.__device.mkdir(dirname)
             self.createDirectoryDone.emit()
         except Exception as exc:
             self.error.emit("mkdir", str(exc))
 
+    @pyqtSlot(str)
+    def makedirs(self, dirname):
+        """
+        Public slot to create a new directory and all intermediates.
+
+        @param dirname name of the directory to create
+        @type str
+        """
+        parts = [d for d in dirname.split("/") if bool(d)]
+        dname = ""
+        try:
+            for part in parts:
+                dname += "/" + part
+                if not self.__device.exists(dname):
+                    self.__device.mkdir(dname)
+            self.createDirectoryDone.emit()
+        except Exception as exc:
+            self.error.emit("makedirs", str(exc))
+
     @pyqtSlot(str)
     @pyqtSlot(str, bool)
     def rmdir(self, dirname, recursive=False):
@@ -498,9 +615,9 @@ class MicroPythonFileManager(QObject):
         """
         try:
             if recursive:
-                self.__commandsInterface.rmrf(dirname, recursive=True, force=True)
+                self.__device.rmrf(dirname, recursive=True, force=True)
             else:
-                self.__commandsInterface.rmdir(dirname)
+                self.__device.rmdir(dirname)
             self.removeDirectoryDone.emit()
         except Exception as exc:
             self.error.emit("rmdir", str(exc))
@@ -511,7 +628,7 @@ class MicroPythonFileManager(QObject):
         systems.
         """
         try:
-            fsinfo = self.__commandsInterface.fileSystemInfo()
+            fsinfo = self.__device.fileSystemInfo()
             self.fsinfoDone.emit(fsinfo)
         except Exception as exc:
             self.error.emit("fileSystemInfo", str(exc))
