@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,7 @@ import os
 import pathlib
 import shutil
 
-from PyQt6.QtCore import QFile, QIODevice, QObject, QUuid, pyqtSignal, pyqtSlot
+from PyQt6.QtCore import QObject, QUuid, pyqtSignal, pyqtSlot
 from PyQt6.QtWidgets import QDialog, QMenu, QToolBar
 
 from eric7 import Preferences
@@ -21,11 +21,11 @@ from eric7.EricGui.EricAction import EricAction, createActionGroup
 from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 from eric7.EricWidgets import EricFileDialog, EricMessageBox, EricPathPickerDialog
 from eric7.EricWidgets.EricPathPickerDialog import EricPathPickerModes
-from eric7.EricXML.MultiProjectReader import MultiProjectReader
 from eric7.Globals import recentNameMultiProject
 from eric7.SystemUtilities import FileSystemUtilities, OSUtilities
 
 from .MultiProjectFile import MultiProjectFile
+from .MultiProjectProjectMeta import MultiProjectProjectMeta
 
 
 class MultiProject(QObject):
@@ -40,11 +40,11 @@ class MultiProject(QObject):
             properties were changed
     @signal showMenu(string, QMenu) emitted when a menu is about to be shown.
             The name of the menu and a reference to the menu are given.
-    @signal projectDataChanged(project data dict) emitted after a project entry
+    @signal projectDataChanged(project metadata) emitted after a project entry
             has been changed
-    @signal projectAdded(project data dict) emitted after a project entry
+    @signal projectAdded(project metadata) emitted after a project entry
             has been added
-    @signal projectRemoved(project data dict) emitted after a project entry
+    @signal projectRemoved(project metadata) emitted after a project entry
             has been removed
     @signal projectOpened(filename) emitted after the project has been opened
     """
@@ -55,19 +55,21 @@ class MultiProject(QObject):
     multiProjectClosed = pyqtSignal()
     multiProjectPropertiesChanged = pyqtSignal()
     showMenu = pyqtSignal(str, QMenu)
-    projectDataChanged = pyqtSignal(dict)
-    projectAdded = pyqtSignal(dict)
-    projectRemoved = pyqtSignal(dict)
+    projectDataChanged = pyqtSignal(MultiProjectProjectMeta)
+    projectAdded = pyqtSignal(MultiProjectProjectMeta)
+    projectRemoved = pyqtSignal(MultiProjectProjectMeta)
     projectOpened = pyqtSignal(str)
 
     def __init__(self, project, parent=None, filename=None):
         """
         Constructor
 
-        @param project reference to the project object (Project.Project)
-        @param parent parent widget (usually the ui object) (QWidget)
+        @param project reference to the project object
+        @type Project.Project
+        @param parent parent widget (usually the ui object)
+        @type QWidget
         @param filename optional filename of a multi project file to open
-            (string)
+        @type str
         """
         super().__init__(parent)
 
@@ -96,14 +98,7 @@ class MultiProject(QObject):
         self.name = ""
         self.opened = False
         self.__projects = {}
-        # dict of project info keyed by 'uid'; each info entry is a dictionary
-        # 'name'        : name of the project
-        # 'file'        : project file name
-        # 'master'      : flag indicating the master
-        #                 project
-        # 'description' : description of the project
-        # 'category'    : name of the group
-        # 'uid'         : unique identifier
+        # dict of project info keyed by 'uid'; each info entry is a MultiProjectProject
         self.categories = []
 
     def __loadRecent(self):
@@ -129,7 +124,8 @@ class MultiProject(QObject):
         """
         Public method to get the most recently opened multiproject.
 
-        @return path of the most recently opened multiproject (string)
+        @return path of the most recently opened multiproject
+        @rtype str
         """
         if len(self.recent):
             return self.recent[0]
@@ -142,7 +138,8 @@ class MultiProject(QObject):
 
         It emits the signal dirty(int).
 
-        @param b dirty state (boolean)
+        @param b dirty state
+        @type bool
         """
         self.__dirty = b
         self.saveAct.setEnabled(b)
@@ -152,7 +149,8 @@ class MultiProject(QObject):
         """
         Public method to return the dirty state.
 
-        @return dirty state (boolean)
+        @return dirty state
+        @rtype bool
         """
         return self.__dirty
 
@@ -160,7 +158,8 @@ class MultiProject(QObject):
         """
         Public method to return the opened state.
 
-        @return open state (boolean)
+        @return open state
+        @rtype bool
         """
         return self.opened
 
@@ -168,7 +167,8 @@ class MultiProject(QObject):
         """
         Public method to get the multi project path.
 
-        @return multi project path (string)
+        @return multi project path
+        @rtype str
         """
         return self.ppath
 
@@ -176,73 +176,39 @@ class MultiProject(QObject):
         """
         Public method to get the path of the multi project file.
 
-        @return path of the multi project file (string)
+        @return path of the multi project file
+        @rtype str
         """
         return self.pfile
 
-    def __checkFilesExist(self):
-        """
-        Private method to check, if the files in a list exist.
-
-        The project files are checked for existance in the
-        filesystem. Non existant projects are removed from the list and the
-        dirty state of the multi project is changed accordingly.
-        """
-        removelist = []
-        for key, project in self.__projects.items():
-            if not os.path.exists(project["file"]):
-                removelist.append(key)
-
-        if removelist:
-            for key in removelist:
-                del self.__projects[key]
-            self.setDirty(True)
-
     def __extractCategories(self):
         """
         Private slot to extract the categories used in the project definitions.
         """
         for project in self.__projects.values():
-            if project["category"] and project["category"] not in self.categories:
-                self.categories.append(project["category"])
+            if project.category and project.category not in self.categories:
+                self.categories.append(project.category)
 
     def getCategories(self):
         """
         Public method to get the list of defined categories.
 
-        @return list of categories (list of string)
+        @return list of categories
+        @rtype list of str
         """
         return [c for c in self.categories if c]
 
     def __readMultiProject(self, fn):
         """
-        Private method to read in a multi project (.emj, .e4m, .e5m) file.
+        Private method to read in a multi project (.emj) file.
 
-        @param fn filename of the multi project file to be read (string)
+        @param fn filename of the multi project file to be read
+        @type str
         @return flag indicating success
+        @rtype bool
         """
-        if os.path.splitext(fn)[1] == ".emj":
-            # new JSON based format
-            with EricOverrideCursor():
-                res = self.__multiProjectFile.readFile(fn)
-        else:
-            # old XML based format
-            f = QFile(fn)
-            if f.open(QIODevice.OpenModeFlag.ReadOnly):
-                with EricOverrideCursor():
-                    reader = MultiProjectReader(f, self)
-                    reader.readXML()
-                    f.close()
-                res = not reader.hasError()
-            else:
-                EricMessageBox.critical(
-                    self.ui,
-                    self.tr("Read Multi Project File"),
-                    self.tr(
-                        "<p>The multi project file <b>{0}</b> could not be read.</p>"
-                    ).format(fn),
-                )
-                res = False
+        with EricOverrideCursor():
+            res = self.__multiProjectFile.readFile(fn)
 
         if res:
             self.pfile = os.path.abspath(fn)
@@ -269,7 +235,9 @@ class MultiProject(QObject):
             is used. This is the 'save' action. If fn is given, this filename
             is used instead of the one in the multi project object. This is the
             'save as' action.
+        @type str
         @return flag indicating success
+        @rtype bool
         """
         if fn is None:
             fn = self.pfile
@@ -291,9 +259,9 @@ class MultiProject(QObject):
         Public method to add a project to the multi-project.
 
         @param project dictionary containing the project data to be added
-        @type dict
+        @type MultiProjectProjectMeta
         """
-        self.__projects[project["uid"]] = project
+        self.__projects[project.uid] = project
 
     @pyqtSlot()
     def addNewProject(self, startdir="", category=""):
@@ -315,35 +283,27 @@ class MultiProject(QObject):
             self.ui, startdir=startdir, categories=self.categories, category=category
         )
         if dlg.exec() == QDialog.DialogCode.Accepted:
-            name, filename, isMaster, description, category, uid = dlg.getData()
+            newProject = dlg.getProjectMetadata()
 
             # step 1: check, if project was already added
             for project in self.__projects.values():
-                if project["file"] == filename:
+                if project.file == newProject.file:
                     return
 
-            # step 2: check, if master should be changed
-            if isMaster:
+            # step 2: check, if main should be changed
+            if newProject.main:
                 for project in self.__projects.values():
-                    if project["master"]:
-                        project["master"] = False
+                    if project.main:
+                        project.main = False
                         self.projectDataChanged.emit(project)
                         self.setDirty(True)
                         break
 
             # step 3: add the project entry
-            project = {
-                "name": name,
-                "file": filename,
-                "master": isMaster,
-                "description": description,
-                "category": category,
-                "uid": uid,
-            }
-            self.__projects[uid] = project
+            self.__projects[newProject.uid] = newProject
             if category not in self.categories:
                 self.categories.append(category)
-            self.projectAdded.emit(project)
+            self.projectAdded.emit(newProject)
             self.setDirty(True)
 
     def copyProject(self, uid):
@@ -358,7 +318,7 @@ class MultiProject(QObject):
             if not startdir:
                 startdir = Preferences.getMultiProject("Workspace")
             srcProject = self.__projects[uid]
-            srcProjectDirectory = os.path.dirname(srcProject["file"])
+            srcProjectDirectory = os.path.dirname(srcProject.file)
             dstProjectDirectory, ok = EricPathPickerDialog.getStrPath(
                 self.parent(),
                 self.tr("Copy Project"),
@@ -385,16 +345,16 @@ class MultiProject(QObject):
                     return
 
                 dstUid = QUuid.createUuid().toString()
-                dstProject = {
-                    "name": self.tr("{0} - Copy").format(srcProject["name"]),
-                    "file": os.path.join(
+                dstProject = MultiProjectProjectMeta(
+                    name=self.tr("{0} - Copy").format(srcProject["name"]),
+                    file=os.path.join(
                         dstProjectDirectory, os.path.basename(srcProject["file"])
                     ),
-                    "master": False,
-                    "description": srcProject["description"],
-                    "category": srcProject["category"],
-                    "uid": dstUid,
-                }
+                    main=False,
+                    description=srcProject.description,
+                    category=srcProject.category,
+                    uid=dstUid,
+                )
                 self.__projects[dstUid] = dstProject
                 self.projectAdded.emit(dstProject)
                 self.setDirty(True)
@@ -403,28 +363,29 @@ class MultiProject(QObject):
         """
         Public method to change the data of a project entry.
 
-        @param pro dictionary with the project data (string)
+        @param pro dictionary with the project data
+        @type str
         """
-        # step 1: check, if master should be changed
-        if pro["master"]:
+        # step 1: check, if main should be changed
+        if pro.main:
             for project in self.__projects.values():
-                if project["master"]:
-                    if project["uid"] != pro["uid"]:
-                        project["master"] = False
+                if project.main:
+                    if project.uid != pro.uid:
+                        project.main = False
                         self.projectDataChanged.emit(project)
                         self.setDirty(True)
                     break
 
         # step 2: change the entry
-        project = self.__projects[pro["uid"]]
+        project = self.__projects[pro.uid]
         # project UID is not changeable via interface
-        project["file"] = pro["file"]
-        project["name"] = pro["name"]
-        project["master"] = pro["master"]
-        project["description"] = pro["description"]
-        project["category"] = pro["category"]
-        if project["category"] not in self.categories:
-            self.categories.append(project["category"])
+        project.file = pro.file
+        project.name = pro.name
+        project.main = pro.main
+        project.description = pro.description
+        project.category = pro.category
+        if project.category not in self.categories:
+            self.categories.append(project.category)
         self.projectDataChanged.emit(project)
         self.setDirty(True)
 
@@ -432,7 +393,8 @@ class MultiProject(QObject):
         """
         Public method to get all project entries.
 
-        @return list of all project entries (list of dictionaries)
+        @return list of all project entries
+        @rtype list of MultiProjectProjectMeta
         """
         return self.__projects.values()
 
@@ -442,8 +404,8 @@ class MultiProject(QObject):
 
         @param uid UID of the project to get
         @type str
-        @return dictionary containing the project data
-        @rtype dict
+        @return project metadata
+        @rtype MultiProjectProjectMeta
         """
         if uid in self.__projects:
             return self.__projects[uid]
@@ -474,8 +436,8 @@ class MultiProject(QObject):
         """
         if uid in self.__projects:
             project = self.__projects[uid]
-            projectPath = os.path.dirname(project["file"])
-            shutil.rmtree(projectPath, True)
+            projectPath = os.path.dirname(project.file)
+            shutil.rmtree(projectPath, ignore_errors=True)
 
             self.removeProject(uid)
 
@@ -517,14 +479,14 @@ class MultiProject(QObject):
 
     @pyqtSlot()
     @pyqtSlot(str)
-    def openMultiProject(self, fn=None, openMaster=True):
+    def openMultiProject(self, fn=None, openMain=True):
         """
         Public slot to open a multi project.
 
         @param fn optional filename of the multi project file to be
             read
         @type str
-        @param openMaster flag indicating, that the master project
+        @param openMain flag indicating, that the main project
             should be opened depending on the configuration
         @type bool
         """
@@ -536,10 +498,7 @@ class MultiProject(QObject):
                 self.parent(),
                 self.tr("Open Multi Project"),
                 Preferences.getMultiProject("Workspace") or OSUtilities.getHomeDir(),
-                self.tr(
-                    "Multi Project Files (*.emj);;"
-                    "XML Multi Project Files (*.e5m *.e4m)"
-                ),
+                self.tr("Multi Project Files (*.emj)"),
             )
 
             if fn == "":
@@ -558,10 +517,8 @@ class MultiProject(QObject):
 
                 self.multiProjectOpened.emit()
 
-                if openMaster and Preferences.getMultiProject(
-                    "OpenMasterAutomatically"
-                ):
-                    self.__openMasterProject(False)
+                if openMain and Preferences.getMultiProject("OpenMainAutomatically"):
+                    self.__openMainProject(False)
 
     def saveMultiProject(self):
         """
@@ -572,11 +529,6 @@ class MultiProject(QObject):
         """
         if self.isDirty():
             if len(self.pfile) > 0:
-                if self.pfile.endswith((".e4m", ".e5m")):
-                    self.pfile = self.pfile.replace(".e4m", ".emj").replace(
-                        ".e5m", ".emj"
-                    )
-                    self.__syncRecent()
                 ok = self.__writeMultiProject()
             else:
                 ok = self.saveMultiProjectAs()
@@ -617,7 +569,7 @@ class MultiProject(QObject):
                     self.parent(),
                     self.tr("Save File"),
                     self.tr(
-                        "<p>The file <b>{0}</b> already exists." " Overwrite it?</p>"
+                        "<p>The file <b>{0}</b> already exists. Overwrite it?</p>"
                     ).format(fn),
                     icon=EricMessageBox.Warning,
                 )
@@ -637,7 +589,8 @@ class MultiProject(QObject):
         """
         Public method to check the dirty status and open a message window.
 
-        @return flag indicating whether this operation was successful (boolean)
+        @return flag indicating whether this operation was successful
+        @rtype bool
         """
         if self.isDirty():
             res = EricMessageBox.okToClearData(
@@ -656,7 +609,8 @@ class MultiProject(QObject):
         """
         Public slot to close the current multi project.
 
-        @return flag indicating success (boolean)
+        @return flag indicating success
+        @rtype bool
         """
         # save the list of recently opened projects
         self.__saveRecent()
@@ -671,7 +625,7 @@ class MultiProject(QObject):
         pfile = self.projectObject.getProjectFile()
         if pfile:
             for project in self.__projects.values():
-                if project["file"] == pfile:
+                if project.file == pfile:
                     if not self.projectObject.closeProject():
                         return False
                     break
@@ -826,17 +780,40 @@ class MultiProject(QObject):
         self.propsAct.triggered.connect(self.__showProperties)
         self.actions.append(self.propsAct)
 
+        self.clearRemovedAct = EricAction(
+            self.tr("Clear Out"),
+            EricPixmapCache.getIcon("clear"),
+            self.tr("Clear Out"),
+            0,
+            0,
+            self,
+            "multi_project_clearout",
+        )
+        self.clearRemovedAct.setStatusTip(
+            self.tr("Remove all projects marked as removed")
+        )
+        self.clearRemovedAct.setWhatsThis(
+            self.tr(
+                """<b>Clear Out...</b>"""
+                """<p>This removes all projects marked as removed.</p>"""
+            )
+        )
+        self.clearRemovedAct.triggered.connect(self.clearRemovedProjects)
+        self.actions.append(self.clearRemovedAct)
+
         self.closeAct.setEnabled(False)
         self.saveAct.setEnabled(False)
         self.saveasAct.setEnabled(False)
         self.addProjectAct.setEnabled(False)
         self.propsAct.setEnabled(False)
+        self.clearRemovedAct.setEnabled(False)
 
     def initMenu(self):
         """
         Public slot to initialize the multi project menu.
 
-        @return the menu generated (QMenu)
+        @return the menu generated
+        @rtype QMenu
         """
         menu = QMenu(self.tr("&Multiproject"), self.parent())
         self.recentMenu = QMenu(self.tr("Open &Recent Multiprojects"), menu)
@@ -863,6 +840,8 @@ class MultiProject(QObject):
         menu.addSeparator()
         menu.addAction(self.addProjectAct)
         menu.addSeparator()
+        menu.addAction(self.clearRemovedAct)
+        menu.addSeparator()
         menu.addAction(self.propsAct)
 
         self.menu = menu
@@ -873,8 +852,9 @@ class MultiProject(QObject):
         Public slot to initialize the multi project toolbar.
 
         @param toolbarManager reference to a toolbar manager object
-            (EricToolBarManager)
-        @return the toolbar generated (QToolBar)
+        @type EricToolBarManager
+        @return the toolbar generated
+        @rtype QToolBar
         """
         tb = QToolBar(self.tr("Multiproject"), self.ui)
         tb.setObjectName("MultiProjectToolbar")
@@ -889,6 +869,7 @@ class MultiProject(QObject):
         toolbarManager.addToolBar(tb, tb.windowTitle())
         toolbarManager.addAction(self.addProjectAct, tb.windowTitle())
         toolbarManager.addAction(self.propsAct, tb.windowTitle())
+        toolbarManager.addAction(self.clearRemovedAct, tb.windowTitle())
 
         return tb
 
@@ -940,7 +921,8 @@ class MultiProject(QObject):
         Private method to open a multi project from the list of rencently
         opened multi projects.
 
-        @param act reference to the action that triggered (QAction)
+        @param act reference to the action that triggered
+        @type QAction
         """
         file = act.data()
         if file:
@@ -957,7 +939,8 @@ class MultiProject(QObject):
         """
         Public method to get a list of all actions.
 
-        @return list of all actions (list of EricAction)
+        @return list of all actions
+        @rtype list of EricAction
         """
         return self.actions[:]
 
@@ -965,7 +948,8 @@ class MultiProject(QObject):
         """
         Public method to add actions to the list of actions.
 
-        @param actions list of actions (list of EricAction)
+        @param actions list of actions
+        @type list of EricAction
         """
         self.actions.extend(actions)
 
@@ -973,7 +957,8 @@ class MultiProject(QObject):
         """
         Public method to remove actions from the list of actions.
 
-        @param actions list of actions (list of EricAction)
+        @param actions list of actions
+        @type list of EricAction
         """
         for act in actions:
             with contextlib.suppress(ValueError):
@@ -983,8 +968,10 @@ class MultiProject(QObject):
         """
         Public method to get a reference to the main menu or a submenu.
 
-        @param menuName name of the menu (string)
-        @return reference to the requested menu (QMenu) or None
+        @param menuName name of the menu
+        @type str
+        @return reference to the requested menu
+        @rtype QMenu or None
         """
         try:
             return self.__menus[menuName]
@@ -995,36 +982,43 @@ class MultiProject(QObject):
         """
         Public slot to open a project.
 
-        @param filename filename of the project file (string)
+        @param filename filename of the project file
+        @type str
         """
         self.projectObject.openProject(filename)
         self.projectOpened.emit(filename)
 
-    def __openMasterProject(self, reopen=True):
+    def __openMainProject(self, reopen=True):
         """
-        Private slot to open the master project.
+        Private slot to open the main project.
 
-        @param reopen flag indicating, that the master project should be
-            reopened, if it has been opened already (boolean)
+        @param reopen flag indicating, that the main project should be
+            reopened, if it has been opened already
+        @type bool
         """
         for project in self.__projects.values():
-            if project["master"] and (
-                reopen
-                or not self.projectObject.isOpen()
-                or self.projectObject.getProjectFile() != project["file"]
+            if (
+                project.main
+                and not project.removed
+                and (
+                    reopen
+                    or not self.projectObject.isOpen()
+                    or self.projectObject.getProjectFile() != project.file
+                )
             ):
-                self.openProject(project["file"])
+                self.openProject(project.file)
                 return
 
-    def getMasterProjectFile(self):
+    def getMainProjectFile(self):
         """
-        Public method to get the filename of the master project.
+        Public method to get the filename of the main project.
 
-        @return name of the master project file (string)
+        @return name of the main project file
+        @rtype str
         """
         for project in self.__projects:
-            if project["master"]:
-                return project["file"]
+            if project.main:
+                return project.file
 
         return None
 
@@ -1032,10 +1026,43 @@ class MultiProject(QObject):
         """
         Public method to get the filenames of the dependent projects.
 
-        @return names of the dependent project files (list of strings)
+        @return names of the dependent project files
+        @rtype list of str
         """
         files = []
         for project in self.__projects.values():
-            if not project["master"]:
-                files.append(project["file"])
+            if not project.main:
+                files.append(project.file)
         return files
+
+    def __checkFilesExist(self):
+        """
+        Private method to check, if the files in a list exist.
+
+        The project files are checked for existance in the
+        filesystem. Non existant projects are removed from the list and the
+        dirty state of the multi project is changed accordingly.
+        """
+        for project in self.__projects.values():
+            project.removed = not os.path.exists(project.file)
+            self.clearRemovedAct.setEnabled(True)
+
+    @pyqtSlot()
+    def clearRemovedProjects(self):
+        """
+        Public slot to clear out all projects marked as removed.
+        """
+        for key in list(self.__projects.keys()):
+            if self.__projects[key].removed:
+                self.removeProject(key)
+
+        self.clearRemovedAct.setEnabled(False)
+
+    def hasRemovedProjects(self):
+        """
+        Public method to check for removed projects.
+
+        @return flag indicating the existence of a removed project
+        @rtype bool
+        """
+        return any(p.removed for p in self.__projects.values())
