@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -30,9 +30,11 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         Constructor
 
         @param manager reference to the IRC network manager object
-            (IrcNetworkManager)
-        @param identityName name of the identity to be selected (string)
-        @param parent reference to the parent widget (QWidget)
+        @type IrcNetworkManager
+        @param identityName name of the identity to be selected
+        @type str
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -73,9 +75,12 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         """
         Public method to handle events for other objects.
 
-        @param obj reference to the object (QObject)
-        @param evt reference to the event (QEvent)
-        @return flag indicating that the event should be filtered out (boolean)
+        @param obj reference to the object
+        @type QObject
+        @param evt reference to the event
+        @type QEvent
+        @return flag indicating that the event should be filtered out
+        @rtype bool
         """
         if (
             obj == self.nicknameEdit
@@ -174,7 +179,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         """
         Private method to check the data for the current identity.
 
-        @return flag indicating a successful check (boolean)
+        @return flag indicating a successful check
+        @rtype bool
         """
         if self.nicknamesList.count() == 0:
             EricMessageBox.critical(
@@ -411,7 +417,8 @@ class IrcIdentitiesEditDialog(QDialog, Ui_IrcIdentitiesEditDialog):
         """
         Private slot handling a change of the nick name.
 
-        @param nick new nick name (string)
+        @param nick new nick name
+        @type str
         """
         sel = self.nicknamesList.selectedItems()
         if sel:
