@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the IRC window.
 """
 
+import enum
 import logging
 import re
 
@@ -36,6 +37,16 @@ from .IrcNetworkManager import IrcNetworkManager
 from .Ui_IrcWidget import Ui_IrcWidget
 
 
+class IrcConnectionState(enum.Enum):
+    """
+    Class defining the connection states.
+    """
+
+    Disconnected = 1
+    Connected = 2
+    Connecting = 3
+
+
 class IrcWidget(QWidget, Ui_IrcWidget):
     """
     Class implementing the IRC window.
@@ -45,15 +56,12 @@ class IrcWidget(QWidget, Ui_IrcWidget):
 
     autoConnected = pyqtSignal()
 
-    ServerDisconnected = 1
-    ServerConnected = 2
-    ServerConnecting = 3
-
     def __init__(self, parent=None):
         """
         Constructor
 
-        @param parent reference to the parent widget (QWidget)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -85,7 +93,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         self.__server = None
         self.__registering = False
 
-        self.__connectionState = IrcWidget.ServerDisconnected
+        self.__connectionState = IrcConnectionState.Disconnected
         self.__sslErrorLock = False
 
         self.__buffer = ""
@@ -133,7 +141,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Public method to shut down the widget.
 
-        @return flag indicating successful shutdown (boolean)
+        @return flag indicating successful shutdown
+        @rtype bool
         """
         if self.__server:
             if Preferences.getIrc("AskOnShutdown"):
@@ -168,9 +177,12 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot to connect to or disconnect from the given network.
 
-        @param name name of the network to connect to (string)
-        @param connect flag indicating to connect (boolean)
-        @param silent flag indicating a silent connect/disconnect (boolean)
+        @param name name of the network to connect to
+        @type str
+        @param connect flag indicating to connect
+        @type bool
+        @param silent flag indicating a silent connect/disconnect
+        @type bool
         """
         if connect:
             network = self.__ircNetworkManager.getNetwork(name)
@@ -210,7 +222,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                         self.__socket.readyRead.connect(self.__readyRead)
                         self.__socket.errorOccurred.connect(self.__tcpError)
 
-                        self.__connectionState = IrcWidget.ServerConnecting
+                        self.__connectionState = IrcConnectionState.Connecting
                         if useSSL:
                             self.networkWidget.addServerMessage(
                                 self.tr("Info"),
@@ -278,11 +290,10 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                 self.__identityName = ""
                 self.__quitMessage = ""
 
-    def __editNetwork(self, name):
+    @pyqtSlot()
+    def __editNetwork(self):
         """
         Private slot to edit the network configuration.
-
-        @param name name of the network to edit (string)
         """
         from .IrcNetworkListDialog import IrcNetworkListDialog
 
@@ -303,8 +314,10 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Public slot to join a channel.
 
-        @param name name of the channel (string)
-        @param key key of the channel (string)
+        @param name name of the channel
+        @type str
+        @param key key of the channel
+        @type str
         """
         from .IrcChannelWidget import IrcChannelWidget
 
@@ -352,7 +365,9 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to handle a new private connection.
 
         @param match reference to the match object
-        @return flag indicating, if the message was handled (boolean)
+        @type re.Match
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         # group(1)   sender user name
         # group(2)   sender user@host
@@ -374,7 +389,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot to open a private chat with the given user.
 
-        @param name name of the user (string)
+        @param name name of the user
+        @type str
         """
         from .IrcChannelWidget import IrcChannelWidget
 
@@ -450,9 +466,10 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot handling the closing of a channel.
 
-        @param name name of the closed channel (string)
+        @param name name of the closed channel
+        @type str
         """
-        for channel in self.__channelList:
+        for channel in self.__channelList[:]:
             if channel.name() == name:
                 self.channelsWidget.removeTab(self.channelsWidget.indexOf(channel))
                 self.__channelList.remove(channel)
@@ -470,7 +487,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private slot to close a channel by pressing the close button of
         the channels widget.
 
-        @param index index of the tab to be closed (integer)
+        @param index index of the tab to be closed
+        @type int
         """
         channel = self.channelsWidget.widget(index)
         channel.requestLeave()
@@ -479,7 +497,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot to send data to the IRC server.
 
-        @param data data to be sent (string)
+        @param data data to be sent
+        @type str
         """
         if self.__socket:
             self.__socket.write(QByteArray("{0}\r\n".format(data).encode("utf-8")))
@@ -574,7 +593,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                 self.__socket.deleteLater()
             self.__socket = None
 
-            self.__connectionState = IrcWidget.ServerDisconnected
+            self.__connectionState = IrcConnectionState.Disconnected
             self.__sslErrorLock = False
 
     def __readyRead(self):
@@ -620,6 +639,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to handle a server message containing a CTCP reply.
 
         @param match reference to the match object
+        @type re.Match
         """
         if "!" in match.group(1):
             sender = match.group(1).split("!", 1)[0]
@@ -659,7 +679,9 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to handle a server message containing a message name.
 
         @param match reference to the match object
-        @return flag indicating, if the message was handled (boolean)
+        @type re.Match
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         name = match.group(2)
         if name == "NOTICE":
@@ -741,22 +763,26 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to handle a server message containing a numeric code.
 
         @param match reference to the match object
-        @return flag indicating, if the message was handled (boolean)
+        @type re.Match
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         code = int(match.group(2))
         if code < 400:
             return self.__handleServerReply(code, match.group(1), match.group(3))
         else:
-            return self.__handleServerError(code, match.group(1), match.group(3))
+            return self.__handleServerError(code, match.group(3))
 
-    def __handleServerError(self, code, server, message):
+    def __handleServerError(self, code, message):
         """
         Private slot to handle a server error reply.
 
-        @param code numerical code sent by the server (integer)
-        @param server name of the server (string)
-        @param message message sent by the server (string)
-        @return flag indicating, if the message was handled (boolean)
+        @param code numerical code sent by the server
+        @type int
+        @param message message sent by the server
+        @type str
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         if code == 433:
             if self.__registering:
@@ -772,10 +798,14 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot to handle a server reply.
 
-        @param code numerical code sent by the server (integer)
-        @param server name of the server (string)
-        @param message message sent by the server (string)
-        @return flag indicating, if the message was handled (boolean)
+        @param code numerical code sent by the server
+        @type int
+        @param server name of the server
+        @type str
+        @param message message sent by the server
+        @type str
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         # determine message type
         if code in [1, 2, 3, 4]:
@@ -826,7 +856,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
 
         if code == 1:
             # register with services after the welcome message
-            self.__connectionState = IrcWidget.ServerConnected
+            self.__connectionState = IrcConnectionState.Connected
             self.__registerWithServices()
             self.networkWidget.setRegistered(True)
             QTimer.singleShot(1000, self.__autoJoinChannels)
@@ -871,7 +901,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private slot to handle errors reported by the TCP socket.
 
         @param error error code reported by the socket
-            (QAbstractSocket.SocketError)
+        @type QAbstractSocket.SocketError
         """
         if error == QAbstractSocket.SocketError.RemoteHostClosedError:
             # ignore this one, it's a disconnect
@@ -883,7 +913,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                         """ waiting for user response to an SSL error."""
                     ).format(self.__server.getName(), self.__server.getPort()),
                 )
-                self.__connectionState = IrcWidget.ServerDisconnected
+                self.__connectionState = IrcConnectionState.Disconnected
         elif error == QAbstractSocket.SocketError.HostNotFoundError:
             self.networkWidget.addErrorMessage(
                 self.tr("Socket Error"),
@@ -921,7 +951,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot to handle SSL errors.
 
-        @param errors list of SSL errors (list of QSslError)
+        @param errors list of SSL errors
+        @type list of QSslError
         """
         ignored, defaultChanged = self.__sslErrorHandler.sslErrors(
             errors, self.__server.getName(), self.__server.getPort()
@@ -951,15 +982,17 @@ class IrcWidget(QWidget, Ui_IrcWidget):
                         """ were accepted by you."""
                     ).format(self.__server.getName(), self.__server.getPort()),
                 )
-            if self.__connectionState == IrcWidget.ServerConnecting:
+            if self.__connectionState == IrcConnectionState.Connecting:
                 self.__socket.ignoreSslErrors()
 
     def __setUserPrivilegePrefix(self, prefix1, prefix2):
         """
         Private method to set the user privilege prefix.
 
-        @param prefix1 first part of the prefix (string)
-        @param prefix2 indictors the first part gets mapped to (string)
+        @param prefix1 first part of the prefix
+        @type str
+        @param prefix2 indictors the first part gets mapped to
+        @type str
         """
         # PREFIX=(ov)@+
         # o = @ -> @ircbot , channel operator
@@ -973,7 +1006,9 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to handle a PING message.
 
         @param match reference to the match object
-        @return flag indicating, if the message was handled (boolean)
+        @type re.Match
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         self.__send("PONG " + match.group(1))
         return True
@@ -983,7 +1018,9 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         Private method to handle a CTCP command.
 
         @param match reference to the match object
-        @return flag indicating, if the message was handled (boolean)
+        @type re.Match
+        @return flag indicating, if the message was handled
+        @rtype bool
         """
         # group(1)   sender user name
         # group(2)   sender user@host
@@ -1095,7 +1132,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot to use a new nick name.
 
-        @param nick nick name to use (str)
+        @param nick nick name to use
+        @type str
         """
         if nick and nick != self.__nickName:
             self.__send("NICK " + nick)
@@ -1104,7 +1142,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private method to set the channel type prefixes.
 
-        @param prefixes channel prefix characters (string)
+        @param prefixes channel prefix characters
+        @type str
         """
         self.__channelTypePrefixes = prefixes
 
@@ -1112,8 +1151,10 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Public method to check, if the given name is a channel name.
 
-        @param name name to check (string)
-        @return flag indicating a channel name (boolean)
+        @param name name to check
+        @type str
+        @return flag indicating a channel name
+        @rtype bool
         """
         if not name:
             return False
@@ -1127,7 +1168,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         Private slot handling the change of the away state.
 
-        @param isAway flag indicating the current away state (boolean)
+        @param isAway flag indicating the current away state
+        @type bool
         """
         if isAway and self.__identityName:
             identity = self.__ircNetworkManager.getIdentity(self.__identityName)
