@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,19 +8,28 @@ Package implementing the pip GUI logic.
 """
 
 import contextlib
+import functools
 import json
 import os
 import sys
 
 from PyQt6.QtCore import QCoreApplication, QObject, QProcess, QThread, QUrl, pyqtSlot
-from PyQt6.QtNetwork import QNetworkAccessManager, QNetworkReply, QNetworkRequest
+from PyQt6.QtNetwork import (
+    QNetworkAccessManager,
+    QNetworkProxyFactory,
+    QNetworkReply,
+    QNetworkRequest,
+)
 from PyQt6.QtWidgets import QDialog, QInputDialog, QLineEdit
 
 from eric7 import Preferences
-from eric7.EricNetwork.EricNetworkProxyFactory import proxyAuthenticationRequired
+from eric7.EricNetwork.EricNetworkProxyFactory import (
+    EricNetworkProxyFactory,
+    proxyAuthenticationRequired,
+)
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
-from eric7.SystemUtilities import OSUtilities, PythonUtilities
+from eric7.SystemUtilities import FileSystemUtilities, OSUtilities, PythonUtilities
 from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
 try:
@@ -56,6 +65,13 @@ class Pip(QObject):
         self.__ui = parent
 
         # attributes for the network objects
+        if Preferences.getUI("UseSystemProxy"):
+            QNetworkProxyFactory.setUseSystemConfiguration(True)
+        else:
+            self.__proxyFactory = EricNetworkProxyFactory()
+            QNetworkProxyFactory.setApplicationProxyFactory(self.__proxyFactory)
+            QNetworkProxyFactory.setUseSystemConfiguration(False)
+
         self.__networkManager = QNetworkAccessManager(self)
         self.__networkManager.proxyAuthenticationRequired.connect(
             proxyAuthenticationRequired
@@ -129,7 +145,7 @@ class Pip(QObject):
                 process.waitForFinished(2000)
                 process.kill()
                 process.waitForFinished(3000)
-                return False, self.tr("python did not finish within" " 30 seconds.")
+                return False, self.tr("python did not finish within 30 seconds.")
 
         return False, self.tr("python could not be started.")
 
@@ -189,9 +205,13 @@ class Pip(QObject):
         @return string for the project environment
         @rtype str
         """
-        if ericApp().getObject("Project").isOpen():
-            return self.tr("<project>")
-        else:
+        try:
+            project = ericApp().getObject("Project")
+            if project.isOpen():
+                return self.tr("<project>")
+            else:
+                return ""
+        except KeyError:
             return ""
 
     def getVirtualenvInterpreter(self, venvName):
@@ -319,7 +339,7 @@ class Pip(QObject):
             p
             for p in packages
             if p.lower()
-            in [
+            in (
                 "pyqt6",
                 "pyqt6-sip",
                 "pyqt6-webengine",
@@ -328,7 +348,7 @@ class Pip(QObject):
                 "pyqt6-qt6",
                 "pyqt6-webengine-qt6",
                 "pyqt6-charts-qt6",
-            ]
+            )
         ]
         return bool(pyqtPackages)
 
@@ -345,6 +365,33 @@ class Pip(QObject):
         ericPackages = [p for p in packages if p.lower() == "eric-ide"]
         return bool(ericPackages)
 
+    def __filterUpgradePackages(self, packages):
+        """
+        Private method to filter out the packages that cannot be upgraded without
+        stopping eric first.
+
+        @param packages list of packages to upgrade
+        @type list of str
+        @return list of packages that can be upgraded
+        @rtype list of str
+        """
+        return [
+            p
+            for p in packages
+            if p.lower()
+            not in (
+                "eric-ide",
+                "pyqt6",
+                "pyqt6-sip",
+                "pyqt6-webengine",
+                "pyqt6-charts",
+                "pyqt6-qscintilla",
+                "pyqt6-qt6",
+                "pyqt6-webengine-qt6",
+                "pyqt6-charts-qt6",
+            )
+        ]
+
     def upgradePackages(self, packages, venvName, userSite=False):
         """
         Public method to upgrade the given list of packages.
@@ -362,28 +409,32 @@ class Pip(QObject):
         if not venvName:
             return False
 
-        if self.getVirtualenvInterpreter(venvName) in (
-            sys.executable,
-            PythonUtilities.getPythonExecutable(),
+        interpreter = self.getVirtualenvInterpreter(venvName)
+        if not interpreter:
+            return False
+
+        if FileSystemUtilities.samefilepath(
+            interpreter, sys.executable, followSymlinks=False
         ):
             upgradePyQt = self.__checkUpgradePyQt(packages)
             upgradeEric = self.__checkUpgradeEric(packages)
             if upgradeEric or upgradePyQt:
                 try:
                     if upgradeEric and upgradePyQt:
-                        self.__ui.upgradeEricPyQt()
+                        res = self.__ui.upgradeEricPyQt()
                     elif upgradeEric:
-                        self.__ui.upgradeEric()
+                        res = self.__ui.upgradeEric()
                     elif upgradePyQt:
-                        self.__ui.upgradePyQt()
-                    return None  # should not be reached; play it safe
+                        res = self.__ui.upgradePyQt()
+                    else:
+                        return None  # should not be reached; play it safe
+
+                    if not res:
+                        # user rejected PyQt6 and/or eric-ide/eric7 update
+                        packages = self.__filterUpgradePackages(packages)
                 except AttributeError:
                     return False
 
-        interpreter = self.getVirtualenvInterpreter(venvName)
-        if not interpreter:
-            return False
-
         if Preferences.getPip("PipSearchIndex"):
             indexUrl = Preferences.getPip("PipSearchIndex") + "/simple"
             args = ["-m", "pip", "install", "--index-url", indexUrl, "--upgrade"]
@@ -650,28 +701,26 @@ class Pip(QObject):
                 proc = QProcess()
                 proc.start(interpreter, args)
                 if proc.waitForStarted(15000) and proc.waitForFinished(30000):
-                    output = (
-                        str(
-                            proc.readAllStandardOutput(),
-                            Preferences.getSystem("IOEncoding"),
-                            "replace",
-                        )
-                        .strip()
-                        .splitlines()[0]
-                    )
-                    try:
-                        jsonList = json.loads(output)
-                    except Exception:
-                        jsonList = []
+                    output = str(
+                        proc.readAllStandardOutput(),
+                        Preferences.getSystem("IOEncoding"),
+                        "replace",
+                    ).strip()
+                    if output:
+                        output = output.splitlines()[0]
+                        try:
+                            jsonList = json.loads(output)
+                        except Exception:
+                            jsonList = []
 
-                    for package in jsonList:
-                        if isinstance(package, dict):
-                            packages.append(
-                                (
-                                    package["name"],
-                                    package["version"],
+                        for package in jsonList:
+                            if isinstance(package, dict):
+                                packages.append(
+                                    (
+                                        package["name"],
+                                        package["version"],
+                                    )
                                 )
-                            )
 
         return packages
 
@@ -682,6 +731,7 @@ class Pip(QObject):
         notRequired=False,
         usersite=False,
         interpreter=None,
+        callback=None,
     ):
         """
         Public method to get the list of outdated packages.
@@ -700,6 +750,9 @@ class Pip(QObject):
         @param interpreter path of an interpreter executable. If this is not
             None, it will override the given environment name (defaults to None)
         @type str (optional)
+        @param callback method accepting a list of tuples containing the
+            package name, installed version and available version
+        @type function
         @return list of tuples containing the package name, installed version
             and available version
         @rtype list of tuple of (str, str, str)
@@ -729,34 +782,78 @@ class Pip(QObject):
                     args += ["--index-url", indexUrl]
 
                 proc = QProcess()
+                if callback:
+                    self.__outdatedProc = proc
+                    proc.finished.connect(
+                        functools.partial(self.__outdatedFinished, callback, proc)
+                    )
+                    proc.start(interpreter, args)
+                    return None
+
                 proc.start(interpreter, args)
                 if proc.waitForStarted(15000) and proc.waitForFinished(30000):
-                    output = (
-                        str(
-                            proc.readAllStandardOutput(),
-                            Preferences.getSystem("IOEncoding"),
-                            "replace",
-                        )
-                        .strip()
-                        .splitlines()[0]
-                    )
-                    try:
-                        jsonList = json.loads(output)
-                    except Exception:
-                        jsonList = []
-
-                    for package in jsonList:
-                        if isinstance(package, dict):
-                            packages.append(
-                                (
-                                    package["name"],
-                                    package["version"],
-                                    package["latest_version"],
-                                )
-                            )
+                    packages = self.__extractOutdatedPackages(proc)
 
         return packages
 
+    def __extractOutdatedPackages(self, proc):
+        """
+        Private method to extract the outdated packages list out of the process output.
+
+        @param proc reference to the process
+        @type QProcess
+        @return list of tuples containing the package name, installed version
+            and available version
+        @rtype list of tuple of (str, str, str)
+        """
+        packages = []
+
+        output = str(
+            proc.readAllStandardOutput(),
+            Preferences.getSystem("IOEncoding"),
+            "replace",
+        ).strip()
+        if output:
+            output = output.splitlines()[0]
+            try:
+                jsonList = json.loads(output)
+            except Exception:
+                jsonList = []
+
+            for package in jsonList:
+                if isinstance(package, dict):
+                    packages.append(
+                        (
+                            package["name"],
+                            package["version"],
+                            package["latest_version"],
+                        )
+                    )
+
+        return packages
+
+    def __outdatedFinished(self, callback, proc, exitCode, exitStatus):
+        """
+        Private method to handle the process finished signal.
+
+        @param callback reference to the function to be called with the list of
+            outdated packages
+        @type function
+        @param proc reference to the process
+        @type QProcess
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
+        """
+        packages = (
+            self.__extractOutdatedPackages(proc)
+            if exitStatus == QProcess.ExitStatus.NormalExit and exitCode == 0
+            else []
+        )
+        callback(packages)
+        self.__outdatedProc = None
+
     def checkPackagesOutdated(self, packageStarts, envName, interpreter=None):
         """
         Public method to check, if groups of packages are outdated.
@@ -844,7 +941,7 @@ class Pip(QObject):
                 )
                 with contextlib.suppress(json.JSONDecodeError, KeyError):
                     data = json.loads(dataStr)
-                    result = list(data["releases"].keys())
+                    result = list(data["releases"])
 
         return result
 
@@ -1019,10 +1116,7 @@ class Pip(QObject):
         if envName:
             interpreter = self.getVirtualenvInterpreter(envName)
             if interpreter:
-                args = [
-                    os.path.join(os.path.dirname(__file__), "pipdeptree.py"),
-                    "--json-tree",
-                ]
+                args = ["-m", "pipdeptree", "--python", interpreter, "--json-tree"]
                 if localPackages:
                     args.append("--local-only")
                 if usersite:
@@ -1031,7 +1125,7 @@ class Pip(QObject):
                     args.append("--reverse")
 
                 proc = QProcess()
-                proc.start(interpreter, args)
+                proc.start(PythonUtilities.getPythonExecutable(), args)
                 if proc.waitForStarted(15000) and proc.waitForFinished(30000):
                     output = str(
                         proc.readAllStandardOutput(),
@@ -1047,21 +1141,12 @@ class Pip(QObject):
     ## License handling methods below
     #######################################################################
 
-    def getLicenses(self, envName, localPackages=True, usersite=False, summary=False):
+    def getLicenses(self, envName):
         """
         Public method to get the licenses per package for a given environment.
 
         @param envName name of the environment to get the licenses for
         @type str
-        @param localPackages flag indicating to get the licenses for local
-            packages only
-        @type bool
-        @param usersite flag indicating to get the licenses for packages
-            installed in user-site directory only
-        @type bool
-        @param summary flag indicating to get a summary listing (defaults to
-            False)
-        @type bool (optional)
         @return list of dictionaries containing the license and version per
             package
         @rtype dict
@@ -1071,7 +1156,6 @@ class Pip(QObject):
         if envName:
             interpreter = self.getVirtualenvInterpreter(envName)
             if interpreter:
-
                 args = [
                     os.path.join(os.path.dirname(__file__), "piplicenses.py"),
                     "--from",
@@ -1081,12 +1165,6 @@ class Pip(QObject):
                     "--with-urls",
                     "--with-description",
                 ]
-                if localPackages:
-                    args.append("--local-only")
-                if usersite:
-                    args.append("--user-only")
-                if summary:
-                    args.append("--summary-by-license")
 
                 proc = QProcess()
                 proc.start(interpreter, args)
@@ -1100,24 +1178,3 @@ class Pip(QObject):
                         licenses = json.loads(output)
 
         return licenses
-
-    def getLicensesSummary(self, envName, localPackages=True, usersite=False):
-        """
-        Public method to get a summary of licenses found in a given
-        environment.
-
-        @param envName name of the environment to get the licenses summary for
-        @type str
-        @param localPackages flag indicating to get the licenses summary for
-            local packages only
-        @type bool
-        @param usersite flag indicating to get the licenses summary for
-            packages installed in user-site directory only
-        @type bool
-        @return list of dictionaries containing the license and the count of
-            packages
-        @rtype dict
-        """
-        return self.getLicenses(
-            envName, localPackages=localPackages, usersite=usersite, summary=True
-        )
