@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -48,9 +48,12 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         Constructor
 
         @param pluginManager reference to the plugin manager object
+        @type PluginManager
         @param pluginFileNames list of plugin files suggested for
-            installation (list of strings)
-        @param parent parent of this dialog (QWidget)
+            installation
+        @type list of str
+        @param parent parent of this dialog
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -110,7 +113,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         """
         Public method to check, if a restart of the IDE is required.
 
-        @return flag indicating a restart is required (boolean)
+        @return flag indicating a restart is required
+        @rtype bool
         """
         return self.__restartNeeded
 
@@ -118,7 +122,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         """
         Private method to create a list of plugin archive names.
 
-        @return list of plugin archive names (list of strings)
+        @return list of plugin archive names
+        @rtype list of str
         """
         archivesList = []
         for row in range(self.archivesList.count()):
@@ -206,7 +211,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         """
         Private slot to handle the click of a button of the button box.
 
-        @param button reference to the button pressed (QAbstractButton)
+        @param button reference to the button pressed
+        @type QAbstractButton
         """
         if button == self.__backButton:
             self.__currentIndex -= 1
@@ -227,7 +233,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         """
         Private method to install the selected plugin archives.
 
-        @return flag indicating success (boolean)
+        @return flag indicating success
+        @rtype bool
         """
         res = True
         self.summaryEdit.clear()
@@ -256,10 +263,12 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         Private slot to install the selected plugin.
 
         @param archiveFilename name of the plugin archive
-            file (string)
+            file
+        @type str
         @return flag indicating success (boolean), error message
             upon failure (string) and flag indicating a restart
-            of the IDE is required (boolean)
+            of the IDE is required
+        @rtype bool
         """
         installedPluginName = ""
 
@@ -335,37 +344,49 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         needsRestart = False
         pyqtApi = 0
         doCompile = True
+
+        separator = "="  # initialize for old-style header
+        insideHeader = False
         for line in pluginSource.splitlines():
-            if line.startswith("packageName"):
-                tokens = line.split("=")
-                if (
-                    tokens[0].strip() == "packageName"
-                    and tokens[1].strip()[1:-1] != "__core__"
-                ):
-                    if tokens[1].strip()[0] in ['"', "'"]:
-                        packageName = tokens[1].strip()[1:-1]
-                    else:
-                        if tokens[1].strip() == "None":
-                            packageName = "None"
-            elif line.startswith("internalPackages"):
-                tokens = line.split("=")
-                token = tokens[1].strip()[1:-1]
-                # it is a comma separated string
-                internalPackages = [p.strip() for p in token.split(",")]
-            elif line.startswith("needsRestart"):
-                tokens = line.split("=")
-                needsRestart = tokens[1].strip() == "True"
-            elif line.startswith("pyqtApi"):
-                tokens = line.split("=")
-                with contextlib.suppress(ValueError):
-                    pyqtApi = int(tokens[1].strip())
-            elif line.startswith("doNotCompile"):
-                tokens = line.split("=")
-                if tokens[1].strip() == "True":
-                    doCompile = False
-            elif line.startswith("# End-Of-Header"):
+            line = line.strip()
+            if line.lower().startswith("# start-of-header"):
+                insideHeader = True
+                continue
+
+            if not insideHeader:
+                continue
+
+            if line.startswith("__header__"):
+                # it is a new style header
+                separator = ":"
+                continue
+            elif line.lower().startswith("# end-of-header"):
                 break
 
+            with contextlib.suppress(ValueError):
+                key, value = line.split(separator)
+                key = key.strip().strip("\"'")
+                value = value.strip().rstrip(",")
+                # get rid of trailing ',' in new-style header
+
+                if key == "packageName":
+                    if value[1:-1] != "__core__":
+                        if value[0] in ['"', "'"]:
+                            packageName = value[1:-1]
+                        else:
+                            if value == "None":
+                                packageName = "None"
+                elif key == "internalPackages":
+                    # it is a comma separated string
+                    internalPackages = [p.strip() for p in value[1:-1].split(",")]
+                elif key == "needsRestart":
+                    needsRestart = value == "True"
+                elif key == "pyqtApi":
+                    with contextlib.suppress(ValueError):
+                        pyqtApi = int(value)
+                elif key == "doNotCompile" and value == "True":
+                    doCompile = False
+
         if not packageName:
             return (
                 False,
@@ -531,8 +552,10 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         This is an extended version of the Python one in order to
         record the created directories.
 
-        @param name name of the directory to create (string)
-        @param mode permission to set for the new directory (integer)
+        @param name name of the directory to create
+        @type str
+        @param mode permission to set for the new directory
+        @type int
         """
         head, tail = os.path.split(name)
         if not tail:
@@ -550,9 +573,12 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         Private method to uninstall an already installed plugin to prepare
         the update.
 
-        @param destination name of the plugin directory (string)
-        @param pluginFileName name of the plugin file (string)
-        @param packageName name of the plugin package (string)
+        @param destination name of the plugin directory
+        @type str
+        @param pluginFileName name of the plugin file
+        @type str
+        @param packageName name of the plugin package
+        @type str
         """
         packageDir = (
             None
@@ -598,9 +624,11 @@ class PluginInstallDialog(QDialog):
         Constructor
 
         @param pluginManager reference to the plugin manager object
-        @param pluginFileNames list of plugin files suggested for
-            installation (list of strings)
-        @param parent reference to the parent widget (QWidget)
+        @type PluginManager
+        @param pluginFileNames list of plugin files suggested for installation
+        @type list of str
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setSizeGripEnabled(True)
@@ -622,7 +650,8 @@ class PluginInstallDialog(QDialog):
         """
         Public method to check, if a restart of the IDE is required.
 
-        @return flag indicating a restart is required (boolean)
+        @return flag indicating a restart is required
+        @rtype bool
         """
         return self.cw.restartNeeded()
 
@@ -637,8 +666,10 @@ class PluginInstallWindow(EricMainWindow):
         Constructor
 
         @param pluginFileNames list of plugin files suggested for
-            installation (list of strings)
-        @param parent reference to the parent widget (QWidget)
+            installation
+        @type list of str
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.cw = PluginInstallWidget(None, pluginFileNames, self)
