@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,6 +10,8 @@ Module implementing the Plugin Manager.
 import contextlib
 import datetime
 import importlib
+import importlib.util
+import itertools
 import os
 import pathlib
 import sys
@@ -47,6 +49,7 @@ from .PluginExceptions import (
     PluginModulesError,
     PluginPathError,
 )
+from .PluginUtilities import getPluginHeaderEntry, hasPluginHeaderEntry
 
 
 class PluginManager(QObject):
@@ -175,8 +178,9 @@ class PluginManager(QObject):
         """
         Public method to finalize the setup of the plugin manager.
         """
-        for module in list(self.__onDemandInactiveModules.values()) + list(
-            self.__onDemandActiveModules.values()
+        for module in itertools.chain(
+            self.__onDemandInactiveModules.values(),
+            self.__onDemandActiveModules.values(),
         ):
             if hasattr(module, "moduleSetup"):
                 module.moduleSetup()
@@ -185,8 +189,10 @@ class PluginManager(QObject):
         """
         Public method to get the path of a plugin directory.
 
-        @param key key of the plug-in directory (string)
-        @return path of the requested plugin directory (string)
+        @param key key of the plug-in directory
+        @type str
+        @return path of the requested plugin directory
+        @rtype str
         """
         if key not in ["global", "user"]:
             return None
@@ -203,7 +209,8 @@ class PluginManager(QObject):
         If the plugin folders don't exist, they are created (if possible).
 
         @return tuple of a flag indicating existence of any of the plugin
-            directories (boolean) and a message (string)
+            directories and a message
+        @rtype tuple of (bool, str)
         """
         if self.__develPluginFile:
             path = FileSystemUtilities.splitPath(self.__develPluginFile)[0]
@@ -236,11 +243,11 @@ class PluginManager(QObject):
                 os.mkdir(self.pluginDirs["global"], 0o755)
                 fname = os.path.join(self.pluginDirs["global"], "__init__.py")
                 with open(fname, "w", encoding="utf-8") as f:
-                    f.write("# -*- coding: utf-8 -*-" + "\n")
+                    f.write("# -*- coding: utf-8 -*-\n")
                     f.write("\n")
-                    f.write('"""' + "\n")
-                    f.write("Package containing the global plugins." + "\n")
-                    f.write('"""' + "\n")
+                    f.write('"""\n')
+                    f.write("Package containing the global plugins.\n")
+                    f.write('"""\n')
             except OSError:
                 del self.pluginDirs["global"]
 
@@ -258,7 +265,8 @@ class PluginManager(QObject):
         """
         Private method to check, if there are plugins available.
 
-        @return flag indicating the availability of plugins (boolean)
+        @return flag indicating the availability of plugins
+        @rtype bool
         """
         if self.__develPluginFile and not os.path.exists(self.__develPluginFile):
             return False
@@ -285,8 +293,10 @@ class PluginManager(QObject):
         """
         Public method to get a list of plugin modules.
 
-        @param pluginPath name of the path to search (string)
-        @return list of plugin module names (list of string)
+        @param pluginPath name of the path to search
+        @type str
+        @return list of plugin module names
+        @rtype list of str
         """
         pluginFiles = [
             f[:-3] for f in os.listdir(pluginPath) if self.isValidPluginName(f)
@@ -299,14 +309,16 @@ class PluginManager(QObject):
 
         Plugin modules must start with "Plugin" and have the extension ".py".
 
-        @param pluginName name of the file to be checked (string)
-        @return flag indicating a valid plugin name (boolean)
+        @param pluginName name of the file to be checked
+        @type str
+        @return flag indicating a valid plugin name
+        @rtype bool
         """
         return pluginName.startswith("Plugin") and pluginName.endswith(".py")
 
     def __insertPluginsPaths(self):
         """
-        Private method to insert the valid plugin paths intos the search path.
+        Private method to insert the valid plugin paths into the search path.
         """
         for key in self.__priorityOrder:
             if key in self.pluginDirs:
@@ -418,18 +430,18 @@ class PluginManager(QObject):
             module = importlib.util.module_from_spec(spec)
             sys.modules[module.__name__] = module
             spec.loader.exec_module(module)
-            if not hasattr(module, "autoactivate"):
+            if not hasPluginHeaderEntry(module, "autoactivate"):
                 module.error = self.tr(
                     "Module is missing the 'autoactivate' attribute."
                 )
                 self.__failedModules[name] = module
                 raise PluginLoadError(name)
-            if getattr(module, "autoactivate", False):
+            if getPluginHeaderEntry(module, "autoactivate", False):
                 self.__inactiveModules[name] = module
             else:
-                if not hasattr(module, "pluginType") or not hasattr(
-                    module, "pluginTypename"
-                ):
+                if not hasPluginHeaderEntry(
+                    module, "pluginType"
+                ) or not hasPluginHeaderEntry(module, "pluginTypename"):
                     module.error = self.tr(
                         "Module is missing the 'pluginType' "
                         "and/or 'pluginTypename' attributes."
@@ -467,8 +479,10 @@ class PluginManager(QObject):
         """
         Public method to unload a plugin module.
 
-        @param name name of the module to be unloaded (string)
-        @return flag indicating success (boolean)
+        @param name name of the module to be unloaded
+        @type str
+        @return flag indicating success
+        @rtype bool
         """
         if name in self.__onDemandActiveModules:
             # cannot unload an ondemand plugin, that is in use
@@ -502,17 +516,20 @@ class PluginManager(QObject):
         Public method to remove a plugin and all related modules from
         sys.modules.
 
-        @param pluginName name of the plugin module (string)
-        @param package name of the plugin package (string)
-        @param internalPackages list of intenal packages (list of string)
+        @param pluginName name of the plugin module
+        @type str
+        @param package name of the plugin package
+        @type str
+        @param internalPackages list of intenal packages
+        @type list of str
         @return flag indicating the plugin module was found in sys.modules
-            (boolean)
+        @rtype bool
         """
         packages = [package] + internalPackages
         found = False
         if not package:
             package = "__None__"
-        for moduleName in list(sys.modules.keys())[:]:
+        for moduleName in list(sys.modules):
             if moduleName == pluginName or moduleName.split(".")[0] in packages:
                 found = True
                 del sys.modules[moduleName]
@@ -524,7 +541,7 @@ class PluginManager(QObject):
 
         Note: The plugins are not activated.
         """
-        names = sorted(self.__onDemandInactiveModules.keys())
+        names = sorted(self.__onDemandInactiveModules)
         for name in names:
             self.initOnDemandPlugin(name)
 
@@ -534,7 +551,8 @@ class PluginManager(QObject):
 
         Note: The plug-in is not activated.
 
-        @param name name of the plug-in (string)
+        @param name name of the plug-in
+        @type str
         @exception PluginActivationError raised to indicate an issue during the
             plug-in activation
         """
@@ -546,8 +564,8 @@ class PluginManager(QObject):
 
             if not self.__canActivatePlugin(module):
                 raise PluginActivationError(module.eric7PluginModuleName)
-            version = getattr(module, "version", "0.0.0")
-            className = getattr(module, "className", "")
+            version = getPluginHeaderEntry(module, "version", "0.0.0")
+            className = getPluginHeaderEntry(module, "className", "")
             pluginClass = getattr(module, className)
             pluginObject = None
             if name not in self.__onDemandInactivePlugins:
@@ -564,7 +582,7 @@ class PluginManager(QObject):
         Public method to initialize plug-in toolbars.
 
         @param toolbarManager reference to the toolbar manager object
-            (EricToolBarManager)
+        @type EricToolBarManager
         """
         self.initOnDemandPlugins()
         for pluginObject in self.__onDemandInactivePlugins.values():
@@ -587,7 +605,7 @@ class PluginManager(QObject):
             and self.__develPluginName in inactiveList
         ):
             inactiveList.remove(self.__develPluginName)
-        names = sorted(self.__inactiveModules.keys())
+        names = sorted(self.__inactiveModules)
         for name in names:
             if name not in inactiveList:
                 self.activatePlugin(name)
@@ -619,8 +637,8 @@ class PluginManager(QObject):
 
             if not self.__canActivatePlugin(module):
                 raise PluginActivationError(module.eric7PluginModuleName)
-            version = getattr(module, "version", "0.0.0")
-            className = getattr(module, "className", "")
+            version = getPluginHeaderEntry(module, "version", "0.0.0")
+            className = getPluginHeaderEntry(module, "className", "")
             pluginClass = getattr(module, className)
             pluginObject = None
             if onDemand and name in self.__onDemandInactivePlugins:
@@ -669,19 +687,21 @@ class PluginManager(QObject):
         Private method to check, if a plugin can be activated.
 
         @param module reference to the module to be activated
+        @type Module
         @return flag indicating, if the module satisfies all requirements
-            for being activated (boolean)
+            for being activated
+        @rtype bool
         @exception PluginModuleFormatError raised to indicate an invalid
             plug-in module format
         @exception PluginClassFormatError raised to indicate an invalid
             plug-in class format
         """
         try:
-            if not hasattr(module, "version"):
+            if not hasPluginHeaderEntry(module, "version"):
                 raise PluginModuleFormatError(module.eric7PluginModuleName, "version")
-            if not hasattr(module, "className"):
+            if not hasPluginHeaderEntry(module, "className"):
                 raise PluginModuleFormatError(module.eric7PluginModuleName, "className")
-            className = getattr(module, "className", "")
+            className = getPluginHeaderEntry(module, "className", "")
             if not className or not hasattr(module, className):
                 raise PluginModuleFormatError(module.eric7PluginModuleName, className)
             pluginClass = getattr(module, className)
@@ -710,8 +730,10 @@ class PluginManager(QObject):
         Public method to deactivate a plugin.
 
         @param name name of the module to be deactivated
+        @type str
         @param onDemand flag indicating deactivation of an
-            on demand plugin (boolean)
+            on demand plugin
+        @type bool
         """
         try:
             module = (
@@ -750,15 +772,17 @@ class PluginManager(QObject):
         Private method to check, if a plugin can be deactivated.
 
         @param module reference to the module to be deactivated
+        @type Module
         @return flag indicating, if the module satisfies all requirements
-            for being deactivated (boolean)
+            for being deactivated
+        @rtype bool
         """
-        return getattr(module, "deactivateable", True)
+        return getPluginHeaderEntry(module, "deactivateable", True)
 
     def getPluginObject(self, type_, typename, maybeActive=False):
         """
-        Public method to activate an ondemand plugin given by type and
-        typename.
+        Public method to activate an on-demand plugin given by type and
+        type name.
 
         @param type_ type of the plugin to be activated
         @type str
@@ -770,18 +794,18 @@ class PluginManager(QObject):
         @return reference to the initialized plugin object and an error string
         @rtype tuple of (QObject, str)
         """
-        for name, module in list(self.__onDemandInactiveModules.items()):
+        for name, module in self.__onDemandInactiveModules.items():
             if (
-                getattr(module, "pluginType", "") == type_
-                and getattr(module, "pluginTypename", "") == typename
+                getPluginHeaderEntry(module, "pluginType", "") == type_
+                and getPluginHeaderEntry(module, "pluginTypename", "") == typename
             ):
                 return self.activatePlugin(name, onDemand=True)
 
         if maybeActive:
-            for name, module in list(self.__onDemandActiveModules.items()):
+            for name, module in self.__onDemandActiveModules.items():
                 if (
-                    getattr(module, "pluginType", "") == type_
-                    and getattr(module, "pluginTypename", "") == typename
+                    getPluginHeaderEntry(module, "pluginType", "") == type_
+                    and getPluginHeaderEntry(module, "pluginTypename", "") == typename
                 ):
                     self.deactivatePlugin(name, onDemand=True)
                     return self.activatePlugin(name, onDemand=True)
@@ -801,7 +825,7 @@ class PluginManager(QObject):
         infos = []
 
         # 1. active, non-on-demand modules
-        for name in list(self.__activeModules.keys()):
+        for name in self.__activeModules:
             info = self.__getShortInfo(self.__activeModules[name])
             info.update(
                 {
@@ -813,7 +837,7 @@ class PluginManager(QObject):
             infos.append(info)
 
         # 2. inactive, non-on-demand modules
-        for name in list(self.__inactiveModules.keys()):
+        for name in self.__inactiveModules:
             info = self.__getShortInfo(self.__inactiveModules[name])
             info.update(
                 {
@@ -825,7 +849,7 @@ class PluginManager(QObject):
             infos.append(info)
 
         # 3. active, on-demand modules
-        for name in list(self.__onDemandActiveModules.keys()):
+        for name in self.__onDemandActiveModules:
             info = self.__getShortInfo(self.__onDemandActiveModules[name])
             info.update(
                 {
@@ -837,7 +861,7 @@ class PluginManager(QObject):
             infos.append(info)
 
         # 4. inactive, non-on-demand modules
-        for name in list(self.__onDemandInactiveModules.keys()):
+        for name in self.__onDemandInactiveModules:
             info = self.__getShortInfo(self.__onDemandInactiveModules[name])
             info.update(
                 {
@@ -849,7 +873,7 @@ class PluginManager(QObject):
             infos.append(info)
 
         # 5. failed modules
-        for name in list(self.__failedModules.keys()):
+        for name in self.__failedModules:
             info = self.__getShortInfo(self.__failedModules[name])
             info.update(
                 {
@@ -867,23 +891,26 @@ class PluginManager(QObject):
         Private method to extract the short info from a module.
 
         @param module module to extract short info from
-        @return dictionay containing plug-in data
+        @type Module
+        @return dictionary containing plug-in data
         @rtype dict ("plugin_name": str, "version": str, "short_desc": str,
             "error": bool)
         """
         return {
-            "plugin_name": getattr(module, "name", ""),
-            "version": getattr(module, "version", ""),
-            "short_desc": getattr(module, "shortDescription", ""),
-            "error": bool(getattr(module, "error", "")),
+            "plugin_name": getPluginHeaderEntry(module, "name", ""),
+            "version": getPluginHeaderEntry(module, "version", ""),
+            "short_desc": getPluginHeaderEntry(module, "shortDescription", ""),
+            "error": bool(getPluginHeaderEntry(module, "error", "")),
         }
 
     def getPluginDetails(self, name):
         """
         Public method to get detailed information about a plugin.
 
-        @param name name of the module to get detailed infos about (string)
+        @param name name of the module to get detailed infos about
+        @type str
         @return details of the plugin as a dictionary
+        @rtype dict
         """
         details = {}
 
@@ -914,14 +941,16 @@ class PluginManager(QObject):
             return None
 
         details["moduleName"] = name
-        details["moduleFileName"] = getattr(module, "eric7PluginModuleFilename", "")
-        details["pluginName"] = getattr(module, "name", "")
-        details["version"] = getattr(module, "version", "")
-        details["author"] = getattr(module, "author", "")
-        details["description"] = getattr(module, "longDescription", "")
+        details["moduleFileName"] = getPluginHeaderEntry(
+            module, "eric7PluginModuleFilename", ""
+        )
+        details["pluginName"] = getPluginHeaderEntry(module, "name", "")
+        details["version"] = getPluginHeaderEntry(module, "version", "")
+        details["author"] = getPluginHeaderEntry(module, "author", "")
+        details["description"] = getPluginHeaderEntry(module, "longDescription", "")
         details["autoactivate"] = autoactivate
         details["active"] = active
-        details["error"] = getattr(module, "error", "")
+        details["error"] = getPluginHeaderEntry(module, "error", "")
 
         return details
 
@@ -930,7 +959,7 @@ class PluginManager(QObject):
         Public method called to perform actions upon shutdown of the IDE.
         """
         names = []
-        for name in list(self.__inactiveModules.keys()):
+        for name in self.__inactiveModules:
             names.append(name)
         Preferences.getSettings().setValue(self.__inactivePluginsKey, names)
 
@@ -941,30 +970,26 @@ class PluginManager(QObject):
         Public method to get the display strings of all plugins of a specific
         type.
 
-        @param type_ type of the plugins (string)
+        @param type_ type of the plugins
+        @type str
         @return dictionary with name as key and display string as value
-            (dictionary of string)
+        @rtype dict
         """
         pluginDict = {}
 
-        for module in list(self.__onDemandActiveModules.values()) + list(
-            self.__onDemandInactiveModules.values()
+        for module in itertools.chain(
+            self.__onDemandActiveModules.values(),
+            self.__onDemandInactiveModules.values(),
         ):
             if (
-                getattr(module, "pluginType", "") == type_
-                and getattr(module, "error", "") == ""
+                getPluginHeaderEntry(module, "pluginType", "") == type_
+                and getPluginHeaderEntry(module, "error", "") == ""
             ):
-                plugin_name = getattr(module, "pluginTypename", "")
+                plugin_name = getPluginHeaderEntry(module, "pluginTypename", "")
                 if plugin_name:
-                    if hasattr(module, "displayString"):
-                        try:
-                            disp = module.displayString()
-                        except TypeError:
-                            disp = getattr(module, "displayString", "")
-                        if disp != "":
-                            pluginDict[plugin_name] = disp
-                    else:
-                        pluginDict[plugin_name] = plugin_name
+                    pluginDict[plugin_name] = getPluginHeaderEntry(
+                        module, "displayString", plugin_name
+                    )
 
         return pluginDict
 
@@ -972,16 +997,20 @@ class PluginManager(QObject):
         """
         Public method to get a preview pixmap of a plugin of a specific type.
 
-        @param type_ type of the plugin (string)
-        @param name name of the plugin type (string)
-        @return preview pixmap (QPixmap)
+        @param type_ type of the plugin
+        @type str
+        @param name name of the plugin type
+        @type str
+        @return preview pixmap
+        @rtype QPixmap
         """
-        for module in list(self.__onDemandActiveModules.values()) + list(
-            self.__onDemandInactiveModules.values()
+        for module in itertools.chain(
+            self.__onDemandActiveModules.values(),
+            self.__onDemandInactiveModules.values(),
         ):
             if (
-                getattr(module, "pluginType", "") == type_
-                and getattr(module, "pluginTypename", "") == name
+                getPluginHeaderEntry(module, "pluginType", "") == type_
+                and getPluginHeaderEntry(module, "pluginTypename", "") == name
             ):
                 if hasattr(module, "previewPix"):
                     return module.previewPix()
@@ -994,13 +1023,16 @@ class PluginManager(QObject):
         """
         Public method to get the list of API files installed by a plugin.
 
-        @param language language of the requested API files (string)
-        @return list of API filenames (list of string)
+        @param language language of the requested API files
+        @type str
+        @return list of API filenames
+        @rtype list of str
         """
         apis = []
 
-        for module in list(self.__activeModules.values()) + list(
-            self.__onDemandActiveModules.values()
+        for module in itertools.chain(
+            self.__activeModules.values(),
+            self.__onDemandActiveModules.values(),
         ):
             if hasattr(module, "apiFiles"):
                 apis.extend(module.apiFiles(language))
@@ -1017,8 +1049,9 @@ class PluginManager(QObject):
         @rtype dict (key: str, value: list of str)
         """
         helpFiles = {}
-        for module in list(self.__activeModules.values()) + list(
-            self.__onDemandActiveModules.values()
+        for module in itertools.chain(
+            self.__activeModules.values(),
+            self.__onDemandActiveModules.values(),
         ):
             if hasattr(module, "helpFiles"):
                 helpFiles.update(module.helpFiles())
@@ -1058,18 +1091,15 @@ class PluginManager(QObject):
                 <li>text - entry text to be shown (string)</li>
                 <li>version - version text to be shown (string)</li>
             </ul>
+        @rtype list of dict
         """
         infos = []
 
-        for module in list(self.__activeModules.values()) + list(
-            self.__inactiveModules.values()
-        ):
-            if hasattr(module, "exeDisplayDataList"):
-                infos.extend(module.exeDisplayDataList())
-            elif hasattr(module, "exeDisplayData"):
-                infos.append(module.exeDisplayData())
-        for module in list(self.__onDemandActiveModules.values()) + list(
-            self.__onDemandInactiveModules.values()
+        for module in itertools.chain(
+            self.__activeModules.values(),
+            self.__inactiveModules.values(),
+            self.__onDemandActiveModules.values(),
+            self.__onDemandInactiveModules.values(),
         ):
             if hasattr(module, "exeDisplayDataList"):
                 infos.extend(module.exeDisplayDataList())
@@ -1109,12 +1139,13 @@ class PluginManager(QObject):
         </dl>
 
         @return plug-in configuration data
+        @rtype dict
         """
         configData = {}
-        for module in (
-            list(self.__activeModules.values())
-            + list(self.__onDemandActiveModules.values())
-            + list(self.__onDemandInactiveModules.values())
+        for module in itertools.chain(
+            self.__activeModules.values(),
+            self.__onDemandActiveModules.values(),
+            self.__onDemandInactiveModules.values(),
         ):
             if hasattr(module, "getConfigData"):
                 configData.update(module.getConfigData())
@@ -1124,8 +1155,10 @@ class PluginManager(QObject):
         """
         Public method to check, if a certain plugin is loaded.
 
-        @param pluginName name of the plugin to check for (string)
-        @return flag indicating, if the plugin is loaded (boolean)
+        @param pluginName name of the plugin to check for
+        @type str
+        @return flag indicating, if the plugin is loaded
+        @rtype bool
         """
         return (
             pluginName in self.__activeModules
@@ -1138,8 +1171,10 @@ class PluginManager(QObject):
         """
         Public method to check, if a certain plugin is active.
 
-        @param pluginName name of the plugin to check for (string)
-        @return flag indicating, if the plugin is active (boolean)
+        @param pluginName name of the plugin to check for
+        @type str
+        @return flag indicating, if the plugin is active
+        @rtype bool
         """
         return (
             pluginName in self.__activeModules
@@ -1163,19 +1198,21 @@ class PluginManager(QObject):
         a tuple with the vcs name (string) and vcs display string (string).
 
         @return dictionary with indicator as key and a list of tuples as
-            values. Each tuple contains the vcs name (string) and vcs display
-            string (string).
+            values. Each tuple contains the vcs name (str) and vcs display
+            string (str).
+        @rtype dict
         """
         vcsDict = {}
 
-        for module in list(self.__onDemandActiveModules.values()) + list(
-            self.__onDemandInactiveModules.values()
+        for module in itertools.chain(
+            self.__onDemandActiveModules.values(),
+            self.__onDemandInactiveModules.values(),
         ):
-            if getattr(module, "pluginType", "") == "version_control" and hasattr(
-                module, "getVcsSystemIndicator"
-            ):
+            if getPluginHeaderEntry(
+                module, "pluginType", ""
+            ) == "version_control" and hasattr(module, "getVcsSystemIndicator"):
                 res = module.getVcsSystemIndicator()
-                for indicator, vcsData in list(res.items()):
+                for indicator, vcsData in res.items():
                     if indicator in vcsDict:
                         vcsDict[indicator].append(vcsData)
                     else:
@@ -1188,7 +1225,7 @@ class PluginManager(QObject):
         Public method to deactivated all activated VCS plugins.
         """
         for name, module in list(self.__onDemandActiveModules.items()):
-            if getattr(module, "pluginType", "") == "version_control":
+            if getPluginHeaderEntry(module, "pluginType", "") == "version_control":
                 self.deactivatePlugin(name, True)
 
     ########################################################################
@@ -1254,12 +1291,13 @@ class PluginManager(QObject):
 
         elif period in [1, 2, 3] and pathlib.Path(self.pluginRepositoryFile).exists():
             lastModified = datetime.datetime.fromtimestamp(
-                pathlib.Path(self.pluginRepositoryFile).stat().st_mtime
+                pathlib.Path(self.pluginRepositoryFile).stat().st_mtime,
+                tz=datetime.timezone.utc,
             )
-            now = datetime.datetime.now()
+            now = datetime.datetime.now(tz=datetime.timezone.utc)
             delta = now - lastModified
             if (
-                (period == 1 and lastModified.date().day == now.date().day)
+                (period == 1 and delta.days < 1)
                 or (period == 2 and delta.days < 7)
                 or (period == 3 and delta.days < 30)
             ):
@@ -1280,6 +1318,8 @@ class PluginManager(QObject):
 
         if url is None:
             url = Preferences.getUI("PluginRepositoryUrl7")
+            if Preferences.getPluginManager("ForceHttpPluginDownload"):
+                url = url.replace("https://", "http://")
         request = QNetworkRequest(QUrl(url))
         request.setAttribute(
             QNetworkRequest.Attribute.CacheLoadControlAttribute,
@@ -1342,19 +1382,38 @@ class PluginManager(QObject):
                     self.pluginRepositoryFileDownloaded.emit()
 
     def checkPluginEntry(
-        self, name, short, description, url, author, version, filename, status
+        self,
+        name,  # noqa: U100
+        short,  # noqa: U100
+        description,  # noqa: U100
+        url,
+        author,  # noqa: U100
+        version,
+        filename,
+        status,  # noqa: U100
+        category,  # noqa: U100
     ):
         """
         Public method to check a plug-in's data for an update.
 
-        @param name data for the name field (string)
-        @param short data for the short field (string)
-        @param description data for the description field (list of strings)
-        @param url data for the url field (string)
-        @param author data for the author field (string)
-        @param version data for the version field (string)
-        @param filename data for the filename field (string)
-        @param status status of the plugin (string [stable, unstable, unknown])
+        @param name data for the name field
+        @type str
+        @param short data for the short field
+        @type str
+        @param description data for the description field
+        @type list of str
+        @param url data for the url field
+        @type str
+        @param author data for the author field
+        @type str
+        @param version data for the version field
+        @type str
+        @param filename data for the filename field
+        @type str
+        @param status status of the plugin (one of stable, unstable, unknown)
+        @type str
+        @param category category designation of the plugin
+        @type str
         """
         # ignore hidden plug-ins
         pluginName = os.path.splitext(url.rsplit("/", 1)[1])[0]
@@ -1406,8 +1465,10 @@ class PluginManager(QObject):
         """
         Private slot to handle SSL errors.
 
-        @param reply reference to the reply object (QNetworkReply)
-        @param errors list of SSL errors (list of QSslError)
+        @param reply reference to the reply object
+        @type QNetworkReply
+        @param errors list of SSL errors
+        @type list of QSslError
         """
         ignored = self.__sslErrorHandler.sslErrorsReply(reply, errors)[0]
         if ignored == EricSslErrorState.NOT_IGNORED:
@@ -1425,15 +1486,16 @@ class PluginManager(QObject):
         Plugins supporting this functionality must support the module function
         clearPrivateData() and have the module level attribute pluginType.
 
-        @param type_ type of the plugin to clear private data for (string)
+        @param type_ type of the plugin to clear private data for
+        @type str
         """
-        for module in (
-            list(self.__onDemandActiveModules.values())
-            + list(self.__onDemandInactiveModules.values())
-            + list(self.__activeModules.values())
-            + list(self.__inactiveModules.values())
+        for module in itertools.chain(
+            self.__onDemandActiveModules.values(),
+            self.__onDemandInactiveModules.values(),
+            self.__activeModules.values(),
+            self.__inactiveModules.values(),
         ):
-            if getattr(module, "pluginType", "") == type_ and hasattr(
+            if getPluginHeaderEntry(module, "pluginType", "") == type_ and hasattr(
                 module, "clearPrivateData"
             ):
                 module.clearPrivateData()
