@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -739,7 +739,8 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         """
         Constructor
 
-        @param parent reference to the parent widget (QWidget)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
