@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -40,18 +40,23 @@ class AnnotationsChecker:
         "A204",
         "A205",
         "A206",
-        ## Mixed kind of annotations
-        "A301",
         ## Dynamically typed annotations
         "A401",
+        ## Type comments
+        "A402",
         ## Annotations Future
         "A871",
         "A872",
+        "A873",
         ## Annotation Coverage
         "A881",
         ## Annotation Complexity
         "A891",
         "A892",
+        ## use of typing.Union (PEP 604)
+        "A901",
+        ## deprecated 'typing' symbols (PEP 585)
+        "A911",
     ]
 
     def __init__(self, source, filename, tree, select, ignore, expected, repeat, args):
@@ -105,13 +110,15 @@ class AnnotationsChecker:
                     "A204",
                     "A205",
                     "A206",
-                    "A301",
                     "A401",
+                    "A402",
                 ),
             ),
-            (self.__checkAnnotationsFuture, ("A871", "A872")),
+            (self.__checkAnnotationsFuture, ("A871", "A872", "A873")),
             (self.__checkAnnotationsCoverage, ("A881",)),
             (self.__checkAnnotationComplexity, ("A891", "A892")),
+            (self.__checkAnnotationPep604, ("A901",)),
+            (self.__checkDeprecatedTypingSymbols, ("A911",)),
         ]
 
         self.__checkers = []
@@ -185,7 +192,7 @@ class AnnotationsChecker:
     #######################################################################
     ## Annotations
     ##
-    ## adapted from: flake8-annotations v2.9.0
+    ## adapted from: flake8-annotations v3.0.1
     #######################################################################
 
     def __checkFunctionAnnotations(self):
@@ -239,6 +246,9 @@ class AnnotationsChecker:
 
         # Iterate over the arguments with missing type hints, by function.
         for function in visitor.functionDefinitions:
+            if function.hasTypeComment:
+                self.__error(function.lineno - 1, function.col_offset, "A402")
+
             if function.isDynamicallyTyped() and (
                 allowUntypedDefs or (function.isNested and allowUntypedNested)
             ):
@@ -252,32 +262,8 @@ class AnnotationsChecker:
             if function.hasDecorator(dispatchDecorators):
                 continue
 
-            # Create sentinels to check for mixed hint styles
-            hasTypeComment = function.hasTypeComment
-
-            has3107Annotation = False
-            # PEP 3107 annotations are captured by the return arg
-
+            # Iterate over the annotated args to look for opinionated warnings
             annotatedArgs = function.getAnnotatedArguments()
-
-            # Iterate over annotated args to detect mixing of type annotations
-            # and type comments. Emit this only once per function definition
-            for arg in annotatedArgs:
-                if arg.hasTypeComment:
-                    hasTypeComment = True
-
-                if arg.has3107Annotation:
-                    has3107Annotation = True
-
-                if hasTypeComment and has3107Annotation:
-                    # Short-circuit check for mixing of type comments &
-                    # 3107-style annotations
-                    self.__error(function.lineno - 1, function.col_offset, "A301")
-                    break
-
-            # Iterate over the annotated args to look for 'typing.Any' annotations
-            # We could combine this with the above loop but I'd rather not add even
-            # more sentinels unless we'd notice a significant enough performance impact
             for arg in annotatedArgs:
                 if arg.isDynamicallyTyped:
                     if allowStarArgAny and arg.annotationType in {
@@ -301,6 +287,11 @@ class AnnotationsChecker:
 
             # Record explicit errors for arguments that are missing annotations
             for arg in function.getMissedAnnotations():
+                # Check for type comments here since we're not considering them as
+                # typed args
+                if arg.hasTypeComment:
+                    self.__error(arg.lineno - 1, arg.col_offset, "A402")
+
                 if arg.argname == "return":
                     # return annotations have multiple possible short-circuit
                     # paths
@@ -513,7 +504,7 @@ class AnnotationsChecker:
     #######################################################################
     ## Annotations Complexity
     ##
-    ## adapted from: flake8-annotations-complexity v0.0.7
+    ## adapted from: flake8-annotations-complexity v0.0.8
     #######################################################################
 
     def __checkAnnotationComplexity(self):
@@ -579,8 +570,8 @@ class AnnotationsChecker:
         """
         if AstUtilities.isString(annotationNode):
             try:
-                annotationNode = ast.parse(annotationNode.s).body[0].value
-            except (SyntaxError, IndexError):
+                annotationNode = ast.parse(annotationNode.value).body[0].value
+            except (IndexError, SyntaxError):
                 return defaultComplexity
 
         complexity = defaultComplexity
@@ -615,8 +606,8 @@ class AnnotationsChecker:
         annotationLength = 0
         if AstUtilities.isString(annotationNode):
             try:
-                annotationNode = ast.parse(annotationNode.s).body[0].value
-            except (SyntaxError, IndexError):
+                annotationNode = ast.parse(annotationNode.value).body[0].value
+            except (IndexError, SyntaxError):
                 return annotationLength
 
         if isinstance(annotationNode, ast.Subscript):
@@ -630,9 +621,9 @@ class AnnotationsChecker:
         return annotationLength
 
     #######################################################################
-    ## 'from __future__ import annotations' checck
+    ## 'from __future__ import annotations' check
     ##
-    ## adapted from: flake8-future-annotations v0.0.5
+    ## adapted from: flake8-future-annotations v1.1.0
     #######################################################################
 
     def __checkAnnotationsFuture(self):
@@ -641,10 +632,18 @@ class AnnotationsChecker:
         """
         from .AnnotationsFutureVisitor import AnnotationsFutureVisitor
 
+        if sys.version_info >= (3, 9):
+            # the __future__ typing import is only needed before Python 3.9
+            return
+
         forceFutureAnnotations = self.__args.get(
             "ForceFutureAnnotations",
             AnnotationsCheckerDefaultArgs["ForceFutureAnnotations"],
         )
+        checkFutureAnnotations = self.__args.get(
+            "CheckFutureAnnotations",
+            AnnotationsCheckerDefaultArgs["CheckFutureAnnotations"],
+        )
 
         visitor = AnnotationsFutureVisitor()
         visitor.visit(self.__tree)
@@ -657,3 +656,62 @@ class AnnotationsChecker:
             self.__error(0, 0, "A871", imports)
         elif forceFutureAnnotations:
             self.__error(0, 0, "A872")
+
+        if checkFutureAnnotations and visitor.hasSimplifiedTypes():
+            simplifiedTypes = ", ".join(sorted(visitor.getSimplifiedTypes()))
+            self.__error(0, 0, "A873", simplifiedTypes)
+
+    #######################################################################
+    ## check use of 'typing.Union' (see PEP 604)
+    ##
+    ## adapted from: flake8-pep604 v1.1.0
+    #######################################################################
+
+    def __checkAnnotationPep604(self):
+        """
+        Private method to check the use of typing.Union.
+        """
+        from .AnnotationsUnionVisitor import AnnotationsUnionVisitor
+
+        if sys.version_info < (3, 10):
+            # the union operator was introduced with Python 3.10
+            return
+
+        visitor = AnnotationsUnionVisitor()
+        visitor.visit(self.__tree)
+
+        for node in visitor.getIssues():
+            self.__error(node.lineno - 1, node.col_offset, "A901")
+
+    #######################################################################
+    ## check use of 'typing.Union' (see PEP 604)
+    ##
+    ## adapted from: flake8-pep585 v0.1.7
+    #######################################################################
+
+    def __checkDeprecatedTypingSymbols(self):
+        """
+        Private method to check the use of deprecated 'typing' symbols.
+        """
+        from .AnnotationsDeprecationsVisitor import (
+            AnnotationsDeprecationsVisitor,
+            AnnotationsFutureImportVisitor,
+        )
+
+        if sys.version_info < (3, 9):
+            # py 3.8: only if activated via __future__ import
+            visitor = AnnotationsFutureImportVisitor()
+            visitor.visit(self.__tree)
+            if not visitor.futureImportPresent():
+                return
+
+        visitor = AnnotationsDeprecationsVisitor(
+            self.__args.get(
+                "ExemptedTypingSymbols",
+                AnnotationsCheckerDefaultArgs["ExemptedTypingSymbols"],
+            )
+        )
+        visitor.visit(self.__tree)
+
+        for node, (name, replacement) in visitor.getIssues():
+            self.__error(node.lineno - 1, node.col_offset, "A911", name, replacement)
