@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -24,4 +24,7 @@ AnnotationsCheckerDefaultArgs = {
     "MaximumLength": 7,
     # Annotations Future
     "ForceFutureAnnotations": False,
+    "CheckFutureAnnotations": False,
+    # deprecated 'typing' symbols
+    "ExemptedTypingSymbols": [],
 }
