@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,15 +15,20 @@ import sys
 
 import pycodestyle
 
+from Annotations.AnnotationsChecker import AnnotationsChecker
+from Async.AsyncChecker import AsyncChecker
 from CodeStyleFixer import CodeStyleFixer
 from Complexity.ComplexityChecker import ComplexityChecker
 from DocStyle.DocStyleChecker import DocStyleChecker
 from Imports.ImportsChecker import ImportsChecker
+from Logging.LoggingChecker import LoggingChecker
 from Miscellaneous.MiscellaneousChecker import MiscellaneousChecker
+from NameOrder.NameOrderChecker import NameOrderChecker
 from Naming.NamingStyleChecker import NamingStyleChecker
 from PathLib.PathlibChecker import PathlibChecker
 from Security.SecurityChecker import SecurityChecker
 from Simplify.SimplifyChecker import SimplifyChecker
+from Unused.UnusedChecker import UnusedChecker
 
 # register the name checker
 pycodestyle.register_check(NamingStyleChecker, NamingStyleChecker.Codes)
@@ -33,7 +38,8 @@ def initService():
     """
     Initialize the service and return the entry point.
 
-    @return the entry point for the background client (function)
+    @return the entry point for the background client
+    @rtype function
     """
     return codeStyleCheck
 
@@ -42,7 +48,8 @@ def initBatchService():
     """
     Initialize the batch service and return the entry point.
 
-    @return the entry point for the background client (function)
+    @return the entry point for the background client
+    @rtype function
     """
     return codeStyleBatchCheck
 
@@ -56,36 +63,43 @@ class CodeStyleCheckerReport(pycodestyle.BaseReport):
         """
         Constructor
 
-        @param options options for the report (optparse.Values)
+        @param options options for the report
+        @type optparse.Values
         """
         super().__init__(options)
 
         self.__repeat = options.repeat
         self.errors = []
 
-    def error_args(self, line_number, offset, code, check, *args):
+    def error_args(self, line_number, offset, errorCode, check, *args):
         """
         Public method to collect the error messages.
 
-        @param line_number line number of the issue (integer)
-        @param offset position within line of the issue (integer)
-        @param code message code (string)
-        @param check reference to the checker function (function)
-        @param args arguments for the message (list)
-        @return error code (string)
+        @param line_number line number of the issue
+        @type int
+        @param offset position within line of the issue
+        @type int
+        @param errorCode error message code
+        @type str
+        @param check reference to the checker function
+        @type function
+        @param args arguments for the message
+        @type list
+        @return error code
+        @rtype str
         """
-        code = super().error_args(line_number, offset, code, check, *args)
-        if code and (self.counters[code] == 1 or self.__repeat):
+        errorCode = super().error_args(line_number, offset, errorCode, check, *args)
+        if errorCode and (self.counters[errorCode] == 1 or self.__repeat):
             self.errors.append(
                 {
                     "file": self.filename,
                     "line": line_number,
                     "offset": offset,
-                    "code": code,
+                    "code": errorCode,
                     "args": args,
                 }
             )
-        return code
+        return errorCode
 
 
 def extractLineFlags(line, startComment="#", endComment="", flagsLine=False):
@@ -93,11 +107,16 @@ def extractLineFlags(line, startComment="#", endComment="", flagsLine=False):
     Function to extract flags starting and ending with '__' from a line
     comment.
 
-    @param line line to extract flags from (string)
-    @param startComment string identifying the start of the comment (string)
-    @param endComment string identifying the end of a comment (string)
-    @param flagsLine flag indicating to check for a flags only line (bool)
-    @return list containing the extracted flags (list of strings)
+    @param line line to extract flags from
+    @type str
+    @param startComment string identifying the start of the comment
+    @type str
+    @param endComment string identifying the end of a comment
+    @type str
+    @param flagsLine flag indicating to check for a flags only line
+    @type bool
+    @return list containing the extracted flags
+    @rtype list of str
     """
     flags = []
 
@@ -109,32 +128,37 @@ def extractLineFlags(line, startComment="#", endComment="", flagsLine=False):
                 endPos = line.rfind(endComment)
                 if endPos >= 0:
                     comment = comment[:endPos]
-            flags = [
-                f.strip()
-                for f in comment.split()
-                if (f.startswith("__") and f.endswith("__"))
-            ]
-            flags += [
-                f.strip().lower()
-                for f in comment.split()
-                if f in ("noqa", "NOQA", "nosec", "NOSEC", "secok", "SECOK")
-            ]
+            if comment.startswith(("noqa:", "NOQA:")):
+                flags = [
+                    "noqa:{0}".format(f.strip())
+                    for f in comment[len("noqa:") :].split(",")
+                ]
+            else:
+                flags = [
+                    f
+                    for f in comment.split()
+                    if (f.startswith("__") and f.endswith("__"))
+                ]
+                flags += [
+                    f.lower()
+                    for f in comment.split()
+                    if f in ("noqa", "NOQA", "nosec", "NOSEC", "secok", "SECOK")
+                ]
     return flags
 
 
-def ignoreCode(code, lineFlags):
+def ignoreCode(errorCode, lineFlags):
     """
     Function to check, if the given code should be ignored as per line flags.
 
-    @param code error code to be checked
+    @param errorCode error code to be checked
     @type str
     @param lineFlags list of line flags to check against
     @type list of str
-    @return flag indicating to ignore the code
+    @return flag indicating to ignore the error code
     @rtype bool
     """
     if lineFlags:
-
         if (
             "__IGNORE_WARNING__" in lineFlags
             or "noqa" in lineFlags
@@ -147,17 +171,21 @@ def ignoreCode(code, lineFlags):
             # check individual warning code
             if flag.startswith("__IGNORE_WARNING_"):
                 ignoredCode = flag[2:-2].rsplit("_", 1)[-1]
-                if code.startswith(ignoredCode):
+                if errorCode.startswith(ignoredCode):
+                    return True
+            elif flag.startswith("noqa:"):
+                ignoredCode = flag[len("noqa:") :].strip()
+                if errorCode.startswith(ignoredCode):
                     return True
 
     return False
 
 
-def securityOk(code, lineFlags):
+def securityOk(errorCode, lineFlags):  # noqa: U100
     """
-    Function to check, if the given code is an acknowledged security report.
+    Function to check, if the given error code is an acknowledged security report.
 
-    @param code error code to be checked
+    @param errorCode error code to be checked
     @type str
     @param lineFlags list of line flags to check against
     @type list of str
@@ -172,20 +200,20 @@ def securityOk(code, lineFlags):
 
 def codeStyleCheck(filename, source, args):
     """
-    Do the code style check and/or fix found errors.
+    Do the source code style check and/or fix found errors.
 
     @param filename source filename
     @type str
-    @param source string containing the code to check
-    @type str
+    @param source list of code lines to be checked
+    @type list of str
     @param args arguments used by the codeStyleCheck function (list of
         excludeMessages, includeMessages, repeatMessages, fixCodes,
         noFixCodes, fixIssues, maxLineLength, maxDocLineLength, blankLines,
         hangClosing, docType, codeComplexityArgs, miscellaneousArgs,
-        annotationArgs, securityArgs, importsArgs, errors, eol, encoding,
-        backup)
+        annotationArgs, securityArgs, importsArgs, nameOrderArgs, unusedArgs, errors,
+        eol, encoding, backup)
     @type list of (str, str, bool, str, str, bool, int, list of (int, int),
-        bool, str, dict, dict, dict, dict, list of str, str, str, bool)
+        bool, str, dict, dict, dict, dict, dict, dict, list of str, str, str, bool)
     @return tuple of statistics (dict) and list of results (tuple for each
         found violation of style (lineno, position, text, ignored, fixed,
         autofixing, fixedMsg))
@@ -197,7 +225,7 @@ def codeStyleCheck(filename, source, args):
 
 def codeStyleBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0):
     """
-    Module function to check code style for a batch of files.
+    Module function to check source code style for a batch of files.
 
     @param argumentsList list of arguments tuples as given for codeStyleCheck
     @type list
@@ -279,8 +307,10 @@ def workerTask(inputQueue, outputQueue):
     """
     Module function acting as the parallel worker for the style check.
 
-    @param inputQueue input queue (multiprocessing.Queue)
-    @param outputQueue output queue (multiprocessing.Queue)
+    @param inputQueue input queue
+    @type multiprocessing.Queue
+    @param outputQueue output queue
+    @type multiprocessing.Queue
     """
     for filename, source, args in iter(inputQueue.get, "STOP"):
         result = __checkCodeStyle(filename, source, args)
@@ -293,8 +323,8 @@ def __checkSyntax(filename, source):
 
     @param filename source filename
     @type str
-    @param source string containing the code to check
-    @type str
+    @param source list of code lines to be checked
+    @type list of str
     @return tuple containing the error dictionary with syntax error details,
         a statistics dictionary and None or a tuple containing two None and
         the generated AST tree
@@ -303,12 +333,8 @@ def __checkSyntax(filename, source):
     src = "".join(source)
 
     try:
-        tree = (
-            ast.parse(src, filename, "exec", type_comments=True)
-            # need the 'type_comments' parameter to include type annotations
-            if sys.version_info >= (3, 8)
-            else ast.parse(src, filename, "exec")
-        )
+        tree = ast.parse(src, filename, "exec", type_comments=True)
+        # need the 'type_comments' parameter to include type annotations
         return None, None, tree
     except (SyntaxError, TypeError):
         exc_type, exc = sys.exc_info()[:2]
@@ -335,28 +361,28 @@ def __checkSyntax(filename, source):
 
 def __checkCodeStyle(filename, source, args):
     """
-    Private module function to perform the code style check and/or fix
+    Private module function to perform the source code style check and/or fix
     found errors.
 
     @param filename source filename
     @type str
-    @param source string containing the code to check
-    @type str
+    @param source list of code lines to be checked
+    @type list of str
     @param args arguments used by the codeStyleCheck function (list of
         excludeMessages, includeMessages, repeatMessages, fixCodes,
         noFixCodes, fixIssues, maxLineLength, maxDocLineLength, blankLines,
         hangClosing, docType, codeComplexityArgs, miscellaneousArgs,
-        annotationArgs, securityArgs, importsArgs, errors, eol, encoding,
-        backup)
+        annotationArgs, securityArgs, importsArgs, nameOrderArgs, unusedArgs, errors,
+        eol, encoding, backup)
     @type list of (str, str, bool, str, str, bool, int, list of (int, int),
-        bool, str, dict, dict, dict, dict, list of str, str, str, bool)
+        bool, str, dict, dict, dict, dict, dict, dict, list of str, str, str, bool)
     @return tuple of statistics data and list of result dictionaries with
         keys:
         <ul>
         <li>file: file name</li>
         <li>line: line_number</li>
         <li>offset: offset within line</li>
-        <li>code: message code</li>
+        <li>code: error message code</li>
         <li>args: list of arguments to format the message</li>
         <li>ignored: flag indicating this issue was ignored</li>
         <li>fixed: flag indicating this issue was fixed</li>
@@ -383,6 +409,8 @@ def __checkCodeStyle(filename, source, args):
         annotationArgs,
         securityArgs,
         importsArgs,
+        nameOrderArgs,
+        unusedArgs,
         errors,
         eol,
         encoding,
@@ -437,7 +465,8 @@ def __checkCodeStyle(filename, source, args):
                 max_doc_length=maxDocLineLength,
                 hang_closing=hangClosing,
             )
-            report = styleGuide.check_files([filename])
+            report = styleGuide.options.report
+            styleGuide.input_file(filename, lines=source)
             stats.update(report.counters)
             errors = report.errors
 
@@ -480,26 +509,19 @@ def __checkCodeStyle(filename, source, args):
             errors += complexityChecker.errors
 
             # check function annotations
-            if sys.version_info >= (3, 8, 0):
-                # annotations with type comments are supported from
-                # Python 3.8 on
-                from Annotations.AnnotationsChecker import (  # __IGNORE_WARNING_I10__
-                    AnnotationsChecker,
-                )
-
-                annotationsChecker = AnnotationsChecker(
-                    source,
-                    filename,
-                    tree,
-                    select,
-                    ignore,
-                    [],
-                    repeatMessages,
-                    annotationArgs,
-                )
-                annotationsChecker.run()
-                stats.update(annotationsChecker.counters)
-                errors += annotationsChecker.errors
+            annotationsChecker = AnnotationsChecker(
+                source,
+                filename,
+                tree,
+                select,
+                ignore,
+                [],
+                repeatMessages,
+                annotationArgs,
+            )
+            annotationsChecker.run()
+            stats.update(annotationsChecker.counters)
+            errors += annotationsChecker.errors
 
             # check for security issues
             securityChecker = SecurityChecker(
@@ -533,6 +555,66 @@ def __checkCodeStyle(filename, source, args):
             stats.update(importsChecker.counters)
             errors += importsChecker.errors
 
+            # check name ordering
+            nameOrderChecker = NameOrderChecker(
+                source,
+                filename,
+                tree,
+                select,
+                ignore,
+                [],
+                repeatMessages,
+                nameOrderArgs,
+            )
+            nameOrderChecker.run()
+            stats.update(nameOrderChecker.counters)
+            errors += nameOrderChecker.errors
+
+            # check unused arguments and variables
+            unusedChecker = UnusedChecker(
+                source,
+                filename,
+                tree,
+                select,
+                ignore,
+                [],
+                repeatMessages,
+                unusedArgs,
+            )
+            unusedChecker.run()
+            stats.update(unusedChecker.counters)
+            errors += unusedChecker.errors
+
+            # check async function definitions
+            asyncChecker = AsyncChecker(
+                source,
+                filename,
+                tree,
+                select,
+                ignore,
+                [],
+                repeatMessages,
+                {},  # no arguments yet
+            )
+            asyncChecker.run()
+            stats.update(asyncChecker.counters)
+            errors += asyncChecker.errors
+
+            # checking logging statements
+            loggingChecker = LoggingChecker(
+                source,
+                filename,
+                tree,
+                select,
+                ignore,
+                [],
+                repeatMessages,
+                {},  # no arguments yet
+            )
+            loggingChecker.run()
+            stats.update(loggingChecker.counters)
+            errors += loggingChecker.errors
+
         elif syntaxError:
             errors = [syntaxError]
             stats.update(syntaxStats)
@@ -561,22 +643,22 @@ def __checkCodeStyle(filename, source, args):
             )
 
             if source:
-                code = error["code"]
+                errorCode = error["code"]
                 lineFlags = extractLineFlags(source[lineno - 1].strip())
                 with contextlib.suppress(IndexError):
                     lineFlags += extractLineFlags(
                         source[lineno].strip(), flagsLine=True
                     )
 
-                if securityOk(code, lineFlags):
+                if securityOk(errorCode, lineFlags):
                     error["securityOk"] = True
 
-                if ignoreCode(code, lineFlags):
+                if ignoreCode(errorCode, lineFlags):
                     error["ignored"] = True
                 else:
                     if fixer:
                         res, fixcode, fixargs, id_ = fixer.fixIssue(
-                            lineno, error["offset"], code
+                            lineno, error["offset"], errorCode
                         )
                         if res == -1:
                             deferredFixes[id_] = error
