@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -50,8 +50,11 @@ class NamingStyleChecker:
         Constructor (according to 'extended' pycodestyle.py API)
 
         @param tree AST tree of the source file
-        @param filename name of the source file (string)
+        @type ast.AST
+        @param filename name of the source file
+        @type str
         @param options options as parsed by pycodestyle.StyleGuide
+        @type optparse.Option
         """
         self.__parents = collections.deque()
         self.__tree = tree
@@ -110,6 +113,7 @@ class NamingStyleChecker:
 
         @return tuple giving line number, offset within line, code and
             checker function
+        @rtype tuple of (int, int, str, function)
         """
         if self.__tree and self.__checkers:
             return self.__visitTree(self.__tree)
@@ -121,6 +125,7 @@ class NamingStyleChecker:
         Private method to scan the given AST tree.
 
         @param node AST tree node to scan
+        @type ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -135,6 +140,7 @@ class NamingStyleChecker:
         Private method to inspect the given AST node.
 
         @param node AST tree node to inspect
+        @type ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -155,6 +161,7 @@ class NamingStyleChecker:
         static methods.
 
         @param classNode AST tree node to tag
+        @type ast.ClassDef
         """
         # try to find all 'old style decorators'
         # like m = staticmethod(m)
@@ -198,6 +205,7 @@ class NamingStyleChecker:
         Private method amend a node with global definitions information.
 
         @param functionNode AST tree node to amend
+        @type ast.FunctionDef or ast.AsyncFunctionDef
         """
         globalNames = set()
         nodesToCheck = collections.deque(ast.iter_child_nodes(functionNode))
@@ -217,7 +225,9 @@ class NamingStyleChecker:
         Private method to get the argument names of a function node.
 
         @param node AST node to extract arguments names from
-        @return list of argument names (list of string)
+        @type ast.FunctionDef or ast.AsyncFunctionDef
+        @return list of argument names
+        @rtype list of str
         """
         posArgs = [arg.arg for arg in node.args.args]
         kwOnly = [arg.arg for arg in node.args.kwonlyargs]
@@ -228,9 +238,11 @@ class NamingStyleChecker:
         Private method to build the error information.
 
         @param node AST node to report an error for
-        @param code error code to report (string)
+        @type ast.AST
+        @param code error code to report
+        @type str
         @return tuple giving line number, offset within line and error code
-            (integer, integer, string)
+        @rtype tuple of (int, int, str)
         """
         if isinstance(node, ast.Module):
             lineno = 0
@@ -250,17 +262,21 @@ class NamingStyleChecker:
         """
         Private method to check, if the given name should be avoided.
 
-        @param name name to be checked (string)
-        @return flag indicating to avoid it (boolen)
+        @param name name to be checked
+        @type str
+        @return flag indicating to avoid it
+        @rtype bool
         """
         return name in ("l", "O", "I")
 
-    def __checkNameToBeAvoided(self, node, parents):
+    def __checkNameToBeAvoided(self, node, parents):  # noqa: U100
         """
         Private class to check the given node for a name to be avoided (N831).
 
         @param node AST note to check
+        @type ast.Ast
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -300,7 +316,7 @@ class NamingStyleChecker:
         @param name name of the class
         @type str
         @param parents list of parent nodes
-        @type ast.AST
+        @type list of ast.AST
         @return node containing the class definition
         @rtype ast.ClassDef
         """
@@ -318,7 +334,7 @@ class NamingStyleChecker:
         @param name name of the class
         @type str
         @param parents list of parent nodes
-        @type ast.AST
+        @type list of ast.AST
         @param names set of collected class names (defaults to None)
         @type set of str (optional)
         @return set of class names
@@ -347,7 +363,9 @@ class NamingStyleChecker:
         Classes for internal use have a leading underscore in addition.
 
         @param node AST note to check
+        @type ast.ClassDef
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -360,7 +378,7 @@ class NamingStyleChecker:
         if "Exception" in superClasses and not name.endswith("Error"):
             yield self.__error(node, "N818")
 
-    def __checkFunctionName(self, node, parents):
+    def __checkFunctionName(self, node, parents):  # noqa: U100
         """
         Private class to check the given node for function name
         conventions (N802, N809).
@@ -372,7 +390,9 @@ class NamingStyleChecker:
         (e.g. threading.py), to retain backwards compatibility.
 
         @param node AST note to check
+        @type ast.FunctionDef or ast.AsynFunctionDef
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -387,7 +407,7 @@ class NamingStyleChecker:
         if functionType == "function" and name[:2] == "__" and name[-2:] == "__":
             yield self.__error(node, "N809")
 
-    def __checkFunctionArgumentNames(self, node, parents):
+    def __checkFunctionArgumentNames(self, node, parents):  # noqa: U100
         """
         Private class to check the argument names of functions
         (N803, N804, N805, N806).
@@ -397,7 +417,9 @@ class NamingStyleChecker:
         first argument. A method should have 'self' as the first argument.
 
         @param node AST note to check
+        @type ast.FunctionDef or ast.AsynFunctionDef
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -440,7 +462,9 @@ class NamingStyleChecker:
         Local variables in functions should be lowercase.
 
         @param node AST note to check
+        @type ast.AST
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -595,14 +619,16 @@ class NamingStyleChecker:
             )
         )
 
-    def __checkModule(self, node, parents):
+    def __checkModule(self, node, parents):  # noqa: U100
         """
         Private method to check module naming conventions (N807, N808).
 
         Module and package names should be lowercase.
 
-        @param node AST note to check
+        @param node AST node to check
+        @type ast.AST
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
@@ -617,13 +643,15 @@ class NamingStyleChecker:
                 if packageName.lower() != packageName:
                     yield self.__error(node, "N808")
 
-    def __checkImportAs(self, node, parents):
+    def __checkImportAs(self, node, parents):  # noqa: U100
         """
         Private method to check that imports don't change the
         naming convention (N811, N812, N813, N814, N815).
 
-        @param node AST note to check
+        @param node AST node to check
+        @type ast.Import
         @param parents list of parent nodes
+        @type list of ast.AST
         @yield tuple giving line number, offset within line and error code
         @ytype tuple of (int, int, str)
         """
