@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2020 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -31,7 +31,7 @@ def getChecks():
     }
 
 
-def checkNoCertificateValidation(reportError, context, config):
+def checkNoCertificateValidation(reportError, context, config):  # noqa: U100
     """
     Function to check for switched off certificate validation.
 
@@ -43,11 +43,12 @@ def checkNoCertificateValidation(reportError, context, config):
     @type dict
     """
     httpVerbs = ("get", "options", "head", "post", "put", "patch", "delete")
+    httpxAttrs = ("request", "stream", "Client", "AsyncClient") + httpVerbs
+    qualName = context.callFunctionNameQual.split(".")[0]
     if (
-        "requests" in context.callFunctionNameQual
-        and context.callFunctionName in httpVerbs
-        and context.checkCallArgValue("verify", "False")
-    ):
+        (qualName == "requests" and context.callFunctionName in httpVerbs)
+        or (qualName == "httpx" and context.callFunctionName in httpxAttrs)
+    ) and context.checkCallArgValue("verify", "False"):
         reportError(
             context.getLinenoForCallArg("verify") - 1,
             context.getOffsetForCallArg("verify"),
