@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2020 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -31,7 +31,7 @@ def getChecks():
     }
 
 
-def checkParamikoCalls(reportError, context, config):
+def checkParamikoCalls(reportError, context, config):  # noqa: U100
     """
     Function to check for shell injection within Paramiko.
 
