@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2020 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -74,7 +74,7 @@ _securityMessages = {
         "'tarfile.extractall()' used without any validation. Please check and"
         " discard dangerous members.",
     ),
-    # blacklisted calls
+    # prohibited calls
     "S301": QCoreApplication.translate(
         "Security",
         "Pickle and modules that wrap it can be unsafe when used to "
@@ -106,12 +106,6 @@ _securityMessages = {
         "Use of mark_safe() may expose cross-site scripting vulnerabilities"
         " and should be reviewed.",
     ),
-    "S309": QCoreApplication.translate(
-        "Security",
-        "Use of HTTPSConnection on older versions of Python prior to 2.7.9"
-        " and 3.4.3 do not provide security, see"
-        " https://wiki.openstack.org/wiki/OSSN/OSSN-0033",
-    ),
     "S310": QCoreApplication.translate(
         "Security",
         "Audit url open for permitted schemes. Allowing use of file:/ or"
@@ -195,11 +189,6 @@ _securityMessages = {
         " reverts to the previous behavior that does not validate"
         " certificates or perform hostname checks.",
     ),
-    "S324": QCoreApplication.translate(
-        "Security",
-        "Use of os.tempnam() and os.tmpnam() is vulnerable to symlink"
-        " attacks. Consider using tmpfile() instead.",
-    ),
     # hashlib.new
     "S331": QCoreApplication.translate(
         "Security", "Use of insecure {0} hash function."
@@ -208,7 +197,7 @@ _securityMessages = {
         "Security",
         "Use of insecure {0} hash for security. Consider 'usedforsecurity=False'.",
     ),
-    # blacklisted imports
+    # prohibited imports
     "S401": QCoreApplication.translate(
         "Security",
         "A telnet-related module is being imported.  Telnet is considered"
@@ -395,6 +384,11 @@ _securityMessages = {
     "S611": QCoreApplication.translate(
         "Security", "Use of 'RawSQL()' opens a potential SQL attack vector."
     ),
+    # insecure logging.config.listen()
+    "S612": QCoreApplication.translate(
+        "Security",
+        "Use of insecure logging.config.listen() detected.",
+    ),
     # Jinja2 templates
     "S701.1": QCoreApplication.translate(
         "Security",
