@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,10 +17,12 @@ try:
     from ast import unparse
 except ImportError:
     # Python < 3.9
-    from .ast_unparse import unparse
+    from ast_unparse import unparse
+
+import AstUtilities
 
 ###############################################################################
-## The following code is derived from the flake8-simplify package (v0.19.3).
+## adapted from: flake8-simplify v0.21.0
 ##
 ## Original License:
 ##
@@ -47,10 +49,6 @@ except ImportError:
 ## IN THE SOFTWARE.
 ###############################################################################
 
-BOOL_CONST_TYPES = (ast.Constant, ast.NameConstant)
-AST_CONST_TYPES = (ast.Constant, ast.NameConstant, ast.Str, ast.Num)
-STR_TYPES = (ast.Constant, ast.Str)
-
 
 class SimplifyNodeVisitor(ast.NodeVisitor):
     """
@@ -182,6 +180,8 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         self.__check901(node)
         self.__check905(node)
         self.__check906(node)
+        self.__check910(node)
+        self.__check911(node)
 
         self.generic_visit(node)
 
@@ -294,7 +294,6 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         """
         return isinstance(expr.op, ast.Add) and (
             (isinstance(expr.value, ast.Constant) and expr.value.value == 1)
-            or (isinstance(expr.value, ast.Num) and expr.value.n == 1)
         )
 
     def __getIfBodyPairs(self, node):
@@ -525,13 +524,13 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         if not (
             len(node.body) != 1
             or not isinstance(node.body[0], ast.Return)
-            or not isinstance(node.body[0].value, BOOL_CONST_TYPES)
+            or not isinstance(node.body[0].value, ast.Constant)
             or not (
                 node.body[0].value.value is True or node.body[0].value.value is False
             )
             or len(node.orelse) != 1
             or not isinstance(node.orelse[0], ast.Return)
-            or not isinstance(node.orelse[0].value, BOOL_CONST_TYPES)
+            or not isinstance(node.orelse[0].value, ast.Constant)
             or not (
                 node.orelse[0].value.value is True
                 or node.orelse[0].value.value is False
@@ -779,7 +778,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             and isinstance(node.body[0], ast.If)
             and len(node.body[0].body) == 1
             and isinstance(node.body[0].body[0], ast.Return)
-            and isinstance(node.body[0].body[0].value, BOOL_CONST_TYPES)
+            and isinstance(node.body[0].body[0].value, ast.Constant)
             and hasattr(node.body[0].body[0].value, "value")
             and isinstance(node.next_sibling, ast.Return)
         ):
@@ -823,7 +822,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             and (
                 (
                     isinstance(node.value.slice, ast.Index)
-                    and isinstance(node.value.slice.value, STR_TYPES)
+                    and isinstance(node.value.slice.value, ast.Constant)
                 )
                 or isinstance(node.value.slice, ast.Constant)
             )
@@ -834,10 +833,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             if isinstance(slice_, ast.Index):
                 # Python < 3.9
                 stringPart = slice_.value  # type: ignore
-                if isinstance(stringPart, ast.Str):
-                    envName = stringPart.s  # Python 3.6 / 3.7 fallback
-                else:
-                    envName = stringPart.value
+                envName = stringPart.value
             elif isinstance(slice_, ast.Constant):
                 # Python 3.9
                 envName = slice_.value
@@ -854,15 +850,12 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             and node.value.func.value.attr == "environ"
             and node.value.func.attr == "get"
             and len(node.value.args) in [1, 2]
-            and isinstance(node.value.args[0], STR_TYPES)
+            and isinstance(node.value.args[0], ast.Constant)
         )
         if isGetCall:
             call = node.value
             stringPart = call.args[0]
-            if isinstance(stringPart, ast.Str):
-                envName = stringPart.s  # Python 3.6 / 3.7 fallback
-            else:
-                envName = stringPart.value
+            envName = stringPart.value
             # Check if this has a change
             hasChange = envName != envName.upper()
         if not (isIndexCall or isGetCall) or not hasChange:
@@ -1005,7 +998,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             and len(node.test.ops) == 1
             and isinstance(node.test.ops[0], ast.Eq)
             and len(node.test.comparators) == 1
-            and isinstance(node.test.comparators[0], AST_CONST_TYPES)
+            and isinstance(node.test.comparators[0], ast.Constant)
             and len(node.body) == 1
             and isinstance(node.body[0], ast.Return)
             and len(node.orelse) == 1
@@ -1018,15 +1011,13 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
                 bodyValueStr = unparse(node.body[0].value).strip("'")
             else:
                 bodyValueStr = "None"
-            if isinstance(node.test.comparators[0], ast.Str):
+            if AstUtilities.isString(node.test.comparators[0]):
                 value = (
                     bodyValueStr
                     if bodyValueStr[0] == '"' and bodyValueStr[-1] == '"'
                     else bodyValueStr[1:-1]
                 )
                 keyValuePairs = {node.test.comparators[0].s: value}
-            elif isinstance(node.test.comparators[0], ast.Num):
-                keyValuePairs = {node.test.comparators[0].n: bodyValueStr}
             else:
                 keyValuePairs = {node.test.comparators[0].value: bodyValueStr}
             while child:
@@ -1037,7 +1028,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
                     and len(child.test.ops) == 1
                     and isinstance(child.test.ops[0], ast.Eq)
                     and len(child.test.comparators) == 1
-                    and isinstance(child.test.comparators[0], AST_CONST_TYPES)
+                    and isinstance(child.test.comparators[0], ast.Constant)
                     and len(child.body) == 1
                     and isinstance(child.body[0], ast.Return)
                     and len(child.orelse) <= 1
@@ -1048,12 +1039,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
                 if isinstance(returnCall.value, ast.Call):
                     return
 
-                if isinstance(child.test.comparators[0], ast.Str):
-                    key = child.test.comparators[0].s
-                elif isinstance(child.test.comparators[0], ast.Num):
-                    key = child.test.comparators[0].n
-                else:
-                    key = child.test.comparators[0].value
+                key = child.test.comparators[0].value
 
                 value = unparse(child.body[0].value)
                 if value[0] == '"' and value[-1] == '"':
@@ -1536,9 +1522,9 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         """
         # True if a else False
         if (
-            isinstance(node.body, BOOL_CONST_TYPES)
+            isinstance(node.body, ast.Constant)
             and node.body.value is True
-            and isinstance(node.orelse, BOOL_CONST_TYPES)
+            and isinstance(node.orelse, ast.Constant)
             and node.orelse.value is False
         ):
             cond = unparse(node.test)
@@ -1557,9 +1543,9 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         """
         # False if a else True
         if (
-            isinstance(node.body, BOOL_CONST_TYPES)
+            isinstance(node.body, ast.Constant)
             and node.body.value is False
-            and isinstance(node.orelse, BOOL_CONST_TYPES)
+            and isinstance(node.orelse, ast.Constant)
             and node.orelse.value is True
         ):
             cond = unparse(node.test)
@@ -1647,7 +1633,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         # a or True
         if isinstance(node.op, ast.Or):
             for exp in node.values:
-                if isinstance(exp, BOOL_CONST_TYPES) and exp.value is True:
+                if isinstance(exp, ast.Constant) and exp.value is True:
                     self.__error(node.lineno - 1, node.col_offset, "Y223")
 
     def __check224(self, node):
@@ -1660,7 +1646,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         # a and False
         if isinstance(node.op, ast.And):
             for exp in node.values:
-                if isinstance(exp, BOOL_CONST_TYPES) and exp.value is False:
+                if isinstance(exp, ast.Constant) and exp.value is False:
                     self.__error(node.lineno - 1, node.col_offset, "Y224")
 
     def __check301(self, node):
@@ -1672,16 +1658,15 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         """
         # 42 == age
         if (
-            isinstance(node.left, AST_CONST_TYPES)
+            isinstance(node.left, ast.Constant)
             and len(node.ops) == 1
             and isinstance(node.ops[0], ast.Eq)
         ):
             left = unparse(node.left)
-            isPy37Str = isinstance(node.left, ast.Str)
-            isPy38Str = isinstance(node.left, ast.Constant) and isinstance(
+            isStr = isinstance(node.left, ast.Constant) and isinstance(
                 node.left.value, str
             )
-            if isPy37Str or isPy38Str:
+            if isStr:
                 left = f"'{left}'"
             right = unparse(node.comparators[0])
             self.__error(node.lineno - 1, node.col_offset, "Y301", left, right)
@@ -1776,12 +1761,9 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
         if (
             isinstance(node.func, ast.Attribute)
             and node.func.attr == "split"
-            and isinstance(node.func.value, (ast.Str, ast.Constant))
+            and isinstance(node.func.value, ast.Constant)
         ):
-            if isinstance(node.func.value, ast.Constant):
-                value = node.func.value.value
-            else:
-                value = node.func.value.s
+            value = node.func.value.value
 
             expected = json.dumps(value.split())
             actual = unparse(node.func.value) + ".split()"
@@ -1793,8 +1775,8 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
 
         @param node reference to the AST node to be checked
         @type ast.Call
-        """
-        # __IGNORE_WARNING_D234r__
+        """  # __IGNORE_WARNING_D234r__
+
         def getOsPathJoinArgs(node):
             names = []
             for arg in node.args:
@@ -1810,8 +1792,8 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
                     names += getOsPathJoinArgs(arg)
                 elif isinstance(arg, ast.Name):
                     names.append(arg.id)
-                elif isinstance(arg, ast.Str):
-                    names.append(f"'{arg.s}'")
+                elif AstUtilities.isString(arg):
+                    names.append(f"'{arg.value}'")
             return names
 
         if (
@@ -1863,7 +1845,7 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             hasNone = False
             others = []
             for elt in tupleVar.elts:
-                if isinstance(elt, BOOL_CONST_TYPES) and elt.value is None:
+                if isinstance(elt, ast.Constant) and elt.value is None:
                     hasNone = True
                 else:
                     others.append(elt)
@@ -1891,6 +1873,62 @@ class SimplifyNodeVisitor(ast.NodeVisitor):
             srccode = unparse(node)
             self.__error(node.lineno - 1, node.col_offset, "Y909", srccode)
 
+    def __check910(self, node):
+        """
+        Private method to check for uses of 'dict.get(key, None)'.
+
+        @param node reference to the AST node to be checked
+        @type ast.Call
+        """
+        if not (
+            isinstance(node.func, ast.Attribute)
+            and node.func.attr == "get"
+            and isinstance(node.func.ctx, ast.Load)
+        ):
+            return
+
+        # check the argument value
+        if not (
+            len(node.args) == 2
+            and isinstance(node.args[1], ast.Constant)
+            and node.args[1].value is None
+        ):
+            return
+
+        actual = unparse(node)
+        func = unparse(node.func)
+        key = unparse(node.args[0])
+        expected = f"{func}({key})"
+        self.__error(node.lineno - 1, node.col_offset, "Y910", expected, actual)
+
+    def __check911(self, node):
+        """
+        Private method to check for the expression "zip(_.keys(), _.values())".
+
+        @param node reference to the AST node to be checked
+        @type ast.Call
+        """
+        if isinstance(node, ast.Call) and (
+            isinstance(node.func, ast.Name)
+            and node.func.id == "zip"
+            and len(node.args) == 2
+        ):
+            firstArg, secondArg = node.args
+            if (
+                isinstance(firstArg, ast.Call)
+                and isinstance(firstArg.func, ast.Attribute)
+                and isinstance(firstArg.func.value, ast.Name)
+                and firstArg.func.attr == "keys"
+                and isinstance(secondArg, ast.Call)
+                and isinstance(secondArg.func, ast.Attribute)
+                and isinstance(secondArg.func.value, ast.Name)
+                and secondArg.func.attr == "values"
+                and firstArg.func.value.id == secondArg.func.value.id
+            ):
+                self.__error(
+                    node.lineno - 1, node.col_offset, "Y911", firstArg.func.value.id
+                )
+
 
 #
 # eflag: noqa = M891
