@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,17 +16,21 @@ from .Annotations.translations import (
     _annotationsMessages,
     _annotationsMessagesSampleArgs,
 )
+from .Async.translations import _asyncMessages, _asyncMessageSampleArgs
 from .Complexity.translations import _complexityMessages, _complexityMessagesSampleArgs
 from .DocStyle.translations import _docStyleMessages, _docStyleMessagesSampleArgs
 from .Imports.translations import _importsMessages, _importsMessagesSampleArgs
+from .Logging.translations import _loggingMessages, _loggingMessagesSampleArgs
 from .Miscellaneous.translations import (
     _miscellaneousMessages,
     _miscellaneousMessagesSampleArgs,
 )
+from .NameOrder.translations import _nameOrderMessages, _nameOrderMessagesSampleArgs
 from .Naming.translations import _namingStyleMessages
 from .PathLib.translations import _pathlibMessages
 from .Security.translations import _securityMessages, _securityMessagesSampleArgs
 from .Simplify.translations import _simplifyMessages, _simplifyMessagesSampleArgs
+from .Unused.translations import _unusedMessages, _unusedMessagesSampleArgs
 
 ##################################################################
 ## pycodestyle error messages
@@ -194,7 +198,9 @@ _pycodestyleErrorMessages = {
         "pycodestyle", "test for object identity should be 'is not'"
     ),
     "E721": QCoreApplication.translate(
-        "pycodestyle", "do not compare types, use 'isinstance()'"
+        "pycodestyle",
+        "do not compare types, for exact checks use 'is' / 'is not', "
+        "for instance checks use 'isinstance()'",
     ),
     "E722": QCoreApplication.translate("pycodestyle", "do not use bare except"),
     "E731": QCoreApplication.translate(
@@ -230,16 +236,6 @@ _pycodestyleWarningMessages = {
     "W505": QCoreApplication.translate(
         "pycodestyle", "doc line too long ({0} > {1} characters)"
     ),
-    "W601": QCoreApplication.translate(
-        "pycodestyle", ".has_key() is deprecated, use 'in'"
-    ),
-    "W602": QCoreApplication.translate(
-        "pycodestyle", "deprecated form of raising exception"
-    ),
-    "W603": QCoreApplication.translate("pycodestyle", "'<>' is deprecated, use '!='"),
-    "W604": QCoreApplication.translate(
-        "pycodestyle", "backticks are deprecated, use 'repr()'"
-    ),
     "W605": QCoreApplication.translate(
         "pycodestyle", "invalid escape sequence '\\{0}'"
     ),
@@ -430,14 +426,18 @@ _fixMessagesSampleArgs = {
 
 messageCatalogs = {
     "A": _annotationsMessages,
+    "ASY": _asyncMessages,
     "C": _complexityMessages,
     "D": _docStyleMessages,
     "E": _pycodestyleErrorMessages,
     "I": _importsMessages,
+    "L": _loggingMessages,
     "M": _miscellaneousMessages,
     "N": _namingStyleMessages,
+    "NO": _nameOrderMessages,
     "P": _pathlibMessages,
     "S": _securityMessages,
+    "U": _unusedMessages,
     "W": _pycodestyleWarningMessages,
     "Y": _simplifyMessages,
     "FIX": _fixMessages,
@@ -445,18 +445,23 @@ messageCatalogs = {
 
 messageSampleArgsCatalog = {
     "A": _annotationsMessagesSampleArgs,
+    "ASY": _asyncMessageSampleArgs,
     "C": _complexityMessagesSampleArgs,
     "D": _docStyleMessagesSampleArgs,
     "E": _pycodestyleErrorMessagesSampleArgs,
     "I": _importsMessagesSampleArgs,
+    "L": _loggingMessagesSampleArgs,
     "M": _miscellaneousMessagesSampleArgs,
+    "NO": _nameOrderMessagesSampleArgs,
     "S": _securityMessagesSampleArgs,
+    "U": _unusedMessagesSampleArgs,
     "W": _pycodestyleWarningMessagesSampleArgs,
     "Y": _simplifyMessagesSampleArgs,
     "FIX": _fixMessagesSampleArgs,
 }
 
 messageCategoryRe = re.compile(r"([A-Z]{1,3}).+")
+# message category is max. 3 characters
 
 
 def getTranslatedMessage(messageCode, messageArgs, example=False):
@@ -521,7 +526,7 @@ def getMessageCodes():
     """
     knownCodes = []
     for catalog in messageCatalogs.values():
-        knownCodes += list(catalog.keys())
+        knownCodes += list(catalog)
     return {c.split(".", 1)[0] for c in knownCodes}
 
 
