@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -72,6 +72,8 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         self.__fileList = []
         self.__project = None
+        self.__arguments = ()
+        self.__statistics = self.__defaultStatistics()
         self.filterFrame.setVisible(False)
 
         self.checkProgress.setVisible(False)
@@ -93,6 +95,65 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             self.resultList.sortColumn(), self.resultList.header().sortIndicatorOrder()
         )
 
+    def __defaultStatistics(self):
+        """
+        Private method to return the default statistics entry.
+
+        @return dictionary with default statistics entry
+        @rtype dict
+        """
+        return {
+            "files_checked": 0,
+            "files_issues": 0,
+            "errors": 0,
+            "py_warnings": 0,
+            "warnings": 0,
+        }
+
+    def __updateStatistics(self, fileStatistics):
+        """
+        Private method to update the statistics.
+
+        @param fileStatistics dictionary containing the file statistics
+        @type dict
+        """
+        self.__statistics["files_checked"] += 1
+        if any(fileStatistics.values()):
+            self.__statistics["files_issues"] += 1
+        self.__statistics["errors"] += fileStatistics["errors"]
+        self.__statistics["py_warnings"] += fileStatistics["py_warnings"]
+        self.__statistics["warnings"] += fileStatistics["warnings"]
+
+    def __resetStatistics(self, skipped):
+        """
+        Private method to reset the statistics data.
+
+        @param skipped number of files not being checked
+        @type int
+        """
+        self.__statistics["files_checked"] = 0
+        self.__statistics["files_skipped"] = skipped
+        self.__statistics["files_issues"] = 0
+        self.__statistics["errors"] = 0
+        self.__statistics["py_warnings"] = 0
+        self.__statistics["warnings"] = 0
+
+    def __createFileStatistics(self, problems):
+        """
+        Private method to return the file statistics entry.
+
+        @param problems dictionary with the keys 'error', 'py_warnings' and
+            'warnings' which hold a list of issues each
+        @type dict
+        @return dictionary with the file statistics
+        @rtype dict
+        """
+        return {
+            "errors": 1 if problems.get("error") else 0,
+            "py_warnings": len(problems.get("py_warnings", [])),
+            "warnings": len(problems.get("warnings", [])),
+        }
+
     def __createErrorItem(self, filename, message):
         """
         Private slot to create a new error item in the result list.
@@ -112,6 +173,43 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             itm = QTreeWidgetItem(self.__errorItem, [msg])
             itm.setForeground(0, Qt.GlobalColor.red)
             itm.setFirstColumnSpanned(True)
+            itm.setData(0, self.filenameRole, filename)
+
+    def __createHeaderItem(self, filename, fileStatistics=None):
+        """
+        Private method to create a header item in the result list.
+
+        @param filename file name of file
+        @type str
+        @param fileStatistics dictionary containing statistical data of the check
+            result (defaults to None)
+        @type dict (optional)
+        """
+        itemText = self.__project.getRelativePath(filename)
+
+        if fileStatistics:
+            statisticsTextList = []
+            if fileStatistics["errors"]:
+                statisticsTextList.append(
+                    self.tr("Errors: {0}").format(fileStatistics["errors"])
+                )
+            if fileStatistics["py_warnings"]:
+                statisticsTextList.append(
+                    self.tr("Python Warnings: {0}").format(
+                        fileStatistics["py_warnings"]
+                    )
+                )
+            if fileStatistics["warnings"]:
+                statisticsTextList.append(
+                    self.tr("Warnings: {0}").format(fileStatistics["warnings"])
+                )
+            if statisticsTextList:
+                itemText += "{0}\n{1}".format(itemText, ", ".join(statisticsTextList))
+
+        self.__lastFileItem = QTreeWidgetItem(self.resultList, [itemText])
+        self.__lastFileItem.setFirstColumnSpanned(True)
+        self.__lastFileItem.setExpanded(True)
+        self.__lastFileItem.setData(0, self.filenameRole, filename)
 
     def __createResultItem(
         self, filename, line, index, error, sourcecode, isWarning=False
@@ -137,12 +235,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             or self.__lastFileItem.data(0, self.filenameRole) != filename
         ):
             # It's a new file
-            self.__lastFileItem = QTreeWidgetItem(
-                self.resultList, [self.__project.getRelativePath(filename)]
-            )
-            self.__lastFileItem.setFirstColumnSpanned(True)
-            self.__lastFileItem.setExpanded(True)
-            self.__lastFileItem.setData(0, self.filenameRole, filename)
+            self.__createHeaderItem(filename)
 
         itm = QTreeWidgetItem(self.__lastFileItem)
         if isWarning:
@@ -158,6 +251,15 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         itm.setData(0, self.errorRole, error)
         itm.setData(0, self.warningRole, isWarning)
 
+    def setArguments(self, args):
+        """
+        Public method to set additional arguments to be used by the syntax check.
+
+        @param args tuple containing the additional arguments
+        @type tuple of Any
+        """
+        self.__arguments = args
+
     def prepare(self, fileList, project):
         """
         Public method to prepare the dialog with a list of filenames.
@@ -179,7 +281,11 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.__data = self.__project.getData("CHECKERSPARMS", "SyntaxChecker")
         if self.__data is None or "ExcludeFiles" not in self.__data:
             self.__data = {"ExcludeFiles": ""}
+        if "AdditionalBuiltins" not in self.__data:
+            self.__data["AdditionalBuiltins"] = ""
+
         self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
+        self.builtinsEdit.setText(self.__data["AdditionalBuiltins"])
 
     def startForBrowser(self, fn):
         """
@@ -214,11 +320,15 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             self.__data = self.__project.getData("CHECKERSPARMS", "SyntaxChecker")
             if self.__data is None or "ExcludeFiles" not in self.__data:
                 self.__data = {"ExcludeFiles": ""}
+            if "AdditionalBuiltins" not in self.__data:
+                self.__data["AdditionalBuiltins"] = ""
+
             self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
+            self.builtinsEdit.setText(self.__data["AdditionalBuiltins"])
 
             self.on_startButton_clicked()  # press the start button
 
-    def start(self, fn, codestring=""):
+    def start(self, fn, codestring="", skipped=0):
         """
         Public slot to start the syntax check.
 
@@ -227,6 +337,8 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         @param codestring string containing the code to be checked. If this is given,
             fn must be a single file name.
         @type str
+        @param skipped number of files not being checked
+        @type int
         """
         self.__batch = False
 
@@ -261,6 +373,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
             self.__errorItem = None
             self.__clearErrors(self.files)
+            self.__resetStatistics(skipped)
 
             if codestring or len(self.files) > 0:
                 self.checkProgress.setMaximum(max(1, len(self.files)))
@@ -302,6 +415,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             return
 
         self.__lastFileItem = None
+        self.__finished = False
 
         if codestring:
             self.source = Utilities.normalizeCode(codestring)
@@ -309,7 +423,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             try:
                 self.source = Utilities.readEncodedFile(self.filename)[0]
                 self.source = Utilities.normalizeCode(self.source)
-            except (UnicodeError, OSError) as msg:
+            except (OSError, UnicodeError) as msg:
                 self.noResults = False
                 self.__createResultItem(
                     self.filename,
@@ -323,8 +437,9 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 self.check()
                 return
 
-        self.__finished = False
-        self.syntaxCheckService.syntaxCheck(None, self.filename, self.source)
+        self.syntaxCheckService.syntaxCheck(
+            None, self.filename, self.source, *self.__arguments
+        )
 
     def checkBatch(self):
         """
@@ -333,6 +448,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         The results are reported to the __processResult slot.
         """
         self.__lastFileItem = None
+        self.__finished = False
 
         argumentsList = []
         for progress, filename in enumerate(self.files, start=1):
@@ -344,7 +460,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             try:
                 source = Utilities.readEncodedFile(filename)[0]
                 source = Utilities.normalizeCode(source)
-            except (UnicodeError, OSError) as msg:
+            except (OSError, UnicodeError) as msg:
                 self.noResults = False
                 self.__createResultItem(
                     self.filename,
@@ -355,13 +471,12 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 )
                 continue
 
-            argumentsList.append((filename, source))
+            argumentsList.append((filename, source, *self.__arguments))
 
         # reset the progress bar to the checked files
         self.checkProgress.setValue(self.progress)
         QApplication.processEvents()
 
-        self.__finished = False
         self.syntaxCheckService.syntaxBatchCheck(argumentsList)
 
     def __batchFinished(self):
@@ -392,11 +507,13 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
         @param fn filename of the checked file
         @type str
-        @param problems dictionary with the keys 'error' and 'warnings' which
-            hold a list containing details about the error/ warnings
-            (file name, line number, column, codestring (only at syntax
-            errors), the message)
-        @type dict
+        @param problems list of dictionaries with the keys 'error', 'py_warnings' and
+            'warnings' which contain a tuple with details about the syntax error or a
+            list of tuples with details about Python warnings and PyFlakes warnings.
+            Each tuple contains the file name, line number, column, code string (only
+            for syntax errors), the message and an optional list with arguments for
+            the message.
+        @type list of dict
         """
         if self.__finished:
             return
@@ -406,33 +523,38 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         if not self.__batch and fn != self.filename:
             return
 
-        error = problems.get("error")
-        if error:
-            self.noResults = False
-            _fn, lineno, col, code, msg = error
-            self.__createResultItem(_fn, lineno, col, msg, code, False)
+        fileStatistics = self.__createFileStatistics(problems)
+        self.__updateStatistics(fileStatistics)
+        if any(fileStatistics.values()):
+            self.__createHeaderItem(fn, fileStatistics)
 
-        warnings = problems.get("warnings", [])
-        if warnings:
-            if self.__batch:
-                try:
-                    source = Utilities.readEncodedFile(fn)[0]
-                    source = Utilities.normalizeCode(source)
-                    source = source.splitlines()
-                except (UnicodeError, OSError):
-                    source = ""
-            else:
-                source = self.source.splitlines()
-            for filename, lineno, col, _code, msg in warnings:
+            error = problems.get("error")
+            if error:
                 self.noResults = False
-                if source:
+                filename, lineno, col, code, msg = error
+                self.__createResultItem(filename, lineno, col, msg, code, False)
+
+            warnings = problems.get("py_warnings", []) + problems.get("warnings", [])
+            if warnings:
+                if self.__batch:
                     try:
-                        scr_line = source[lineno - 1].strip()
-                    except IndexError:
-                        scr_line = ""
+                        source = Utilities.readEncodedFile(fn)[0]
+                        source = Utilities.normalizeCode(source)
+                        source = source.splitlines()
+                    except (OSError, UnicodeError):
+                        source = ""
                 else:
-                    scr_line = ""
-                self.__createResultItem(filename, lineno, col, msg, scr_line, True)
+                    source = self.source.splitlines()
+                for filename, lineno, col, _code, msg in warnings:
+                    self.noResults = False
+                    if source:
+                        try:
+                            src_line = source[lineno - 1].strip()
+                        except IndexError:
+                            src_line = ""
+                    else:
+                        src_line = ""
+                    self.__createResultItem(filename, lineno, col, msg, src_line, True)
 
         self.progress += 1
         self.checkProgress.setValue(self.progress)
@@ -444,6 +566,20 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         if not self.__batch:
             self.check()
 
+    def __updateStatisticsArea(self):
+        """
+        Private method to update the statistics area of the dialog.
+        """
+        self.totalLabel.setText(
+            str(self.__statistics["files_skipped"] + self.__statistics["files_checked"])
+        )
+        self.skippedLabel.setText(str(self.__statistics["files_skipped"]))
+        self.checkedLabel.setText(str(self.__statistics["files_checked"]))
+        self.issuesLabel.setText(str(self.__statistics["files_issues"]))
+        self.errorsLabel.setText(str(self.__statistics["errors"]))
+        self.warningsLabel.setText(str(self.__statistics["warnings"]))
+        self.pyWarningsLabel.setText(str(self.__statistics["py_warnings"]))
+
     def __finish(self):
         """
         Private slot called when the syntax check finished or the user
@@ -473,9 +609,29 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 QHeaderView.ResizeMode.ResizeToContents
             )
             self.resultList.header().setStretchLastSection(True)
+            self.__updateStatisticsArea()
 
             self.checkProgress.setVisible(False)
 
+    def __cancel(self):
+        """
+        Private method to cancel the current check run.
+        """
+        if self.__batch:
+            self.syntaxCheckService.cancelSyntaxBatchCheck()
+            QTimer.singleShot(1000, self.__finish)
+        else:
+            self.__finish()
+
+    def closeEvent(self, evt):
+        """
+        Protected method to handle a close event.
+
+        @param evt reference to the close event
+        @type QCloseEvent
+        """
+        self.__cancel()
+
     def on_buttonBox_clicked(self, button):
         """
         Private slot called by a button of the button box clicked.
@@ -486,11 +642,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
         elif button == self.buttonBox.button(QDialogButtonBox.StandardButton.Cancel):
-            if self.__batch:
-                self.syntaxCheckService.cancelSyntaxBatchCheck()
-                QTimer.singleShot(1000, self.__finish)
-            else:
-                self.__finish()
+            self.__cancel()
         elif button == self.showButton:
             self.on_showButton_clicked()
 
@@ -500,13 +652,12 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         Private slot to start a syntax check run.
         """
         fileList = self.__fileList[:]
+        totalLen = len(fileList)
 
         filterString = self.excludeFilesEdit.text()
-        if (
-            "ExcludeFiles" not in self.__data
-            or filterString != self.__data["ExcludeFiles"]
-        ):
-            self.__data["ExcludeFiles"] = filterString
+        self.__data["ExcludeFiles"] = filterString
+        self.__data["AdditionalBuiltins"] = self.builtinsEdit.text().strip()
+        if self.__data != self.__project.getData("CHECKERSPARMS", "SyntaxChecker"):
             self.__project.setData("CHECKERSPARMS", "SyntaxChecker", self.__data)
         filterList = [f.strip() for f in filterString.split(",") if f.strip()]
         if filterList:
@@ -516,8 +667,10 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.resultList.clear()
         self.noResults = True
         self.cancelled = False
-        self.start(fileList)
+        self.setArguments((self.__data["AdditionalBuiltins"].split(),))
+        self.start(fileList, skipped=totalLen - len(fileList))
 
+    @pyqtSlot(QTreeWidgetItem, int)
     def on_resultList_itemActivated(self, itm, col):
         """
         Private slot to handle the activation of an item.
@@ -527,7 +680,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         @param col column the item was activated in
         @type int
         """
-        if self.noResults:
+        if self.noResults or itm.data(0, self.filenameRole) is None:
             return
 
         vm = ericApp().getObject("ViewManager")
@@ -577,31 +730,31 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             selectedIndexes = list(range(self.resultList.topLevelItemCount()))
         for index in selectedIndexes:
             itm = self.resultList.topLevelItem(index)
-            fn = os.path.abspath(itm.data(0, self.filenameRole))
-            vm.openSourceFile(fn, 1)
-            editor = vm.getOpenEditor(fn)
-            editor.clearSyntaxError()
-            editor.clearFlakesWarnings()
-            for cindex in range(itm.childCount()):
-                citm = itm.child(cindex)
-                lineno = citm.data(0, self.lineRole)
-                index = citm.data(0, self.indexRole)
-                error = citm.data(0, self.errorRole)
-                if citm.data(0, self.warningRole):
-                    editor.toggleWarning(lineno, 0, True, error)
-                else:
-                    editor.toggleSyntaxError(lineno, index, True, error, show=True)
+            if itm.data(0, self.filenameRole) is not None:
+                fn = os.path.abspath(itm.data(0, self.filenameRole))
+                vm.openSourceFile(fn, 1)
+                editor = vm.getOpenEditor(fn)
+                editor.clearSyntaxError()
+                editor.clearFlakesWarnings()
+                for cindex in range(itm.childCount()):
+                    citm = itm.child(cindex)
+                    lineno = citm.data(0, self.lineRole)
+                    index = citm.data(0, self.indexRole)
+                    error = citm.data(0, self.errorRole)
+                    if citm.data(0, self.warningRole):
+                        editor.toggleWarning(lineno, 0, True, error)
+                    else:
+                        editor.toggleSyntaxError(lineno, index, True, error, show=True)
 
         # go through the list again to clear syntax error and
         # flakes warning markers for files, that are ok
-        openFiles = vm.getOpenFilenames()
         errorFiles = []
         for index in range(self.resultList.topLevelItemCount()):
             itm = self.resultList.topLevelItem(index)
             errorFiles.append(os.path.abspath(itm.data(0, self.filenameRole)))
-        for file in openFiles:
-            if file not in errorFiles:
-                editor = vm.getOpenEditor(file)
+        for fn in vm.getOpenFilenames():
+            if fn not in errorFiles:
+                editor = vm.getOpenEditor(fn)
                 editor.clearSyntaxError()
                 editor.clearFlakesWarnings()
 
