@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -34,9 +34,12 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         Constructor
 
-        @param project reference to the project object (Project.Project)
+        @param project reference to the project object
+        @type Project
         @param parms parameters to set in the dialog
+        @type dict
         @param parent parent widget of this dialog
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -406,7 +409,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         Private method to select a color.
 
-        @param colorKey key of the color to select (string)
+        @param colorKey key of the color to select
+        @type str
         """
         color = QColorDialog.getColor(QColor(self.colors[colorKey]))
         if color.isValid():
@@ -500,7 +504,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         Private slot to toggle the generation of QtHelp files.
 
-        @param enabled flag indicating the state (boolean)
+        @param enabled flag indicating the state
+        @type bool
         """
         self.__checkQtHelpOptions()
 
@@ -509,7 +514,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         Private slot to check the namespace.
 
-        @param txt text of the line edit (string)
+        @param txt text of the line edit
+        @type str
         """
         self.__checkQtHelpOptions()
 
@@ -518,7 +524,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         Private slot to check the virtual folder.
 
-        @param txt text of the line edit (string)
+        @param txt text of the line edit
+        @type str
         """
         self.__checkQtHelpOptions()
 
@@ -527,7 +534,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         Private slot to check the title.
 
-        @param txt text of the line edit (string)
+        @param txt text of the line edit
+        @type str
         """
         self.__checkQtHelpOptions()
 
