@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,8 +21,10 @@ class GitListDialog(QDialog, Ui_GitListDialog):
         """
         Constructor
 
-        @param selections list of entries to select from (list of string)
-        @param parent reference to the parent widget (QWidget)
+        @param selections list of entries to select from
+        @type list of str
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -33,7 +35,8 @@ class GitListDialog(QDialog, Ui_GitListDialog):
         """
         Public method to return the selected entries.
 
-        @return list of selected entries (list of string)
+        @return list of selected entries
+        @rtype list of str
         """
         selection = []
         for itm in self.selectionList.selectedItems():
