@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -48,7 +48,9 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         Constructor
 
         @param vcs reference to the vcs object
-        @param parent reference to the parent widget (QWidget)
+        @type Git
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -104,7 +106,8 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Protected slot implementing a close event handler.
 
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         if (
             self.__process is not None
@@ -145,9 +148,12 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Private method to generate the stash items.
 
-        @param name name of the stash (string)
-        @param date date the stash was created (string)
-        @param message stash message (string)
+        @param name name of the stash
+        @type str
+        @param date date the stash was created
+        @type str
+        @param message stash message
+        @type str
         """
         QTreeWidgetItem(self.stashList, [name, date, message])
 
@@ -196,7 +202,8 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Public slot to start the git stash command.
 
-        @param projectDir name of the project directory (string)
+        @param projectDir name of the project directory
+        @type str
         """
         self.errorGroup.hide()
         QApplication.processEvents()
@@ -215,12 +222,15 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         self.__started = True
         self.__getStashEntries()
 
+    @pyqtSlot(int, QProcess.ExitStatus)
     def __procFinished(self, exitCode, exitStatus):
         """
         Private slot connected to the finished signal.
 
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.__processBuffer()
         self.__finish()
@@ -292,7 +302,8 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
@@ -307,8 +318,10 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Private slot called, when the current item of the stash list changes.
 
-        @param current reference to the new current item (QTreeWidgetItem)
-        @param previous reference to the old current item (QTreeWidgetItem)
+        @param current reference to the new current item
+        @type QTreeWidgetItem
+        @param previous reference to the old current item
+        @type QTreeWidgetItem
         """
         self.statisticsList.clear()
         self.filesLabel.setText("")
@@ -394,7 +407,8 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Private slot to show the context menu of the stash list.
 
-        @param pos position of the mouse pointer (QPoint)
+        @param pos position of the mouse pointer
+        @type QPoint
         """
         enable = len(self.stashList.selectedItems()) == 1
         self.__differencesAct.setEnabled(enable)
@@ -447,7 +461,8 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Private slot to handle the password checkbox toggled.
 
-        @param checked flag indicating the status of the check box (boolean)
+        @param checked flag indicating the status of the check box
+        @type bool
         """
         if checked:
             self.input.setEchoMode(QLineEdit.EchoMode.Password)
@@ -458,7 +473,8 @@ class GitStashBrowserDialog(QWidget, Ui_GitStashBrowserDialog):
         """
         Protected slot to handle a key press event.
 
-        @param evt the key press event (QKeyEvent)
+        @param evt the key press event
+        @type QKeyEvent
         """
         if self.intercept:
             self.intercept = False
