@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,8 +21,10 @@ class GitUserConfigDataDialog(QDialog, Ui_GitUserConfigDataDialog):
         """
         Constructor
 
-        @param version Git version info (tuple of two integers)
-        @param parent reference to the parent widget (QWidget)
+        @param version Git version info
+        @type tuple of (int, int)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -35,7 +37,7 @@ class GitUserConfigDataDialog(QDialog, Ui_GitUserConfigDataDialog):
         Public method to retrieve the entered data.
 
         @return tuple with user's first name, last name and email address
-            (tuple of three strings)
+        @rtype tuple of (str, str, str)
         """
         return (
             self.firstNameEdit.text(),
