@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2022 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2022 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -136,7 +136,8 @@ class GitWorktreeDialog(QWidget, Ui_GitWorktreeDialog):
         """
         Protected slot implementing a close event handler.
 
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         if (
             self.__process is not None
@@ -354,12 +355,15 @@ class GitWorktreeDialog(QWidget, Ui_GitWorktreeDialog):
         """
         self.start(self.__projectDir)
 
+    @pyqtSlot(int, QProcess.ExitStatus)
     def __procFinished(self, exitCode, exitStatus):
         """
         Private slot connected to the finished signal.
 
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.__finish()
 
@@ -493,7 +497,7 @@ class GitWorktreeDialog(QWidget, Ui_GitWorktreeDialog):
         dlg = GitWorktreeAddDialog(
             parentDirectory,
             self.__vcs.gitGetTagsList(self.__repodir),
-            self.__vcs.gitGetBranchesList(self.__repodir, withMaster=True),
+            self.__vcs.gitGetBranchesList(self.__repodir),
         )
         if dlg.exec() == QDialog.DialogCode.Accepted:
             params = dlg.getParameters()
