@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -36,12 +36,18 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         Constructor
 
         @param vcsObject reference to the vcs object
+        @type Git
         @param browserObject reference to the project browser object
+        @type ProjectBaseBrowser
         @param projectObject reference to the project object
+        @type Project
         @param isTranslationsBrowser flag indicating, the helper is requested
             for the translations browser (this needs some special treatment)
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @type bool
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         VcsProjectBrowserHelper.__init__(
             self,
@@ -53,7 +59,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
             name,
         )
 
-    def showContextMenu(self, menu, standardItems):
+    def showContextMenu(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -61,8 +67,10 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the file status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
             for act in self.vcsMenuActions:
@@ -77,7 +85,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(True)
 
-    def showContextMenuMulti(self, menu, standardItems):
+    def showContextMenuMulti(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu (multiple selections) is
         shown.
@@ -86,8 +94,10 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the files status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         vcsName = self.vcs.vcsName()
         items = self.browser.getSelectedItems()
@@ -112,7 +122,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(True)
 
-    def showContextMenuDir(self, menu, standardItems):
+    def showContextMenuDir(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -120,8 +130,10 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the directory status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
             for act in self.vcsDirMenuActions:
@@ -134,7 +146,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(True)
 
-    def showContextMenuDirMulti(self, menu, standardItems):
+    def showContextMenuDirMulti(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -142,8 +154,10 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the directory status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         vcsName = self.vcs.vcsName()
         items = self.browser.getSelectedItems()
@@ -177,6 +191,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         self.vcsMenuActions = []
         self.vcsAddMenuActions = []
@@ -318,6 +333,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         self.vcsMultiMenuActions = []
 
@@ -422,7 +438,11 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
+        if mainMenu is None:
+            return
+
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
@@ -463,6 +483,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         if mainMenu is None:
             return
@@ -577,6 +598,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         if mainMenu is None:
             return
