@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -52,7 +52,7 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
         }
 
         self.lfUserCachePicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
-        if OSUtilities.isLinuxPlatform():
+        if OSUtilities.isLinuxPlatform() or OSUtilities.isFreeBsdPlatform():
             self.lfUserCachePicker.setDefaultDirectory(
                 os.path.expanduser("~/.cache/largefiles")
             )
@@ -74,7 +74,7 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
         self.protocolEditButton.setIcon(EricPixmapCache.getIcon("edit"))
 
         self.minimumProtocolComboBox.addItem(self.tr("Default"), "")
-        for protocol in sorted(self.__minimumProtocols.keys()):
+        for protocol in sorted(self.__minimumProtocols):
             self.minimumProtocolComboBox.addItem(
                 self.__minimumProtocols[protocol], protocol
             )
@@ -306,8 +306,8 @@ class HgUserConfigDialog(QDialog, Ui_HgUserConfigDialog):
                 else:
                     name = username
                     email = ""
-                self.userNameEdit.setText(name.strip()),
-                self.emailEdit.setText(email.strip()),
+                self.userNameEdit.setText(name.strip())
+                self.emailEdit.setText(email.strip())
 
             # step 2: extract extensions information
             if "extensions" in self.__config:
