@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -36,12 +36,18 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         Constructor
 
         @param vcsObject reference to the vcs object
+        @type Hg
         @param browserObject reference to the project browser object
+        @type ProjectBaseBrowser
         @param projectObject reference to the project object
+        @type Project
         @param isTranslationsBrowser flag indicating, the helper is requested
             for the translations browser (this needs some special treatment)
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @type bool
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         from .LargefilesExtension.ProjectBrowserHelper import (
             LargefilesProjectBrowserHelper,
@@ -80,11 +86,12 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         """
         Private slot showing the extensions menu.
 
-        @param key menu key (string, one of 'mainMenu', 'multiMenu',
-            'backMenu', 'dirMenu' or 'dirMultiMenu')
+        @param key menu key (one of 'mainMenu', 'multiMenu', 'backMenu', 'dirMenu'
+            or 'dirMultiMenu')
+        @type str
         @param controlled flag indicating to show the menu for a
             version controlled entry or a non-version controlled entry
-            (boolean)
+        @type bool
         """
         for extensionName in self.__extensionMenus:
             if key in self.__extensionMenus[extensionName]:
@@ -100,7 +107,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 ):
                     self.__extensionMenus[extensionName][key].hideTearOffMenu()
 
-    def showContextMenu(self, menu, standardItems):
+    def showContextMenu(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -108,8 +115,10 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the file status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
             controlled = True
@@ -134,7 +143,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 act.setEnabled(True)
         self.__showExtensionMenu("mainMenu", controlled)
 
-    def showContextMenuMulti(self, menu, standardItems):
+    def showContextMenuMulti(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu (multiple selections) is
         shown.
@@ -143,8 +152,10 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the files status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         vcsName = self.vcs.vcsName()
         items = self.browser.getSelectedItems()
@@ -176,7 +187,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 act.setEnabled(True)
         self.__showExtensionMenu("multiMenu", controlled)
 
-    def showContextMenuDir(self, menu, standardItems):
+    def showContextMenuDir(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -184,8 +195,10 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the directory status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
             controlled = True
@@ -205,7 +218,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
                 act.setEnabled(True)
         self.__showExtensionMenu("dirMenu", controlled)
 
-    def showContextMenuDirMulti(self, menu, standardItems):
+    def showContextMenuDirMulti(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -213,8 +226,10 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the directory status.
 
         @param menu reference to the menu to be shown
-        @param standardItems array of standard items that need
+        @type QMenu
+        @param standardItems list of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         vcsName = self.vcs.vcsName()
         items = self.browser.getSelectedItems()
@@ -254,10 +269,13 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         """
         Private method to add an extension menu entry.
 
-        @param menu menu to add it to (QMenu)
-        @param key menu key (string, one of 'mainMenu', 'multiMenu',
-            'backMenu', 'dirMenu' or 'dirMultiMenu')
-        @return reference to the menu action (QAction)
+        @param menu menu to add it to
+        @type QMenu
+        @param key menu key (one of 'mainMenu', 'multiMenu', 'backMenu', 'dirMenu'
+            or 'dirMultiMenu')
+        @type str
+        @return reference to the menu action
+        @rtype QAction
         """
         act = None
         if key in ["mainMenu", "multiMenu", "backMenu", "dirMenu", "dirMultiMenu"]:
@@ -282,6 +300,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         self.vcsMenuActions = []
         self.vcsAddMenuActions = []
@@ -424,6 +443,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         self.vcsMultiMenuActions = []
         self.vcsAddMultiMenuActions = []
@@ -528,7 +548,11 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
+        if mainMenu is None:
+            return
+
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
@@ -569,6 +593,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         if mainMenu is None:
             return
@@ -682,6 +707,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         if mainMenu is None:
             return
