@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,9 +29,13 @@ class HgProjectHelper(VcsProjectHelper):
         Constructor
 
         @param vcsObject reference to the vcs object
+        @type Hg
         @param projectObject reference to the project object
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @type Project
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         from .CloseheadExtension.ProjectHelper import CloseheadProjectHelper
         from .GpgExtension.ProjectHelper import GpgProjectHelper
@@ -71,7 +75,9 @@ class HgProjectHelper(VcsProjectHelper):
         Public method to set references to the vcs and project objects.
 
         @param vcsObject reference to the vcs object
+        @type Hg
         @param projectObject reference to the project object
+        @type Project
         """
         self.vcs = vcsObject
         self.project = projectObject
@@ -95,7 +101,8 @@ class HgProjectHelper(VcsProjectHelper):
         """
         Public method to get a reference to the project object.
 
-        @return reference to the project object (Project)
+        @return reference to the project object
+        @rtype Project
         """
         return self.project
 
@@ -103,7 +110,8 @@ class HgProjectHelper(VcsProjectHelper):
         """
         Public method to get a list of all actions.
 
-        @return list of all actions (list of EricAction)
+        @return list of all actions
+        @rtype list of EricAction
         """
         actions = self.actions[:]
         for extension in self.__extensions.values():
@@ -1681,7 +1689,8 @@ class HgProjectHelper(VcsProjectHelper):
         """
         Public method to generate the VCS menu.
 
-        @param menu reference to the menu to be populated (QMenu)
+        @param menu reference to the menu to be populated
+        @type QMenu
         """
         menu.clear()
 
@@ -1882,9 +1891,10 @@ class HgProjectHelper(VcsProjectHelper):
         """
         Public slot to initialize the VCS toolbar.
 
-        @param ui reference to the main window (UserInterface)
+        @param ui reference to the main window
+        @type UserInterface
         @param toolbarManager reference to a toolbar manager object
-            (EricToolBarManager)
+        @type EricToolBarManager
         """
         self.__toolbarManager = toolbarManager
 
@@ -1953,9 +1963,10 @@ class HgProjectHelper(VcsProjectHelper):
         """
         Public method to remove a toolbar created by initToolbar().
 
-        @param ui reference to the main window (UserInterface)
+        @param ui reference to the main window
+        @type UserInterface
         @param toolbarManager reference to a toolbar manager object
-            (EricToolBarManager)
+        @type EricToolBarManager
         """
         ui.removeToolBar(self.__toolbar)
         ui.unregisterToolbar("mercurial")
