@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the queues extension interface.
 """
 
+import enum
+
 from PyQt6.QtWidgets import QApplication, QDialog, QInputDialog
 
 from eric7.EricWidgets import EricMessageBox
@@ -15,28 +17,41 @@ from ..HgDialog import HgDialog
 from ..HgExtension import HgExtension
 
 
-class Queues(HgExtension):
+class QueuePatchesListType(enum.Enum):
     """
-    Class implementing the queues extension interface.
+    Class defining the supported queue patch list types.
     """
 
-    APPLIED_LIST = 0
-    UNAPPLIED_LIST = 1
-    SERIES_LIST = 2
+    APPLIED = 0
+    UNAPPLIED = 1
+    SERIES = 2
+
+
+class QueueOperation(enum.Enum):
+    """
+    Class defining the supported queue operations.
+    """
 
     POP = 0
     PUSH = 1
     GOTO = 2
 
-    QUEUE_DELETE = 0
-    QUEUE_PURGE = 1
-    QUEUE_ACTIVATE = 2
+    DELETE = 3
+    PURGE = 4
+    ACTIVATE = 5
+
+
+class Queues(HgExtension):
+    """
+    Class implementing the queues extension interface.
+    """
 
     def __init__(self, vcs):
         """
         Constructor
 
         @param vcs reference to the Mercurial vcs object
+        @type Hg
         """
         super().__init__(vcs)
 
@@ -75,23 +90,21 @@ class Queues(HgExtension):
         Private method to get a list of patches of a given type.
 
         @param listType type of patches list to get
-            (Queues.APPLIED_LIST, Queues.UNAPPLIED_LIST, Queues.SERIES_LIST)
-        @param withSummary flag indicating to get a summary as well (boolean)
-        @return list of patches (list of string)
+        @type QueuePatchesListType
+        @param withSummary flag indicating to get a summary as well
+        @type bool
+        @return list of patches
+        @rtype list of str
         @exception ValueError raised to indicate an invalid patch list type
         """
         patchesList = []
 
-        if listType not in (
-            Queues.APPLIED_LIST,
-            Queues.UNAPPLIED_LIST,
-            Queues.SERIES_LIST,
-        ):
+        if not isinstance(listType, QueuePatchesListType):
             raise ValueError("illegal value for listType")
 
-        if listType == Queues.APPLIED_LIST:
+        if listType == QueuePatchesListType.APPLIED:
             args = self.vcs.initCommand("qapplied")
-        elif listType == Queues.UNAPPLIED_LIST:
+        elif listType == QueuePatchesListType.UNAPPLIED:
             args = self.vcs.initCommand("qunapplied")
         else:
             args = self.vcs.initCommand("qseries")
@@ -119,7 +132,8 @@ class Queues(HgExtension):
         """
         Private method to get the name of the current patch.
 
-        @return name of the current patch (string)
+        @return name of the current patch
+        @rtype str
         """
         currentPatch = ""
 
@@ -134,7 +148,8 @@ class Queues(HgExtension):
         """
         Private method to get the commit message of the current patch.
 
-        @return name of the current patch (string)
+        @return name of the current patch
+        @rtype str
         """
         message = ""
 
@@ -149,8 +164,10 @@ class Queues(HgExtension):
         """
         Public method to get a list of all guards defined.
 
-        @param allGuards flag indicating to get all guards (boolean)
-        @return sorted list of guards (list of strings)
+        @param allGuards flag indicating to get all guards
+        @type bool
+        @return sorted list of guards
+        @rtype list of str
         """
         guardsList = []
 
@@ -174,9 +191,12 @@ class Queues(HgExtension):
         """
         Public method to create a new named patch.
         """
-        from .HgQueuesNewPatchDialog import HgQueuesNewPatchDialog
+        from .HgQueuesNewPatchDialog import (
+            HgQueuesNewPatchDialog,
+            HgQueuesNewPatchDialogMode,
+        )
 
-        dlg = HgQueuesNewPatchDialog(HgQueuesNewPatchDialog.NEW_MODE)
+        dlg = HgQueuesNewPatchDialog(HgQueuesNewPatchDialogMode.NEW)
         if dlg.exec() == QDialog.DialogCode.Accepted:
             (
                 name,
@@ -214,16 +234,20 @@ class Queues(HgExtension):
         Public method to refresh the current patch.
 
         @param editMessage flag indicating to edit the current
-            commit message (boolean)
+            commit message
+        @type bool
         """
-        from .HgQueuesNewPatchDialog import HgQueuesNewPatchDialog
+        from .HgQueuesNewPatchDialog import (
+            HgQueuesNewPatchDialog,
+            HgQueuesNewPatchDialogMode,
+        )
 
         args = self.vcs.initCommand("qrefresh")
 
         if editMessage:
             currentMessage = self.__getCommitMessage()
             dlg = HgQueuesNewPatchDialog(
-                HgQueuesNewPatchDialog.REFRESH_MODE, currentMessage
+                HgQueuesNewPatchDialogMode.REFRESH, currentMessage
             )
             if dlg.exec() == QDialog.DialogCode.Accepted:
                 (
@@ -260,7 +284,8 @@ class Queues(HgExtension):
         """
         Public method to show the contents of the current patch.
 
-        @param name file/directory name (string)
+        @param name file/directory name
+        @type str
         """
         from ..HgDiffDialog import HgDiffDialog
 
@@ -285,37 +310,45 @@ class Queues(HgExtension):
         Public method to push patches onto the stack or pop patches off the
         stack.
 
-        @param operation operation type to be performed (Queues.POP,
-            Queues.PUSH, Queues.GOTO)
-        @param doAll flag indicating to push/pop all (boolean)
+        @param operation operation to be performed (POP, PUSH or GOTO)
+        @type QueueOperation
+        @param doAll flag indicating to push/pop all
+        @type bool
         @param named flag indicating to push/pop until a named patch
-            is at the top of the stack (boolean)
-        @param force flag indicating a forceful pop (boolean)
-        @return flag indicating that the project should be reread (boolean)
+            is at the top of the stack
+        @type bool
+        @param force flag indicating a forceful pop
+        @type bool
+        @return flag indicating that the project should be reread
+        @rtype bool
         @exception ValueError raised to indicate an invalid operation
         """
-        if operation not in (Queues.POP, Queues.PUSH, Queues.GOTO):
+        if operation not in (
+            QueueOperation.POP,
+            QueueOperation.PUSH,
+            QueueOperation.GOTO,
+        ):
             raise ValueError("illegal value for operation")
 
-        if operation == Queues.POP:
+        if operation == QueueOperation.POP:
             args = self.vcs.initCommand("qpop")
             title = self.tr("Pop Patches")
-            listType = Queues.APPLIED_LIST
-        elif operation == Queues.PUSH:
+            listType = QueuePatchesListType
+        elif operation == QueueOperation.PUSH:
             args = self.vcs.initCommand("qpush")
             title = self.tr("Push Patches")
-            listType = Queues.UNAPPLIED_LIST
+            listType = QueuePatchesListType.UNAPPLIED
         else:
             args = self.vcs.initCommand("qgoto")
             title = self.tr("Go to Patch")
-            listType = Queues.SERIES_LIST
+            listType = QueuePatchesListType.SERIES
 
         args.append("-v")
         if force:
             args.append("--force")
-        if doAll and operation in (Queues.POP, Queues.PUSH):
+        if doAll and operation in (QueueOperation.POP, QueueOperation.PUSH):
             args.append("--all")
-        elif named or operation == Queues.GOTO:
+        elif named or operation == QueueOperation.GOTO:
             patchnames = self.__getPatchesList(listType)
             if patchnames:
                 patch, ok = QInputDialog.getItem(
@@ -376,7 +409,7 @@ class Queues(HgExtension):
         from .HgQueuesRenamePatchDialog import HgQueuesRenamePatchDialog
 
         args = self.vcs.initCommand("qrename")
-        patchnames = sorted(self.__getPatchesList(Queues.SERIES_LIST))
+        patchnames = sorted(self.__getPatchesList(QueuePatchesListType.SERIES))
         if patchnames:
             currentPatch = self.__getCurrentPatch()
             if currentPatch:
@@ -397,7 +430,7 @@ class Queues(HgExtension):
         Public method to delete a selected unapplied patch.
         """
         args = self.vcs.initCommand("qdelete")
-        patchnames = sorted(self.__getPatchesList(Queues.UNAPPLIED_LIST))
+        patchnames = sorted(self.__getPatchesList(QueuePatchesListType.UNAPPLIED))
         if patchnames:
             patch, ok = QInputDialog.getItem(
                 None,
@@ -427,7 +460,7 @@ class Queues(HgExtension):
 
         args = self.vcs.initCommand("qfold")
         patchnames = sorted(
-            self.__getPatchesList(Queues.UNAPPLIED_LIST, withSummary=True)
+            self.__getPatchesList(QueuePatchesListType.UNAPPLIED, withSummary=True)
         )
         if patchnames:
             dlg = HgQueuesFoldDialog(patchnames)
@@ -462,7 +495,7 @@ class Queues(HgExtension):
         """
         from .HgQueuesListGuardsDialog import HgQueuesListGuardsDialog
 
-        patchnames = sorted(self.__getPatchesList(Queues.SERIES_LIST))
+        patchnames = sorted(self.__getPatchesList(QueuePatchesListType.SERIES))
         if patchnames:
             self.queuesListGuardsDialog = HgQueuesListGuardsDialog(self.vcs, patchnames)
             self.queuesListGuardsDialog.show()
@@ -490,7 +523,7 @@ class Queues(HgExtension):
         """
         from .HgQueuesDefineGuardsDialog import HgQueuesDefineGuardsDialog
 
-        patchnames = sorted(self.__getPatchesList(Queues.SERIES_LIST))
+        patchnames = sorted(self.__getPatchesList(QueuePatchesListType.SERIES))
         if patchnames:
             self.queuesDefineGuardsDialog = HgQueuesDefineGuardsDialog(
                 self.vcs, self, patchnames
@@ -508,7 +541,7 @@ class Queues(HgExtension):
         """
         Public method to drop all guards of the current or a named patch.
         """
-        patchnames = sorted(self.__getPatchesList(Queues.SERIES_LIST))
+        patchnames = sorted(self.__getPatchesList(QueuePatchesListType.SERIES))
         if patchnames:
             patch, ok = QInputDialog.getItem(
                 None,
@@ -593,15 +626,19 @@ class Queues(HgExtension):
         """
         Public method to create a new queue or rename the active queue.
 
-        @param isCreate flag indicating to create a new queue (boolean)
+        @param isCreate flag indicating to create a new queue
+        @type bool
         """
-        from .HgQueuesQueueManagementDialog import HgQueuesQueueManagementDialog
+        from .HgQueuesQueueManagementDialog import (
+            HgQueuesQueueManagementDialog,
+            HgQueuesQueueManagementDialogMode,
+        )
 
         title = (
             self.tr("Create New Queue") if isCreate else self.tr("Rename Active Queue")
         )
         dlg = HgQueuesQueueManagementDialog(
-            HgQueuesQueueManagementDialog.NAME_INPUT, title, False, self.vcs
+            HgQueuesQueueManagementDialogMode.NAME_INPUT, title, False, self.vcs
         )
         if dlg.exec() == QDialog.DialogCode.Accepted:
             queueName = dlg.getData()
@@ -636,36 +673,39 @@ class Queues(HgExtension):
         Public method to delete the reference to a queue and optionally
         remove the patch directory or set the active queue.
 
-        @param operation operation to be performed (Queues.QUEUE_DELETE,
-            Queues.QUEUE_PURGE, Queues.QUEUE_ACTIVATE)
+        @param operation operation to be performed (PURGE, DELETE or ACTIVATE)
+        @type QueueOperation
         @exception ValueError raised to indicate an invalid operation
         """
-        from .HgQueuesQueueManagementDialog import HgQueuesQueueManagementDialog
+        from .HgQueuesQueueManagementDialog import (
+            HgQueuesQueueManagementDialog,
+            HgQueuesQueueManagementDialogMode,
+        )
 
         if operation not in (
-            Queues.QUEUE_PURGE,
-            Queues.QUEUE_DELETE,
-            Queues.QUEUE_ACTIVATE,
+            QueueOperation.PURGE,
+            QueueOperation.DELETE,
+            QueueOperation.ACTIVATE,
         ):
             raise ValueError("illegal value for operation")
 
-        if operation == Queues.QUEUE_PURGE:
+        if operation == QueueOperation.PURGE:
             title = self.tr("Purge Queue")
-        elif operation == Queues.QUEUE_DELETE:
+        elif operation == QueueOperation.DELETE:
             title = self.tr("Delete Queue")
         else:
             title = self.tr("Activate Queue")
 
         dlg = HgQueuesQueueManagementDialog(
-            HgQueuesQueueManagementDialog.QUEUE_INPUT, title, True, self.vcs
+            HgQueuesQueueManagementDialogMode.QUEUE_INPUT, title, True, self.vcs
         )
         if dlg.exec() == QDialog.DialogCode.Accepted:
             queueName = dlg.getData()
             if queueName:
                 args = self.vcs.initCommand("qqueue")
-                if operation == Queues.QUEUE_PURGE:
+                if operation == QueueOperation.PURGE:
                     args.append("--purge")
-                elif operation == Queues.QUEUE_DELETE:
+                elif operation == QueueOperation.DELETE:
                     args.append("--delete")
                 args.append(queueName)
 
@@ -673,11 +713,11 @@ class Queues(HgExtension):
                 error = client.runcommand(args)[1]
 
                 if error:
-                    if operation == Queues.QUEUE_PURGE:
+                    if operation == QueueOperation.PURGE:
                         errMsg = self.tr("Error while purging the queue.")
-                    elif operation == Queues.QUEUE_DELETE:
+                    elif operation == QueueOperation.DELETE:
                         errMsg = self.tr("Error while deleting the queue.")
-                    elif operation == Queues.QUEUE_ACTIVATE:
+                    elif operation == QueueOperation.ACTIVATE:
                         errMsg = self.tr("Error while setting the active queue.")
                     EricMessageBox.warning(
                         None, title, """<p>{0}</p><p>{1}</p>""".format(errMsg, error)
@@ -693,21 +733,22 @@ class Queues(HgExtension):
         """
         Public method to list available queues.
         """
-        from .HgQueuesQueueManagementDialog import HgQueuesQueueManagementDialog
+        from .HgQueuesQueueManagementDialog import (
+            HgQueuesQueueManagementDialog,
+            HgQueuesQueueManagementDialogMode,
+        )
 
         self.queuesListQueuesDialog = HgQueuesQueueManagementDialog(
-            HgQueuesQueueManagementDialog.NO_INPUT,
+            HgQueuesQueueManagementDialogMode.NO_INPUT,
             self.tr("Available Queues"),
             False,
             self.vcs,
         )
         self.queuesListQueuesDialog.show()
 
-    def hgQueueInit(self, name):
+    def hgQueueInit(self):
         """
         Public method to initialize a new queue repository.
-
-        @param name directory name (string)
         """
         args = self.vcs.initCommand("init")
         args.append("--mq")
@@ -722,7 +763,8 @@ class Queues(HgExtension):
         """
         Public method used to view the status of a queue repository.
 
-        @param name directory name (string)
+        @param name directory name
+        @type str
         """
         from ..HgStatusDialog import HgStatusDialog
 
