@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,7 +39,9 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         Constructor
 
         @param vcs reference to the vcs object
-        @param parent parent widget (QWidget)
+        @type Subversion
+        @param parent parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -75,8 +77,10 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         Private method to get a pysvn revision object for the given version
         number.
 
-        @param version revision (integer or string)
-        @return revision object (pysvn.Revision)
+        @param version revision
+        @type int or str
+        @return revision object
+        @rtype pysvn.Revision
         """
         if isinstance(version, int):
             return pysvn.Revision(pysvn.opt_revision_kind.number, version)
@@ -97,8 +101,10 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private method to get a string descripion of the diff summary.
 
-        @param summaryKind (pysvn.diff_summarize.summarize_kind)
-        @return one letter string indicating the change type (string)
+        @param summaryKind
+        @type pysvn.diff_summarize.summarize_kind
+        @return one letter string indicating the change type
+        @rtype str
         """
         if summaryKind == pysvn.diff_summarize_kind.delete:
             return "D"
@@ -123,14 +129,19 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Public slot to start the svn diff command.
 
-        @param fn filename to be diffed (string)
-        @param versions list of versions to be diffed (list of up to 2 integer
-            or None)
-        @param urls list of repository URLs (list of 2 strings)
+        @param fn filename to be diffed
+        @type str
+        @param versions list of versions to be diffed
+        @type list of up to 2 int or None
+        @param urls list of repository URLs
+        @type list of [str, str]
         @param summary flag indicating a summarizing diff
-            (only valid for URL diffs) (boolean)
-        @param pegRev revision number the filename is valid (integer)
-        @param refreshable flag indicating a refreshable diff (boolean)
+            (only valid for URL diffs)
+        @type bool
+        @param pegRev revision number the filename is valid
+        @type int
+        @param refreshable flag indicating a refreshable diff
+        @type bool
         """
         self.refreshButton.setVisible(refreshable)
 
@@ -291,7 +302,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private method to append text to the end of the contents pane.
 
-        @param line line of text to insert (string)
+        @param line line of text to insert
+        @type str
         """
         tc = self.contents.textCursor()
         tc.movePosition(QTextCursor.MoveOperation.End)
@@ -303,8 +315,10 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private method to extract the file name out of a file separator line.
 
-        @param line line to be processed (string)
-        @return extracted file name (string)
+        @param line line to be processed
+        @type str
+        @return extracted file name
+        @rtype str
         """
         f = line.split(None, 1)[1]
         f = f.rsplit(None, 2)[0]
@@ -314,7 +328,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private slot to process a line giving the old/new file.
 
-        @param line line to be processed (string)
+        @param line line to be processed
+        @type str
         """
         if line.startswith("---"):
             self.__oldFileLine = self.paras
@@ -353,7 +368,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
@@ -369,7 +385,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private slot to handle the selection of a file.
 
-        @param index activated row (integer)
+        @param index activated row
+        @type int
         """
         para = self.filesCombo.itemData(index)
 
@@ -480,7 +497,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         """
         Private slot to show an error message.
 
-        @param msg error message to show (string)
+        @param msg error message to show
+        @type str
         """
         self.errorGroup.show()
         self.errors.insertPlainText(msg)
