@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,7 +41,9 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         Constructor
 
         @param vcs reference to the vcs object
-        @param parent parent widget (QWidget)
+        @type Subversion
+        @param parent parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -103,7 +105,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Protected slot implementing a close event handler.
 
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         self.__position = self.pos()
 
@@ -185,13 +188,19 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private method to generate a log tree entry.
 
-        @param author author info (string)
-        @param date date info (integer)
-        @param message text of the log message (string)
-        @param revision revision info (string or pysvn.opt_revision_kind)
+        @param author author info
+        @type str
+        @param date date info
+        @type int
+        @param message text of the log message
+        @type str
+        @param revision revision info
+        @type str or pysvn.opt_revision_kind
         @param changedPaths list of pysvn dictionary like objects containing
             info about the changed files/directories
-        @return reference to the generated item (QTreeWidgetItem)
+        @type dict like
+        @return reference to the generated item
+        @rtype QTreeWidgetItem
         """
         if revision == "":
             rev = ""
@@ -242,10 +251,15 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         Private method to generate a changed files tree entry.
 
         @param action indicator for the change action ("A", "D" or "M")
-        @param path path of the file in the repository (string)
-        @param copyFrom path the file was copied from (None, string)
-        @param copyRev revision the file was copied from (None, string)
-        @return reference to the generated item (QTreeWidgetItem)
+        @type str
+        @param path path of the file in the repository
+        @type str
+        @param copyFrom path the file was copied from
+        @type str
+        @param copyRev revision the file was copied from
+        @type str
+        @return reference to the generated item
+        @rtype QTreeWidgetItem
         """
         itm = QTreeWidgetItem(
             self.filesTree, [self.flags[action], path, copyFrom, copyRev]
@@ -259,7 +273,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private method to retrieve log entries from the repository.
 
-        @param startRev revision number to start from (integer, string)
+        @param startRev revision number to start from
+        @type tuple of (int, str)
         """
         fetchLimit = 10
         self._reset()
@@ -346,9 +361,10 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Public slot to start the svn log command.
 
-        @param fn filename to show the log for (string)
+        @param fn filename to show the log for
+        @type str
         @param isFile flag indicating log for a file is to be shown
-            (boolean)
+        @type bool
         """
         self.sbsCheckBox.setEnabled(isFile)
         self.sbsCheckBox.setVisible(isFile)
@@ -379,9 +395,12 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private method to do a diff of two revisions.
 
-        @param rev1 first revision number (integer)
-        @param rev2 second revision number (integer)
-        @param peg_rev revision number to use as a reference (integer)
+        @param rev1 first revision number
+        @type int
+        @param rev2 second revision number
+        @type int
+        @param peg_rev revision number to use as a reference
+        @type int
         """
         from .SvnDiffDialog import SvnDiffDialog
 
@@ -399,7 +418,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
@@ -412,8 +432,10 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the current item of the log tree changes.
 
-        @param current reference to the new current item (QTreeWidgetItem)
-        @param previous reference to the old current item (QTreeWidgetItem)
+        @param current reference to the new current item
+        @type QTreeWidgetItem
+        @param previous reference to the old current item
+        @type QTreeWidgetItem
         """
         if current is not None:
             self.messageEdit.setPlainText(current.data(0, self.__messageRole))
@@ -511,7 +533,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot to show an error message.
 
-        @param msg error message to show (string)
+        @param msg error message to show
+        @type str
         """
         EricMessageBox.critical(self, self.tr("Subversion Error"), msg)
 
@@ -520,7 +543,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the from date changes.
 
-        @param date new date (QDate)
+        @param date new date
+        @type QDate
         """
         self.__filterLogs()
 
@@ -529,7 +553,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the from date changes.
 
-        @param date new date (QDate)
+        @param date new date
+        @type QDate
         """
         self.__filterLogs()
 
@@ -548,7 +573,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when a filter expression is entered.
 
-        @param txt filter expression (string)
+        @param txt filter expression
+        @type str
         """
         self.__filterLogs()
 
@@ -596,7 +622,8 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the stop on copy/move checkbox is clicked.
 
-        @param checked flag indicating the check box state (boolean)
+        @param checked flag indicating the check box state
+        @type bool
         """
         self.vcs.getPlugin().setPreferences(
             "StopLogOnCopy", int(self.stopCheckBox.isChecked())
