@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -45,7 +45,9 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         Constructor
 
         @param vcs reference to the vcs object
-        @param parent parent widget (QWidget)
+        @type Subversion
+        @param parent parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -234,18 +236,30 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private method to generate a status item in the status list.
 
-        @param changelist name of the changelist (string)
-        @param status text status (pysvn.wc_status_kind)
-        @param propStatus property status (pysvn.wc_status_kind)
-        @param locked locked flag (boolean)
-        @param history history flag (boolean)
-        @param switched switched flag (boolean)
-        @param lockinfo lock indicator (string)
-        @param uptodate up to date flag (boolean)
-        @param revision revision (integer)
-        @param change revision of last change (integer)
-        @param author author of the last change (string)
-        @param path path of the file or directory (string)
+        @param changelist name of the changelist
+        @type str
+        @param status text status
+        @type pysvn.wc_status_kind
+        @param propStatus property status
+        @type pysvn.wc_status_kind
+        @param locked locked flag
+        @type bool
+        @param history history flag
+        @type bool
+        @param switched switched flag
+        @type bool
+        @param lockinfo lock indicator
+        @type str
+        @param uptodate up to date flag
+        @type bool
+        @param revision revision
+        @type int
+        @param change revision of last change
+        @type int
+        @param author author of the last change
+        @type str
+        @param path path of the file or directory
+        @type str
         """
         statusText = self.tr(svnStatusMap[status])
         itm = QTreeWidgetItem(self.statusList)
@@ -298,7 +312,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         Public slot to start the svn status command.
 
         @param fn filename(s)/directoryname(s) to show the status of
-            (string or list of strings)
+        @type str or list of str
         """
         self.errorGroup.hide()
 
@@ -352,7 +366,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
             try:
                 with EricMutexLocker(self.vcs.vcsExecutionMutex):
                     for name in fnames:
-                        # step 1: determine changelists and their files
+                        # step 1: determine change lists and their files
                         changelistsDict = {}
                         if hasattr(self.client, "get_changelist"):
                             if recurse:
@@ -503,7 +517,8 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
@@ -523,7 +538,8 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private slot to show an error message.
 
-        @param msg error message to show (string)
+        @param msg error message to show
+        @type str
         """
         self.errorGroup.show()
         self.errors.insertPlainText(msg)
@@ -573,8 +589,10 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private slot to act upon item changes.
 
-        @param item reference to the changed item (QTreeWidgetItem)
-        @param column index of column that changed (integer)
+        @param item reference to the changed item
+        @type QTreeWidgetItem
+        @param column index of column that changed
+        @type int
         """
         if column == self.__toBeCommittedColumn:
             self.__updateCommitButton()
@@ -636,7 +654,8 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private slot to show the context menu of the status list.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         self.menu.popup(self.statusList.mapToGlobal(coord))
 
@@ -903,7 +922,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
 
     def __removeFromChangelist(self):
         """
-        Private slot to remove entries from their changelists.
+        Private slot to remove entries from their change lists.
         """
         names = [
             os.path.join(self.dname, itm.text(self.__pathColumn))
@@ -927,6 +946,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         Private method to retrieve all entries the user wants to commit.
 
         @return list of all items, the user has checked
+        @rtype list of QTreeWidgetItem
         """
         commitableItems = []
         for index in range(self.statusList.topLevelItemCount()):
@@ -940,6 +960,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         Private method to retrieve all entries, that have a modified status.
 
         @return list of all items with a modified status
+        @rtype list of QTreeWidgetItem
         """
         modifiedItems = []
         for itm in self.statusList.selectedItems():
@@ -956,6 +977,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         unversioned status.
 
         @return list of all items with an unversioned status
+        @rtype list of QTreeWidgetItem
         """
         unversionedItems = []
         for itm in self.statusList.selectedItems():
@@ -968,6 +990,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         Private method to retrieve all entries, that have a missing status.
 
         @return list of all items with a missing status
+        @rtype list of QTreeWidgetItem
         """
         missingItems = []
         for itm in self.statusList.selectedItems():
@@ -979,8 +1002,10 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private method to retrieve all entries, that have a locked status.
 
-        @param indicators list of indicators to check against (list of strings)
+        @param indicators list of indicators to check against
+        @type list of str
         @return list of all items with a locked status
+        @rtype list of QTreeWidgetItem
         """
         lockitems = []
         for itm in self.statusList.selectedItems():
@@ -994,6 +1019,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         a changelist.
 
         @return list of all items belonging to a changelist
+        @rtype list of QTreeWidgetItem
         """
         clitems = []
         for itm in self.statusList.selectedItems():
@@ -1007,6 +1033,7 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         a changelist.
 
         @return list of all items not belonging to a changelist
+        @rtype list of QTreeWidgetItem
         """
         clitems = []
         for itm in self.statusList.selectedItems():
@@ -1018,7 +1045,8 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         """
         Private slot to select or deselect all entries.
 
-        @param selected commit selection state to be set (boolean)
+        @param selected commit selection state to be set
+        @type bool
         """
         for index in range(self.statusList.topLevelItemCount()):
             itm = self.statusList.topLevelItem(index)
