@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -35,12 +35,18 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         Constructor
 
         @param vcsObject reference to the vcs object
+        @type Subversion
         @param browserObject reference to the project browser object
+        @type ProjectBaseBrowser
         @param projectObject reference to the project object
+        @type Project
         @param isTranslationsBrowser flag indicating, the helper is requested
             for the translations browser (this needs some special treatment)
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @type bool
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         VcsProjectBrowserHelper.__init__(
             self,
@@ -52,7 +58,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             name,
         )
 
-    def showContextMenu(self, menu, standardItems):
+    def showContextMenu(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -60,8 +66,10 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the file status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
             for act in self.vcsMenuActions:
@@ -87,7 +95,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(True)
 
-    def showContextMenuMulti(self, menu, standardItems):
+    def showContextMenuMulti(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu (multiple selections) is
         shown.
@@ -96,8 +104,10 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the files status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         vcsName = self.vcs.vcsName()
         items = self.browser.getSelectedItems()
@@ -128,7 +138,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(True)
 
-    def showContextMenuDir(self, menu, standardItems):
+    def showContextMenuDir(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -136,8 +146,10 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the directory status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         if self.browser.currentItem().data(1) == self.vcs.vcsName():
             for act in self.vcsDirMenuActions:
@@ -154,7 +166,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             for act in standardItems:
                 act.setEnabled(True)
 
-    def showContextMenuDirMulti(self, menu, standardItems):
+    def showContextMenuDirMulti(self, menu, standardItems):  # noqa: U100
         """
         Public slot called before the context menu is shown.
 
@@ -162,8 +174,10 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         VCS status and the directory status.
 
         @param menu reference to the menu to be shown
+        @type QMenu
         @param standardItems array of standard items that need
             activation/deactivation depending on the overall VCS status
+        @type list of QAction
         """
         vcsName = self.vcs.vcsName()
         items = self.browser.getSelectedItems()
@@ -201,6 +215,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         self.vcsMenuActions = []
         self.vcsAddMenuActions = []
@@ -387,6 +402,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         self.vcsMultiMenuActions = []
         self.vcsAddMultiMenuActions = []
@@ -540,7 +556,11 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
+        if mainMenu is None:
+            return
+
         menu = QMenu(self.tr("Version Control"))
 
         act = menu.addAction(
@@ -581,6 +601,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         if mainMenu is None:
             return
@@ -724,6 +745,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         Protected method used to add the VCS menu to all project browsers.
 
         @param mainMenu reference to the menu to be amended
+        @type QMenu
         """
         if mainMenu is None:
             return
@@ -1085,7 +1107,9 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         """
         Private method to check, if items contain file type items.
 
-        @param items items to check (list of QTreeWidgetItems)
-        @return flag indicating items contain file type items (boolean)
+        @param items items to check
+        @type list of QTreeWidgetItems
+        @return flag indicating items contain file type items
+        @rtype bool
         """
         return any(isinstance(itm, ProjectBrowserFileItem) for itm in items)
