@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,7 +39,9 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         Constructor
 
         @param vcs reference to the vcs object
-        @param parent parent widget (QWidget)
+        @type Subversion
+        @param parent parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -134,7 +136,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Protected slot implementing a close event handler.
 
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         if (
             self.__process is not None
@@ -211,13 +214,19 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private method to generate a log tree entry.
 
-        @param author author info (string)
-        @param date date info (string)
-        @param message text of the log message (list of strings)
-        @param revision revision info (string)
+        @param author author info
+        @type str
+        @param date date info
+        @type str
+        @param message text of the log message
+        @type list of str
+        @param revision revision info
+        @type str
         @param changedPaths list of dictionary objects containing
             info about the changed files/directories
-        @return reference to the generated item (QTreeWidgetItem)
+        @type dict
+        @return reference to the generated item
+        @rtype QTreeWidgetItem
         """
         msg = []
         for line in message:
@@ -250,10 +259,15 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         Private method to generate a changed files tree entry.
 
         @param action indicator for the change action ("A", "D" or "M")
-        @param path path of the file in the repository (string)
-        @param copyFrom path the file was copied from (None, string)
-        @param copyRev revision the file was copied from (None, string)
-        @return reference to the generated item (QTreeWidgetItem)
+        @type str
+        @param path path of the file in the repository
+        @type str
+        @param copyFrom path the file was copied from
+        @type str
+        @param copyRev revision the file was copied from
+        @type str
+        @return reference to the generated item
+        @rtype QTreeWidgetItem
         """
         itm = QTreeWidgetItem(
             self.filesTree,
@@ -273,7 +287,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private method to retrieve log entries from the repository.
 
-        @param startRev revision number to start from (integer, string)
+        @param startRev revision number to start from
+        @type int or str
         """
         self.buttonBox.button(QDialogButtonBox.StandardButton.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.StandardButton.Cancel).setEnabled(True)
@@ -324,9 +339,10 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Public slot to start the svn log command.
 
-        @param fn filename to show the log for (string)
+        @param fn filename to show the log for
+        @type str
         @param isFile flag indicating log for a file is to be shown
-            (boolean)
+        @type bool
         """
         self.sbsCheckBox.setEnabled(isFile)
         self.sbsCheckBox.setVisible(isFile)
@@ -346,12 +362,15 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.__started = True
         self.__getLogEntries()
 
+    @pyqtSlot(int, QProcess.ExitStatus)
     def __procFinished(self, exitCode, exitStatus):
         """
         Private slot connected to the finished signal.
 
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.__processBuffer()
         self.__finish()
@@ -509,8 +528,10 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private method to do a diff of two revisions.
 
-        @param rev1 first revision number (integer)
-        @param rev2 second revision number (integer)
+        @param rev1 first revision number
+        @type int
+        @param rev2 second revision number
+        @type int
         """
         from .SvnDiffDialog import SvnDiffDialog
 
@@ -527,7 +548,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
@@ -540,8 +562,10 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the current item of the log tree changes.
 
-        @param current reference to the new current item (QTreeWidgetItem)
-        @param previous reference to the old current item (QTreeWidgetItem)
+        @param current reference to the new current item
+        @type QTreeWidgetItem
+        @param previous reference to the old current item
+        @type QTreeWidgetItem
         """
         if current is not None:
             self.messageEdit.clear()
@@ -630,7 +654,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the from date changes.
 
-        @param date new date (QDate)
+        @param date new date
+        @type QDate
         """
         self.__filterLogs()
 
@@ -639,7 +664,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the from date changes.
 
-        @param date new date (QDate)
+        @param date new date
+        @type QDate
         """
         self.__filterLogs()
 
@@ -658,7 +684,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when a filter expression is entered.
 
-        @param txt filter expression (string)
+        @param txt filter expression
+        @type str
         """
         self.__filterLogs()
 
@@ -706,7 +733,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot called, when the stop on copy/move checkbox is clicked.
 
-        @param checked flag indicating the checked state (boolean)
+        @param checked flag indicating the checked state
+        @type bool
         """
         self.vcs.getPlugin().setPreferences(
             "StopLogOnCopy", self.stopCheckBox.isChecked()
@@ -740,7 +768,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Private slot to handle the password checkbox toggled.
 
-        @param isOn flag indicating the status of the check box (boolean)
+        @param isOn flag indicating the status of the check box
+        @type bool
         """
         if isOn:
             self.input.setEchoMode(QLineEdit.EchoMode.Password)
@@ -779,7 +808,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         """
         Protected slot to handle a key press event.
 
-        @param evt the key press event (QKeyEvent)
+        @param evt the key press event
+        @type QKeyEvent
         """
         if self.intercept:
             self.intercept = False
