@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,7 +41,9 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         Constructor
 
         @param vcs reference to the vcs object
-        @param parent parent widget (QWidget)
+        @type Subversion
+        @param parent parent widget
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -266,17 +268,28 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private method to generate a status item in the status list.
 
-        @param status status indicator (string)
-        @param propStatus property status indicator (string)
-        @param locked locked indicator (string)
-        @param history history indicator (string)
-        @param switched switched indicator (string)
-        @param lockinfo lock indicator (string)
-        @param uptodate up to date indicator (string)
-        @param revision revision string (string)
-        @param change revision of last change (string)
-        @param author author of the last change (string)
-        @param path path of the file or directory (string)
+        @param status status indicator
+        @type str
+        @param propStatus property status indicator
+        @type str
+        @param locked locked indicator
+        @type str
+        @param history history indicator
+        @type str
+        @param switched switched indicator
+        @type str
+        @param lockinfo lock indicator
+        @type str
+        @param uptodate up to date indicator
+        @type str
+        @param revision revision string
+        @type str
+        @param change revision of last change
+        @type str
+        @param author author of the last change
+        @type str
+        @param path path of the file or directory
+        @type str
         """
         if (
             self.__nonverbose
@@ -358,7 +371,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Protected slot implementing a close event handler.
 
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         if (
             self.process is not None
@@ -375,7 +389,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         Public slot to start the svn status command.
 
         @param fn filename(s)/directoryname(s) to show the status of
-            (string or list of strings)
+        @type str or list of str
         """
         self.errorGroup.hide()
         self.intercept = False
@@ -516,7 +530,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Close):
             self.close()
@@ -525,12 +540,15 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         elif button == self.refreshButton:
             self.on_refreshButton_clicked()
 
+    @pyqtSlot(int, QProcess.ExitStatus)
     def __procFinished(self, exitCode, exitStatus):
         """
         Private slot connected to the finished signal.
 
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.__finish()
 
@@ -618,7 +636,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private slot to handle the password checkbox toggled.
 
-        @param isOn flag indicating the status of the check box (boolean)
+        @param isOn flag indicating the status of the check box
+        @type bool
         """
         if isOn:
             self.input.setEchoMode(QLineEdit.EchoMode.Password)
@@ -656,7 +675,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Protected slot to handle a key press event.
 
-        @param evt the key press event (QKeyEvent)
+        @param evt the key press event
+        @type QKeyEvent
         """
         if self.intercept:
             self.intercept = False
@@ -715,8 +735,10 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private slot to act upon item changes.
 
-        @param item reference to the changed item (QTreeWidgetItem)
-        @param column index of column that changed (integer)
+        @param item reference to the changed item
+        @type QTreeWidgetItem
+        @param column index of column that changed
+        @type int
         """
         if column == self.__toBeCommittedColumn:
             self.__updateCommitButton()
@@ -778,7 +800,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private slot to show the context menu of the status list.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         self.menu.popup(self.statusList.mapToGlobal(coord))
 
@@ -1045,7 +1068,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
 
     def __removeFromChangelist(self):
         """
-        Private slot to remove entries from their changelists.
+        Private slot to remove entries from their change lists.
         """
         names = [
             os.path.join(self.dname, itm.text(self.__pathColumn))
@@ -1069,6 +1092,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         Private method to retrieve all entries the user wants to commit.
 
         @return list of all items, the user has checked
+        @rtype list of QTreeWidgetItem
         """
         commitableItems = []
         for index in range(self.statusList.topLevelItemCount()):
@@ -1082,6 +1106,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         Private method to retrieve all entries, that have a modified status.
 
         @return list of all items with a modified status
+        @rtype list of QTreeWidgetItem
         """
         modifiedItems = []
         for itm in self.statusList.selectedItems():
@@ -1098,6 +1123,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         status.
 
         @return list of all items with an unversioned status
+        @rtype list of QTreeWidgetItem
         """
         unversionedItems = []
         for itm in self.statusList.selectedItems():
@@ -1110,6 +1136,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         Private method to retrieve all entries, that have a missing status.
 
         @return list of all items with a missing status
+        @rtype list of QTreeWidgetItem
         """
         missingItems = []
         for itm in self.statusList.selectedItems():
@@ -1121,8 +1148,10 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private method to retrieve all emtries, that have a locked status.
 
-        @param indicators list of indicators to check against (list of strings)
+        @param indicators list of indicators to check against
+        @type list of str
         @return list of all items with a locked status
+        @rtype list of QTreeWidgetItem
         """
         lockitems = []
         for itm in self.statusList.selectedItems():
@@ -1136,6 +1165,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         a changelist.
 
         @return list of all items belonging to a changelist
+        @rtype list of QTreeWidgetItem
         """
         clitems = []
         for itm in self.statusList.selectedItems():
@@ -1149,6 +1179,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         a changelist.
 
         @return list of all items not belonging to a changelist
+        @rtype list of QTreeWidgetItem
         """
         clitems = []
         for itm in self.statusList.selectedItems():
@@ -1160,7 +1191,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         """
         Private slot to select or deselect all entries.
 
-        @param selected commit selection state to be set (boolean)
+        @param selected commit selection state to be set
+        @type bool
         """
         for index in range(self.statusList.topLevelItemCount()):
             itm = self.statusList.topLevelItem(index)
