@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,7 +20,7 @@ from eric7 import Preferences, Utilities
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
 from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
-from eric7.VCS.VersionControl import VersionControl
+from eric7.VCS.VersionControl import VersionControl, VersionControlState
 
 from .SvnDialog import SvnDialog
 from .SvnUtilities import amendConfig, createDefaultConfig, getConfigPath
@@ -40,8 +40,11 @@ class Subversion(VersionControl):
         Constructor
 
         @param plugin reference to the plugin object
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @type VcsSubversionPlugin
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         VersionControl.__init__(self, parent, name)
         self.defaultOptions = {
@@ -114,7 +117,8 @@ class Subversion(VersionControl):
         """
         Public method to get a reference to the plugin object.
 
-        @return reference to the plugin object (VcsSubversionPlugin)
+        @return reference to the plugin object
+        @rtype VcsSubversionPlugin
         """
         return self.__plugin
 
@@ -145,8 +149,8 @@ class Subversion(VersionControl):
         """
         Public method used to test for the presence of the svn executable.
 
-        @return flag indicating the existance (boolean) and an error message
-            (string)
+        @return flag indicating the existence and an error message
+        @rtype tuple of (bool, str)
         """
         self.versionStr = ""
         errMsg = ""
@@ -184,7 +188,7 @@ class Subversion(VersionControl):
 
         return False, errMsg
 
-    def vcsInit(self, vcsDir, noDialog=False):
+    def vcsInit(self, vcsDir, noDialog=False):  # noqa: U100
         """
         Public method used to initialize the subversion repository.
 
@@ -192,9 +196,12 @@ class Subversion(VersionControl):
         because the respective command always works locally. Therefore we
         always return TRUE without doing anything.
 
-        @param vcsDir name of the VCS directory (string)
-        @param noDialog flag indicating quiet operations (boolean)
-        @return always TRUE
+        @param vcsDir name of the VCS directory
+        @type str
+        @param noDialog flag indicating quiet operations
+        @type bool
+        @return always True
+        @rtype bool
         """
         return True
 
@@ -227,7 +234,7 @@ class Subversion(VersionControl):
                 os.chdir(os.path.dirname(project.ppath))
                 cwdIsPpath = True
             tmpProjectDir = "{0}_tmp".format(project.ppath)
-            shutil.rmtree(tmpProjectDir, True)
+            shutil.rmtree(tmpProjectDir, ignore_errors=True)
             os.rename(project.ppath, tmpProjectDir)
             os.makedirs(project.ppath)
             self.vcsCheckout(vcsDataDict, project.ppath)
@@ -252,7 +259,7 @@ class Subversion(VersionControl):
                     cwdIsPpath = True
                 else:
                     cwdIsPpath = False
-                shutil.rmtree(project.ppath, True)
+                shutil.rmtree(project.ppath, ignore_errors=True)
                 os.rename(tmpProjectDir, project.ppath)
                 project.setProjectData("None", dataKey="VCS")
                 project.vcs = None
@@ -260,18 +267,20 @@ class Subversion(VersionControl):
                 project.saveProject()
                 project.closeProject()
                 return
-            shutil.rmtree(tmpProjectDir, True)
+            shutil.rmtree(tmpProjectDir, ignore_errors=True)
             project.closeProject(noSave=True)
             project.openProject(pfn)
 
-    def vcsImport(self, vcsDataDict, projectDir, noDialog=False, addAll=True):
+    def vcsImport(
+        self, vcsDataDict, projectDir, noDialog=False, addAll=True  # noqa: U100
+    ):
         """
         Public method used to import the project into the Subversion
         repository.
 
         @param vcsDataDict dictionary of data required for the import
         @type dict
-        @param projectDir project directory (string)
+        @param projectDir project directory
         @type str
         @param noDialog flag indicating quiet operations
         @type bool
@@ -307,7 +316,7 @@ class Subversion(VersionControl):
                 shutil.copytree(projectDir, os.path.join(tmpDir, project))
         except OSError:
             if os.path.isdir(tmpDir):
-                shutil.rmtree(tmpDir, True)
+                shutil.rmtree(tmpDir, ignore_errors=True)
             return False, False
 
         args = []
@@ -328,7 +337,7 @@ class Subversion(VersionControl):
                 dia.exec()
             status = dia.normalExit()
 
-        shutil.rmtree(tmpDir, True)
+        shutil.rmtree(tmpDir, ignore_errors=True)
         return status, False
 
     def vcsCheckout(self, vcsDataDict, projectDir, noDialog=False):
@@ -337,9 +346,13 @@ class Subversion(VersionControl):
         repository.
 
         @param vcsDataDict dictionary of data required for the checkout
-        @param projectDir project directory to create (string)
+        @type dict
+        @param projectDir project directory to create
+        @type str
         @param noDialog flag indicating quiet operations
-        @return flag indicating an execution without errors (boolean)
+        @type bool
+        @return flag indicating an execution without errors
+        @rtype bool
         """
         noDialog = False
         try:
@@ -398,8 +411,11 @@ class Subversion(VersionControl):
         repository.
 
         @param vcsDataDict dictionary of data required for the checkout
-        @param projectDir project directory to create (string)
-        @return flag indicating an execution without errors (boolean)
+        @type dict
+        @param projectDir project directory to create
+        @type str
+        @return flag indicating an execution without errors
+        @rtype bool
         """
         try:
             tag = vcsDataDict["tag"]
@@ -451,10 +467,12 @@ class Subversion(VersionControl):
         Public method used to make the change of a file/directory permanent
         in the Subversion repository.
 
-        @param name file/directory name to be committed (string or list of
-            strings)
-        @param message message for this operation (string)
+        @param name file/directory name to be committed
+        @type str or list of str
+        @param message message for this operation
+        @type str
         @param noDialog flag indicating quiet operations
+        @type bool
         """
         from .SvnCommitDialog import SvnCommitDialog
 
@@ -611,11 +629,12 @@ class Subversion(VersionControl):
         Public method used to update a file/directory with the Subversion
         repository.
 
-        @param name file/directory name to be updated (string or list of
-            strings)
-        @param noDialog flag indicating quiet operations (boolean)
-        @return flag indicating, that the update contained an add
-            or delete (boolean)
+        @param name file/directory name to be updated
+        @type str or list of str
+        @param noDialog flag indicating quiet operations
+        @type bool
+        @return flag indicating, that the update contained an add or delete
+        @rtype bool
         """
         args = []
         args.append("update")
@@ -648,9 +667,12 @@ class Subversion(VersionControl):
         Public method used to add a file/directory to the Subversion
         repository.
 
-        @param name file/directory name to be added (string)
-        @param isDir flag indicating name is a directory (boolean)
+        @param name file/directory name to be added
+        @type str
+        @param isDir flag indicating name is a directory
+        @type bool
         @param noDialog flag indicating quiet operations
+        @type bool
         """
         args = []
         args.append("add")
@@ -680,7 +702,8 @@ class Subversion(VersionControl):
                     return  # oops, project is not version controlled
             while os.path.normcase(dname) != os.path.normcase(repodir) and (
                 os.path.normcase(dname) not in self.statusCache
-                or self.statusCache[os.path.normcase(dname)] == self.canBeAdded
+                or self.statusCache[os.path.normcase(dname)]
+                == VersionControlState.Uncontrolled
             ):
                 # add directories recursively, if they aren't in the
                 # repository already
@@ -711,7 +734,8 @@ class Subversion(VersionControl):
                         and (d not in tree2 + tree)
                         and (
                             os.path.normcase(d) not in self.statusCache
-                            or self.statusCache[os.path.normcase(d)] == self.canBeAdded
+                            or self.statusCache[os.path.normcase(d)]
+                            == VersionControlState.Uncontrolled
                         )
                     ):
                         tree2.append(d)
@@ -743,8 +767,10 @@ class Subversion(VersionControl):
         Public method used to add a file/directory in binary mode to the
         Subversion repository.
 
-        @param name file/directory name to be added (string)
-        @param isDir flag indicating name is a directory (boolean)
+        @param name file/directory name to be added
+        @type str
+        @param isDir flag indicating name is a directory
+        @type bool
         """
         self.vcsAdd(name, isDir)
 
@@ -753,8 +779,8 @@ class Subversion(VersionControl):
         Public method to add a directory tree rooted at path to the Subversion
         repository.
 
-        @param path root directory of the tree to be added (string or list of
-            strings))
+        @param path root directory of the tree to be added
+        @type str or list of str
         """
         args = []
         args.append("add")
@@ -777,7 +803,8 @@ class Subversion(VersionControl):
                         and (d not in tree)
                         and (
                             os.path.normcase(d) not in self.statusCache
-                            or self.statusCache[os.path.normcase(d)] == self.canBeAdded
+                            or self.statusCache[os.path.normcase(d)]
+                            == VersionControlState.Uncontrolled
                         )
                     ):
                         tree.append(d)
@@ -801,7 +828,8 @@ class Subversion(VersionControl):
                         return  # oops, project is not version controlled
                 while os.path.normcase(dname) != os.path.normcase(repodir) and (
                     os.path.normcase(dname) not in self.statusCache
-                    or self.statusCache[os.path.normcase(dname)] == self.canBeAdded
+                    or self.statusCache[os.path.normcase(dname)]
+                    == VersionControlState.Uncontrolled
                 ):
                     # add directories recursively, if they aren't in the
                     # repository already
@@ -826,19 +854,21 @@ class Subversion(VersionControl):
         if res:
             dia.exec()
 
-    def vcsRemove(self, name, project=False, noDialog=False):
+    def vcsRemove(self, name, project=False, noDialog=False):  # noqa: U100
         """
         Public method used to remove a file/directory from the Subversion
         repository.
 
         The default operation is to remove the local copy as well.
 
-        @param name file/directory name to be removed (string or list of
-            strings))
-        @param project flag indicating deletion of a project tree (boolean)
-            (not needed)
+        @param name file/directory name to be removed
+        @type str or list of str
+        @param project flag indicating deletion of a project tree
+        @type bool
         @param noDialog flag indicating quiet operations
-        @return flag indicating successfull operation (boolean)
+        @type bool
+        @return flag indicating successfull operation
+        @rtype bool
         """
         args = []
         args.append("delete")
@@ -869,11 +899,16 @@ class Subversion(VersionControl):
         """
         Public method used to move a file/directory.
 
-        @param name file/directory name to be moved (string)
+        @param name file/directory name to be moved
+        @type str
         @param project reference to the project object
-        @param target new name of the file/directory (string)
+        @type Project
+        @param target new name of the file/directory
+        @type str
         @param noDialog flag indicating quiet operations
-        @return flag indicating successfull operation (boolean)
+        @type bool
+        @return flag indicating successfull operation
+        @rtype bool
         """
         from .SvnCopyDialog import SvnCopyDialog
 
@@ -943,7 +978,8 @@ class Subversion(VersionControl):
         being edited and has unsaved modification, they can be saved or the
         operation may be aborted.
 
-        @param name file/directory name to be diffed (string)
+        @param name file/directory name to be diffed
+        @type str
         """
         from .SvnDiffDialog import SvnDiffDialog
 
@@ -970,7 +1006,7 @@ class Subversion(VersionControl):
         Subversion repository.
 
         @param name file/directory name(s) to show the status of
-            (string or list of strings)
+        @type str or list of str
         """
         from .SvnStatusDialog import SvnStatusDialog
 
@@ -985,7 +1021,8 @@ class Subversion(VersionControl):
         Public method used to set the tag of a file/directory in the
         Subversion repository.
 
-        @param name file/directory name to be tagged (string)
+        @param name file/directory name to be tagged
+        @type str
         """
         from .SvnTagDialog import SvnTagDialog
 
@@ -1134,8 +1171,10 @@ class Subversion(VersionControl):
         """
         Public method used to switch a directory to a different tag/branch.
 
-        @param name directory name to be switched (string)
-        @return flag indicating added or changed files (boolean)
+        @param name directory name to be switched
+        @type str
+        @return flag indicating added or changed files
+        @rtype bool
         """
         from .SvnSwitchDialog import SvnSwitchDialog
 
@@ -1216,7 +1255,8 @@ class Subversion(VersionControl):
         """
         Public method used to merge a URL/revision into the local project.
 
-        @param name file/directory name to be merged (string)
+        @param name file/directory name to be merged
+        @type str
         """
         from .SvnMergeDialog import SvnMergeDialog
 
@@ -1279,8 +1319,10 @@ class Subversion(VersionControl):
         """
         Public method used to get the registered state of a file in the vcs.
 
-        @param name filename to check (string)
-        @return a combination of canBeCommited and canBeAdded
+        @param name filename to check
+        @type str
+        @return registered state
+        @rtype VersionControlState
         """
         if self.__wcng:
             return self.__vcsRegisteredState_wcng(name)
@@ -1294,8 +1336,10 @@ class Subversion(VersionControl):
         This is the variant for subversion installations using the new
         working copy meta-data format.
 
-        @param name filename to check (string)
-        @return a combination of canBeCommited and canBeAdded
+        @param name filename to check
+        @type str
+        @return registered state
+        @rtype VersionControlState
         """
         if name.endswith(os.sep):
             name = name[:-1]
@@ -1303,7 +1347,7 @@ class Subversion(VersionControl):
         dname, fname = self.splitPath(name)
 
         if fname == "." and os.path.isdir(os.path.join(dname, self.adminDir)):
-            return self.canBeCommitted
+            return VersionControlState.Controlled
 
         if name in self.statusCache:
             return self.statusCache[name]
@@ -1311,10 +1355,10 @@ class Subversion(VersionControl):
         name = os.path.normcase(name)
         states = {name: 0}
         states = self.vcsAllRegisteredStates(states, dname, False)
-        if states[name] == self.canBeCommitted:
-            return self.canBeCommitted
+        if states[name] == VersionControlState.Controlled:
+            return VersionControlState.Controlled
         else:
-            return self.canBeAdded
+            return VersionControlState.Uncontrolled
 
     def __vcsRegisteredState_wc(self, name):
         """
@@ -1323,24 +1367,26 @@ class Subversion(VersionControl):
         This is the variant for subversion installations using the old working
         copy meta-data format.
 
-        @param name filename to check (string)
-        @return a combination of canBeCommited and canBeAdded
+        @param name filename to check
+        @type str
+        @return registered state
+        @rtype VersionControlState
         """
         dname, fname = self.splitPath(name)
 
         if fname == ".":
             if os.path.isdir(os.path.join(dname, self.adminDir)):
-                return self.canBeCommitted
+                return VersionControlState.Controlled
             else:
-                return self.canBeAdded
+                return VersionControlState.Uncontrolled
 
         name = os.path.normcase(name)
         states = {name: 0}
         states = self.vcsAllRegisteredStates(states, dname, False)
-        if states[name] == self.canBeCommitted:
-            return self.canBeCommitted
+        if states[name] == VersionControlState.Controlled:
+            return VersionControlState.Controlled
         else:
-            return self.canBeAdded
+            return VersionControlState.Uncontrolled
 
     def vcsAllRegisteredStates(self, names, dname, shortcut=True):
         """
@@ -1352,17 +1398,21 @@ class Subversion(VersionControl):
         that the states for all files have been populated by the previous run.
 
         @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of
-            canBeCommited and canBeAdded or None in order to signal an error
+        @type dict
+        @param dname directory to check in
+        @type str
+        @param shortcut flag indicating a shortcut should be taken
+        @type bool
+        @return the received dictionary completed with the VCS state or None in
+            order to signal an error
+        @rtype dict
         """
         if self.__wcng:
-            return self.__vcsAllRegisteredStates_wcng(names, dname, shortcut)
+            return self.__vcsAllRegisteredStates_wcng(names, dname)
         else:
             return self.__vcsAllRegisteredStates_wc(names, dname, shortcut)
 
-    def __vcsAllRegisteredStates_wcng(self, names, dname, shortcut=True):
+    def __vcsAllRegisteredStates_wcng(self, names, dname):
         """
         Private method used to get the registered states of a number of files
         in the VCS.
@@ -1375,10 +1425,12 @@ class Subversion(VersionControl):
         that the states for all files has been populated by the previous run.
 
         @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of
-            canBeCommited and canBeAdded or None in order to signal an error
+        @type dict
+        @param dname directory to check in
+        @type str
+        @return the received dictionary completed with the VCS state or None in
+            order to signal an error
+        @rtype dict
         """
         if dname.endswith(os.sep):
             dname = dname[:-1]
@@ -1426,10 +1478,10 @@ class Subversion(VersionControl):
                         name = os.path.normcase(path)
                         if flags[0] not in "?I":
                             if name in names:
-                                names[name] = self.canBeCommitted
-                            self.statusCache[name] = self.canBeCommitted
+                                names[name] = VersionControlState.Controlled
+                            self.statusCache[name] = VersionControlState.Controlled
                         else:
-                            self.statusCache[name] = self.canBeAdded
+                            self.statusCache[name] = VersionControlState.Uncontrolled
 
         return names
 
@@ -1446,17 +1498,21 @@ class Subversion(VersionControl):
         that the states for all files has been populated by the previous run.
 
         @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of
-            canBeCommited and canBeAdded or None in order to signal an error
+        @type dict
+        @param dname directory to check in
+        @type str
+        @param shortcut flag indicating a shortcut should be taken
+        @type bool
+        @return the received dictionary completed with the VCS state or None in
+            order to signal an error
+        @rtype dict
         """
         if not os.path.isdir(os.path.join(dname, self.adminDir)):
             # not under version control -> do nothing
             return names
 
         found = False
-        for name in list(self.statusCache.keys()):
+        for name in self.statusCache:
             if os.path.dirname(name) == dname:
                 if shortcut:
                     found = True
@@ -1494,10 +1550,10 @@ class Subversion(VersionControl):
                         name = os.path.normcase(path)
                         if flags[0] not in "?I":
                             if name in names:
-                                names[name] = self.canBeCommitted
-                            self.statusCache[name] = self.canBeCommitted
+                                names[name] = VersionControlState.Controlled
+                            self.statusCache[name] = VersionControlState.Controlled
                         else:
-                            self.statusCache[name] = self.canBeAdded
+                            self.statusCache[name] = VersionControlState.Uncontrolled
 
         return names
 
@@ -1507,13 +1563,14 @@ class Subversion(VersionControl):
         """
         self.statusCache = {}
 
-    def vcsInitConfig(self, project):
+    def vcsInitConfig(self, project):  # noqa: U100
         """
         Public method to initialize the VCS configuration.
 
         This method ensures, that an ignore file exists.
 
-        @param project reference to the project (Project)
+        @param project reference to the project
+        @type Project
         """
         configPath = getConfigPath()
         if os.path.exists(configPath):
@@ -1525,7 +1582,8 @@ class Subversion(VersionControl):
         """
         Public method returning the name of the vcs.
 
-        @return always 'Subversion' (string)
+        @return always 'Subversion'
+        @rtype str
         """
         return "Subversion"
 
@@ -1533,7 +1591,8 @@ class Subversion(VersionControl):
         """
         Public method used to cleanup the working copy.
 
-        @param name directory name to be cleaned up (string)
+        @param name directory name to be cleaned up
+        @type str
         """
         args = []
         args.append("cleanup")
@@ -1549,7 +1608,8 @@ class Subversion(VersionControl):
         """
         Public method used to execute arbitrary subversion commands.
 
-        @param name directory name of the working directory (string)
+        @param name directory name of the working directory
+        @type str
         """
         from .SvnCommandDialog import SvnCommandDialog
 
@@ -1575,16 +1635,22 @@ class Subversion(VersionControl):
             if res:
                 dia.exec()
 
-    def vcsOptionsDialog(self, project, archive, editable=False, parent=None):
+    def vcsOptionsDialog(
+        self, project, archive, editable=False, parent=None  # noqa: U100
+    ):
         """
         Public method to get a dialog to enter repository info.
 
         @param project reference to the project object
-        @param archive name of the project in the repository (string)
+        @type Project
+        @param archive name of the project in the repository
+        @type str
         @param editable flag indicating that the project name is editable
-            (boolean)
-        @param parent parent widget (QWidget)
-        @return reference to the instantiated options dialog (SvnOptionsDialog)
+        @type bool
+        @param parent parent widget
+        @type QWidget
+        @return reference to the instantiated options dialog
+        @rtype SvnOptionsDialog
         """
         from .SvnOptionsDialog import SvnOptionsDialog
 
@@ -1595,9 +1661,10 @@ class Subversion(VersionControl):
         Public method to get a dialog to enter repository info for getting
         a new project.
 
-        @param parent parent widget (QWidget)
+        @param parent parent widget
+        @type QWidget
         @return reference to the instantiated options dialog
-            (SvnNewProjectOptionsDialog)
+        @rtype SvnNewProjectOptionsDialog
         """
         from .SvnNewProjectOptionsDialog import SvnNewProjectOptionsDialog
 
@@ -1607,8 +1674,10 @@ class Subversion(VersionControl):
         """
         Public method to retrieve information about the repository.
 
-        @param ppath local path to get the repository infos (string)
-        @return string with ready formated info for display (string)
+        @param ppath local path to get the repository infos
+        @type str
+        @return string with ready formated info for display
+        @rtype str
         """
         info = {
             "committed-rev": "",
@@ -1695,8 +1764,10 @@ class Subversion(VersionControl):
         Public method used to retrieve the URL of the subversion repository
         path.
 
-        @param path local path to get the svn repository path for (string)
+        @param path local path to get the svn repository path for
+        @type str
         @return string with the repository path URL
+        @rtype str
         """
         ioEncoding = Preferences.getSystem("IOEncoding")
 
@@ -1724,7 +1795,8 @@ class Subversion(VersionControl):
         """
         Public method used to resolve conflicts of a file/directory.
 
-        @param name file/directory name to be resolved (string)
+        @param name file/directory name to be resolved
+        @type str
         """
         args = []
         if self.version >= (1, 5, 0):
@@ -1751,9 +1823,12 @@ class Subversion(VersionControl):
         """
         Public method used to copy a file/directory.
 
-        @param name file/directory name to be copied (string)
+        @param name file/directory name to be copied
+        @type str
         @param project reference to the project object
-        @return flag indicating successfull operation (boolean)
+        @type Project
+        @return flag indicating successfull operation
+        @rtype bool
         """
         from .SvnCopyDialog import SvnCopyDialog
 
@@ -1794,8 +1869,10 @@ class Subversion(VersionControl):
         """
         Public method used to list the properties of a file/directory.
 
-        @param name file/directory name (string or list of strings)
+        @param name file/directory name
+        @type str or list of str
         @param recursive flag indicating a recursive list is requested
+        @type bool
         """
         from .SvnPropListDialog import SvnPropListDialog
 
@@ -1809,8 +1886,10 @@ class Subversion(VersionControl):
         """
         Public method used to add a property to a file/directory.
 
-        @param name file/directory name (string or list of strings)
+        @param name file/directory name
+        @type str or list of str
         @param recursive flag indicating a recursive list is requested
+        @type bool
         """
         from .SvnPropSetDialog import SvnPropSetDialog
 
@@ -1850,8 +1929,10 @@ class Subversion(VersionControl):
         """
         Public method used to delete a property of a file/directory.
 
-        @param name file/directory name (string or list of strings)
+        @param name file/directory name
+        @type str or list of str
         @param recursive flag indicating a recursive list is requested
+        @type bool
         """
         propName, ok = QInputDialog.getText(
             None,
@@ -1893,9 +1974,11 @@ class Subversion(VersionControl):
         """
         Public method used to list the available tags or branches.
 
-        @param path directory name of the project (string)
+        @param path directory name of the project
+        @type str
         @param tags flag indicating listing of branches or tags
-                (False = branches, True = tags)
+            (False = branches, True = tags)
+        @type bool
         """
         from .SvnTagBranchListDialog import SvnTagBranchListDialog
 
@@ -1926,7 +2009,8 @@ class Subversion(VersionControl):
         """
         Public method to show the output of the svn blame command.
 
-        @param name file name to show the blame for (string)
+        @param name file name to show the blame for
+        @type str
         """
         from .SvnBlameDialog import SvnBlameDialog
 
@@ -1948,7 +2032,8 @@ class Subversion(VersionControl):
 
         This method gives the chance to enter the revisions to be compared.
 
-        @param name file/directory name to be diffed (string)
+        @param name file/directory name to be diffed
+        @type str
         """
         from .SvnDiffDialog import SvnDiffDialog
         from .SvnRevisionSelectionDialog import SvnRevisionSelectionDialog
@@ -1982,7 +2067,8 @@ class Subversion(VersionControl):
 
         This method gives the chance to enter the revisions to be compared.
 
-        @param name file/directory name to be diffed (string)
+        @param name file/directory name to be diffed
+        @type str
         """
         from .SvnDiffDialog import SvnDiffDialog
         from .SvnUrlSelectionDialog import SvnUrlSelectionDialog
@@ -2013,9 +2099,12 @@ class Subversion(VersionControl):
         Private method to get a file for a specific revision from the
         repository.
 
-        @param name file name to get from the repository (string)
-        @param rev revision to retrieve (integer or string)
-        @return contents of the file (string) and an error message (string)
+        @param name file name to get from the repository
+        @type str
+        @param rev revision to retrieve
+        @type int or str
+        @return contents of the file (string) and an error message
+        @rtype str
         """
         args = []
         args.append("cat")
@@ -2060,9 +2149,12 @@ class Subversion(VersionControl):
         Public method used to view the difference of a file to the Mercurial
         repository side-by-side.
 
-        @param name file name to be diffed (string)
-        @param extended flag indicating the extended variant (boolean)
-        @param revisions tuple of two revisions (tuple of strings)
+        @param name file name to be diffed
+        @type str
+        @param extended flag indicating the extended variant
+        @type bool
+        @param revisions tuple of two revisions
+        @type tuple of (str, str)
         @exception ValueError raised to indicate an illegal name parameter type
         """
         from eric7.UI.CompareDialog import CompareDialog
@@ -2129,8 +2221,10 @@ class Subversion(VersionControl):
         Public method used to browse the log of a file/directory from the
         Subversion repository.
 
-        @param name file/directory name to show the log of (string)
-        @param isFile flag indicating log for a file is to be shown (boolean)
+        @param name file/directory name to show the log of
+        @type str
+        @param isFile flag indicating log for a file is to be shown
+        @type bool
         """
         from .SvnLogBrowserDialog import SvnLogBrowserDialog
 
@@ -2144,11 +2238,12 @@ class Subversion(VersionControl):
         """
         Public method used to lock a file in the Subversion repository.
 
-        @param name file/directory name to be locked (string or list of
-            strings)
-        @param stealIt flag indicating a forced operation (boolean)
+        @param name file/directory name to be locked
+        @type str or list of str
+        @param stealIt flag indicating a forced operation
+        @type bool
         @param parent reference to the parent object of the subversion dialog
-            (QWidget)
+        @type QWidget
         """
         args = []
         args.append("lock")
@@ -2171,11 +2266,12 @@ class Subversion(VersionControl):
         """
         Public method used to unlock a file in the Subversion repository.
 
-        @param name file/directory name to be unlocked (string or list of
-            strings)
-        @param breakIt flag indicating a forced operation (boolean)
+        @param name file/directory name to be unlocked
+        @type str or list of str
+        @param breakIt flag indicating a forced operation
+        @type bool
         @param parent reference to the parent object of the subversion dialog
-            (QWidget)
+        @type QWidget
         """
         args = []
         args.append("unlock")
@@ -2198,7 +2294,8 @@ class Subversion(VersionControl):
         """
         Public method to relocate the working copy to a new repository URL.
 
-        @param projectPath path name of the project (string)
+        @param projectPath path name of the project
+        @type str
         """
         from .SvnRelocateDialog import SvnRelocateDialog
 
@@ -2223,7 +2320,8 @@ class Subversion(VersionControl):
         """
         Public method to open the repository browser.
 
-        @param projectPath path name of the project (string)
+        @param projectPath path name of the project
+        @type str
         """
         from .SvnRepoBrowserDialog import SvnRepoBrowserDialog
 
@@ -2252,7 +2350,7 @@ class Subversion(VersionControl):
         Note: Directories will be removed recursively.
 
         @param names name or list of names of file or directory to remove
-            (string)
+        @type str or list of str
         """
         args = []
         args.append("changelist")
@@ -2278,7 +2376,7 @@ class Subversion(VersionControl):
         Note: Directories will be added recursively.
 
         @param names name or list of names of file or directory to add
-            (string)
+        @type str or list of str
         """
         clname, ok = QInputDialog.getItem(
             None,
@@ -2312,7 +2410,8 @@ class Subversion(VersionControl):
         """
         Public method used to inspect the change lists defined for the project.
 
-        @param path directory name to show change lists for (string)
+        @param path directory name to show change lists for
+        @type str
         """
         from .SvnChangeListsDialog import SvnChangeListsDialog
 
@@ -2325,7 +2424,8 @@ class Subversion(VersionControl):
         """
         Public method to get a list of all defined change lists.
 
-        @return list of defined change list names (list of strings)
+        @return list of defined change list names
+        @rtype list of str
         """
         changelists = []
         rx_changelist = re.compile("--- \\S+ .([\\w\\s]+).:\\s*")
@@ -2364,7 +2464,8 @@ class Subversion(VersionControl):
         """
         Public method to upgrade the working copy format.
 
-        @param path directory name to show change lists for (string)
+        @param path directory name to show change lists for
+        @type str
         """
         args = []
         args.append("upgrade")
@@ -2383,8 +2484,10 @@ class Subversion(VersionControl):
         """
         Private method to format a url for subversion.
 
-        @param url unformatted url string (string)
-        @return properly formated url for subversion (string)
+        @param url unformatted url string
+        @type str
+        @return properly formated url for subversion
+        @rtype str
         """
         url = self.svnNormalizeURL(url)
         url = url.split(":", 2)
@@ -2409,8 +2512,10 @@ class Subversion(VersionControl):
         """
         Public method to normalize a url for subversion.
 
-        @param url url string (string)
-        @return properly normalized url for subversion (string)
+        @param url url string
+        @type str
+        @return properly normalized url for subversion
+        @rtype str
         """
         protocol, url = url.split("://", 1)
         if url.startswith("\\\\"):
@@ -2434,10 +2539,14 @@ class Subversion(VersionControl):
         project browsers.
 
         @param browser reference to the project browser object
+        @type ProjectBaseBrowser
         @param project reference to the project object
+        @type Project
         @param isTranslationsBrowser flag indicating, the helper is requested
             for the translations browser (this needs some special treatment)
+        @type bool
         @return the project browser helper object
+        @rtype SvnProjectBrowserHelper
         """
         from .ProjectBrowserHelper import SvnProjectBrowserHelper
 
@@ -2448,7 +2557,9 @@ class Subversion(VersionControl):
         Public method to instanciate a helper object for the project.
 
         @param project reference to the project object
+        @type Project
         @return the project helper object
+        @rtype SvnProjectHelper
         """
         helper = self.__plugin.getProjectHelper()
         helper.setObjects(self, project)
@@ -2470,9 +2581,11 @@ class Subversion(VersionControl):
         thread.
 
         @param interval check interval for the monitor thread in seconds
-            (integer)
+        @type int
         @param project reference to the project object
-        @return reference to the monitor thread (QThread)
+        @type Project
+        @return reference to the monitor thread
+        @rtype SvnStatusMonitorThread
         """
         from .SvnStatusMonitorThread import SvnStatusMonitorThread
 
