@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a tabbed viewmanager class.
 """
 
+import itertools
 import os
 
 from PyQt6.QtCore import (
@@ -297,6 +298,14 @@ class TabWidget(EricTabWidget):
             self.tr("Close Others"),
             self.__contextMenuCloseOthers,
         )
+        self.closeLeftMenuAct = self.__menu.addAction(
+            self.tr("Close Tabs to the Left"),
+            self.__contextMenuCloseLeft,
+        )
+        self.closeRightMenuAct = self.__menu.addAction(
+            self.tr("Close Tabs to the Right"),
+            self.__contextMenuCloseRight,
+        )
         self.__menu.addAction(self.tr("Close All"), self.__contextMenuCloseAll)
         self.__menu.addSeparator()
         self.saveMenuAct = self.__menu.addAction(
@@ -371,6 +380,8 @@ class TabWidget(EricTabWidget):
                 self.lastMenuAct.setEnabled(index < self.count() - 1)
 
                 self.closeOthersMenuAct.setEnabled(self.count() > 1)
+                self.closeLeftMenuAct.setEnabled(index > 0)
+                self.closeRightMenuAct.setEnabled(index < self.count() - 1)
 
                 coord = self.mapToGlobal(coord)
                 self.__menu.popup(coord)
@@ -466,7 +477,7 @@ class TabWidget(EricTabWidget):
 
         return newIndex
 
-    def __captionChange(self, cap, editor):
+    def __captionChange(self, cap, editor):  # noqa: U100
         """
         Private slot to handle Caption change signals from the editor.
 
@@ -488,7 +499,7 @@ class TabWidget(EricTabWidget):
             maxFileNameChars = Preferences.getUI("TabViewManagerFilenameLength")
             if len(txt) > maxFileNameChars:
                 txt = "...{0}".format(txt[-maxFileNameChars:])
-            if editor.isReadOnly():
+            if editor.checkReadOnly():
                 txt = self.tr("{0} (ro)").format(txt)
 
             assembly = editor.parent()
@@ -672,12 +683,30 @@ class TabWidget(EricTabWidget):
         Private method to close the other tabs.
         """
         index = self.contextMenuIndex
-        for i in list(range(self.count() - 1, index, -1)) + list(
-            range(index - 1, -1, -1)
+        for i in itertools.chain(
+            range(self.count() - 1, index, -1), range(index - 1, -1, -1)
         ):
             editor = self.widget(i).getEditor()
             self.vm.closeEditorWindow(editor)
 
+    def __contextMenuCloseLeft(self):
+        """
+        Private method to close tabs to the left.
+        """
+        index = self.contextMenuIndex
+        for i in range(index - 1, -1, -1):
+            editor = self.widget(i).getEditor()
+            self.vm.closeEditorWindow(editor)
+
+    def __contextMenuCloseRight(self):
+        """
+        Private method to close tabs to the right.
+        """
+        index = self.contextMenuIndex
+        for i in range(self.count() - 1, index, -1):
+            editor = self.widget(i).getEditor()
+            self.vm.closeEditorWindow(editor)
+
     def __contextMenuCloseAll(self):
         """
         Private method to close all tabs.
@@ -813,7 +842,8 @@ class TabWidget(EricTabWidget):
         """
         Private method to handle the press of the individual tab close button.
 
-        @param index index of the tab (integer)
+        @param index index of the tab
+        @type int
         """
         if index >= 0:
             self.vm.closeEditorWindow(self.widget(index).getEditor())
@@ -822,7 +852,8 @@ class TabWidget(EricTabWidget):
         """
         Protected method handling double click events.
 
-        @param event reference to the event object (QMouseEvent)
+        @param event reference to the event object
+        @type QMouseEvent
         """
         self.vm.newEditor()
 
@@ -991,8 +1022,9 @@ class Tabview(ViewManager):
 
         # if this was the last editor in this view, switch to the next, that
         # still has open editors
-        for i in list(range(self.tabWidgets.index(tw), -1, -1)) + list(
-            range(self.tabWidgets.index(tw) + 1, len(self.tabWidgets))
+        for i in itertools.chain(
+            range(self.tabWidgets.index(tw), -1, -1),
+            range(self.tabWidgets.index(tw) + 1, len(self.tabWidgets)),
         ):
             if self.tabWidgets[i].hasEditors():
                 self.currentTabWidget.showIndicator(False)
@@ -1052,7 +1084,7 @@ class Tabview(ViewManager):
                 txt = ericApp().getObject("Project").getRelativePath(fn)
             if len(txt) > self.maxFileNameChars:
                 txt = "...{0}".format(txt[-self.maxFileNameChars :])
-            if not os.access(fn, os.W_OK):
+            if editor.checkReadOnly():
                 txt = self.tr("{0} (ro)").format(txt)
             if addNext:
                 index = self.currentTabWidget.currentIndex() + 1
@@ -1107,7 +1139,7 @@ class Tabview(ViewManager):
                 txt = ericApp().getObject("Project").getRelativePath(fn)
             if len(txt) > self.maxFileNameChars:
                 txt = "...{0}".format(txt[-self.maxFileNameChars :])
-            if not os.access(fn, os.W_OK):
+            if editor.checkReadOnly():
                 txt = self.tr("{0} (ro)").format(txt)
             nindex = tabWidget.insertWidget(index, win, txt)
             tabWidget.setTabToolTip(nindex, fn)
@@ -1125,7 +1157,7 @@ class Tabview(ViewManager):
         self._modificationStatusChanged(editor.isModified(), editor)
         self._checkActions(editor)
 
-    def _showView(self, win, fn=None):
+    def _showView(self, win, fn=None):  # noqa: U100
         """
         Protected method to show a view (i.e. window).
 
@@ -1195,21 +1227,21 @@ class Tabview(ViewManager):
             self.currentTabWidget.setTabToolTip(index, newName)
             self.changeCaption.emit(newName)
 
-    def _modificationStatusChanged(self, m, editor):
+    def __setIcon(self, editor, modified):
         """
-        Protected slot to handle the modificationStatusChanged signal.
+        Private method to set the icon for the given editor.
 
-        @param m flag indicating the modification status
-        @type bool
-        @param editor editor window changed
+        @param editor reference to the editor to set the icon for
         @type Editor
+        @param modified flag indicating the modification status
+        @type bool
         """
         for tw in self.tabWidgets:
             if tw.hasEditor(editor):
                 break
         index = tw.indexOf(editor)
         keys = []
-        if m:
+        if modified:
             keys.append("fileModified")
         if editor.hasSyntaxErrors():
             keys.append("syntaxError22")
@@ -1218,6 +1250,17 @@ class Tabview(ViewManager):
         if not keys:
             keys.append("empty")
         tw.setTabIcon(index, EricPixmapCache.getCombinedIcon(keys))
+
+    def _modificationStatusChanged(self, modified, editor):
+        """
+        Protected slot to handle the modificationStatusChanged signal.
+
+        @param modified flag indicating the modification status
+        @type bool
+        @param editor editor that sent the signal
+        @type Editor
+        """
+        self.__setIcon(editor, modified)
         self._checkActions(editor)
 
     def _syntaxErrorToggled(self, editor):
@@ -1227,20 +1270,7 @@ class Tabview(ViewManager):
         @param editor editor that sent the signal
         @type Editor
         """
-        for tw in self.tabWidgets:
-            if tw.hasEditor(editor):
-                break
-        index = tw.indexOf(editor)
-        keys = []
-        if editor.isModified():
-            keys.append("fileModified")
-        if editor.hasSyntaxErrors():
-            keys.append("syntaxError22")
-        elif editor.hasWarnings():
-            keys.append("warning22")
-        if not keys:
-            keys.append("empty")
-        tw.setTabIcon(index, EricPixmapCache.getCombinedIcon(keys))
+        self.__setIcon(editor, editor.isModified())
 
         ViewManager._syntaxErrorToggled(self, editor)
 
@@ -1498,7 +1528,7 @@ class Tabview(ViewManager):
                             txt = ericApp().getObject("Project").getRelativePath(fn)
                         if len(txt) > self.maxFileNameChars:
                             txt = "...{0}".format(txt[-self.maxFileNameChars :])
-                        if not os.access(fn, os.W_OK):
+                        if editor.checkReadOnly():
                             txt = self.tr("{0} (ro)").format(txt)
                         tabWidget.setTabText(index, txt)
 
