@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -31,7 +31,7 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
             "eric_string",
         ),
         (
-            QCoreApplication.translate("FileDialogWizardDialog", "eric (Path)"),
+            QCoreApplication.translate("FileDialogWizardDialog", "eric (pathlib.Path)"),
             "eric_pathlib",
         ),
     )
@@ -165,7 +165,8 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.bTest:
             self.on_bTest_clicked()
@@ -313,11 +314,12 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
         Private slot to enable/disable the initial filter elements and the
         results entries.
 
-        @param checkedId id of the clicked button (integer)
+        @param checkedId id of the clicked button
+        @type int
         """
-        enable = (self.__dialogVariant in (-1, -2) and checkedId in [11, 12, 13]) or (
-            self.__dialogVariant in (5, 6) and checkedId in [1, 2, 3, 21, 22, 23]
-        )
+        enable = (
+            self.__dialogVariant in (-1, -2) and checkedId in [1, 2, 3, 11, 12, 13]
+        ) or (self.__dialogVariant in (5, 6) and checkedId in [1, 2, 3, 21, 22, 23])
 
         self.lInitialFilter.setEnabled(enable)
         self.eInitialFilter.setEnabled(enable)
@@ -332,9 +334,12 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
         """
         Public method to get the source code for Qt6.
 
-        @param indLevel indentation level (int)
-        @param indString string used for indentation (space or tab) (string)
-        @return generated code (string)
+        @param indLevel indentation level
+        @type int
+        @param indString string used for indentation (space or tab)
+        @type str
+        @return generated code
+        @rtype str
         """
         # calculate our indentation level and the indentation string
         il = indLevel + 1
@@ -454,16 +459,15 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 else:
                     fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eFilters.text())
-            if self.rfOpenFile.isChecked() or self.__dialogVariant in (5, 6):
-                if self.eInitialFilter.text() == "":
-                    initialFilter = "None"
+            if self.eInitialFilter.text() == "":
+                initialFilter = "None"
+            else:
+                if self.cInitialFilter.isChecked():
+                    fmt = "{0}"
                 else:
-                    if self.cInitialFilter.isChecked():
-                        fmt = "{0}"
-                    else:
-                        fmt = 'self.tr("{0}")'
-                    initialFilter = fmt.format(self.eInitialFilter.text())
-                code += ",{0}{1}{2}".format(os.linesep, istring, initialFilter)
+                    fmt = 'self.tr("{0}")'
+                initialFilter = fmt.format(self.eInitialFilter.text())
+            code += ",{0}{1}{2}".format(os.linesep, istring, initialFilter)
             if not self.cSymlinks.isChecked():
                 code += ",{0}{1}{2}{3}.DontResolveSymlinks".format(
                     os.linesep, istring, dialogType, optionStr
@@ -530,16 +534,15 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 else:
                     fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eFilters.text())
-            if self.rfOpenFiles.isChecked() or self.__dialogVariant in (5, 6):
-                if self.eInitialFilter.text() == "":
-                    initialFilter = "None"
+            if self.eInitialFilter.text() == "":
+                initialFilter = "None"
+            else:
+                if self.cInitialFilter.isChecked():
+                    fmt = "{0}"
                 else:
-                    if self.cInitialFilter.isChecked():
-                        fmt = "{0}"
-                    else:
-                        fmt = 'self.tr("{0}")'
-                    initialFilter = fmt.format(self.eInitialFilter.text())
-                code += ",{0}{1}{2}".format(os.linesep, istring, initialFilter)
+                    fmt = 'self.tr("{0}")'
+                initialFilter = fmt.format(self.eInitialFilter.text())
+            code += ",{0}{1}{2}".format(os.linesep, istring, initialFilter)
             if not self.cSymlinks.isChecked():
                 code += ",{0}{1}{2}{3}.DontResolveSymlinks".format(
                     os.linesep, istring, dialogType, optionStr
@@ -606,16 +609,15 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 else:
                     fmt = 'self.tr("{0}")'
                 code += fmt.format(self.eFilters.text())
-            if self.rfSaveFile.isChecked() or self.__dialogVariant in (5, 6):
-                if self.eInitialFilter.text() == "":
-                    initialFilter = "None"
+            if self.eInitialFilter.text() == "":
+                initialFilter = "None"
+            else:
+                if self.cInitialFilter.isChecked():
+                    fmt = "{0}"
                 else:
-                    if self.cInitialFilter.isChecked():
-                        fmt = "{0}"
-                    else:
-                        fmt = 'self.tr("{0}")'
-                    initialFilter = fmt.format(self.eInitialFilter.text())
-                code += ",{0}{1}{2}".format(os.linesep, istring, initialFilter)
+                    fmt = 'self.tr("{0}")'
+                initialFilter = fmt.format(self.eInitialFilter.text())
+            code += ",{0}{1}{2}".format(os.linesep, istring, initialFilter)
             if (not self.cSymlinks.isChecked()) or (
                 not self.cConfirmOverwrite.isChecked()
             ):
