@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -53,11 +53,14 @@ class ConfigurationPageItem(QTreeWidgetItem):
         """
         Constructor
 
-        @param parent parent widget of the item (QTreeWidget or
-            QTreeWidgetItem)
-        @param text text to be displayed (string)
-        @param pageName name of the configuration page (string)
-        @param iconFile file name of the icon to be shown (string)
+        @param parent parent widget of the item
+        @type QTreeWidget or QTreeWidgetItem
+        @param text text to be displayed
+        @type str
+        @param pageName name of the configuration page
+        @type str
+        @param iconFile file name of the icon to be shown
+        @type str
         """
         super().__init__(parent, [text])
         self.setIcon(0, EricPixmapCache.getIcon(iconFile))
@@ -68,7 +71,8 @@ class ConfigurationPageItem(QTreeWidgetItem):
         """
         Public method to get the name of the associated configuration page.
 
-        @return name of the configuration page (string)
+        @return name of the configuration page
+        @rtype str
         """
         return self.__pageName
 
@@ -83,6 +87,10 @@ class ConfigurationMode(enum.Enum):
     HEXEDITORMODE = 2
     WEBBROWSERMODE = 3
     EDITORMODE = 4
+    PDFVIEWERMODE = 5
+    PIPMANAGERMODE = 6
+    SHELLMODE = 7
+    MICROPYTHONMODE = 8
 
 
 class ConfigurationWidget(QWidget):
@@ -90,14 +98,14 @@ class ConfigurationWidget(QWidget):
     Class implementing a dialog for the configuration of eric.
 
     @signal preferencesChanged() emitted after settings have been changed
-    @signal masterPasswordChanged(str, str) emitted after the master
+    @signal mainPasswordChanged(str, str) emitted after the main
         password has been changed with the old and the new password
     @signal accepted() emitted to indicate acceptance of the changes
     @signal rejected() emitted to indicate rejection of the changes
     """
 
     preferencesChanged = pyqtSignal()
-    masterPasswordChanged = pyqtSignal(str, str)
+    mainPasswordChanged = pyqtSignal(str, str)
     accepted = pyqtSignal()
     rejected = pyqtSignal()
 
@@ -107,19 +115,23 @@ class ConfigurationWidget(QWidget):
         fromEric=True,
         displayMode=ConfigurationMode.DEFAULTMODE,
         expandedEntries=None,
+        withApply=True,
     ):
         """
         Constructor
 
-        @param parent reference to the parent widget
-        @type QWidget
+        @param parent reference to the parent widget (defaults to None)
+        @type QWidget (optional)
         @param fromEric flag indicating a dialog generation from within the
-            eric IDE
-        @type bool
-        @param displayMode mode of the configuration dialog
-        @type ConfigurationMode
-        @param expandedEntries list of entries to be shown expanded
-        @type list of str
+            eric IDE (defaults to True)
+        @type bool (optional)
+        @param displayMode mode of the configuration dialog (defaults to
+            ConfigurationMode.DEFAULTMODE)
+        @type ConfigurationMode (optional)
+        @param expandedEntries list of entries to be shown expanded (defaults to None)
+        @type list of str (optional)
+        @param withApply flag indicating to show the 'Apply' button (defaults to True)
+        @type bool (optional)
         """
         super().__init__(parent)
 
@@ -128,7 +140,7 @@ class ConfigurationWidget(QWidget):
         self.__webEngine = getWebBrowserSupport() == "QtWebEngine"
         expandedEntries = [] if expandedEntries is None else expandedEntries[:]
 
-        self.__setupUi()
+        self.__setupUi(withApply=withApply)
 
         self.itmDict = {}
 
@@ -153,6 +165,14 @@ class ConfigurationWidget(QWidget):
                 self.virtualenvManager = VirtualenvManager(self)
                 ericApp().registerObject("VirtualEnvManager", self.virtualenvManager)
 
+            from eric7.PipInterface.Pip import Pip  # __IGNORE_WARNING_I101__
+
+            try:
+                self.pip = ericApp().getObject("Pip")
+            except KeyError:
+                self.pip = Pip(self)
+                ericApp().registerObject("Pip", self.pip)
+
         if displayMode == ConfigurationMode.DEFAULTMODE:
             self.configItems = {
                 # key : [display string, pixmap name, dialog module name or
@@ -227,7 +247,7 @@ class ConfigurationWidget(QWidget):
                     None,
                 ],
                 "mimeTypesPage": [
-                    self.tr("Mimetypes"),
+                    self.tr("MIME-Types"),
                     "preferences-mimetypes",
                     "MimeTypesPage",
                     None,
@@ -247,6 +267,13 @@ class ConfigurationWidget(QWidget):
                     None,
                     None,
                 ],
+                "pdfViewerPage": [
+                    self.tr("PDF Viewer"),
+                    "ericPdf",
+                    "PdfViewerPage",
+                    None,
+                    None,
+                ],
                 "pipPage": [
                     self.tr("Python Package Management"),
                     "pypi",
@@ -501,7 +528,13 @@ class ConfigurationWidget(QWidget):
                     "1editorMouseClickHandlers",
                     None,
                 ],
-                "0helpPage": [self.tr("Help"), "preferences-help", None, None, None],
+                "0helpPage": [
+                    self.tr("Help"),
+                    "preferences-help",
+                    None,
+                    None,
+                    None,
+                ],
                 "helpDocumentationPage": [
                     self.tr("Help Documentation"),
                     "preferences-helpdocumentation",
@@ -854,6 +887,221 @@ class ConfigurationWidget(QWidget):
                 ],
             }
 
+        elif displayMode == ConfigurationMode.PDFVIEWERMODE:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "iconsPage": [
+                    self.tr("Icons"),
+                    "preferences-icons",
+                    "IconsPage",
+                    None,
+                    None,
+                ],
+                "interfacePage": [
+                    self.tr("Interface"),
+                    "preferences-interface",
+                    "InterfaceLightPage",
+                    None,
+                    None,
+                ],
+                "pdfViewerPage": [
+                    self.tr("PDF Viewer"),
+                    "ericPdf",
+                    "PdfViewerPage",
+                    None,
+                    None,
+                ],
+            }
+
+        elif displayMode == ConfigurationMode.PIPMANAGERMODE:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "iconsPage": [
+                    self.tr("Icons"),
+                    "preferences-icons",
+                    "IconsPage",
+                    None,
+                    None,
+                ],
+                "interfacePage": [
+                    self.tr("Interface"),
+                    "preferences-interface",
+                    "InterfaceLightPage",
+                    None,
+                    None,
+                ],
+                "networkProxyPage": [
+                    self.tr("Network Proxy"),
+                    "preferences-network",
+                    "NetworkProxyPage",
+                    None,
+                    None,
+                ],
+                "pipPage": [
+                    self.tr("Python Package Management"),
+                    "pypi",
+                    "PipPage",
+                    None,
+                    None,
+                ],
+            }
+
+        elif displayMode == ConfigurationMode.SHELLMODE:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "iconsPage": [
+                    self.tr("Icons"),
+                    "preferences-icons",
+                    "IconsPage",
+                    None,
+                    None,
+                ],
+                "interfacePage": [
+                    self.tr("Interface"),
+                    "preferences-interface",
+                    "InterfaceLightPage",
+                    None,
+                    None,
+                ],
+                "0shellPage": [
+                    self.tr("Shell"),
+                    "preferences-shell",
+                    "ShellPage",
+                    None,
+                    None,
+                ],
+                "editorGeneralPage": [
+                    self.tr("General"),
+                    "preferences-general",
+                    "EditorGeneralPage",
+                    "0shellPage",
+                    None,
+                ],
+                "editorSearchPage": [
+                    self.tr("Searching"),
+                    "preferences-search",
+                    "EditorSearchPage",
+                    "0shellPage",
+                    None,
+                ],
+                "editorStylesPage": [
+                    self.tr("Style"),
+                    "preferences-styles",
+                    "EditorStylesPage",
+                    "0shellPage",
+                    None,
+                ],
+                "1editorAutocompletionPage": [
+                    self.tr("Autocompletion"),
+                    "preferences-autocompletion",
+                    "EditorAutocompletionPage",
+                    "0shellPage",
+                    None,
+                ],
+                "editorAutocompletionQScintillaPage": [
+                    self.tr("QScintilla"),
+                    "qscintilla",
+                    "EditorAutocompletionQScintillaPage",
+                    "1editorAutocompletionPage",
+                    None,
+                ],
+                "1editorCalltipsPage": [
+                    self.tr("Calltips"),
+                    "preferences-calltips",
+                    "EditorCalltipsPage",
+                    "0shellPage",
+                    None,
+                ],
+                "editorCalltipsQScintillaPage": [
+                    self.tr("QScintilla"),
+                    "qscintilla",
+                    "EditorCalltipsQScintillaPage",
+                    "1editorCalltipsPage",
+                    None,
+                ],
+                "1editorLexerPage": [
+                    self.tr("Highlighters"),
+                    "preferences-highlighting-styles",
+                    None,
+                    "0shellPage",
+                    None,
+                ],
+                "editorHighlightingStylesPage": [
+                    self.tr("Styles"),
+                    "preferences-highlighting-styles",
+                    "EditorHighlightingStylesPage",
+                    "1editorLexerPage",
+                    None,
+                ],
+                "editorKeywordsPage": [
+                    self.tr("Keywords"),
+                    "preferences-keywords",
+                    "EditorKeywordsPage",
+                    "1editorLexerPage",
+                    None,
+                ],
+                "editorPropertiesPage": [
+                    self.tr("Properties"),
+                    "preferences-properties",
+                    "EditorPropertiesPage",
+                    "1editorLexerPage",
+                    None,
+                ],
+            }
+
+        elif displayMode == ConfigurationMode.MICROPYTHONMODE:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "iconsPage": [
+                    self.tr("Icons"),
+                    "preferences-icons",
+                    "IconsPage",
+                    None,
+                    None,
+                ],
+                "interfacePage": [
+                    self.tr("Interface"),
+                    "preferences-interface",
+                    self.__createInterfaceLightPageWithSidebars,
+                    None,
+                    None,
+                ],
+                "microPythonPage": [
+                    self.tr("MicroPython"),
+                    "micropython",
+                    "MicroPythonPage",
+                    None,
+                    None,
+                ],
+                "networkProxyPage": [
+                    self.tr("Network Proxy"),
+                    "preferences-network",
+                    "NetworkProxyPage",
+                    None,
+                    None,
+                ],
+            }
+
         else:
             # display mode for generic use
             self.configItems = {
@@ -881,7 +1129,7 @@ class ConfigurationWidget(QWidget):
 
         # generate the list entries
         self.__expandedEntries = []
-        for key in sorted(self.configItems.keys()):
+        for key in sorted(self.configItems):
             pageData = self.configItems[key]
             if pageData[3]:
                 if pageData[3] in self.itmDict:
@@ -915,6 +1163,9 @@ class ConfigurationWidget(QWidget):
             ConfigurationMode.TRAYSTARTERMODE,
             ConfigurationMode.HEXEDITORMODE,
             ConfigurationMode.WEBBROWSERMODE,
+            ConfigurationMode.PDFVIEWERMODE,
+            ConfigurationMode.PIPMANAGERMODE,
+            ConfigurationMode.SHELLMODE,
         ]:
             self.configListSearch.hide()
 
@@ -935,10 +1186,13 @@ class ConfigurationWidget(QWidget):
 
         self.accepted.emit()
 
-    def __setupUi(self):
+    def __setupUi(self, withApply=True):
         """
         Private method to perform the general setup of the configuration
         widget.
+
+        @param withApply flag indicating to show the 'Apply' button (defaults to True)
+        @type bool (optional)
         """
         self.setObjectName("ConfigurationDialog")
         self.resize(900, 750)
@@ -1024,7 +1278,9 @@ class ConfigurationWidget(QWidget):
             | QDialogButtonBox.StandardButton.Reset
         )
         self.buttonBox.setObjectName("buttonBox")
-        if not self.fromEric and self.displayMode == ConfigurationMode.DEFAULTMODE:
+        if (
+            not self.fromEric and self.displayMode == ConfigurationMode.DEFAULTMODE
+        ) or not withApply:
             self.buttonBox.button(QDialogButtonBox.StandardButton.Apply).hide()
         self.buttonBox.button(QDialogButtonBox.StandardButton.Apply).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.StandardButton.Reset).setEnabled(False)
@@ -1053,7 +1309,8 @@ class ConfigurationWidget(QWidget):
         """
         Private slot to handle a change of the search text.
 
-        @param text text to search for (string)
+        @param text text to search for
+        @type str
         """
         self.__searchChildItems(self.configList.invisibleRootItem(), text)
 
@@ -1061,9 +1318,12 @@ class ConfigurationWidget(QWidget):
         """
         Private method to enable child items based on a search string.
 
-        @param parent reference to the parent item (QTreeWidgetItem)
-        @param text text to search for (string)
-        @return flag indicating an enabled child item (boolean)
+        @param parent reference to the parent item
+        @type QTreeWidgetItem
+        @param text text to search for
+        @type str
+        @return flag indicating an enabled child item
+        @rtype bool
         """
         childEnabled = False
         text = text.lower()
@@ -1102,8 +1362,10 @@ class ConfigurationWidget(QWidget):
         """
         Private method to import a configuration page module.
 
-        @param name name of the configuration page module (string)
+        @param name name of the configuration page module
+        @type str
         @return reference to the configuration page module
+        @rtype Module
         """
         try:
             mod = importlib.import_module(
@@ -1121,12 +1383,13 @@ class ConfigurationWidget(QWidget):
             )
             return None
 
-    def __showConfigurationPage(self, itm, column):
+    @pyqtSlot(QTreeWidgetItem)
+    def __showConfigurationPage(self, itm):
         """
         Private slot to show a selected configuration page.
 
-        @param itm reference to the selected item (QTreeWidgetItem)
-        @param column column that was selected (integer) (ignored)
+        @param itm reference to the selected item
+        @type QTreeWidgetItem
         """
         pageName = itm.getPageName()
         self.showConfigurationPageByName(pageName, setCurrent=False)
@@ -1136,10 +1399,15 @@ class ConfigurationWidget(QWidget):
         Private method to initialize a configuration page.
 
         @param pageData data structure for the page to initialize
+        @type list
         @return reference to the initialized page
+        @rtype ConfigurationPageBase
         """
         page = None
-        if isinstance(pageData[2], types.FunctionType):
+        if isinstance(
+            pageData[2],
+            (types.FunctionType, types.LambdaType, types.MethodType),
+        ):
             page = pageData[2](self)
         else:
             mod = self.__importConfigurationPage(pageData[2])
@@ -1156,8 +1424,10 @@ class ConfigurationWidget(QWidget):
         """
         Public slot to show a named configuration page.
 
-        @param pageName name of the configuration page to show (string)
-        @param setCurrent flag indicating to set the current item (boolean)
+        @param pageName name of the configuration page to show
+        @type str
+        @param setCurrent flag indicating to set the current item
+        @type bool
         """
         if pageName == "empty" or pageName not in self.configItems:
             page = self.emptyPage
@@ -1207,6 +1477,20 @@ class ConfigurationWidget(QWidget):
 
         self.__currentConfigurationPageName = pageName
 
+    def __createInterfaceLightPageWithSidebars(self, configDlg):  # noqa: U100
+        """
+        Private method to create the interface configuration page in light mode.
+
+        @param configDlg reference to the configuration dialog
+        @type ConfigurationWidget
+        @return reference to the configuration page
+        @rtype InterfaceLightPage
+        """
+        from .ConfigurationPages import InterfaceLightPage
+
+        page = InterfaceLightPage.create(self, withSidebars=True)
+        return page
+
     def resizeEvent(self, evt):
         """
         Protected method to handle the resizing of the widget.
@@ -1238,7 +1522,8 @@ class ConfigurationWidget(QWidget):
         """
         Public method to get the page name of the current page.
 
-        @return page name of the current page (string)
+        @return page name of the current page
+        @rtype str
         """
         return self.__currentConfigurationPageName
 
@@ -1246,7 +1531,8 @@ class ConfigurationWidget(QWidget):
         """
         Public method to check, if invoked from within eric.
 
-        @return flag indicating invocation from within eric (boolean)
+        @return flag indicating invocation from within eric
+        @rtype bool
         """
         return self.fromEric
 
@@ -1254,9 +1540,11 @@ class ConfigurationWidget(QWidget):
         """
         Public method to get a reference to the named page.
 
-        @param pageName name of the configuration page (string)
+        @param pageName name of the configuration page
+        @type str
         @return reference to the page or None, indicating page was
             not loaded yet
+        @rtype ConfigurationPageBase
         """
         return self.configItems[pageName][-1]
 
@@ -1265,6 +1553,7 @@ class ConfigurationWidget(QWidget):
         Public method to get a reference to the lexers dictionary.
 
         @return reference to the lexers dictionary
+        @rtype dict
         """
         return self.lexers
 
@@ -1286,7 +1575,8 @@ class ConfigurationWidget(QWidget):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.StandardButton.Apply):
             self.on_applyButton_clicked()
@@ -1329,7 +1619,8 @@ class ConfigurationWidget(QWidget):
         """
         Public method to get a list of expanded entries.
 
-        @return list of expanded entries (list of string)
+        @return list of expanded entries
+        @rtype list of str
         """
         return self.__expandedEntries
 
@@ -1338,7 +1629,8 @@ class ConfigurationWidget(QWidget):
         """
         Private slot handling a list entry being collapsed.
 
-        @param item reference to the collapsed item (QTreeWidgetItem)
+        @param item reference to the collapsed item
+        @type QTreeWidgetItem
         """
         pageName = item.data(0, Qt.ItemDataRole.UserRole)
         if pageName in self.__expandedEntries:
@@ -1349,7 +1641,8 @@ class ConfigurationWidget(QWidget):
         """
         Private slot handling a list entry being expanded.
 
-        @param item reference to the expanded item (QTreeWidgetItem)
+        @param item reference to the expanded item
+        @type QTreeWidgetItem
         """
         pageName = item.data(0, Qt.ItemDataRole.UserRole)
         if pageName not in self.__expandedEntries:
@@ -1370,12 +1663,12 @@ class ConfigurationDialog(QDialog):
     Class for the dialog variant.
 
     @signal preferencesChanged() emitted after settings have been changed
-    @signal masterPasswordChanged(str, str) emitted after the master
+    @signal mainPasswordChanged(str, str) emitted after the main
         password has been changed with the old and the new password
     """
 
     preferencesChanged = pyqtSignal()
-    masterPasswordChanged = pyqtSignal(str, str)
+    mainPasswordChanged = pyqtSignal(str, str)
 
     def __init__(
         self,
@@ -1389,19 +1682,20 @@ class ConfigurationDialog(QDialog):
         """
         Constructor
 
-        @param parent reference to the parent widget
-        @type QWidget
-        @param name name of the dialog
-        @type str
-        @param modal flag indicating a modal dialog
-        @type bool
+        @param parent reference to the parent widget (defaults to None)
+        @type QWidget (optional)
+        @param name name of the dialog (defaults to None)
+        @type str (optional)
+        @param modal flag indicating a modal dialog (defaults to False)
+        @type bool (optional)
         @param fromEric flag indicating a dialog generation from within the
-            eric IDE
-        @type bool
-        @param displayMode mode of the configuration dialog
-        @type ConfigurationMode
-        @param expandedEntries list of entries to be shown expanded
-        @type list of str
+            eric IDE (defaults to True)
+        @type bool (optional)
+        @param displayMode mode of the configuration dialog (defaults to
+            ConfigurationMode.DEFAULTMODE)
+        @type ConfigurationMode (optional)
+        @param expandedEntries list of entries to be shown expanded (defaults to None)
+        @type list of str (optional)
         """
         super().__init__(parent)
         if name:
@@ -1418,6 +1712,7 @@ class ConfigurationDialog(QDialog):
             fromEric=fromEric,
             displayMode=displayMode,
             expandedEntries=expandedEntries,
+            withApply=not modal,
         )
         size = self.cw.size()
         self.layout.addWidget(self.cw)
@@ -1427,7 +1722,7 @@ class ConfigurationDialog(QDialog):
         self.cw.accepted.connect(self.accept)
         self.cw.rejected.connect(self.reject)
         self.cw.preferencesChanged.connect(self.__preferencesChanged)
-        self.cw.masterPasswordChanged.connect(self.__masterPasswordChanged)
+        self.cw.mainPasswordChanged.connect(self.__mainPasswordChanged)
 
     def __preferencesChanged(self):
         """
@@ -1435,20 +1730,23 @@ class ConfigurationDialog(QDialog):
         """
         self.preferencesChanged.emit()
 
-    def __masterPasswordChanged(self, oldPassword, newPassword):
+    def __mainPasswordChanged(self, oldPassword, newPassword):
         """
-        Private slot to handle the change of the master password.
+        Private slot to handle the change of the main password.
 
-        @param oldPassword current master password (string)
-        @param newPassword new master password (string)
+        @param oldPassword current password
+        @type str
+        @param newPassword new password
+        @type str
         """
-        self.masterPasswordChanged.emit(oldPassword, newPassword)
+        self.mainPasswordChanged.emit(oldPassword, newPassword)
 
     def showConfigurationPageByName(self, pageName):
         """
         Public slot to show a named configuration page.
 
-        @param pageName name of the configuration page to show (string)
+        @param pageName name of the configuration page to show
+        @type str
         """
         self.cw.showConfigurationPageByName(pageName)
 
@@ -1456,7 +1754,8 @@ class ConfigurationDialog(QDialog):
         """
         Public method to get the page name of the current page.
 
-        @return page name of the current page (string)
+        @return page name of the current page
+        @rtype str
         """
         return self.cw.getConfigurationPageName()
 
@@ -1464,7 +1763,8 @@ class ConfigurationDialog(QDialog):
         """
         Public method to get a list of expanded entries.
 
-        @return list of expanded entries (list of string)
+        @return list of expanded entries
+        @rtype list of str
         """
         return self.cw.getExpandedEntries()
 
@@ -1491,11 +1791,12 @@ class ConfigurationWindow(EricMainWindow):
         """
         Constructor
 
-        @param parent reference to the parent widget (QWidget)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
 
-        self.cw = ConfigurationWidget(self, fromEric=False)
+        self.cw = ConfigurationWidget(self, fromEric=False, withApply=False)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
         self.resize(size)
@@ -1503,6 +1804,9 @@ class ConfigurationWindow(EricMainWindow):
 
         self.setStyle(Preferences.getUI("Style"), Preferences.getUI("StyleSheet"))
 
+        # Setting the style sheet above set the button state of the Apply button
+        # to be visible. So we need to hide it again.
+        self.cw.buttonBox.button(QDialogButtonBox.StandardButton.Apply).hide()
         self.cw.accepted.connect(self.accept)
         self.cw.rejected.connect(self.close)
 
@@ -1510,7 +1814,8 @@ class ConfigurationWindow(EricMainWindow):
         """
         Public slot to show a named configuration page.
 
-        @param pageName name of the configuration page to show (string)
+        @param pageName name of the configuration page to show
+        @type str
         """
         self.cw.showConfigurationPageByName(pageName)
 
