@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,7 @@ Module implementing the Debugger General configuration page.
 from PyQt6.QtCore import QAbstractItemModel, QModelIndex, Qt, pyqtSlot
 from PyQt6.QtGui import QBrush, QColor
 from PyQt6.QtNetwork import QAbstractSocket, QHostAddress, QNetworkInterface
-from PyQt6.QtWidgets import QInputDialog, QLineEdit
+from PyQt6.QtWidgets import QInputDialog, QLineEdit, QListWidgetItem
 
 from eric7 import Preferences, Utilities
 from eric7.EricWidgets import EricMessageBox
@@ -120,6 +120,7 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
         self.remoteDebuggerGroup.setChecked(Preferences.getDebugger("RemoteDbgEnabled"))
         self.hostLineEdit.setText(Preferences.getDebugger("RemoteHost"))
         self.execLineEdit.setText(Preferences.getDebugger("RemoteExecution"))
+        self.remoteDebugClientEdit.setText(Preferences.getDebugger("RemoteDebugClient"))
 
         if self.passiveDbgGroup.isEnabled():
             self.passiveDbgGroup.setChecked(
@@ -203,6 +204,7 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
         )
         Preferences.setDebugger("RemoteHost", self.hostLineEdit.text())
         Preferences.setDebugger("RemoteExecution", self.execLineEdit.text())
+        Preferences.setDebugger("RemoteDebugClient", self.remoteDebugClientEdit.text())
 
         Preferences.setDebugger("PassiveDbgEnabled", self.passiveDbgGroup.isChecked())
         Preferences.setDebugger("PassiveDbgPort", self.passiveDbgPortSpinBox.value())
@@ -284,12 +286,15 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
             index == self.interfaceSelectorComboBox.count() - 1
         )
 
+    @pyqtSlot(QListWidgetItem, QListWidgetItem)
     def on_allowedHostsList_currentItemChanged(self, current, previous):
         """
-        Private method set the state of the edit and delete button.
+        Private method to set the state of the edit and delete button.
 
-        @param current new current item (QListWidgetItem)
-        @param previous previous current item (QListWidgetItem)
+        @param current new current item
+        @type QListWidgetItem
+        @param previous previous current item
+        @type QListWidgetItem
         """
         self.editAllowedHostButton.setEnabled(current is not None)
         self.deleteAllowedHostButton.setEnabled(current is not None)
@@ -411,7 +416,7 @@ class PreviewModel(QAbstractItemModel):
 
         return self.createIndex(row, column, None)
 
-    def parent(self, child):
+    def parent(self, child):  # noqa: U100
         """
         Public Qt slot to get the parent of the given child.
 
@@ -422,7 +427,7 @@ class PreviewModel(QAbstractItemModel):
         """
         return QModelIndex()
 
-    def columnCount(self, parent=QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):  # noqa: U100
         """
         Public Qt slot to get the column count.
 
@@ -433,7 +438,7 @@ class PreviewModel(QAbstractItemModel):
         """
         return 1
 
-    def rowCount(self, parent=QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):  # noqa: U100
         """
         Public Qt slot to get the row count.
 
@@ -444,7 +449,7 @@ class PreviewModel(QAbstractItemModel):
         """
         return 4
 
-    def flags(self, index):
+    def flags(self, index):  # noqa: U100
         """
         Public Qt slot to get the item flags.
 
@@ -477,12 +482,14 @@ class PreviewModel(QAbstractItemModel):
         return None
 
 
-def create(dlg):
+def create(dlg):  # noqa: U100
     """
     Module function to create the configuration page.
 
     @param dlg reference to the configuration dialog
-    @return reference to the instantiated page (ConfigurationPageBase)
+    @type ConfigurationDialog
+    @return reference to the instantiated page
+    @rtype ConfigurationPageBase
     """
     return DebuggerGeneralPage()
 
