@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Highlighting Styles configuration page.
 """
 
+import enum
 import pathlib
 
-from PyQt6.QtCore import QFile, QIODevice, Qt, pyqtSlot
+from PyQt6.QtCore import Qt, pyqtSlot
 from PyQt6.QtGui import QColor, QFont
 from PyQt6.QtWidgets import (
     QColorDialog,
@@ -22,7 +23,6 @@ from PyQt6.QtWidgets import (
 
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets import EricFileDialog, EricMessageBox
-from eric7.EricXML.HighlightingStylesReader import HighlightingStylesReader
 from eric7.Preferences.HighlightingStylesFile import HighlightingStylesFile
 from eric7.QScintilla import Lexers
 
@@ -31,6 +31,17 @@ from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_EditorHighlightingStylesPage import Ui_EditorHighlightingStylesPage
 
 
+class FontChangeMode(enum.Enum):
+    """
+    Class defining the modes for font changes.
+    """
+
+    FAMILYONLY = 0
+    SIZEONLY = 1
+    FAMILYANDSIZE = 2
+    FONT = 99
+
+
 class EditorHighlightingStylesPage(
     ConfigurationPageBase, Ui_EditorHighlightingStylesPage
 ):
@@ -38,11 +49,6 @@ class EditorHighlightingStylesPage(
     Class implementing the Editor Highlighting Styles configuration page.
     """
 
-    FAMILYONLY = 0
-    SIZEONLY = 1
-    FAMILYANDSIZE = 2
-    FONT = 99
-
     StyleRole = Qt.ItemDataRole.UserRole + 1
     SubstyleRole = Qt.ItemDataRole.UserRole + 2
 
@@ -51,6 +57,7 @@ class EditorHighlightingStylesPage(
         Constructor
 
         @param lexers reference to the lexers dictionary
+        @type dict
         """
         super().__init__()
         self.setupUi(self)
@@ -64,27 +71,27 @@ class EditorHighlightingStylesPage(
 
         self.__fontButtonMenu = QMenu()
         act = self.__fontButtonMenu.addAction(self.tr("Font"))
-        act.setData(self.FONT)
+        act.setData(FontChangeMode.FONT)
         self.__fontButtonMenu.addSeparator()
         act = self.__fontButtonMenu.addAction(self.tr("Family and Size only"))
-        act.setData(self.FAMILYANDSIZE)
+        act.setData(FontChangeMode.FAMILYANDSIZE)
         act = self.__fontButtonMenu.addAction(self.tr("Family only"))
-        act.setData(self.FAMILYONLY)
+        act.setData(FontChangeMode.FAMILYONLY)
         act = self.__fontButtonMenu.addAction(self.tr("Size only"))
-        act.setData(self.SIZEONLY)
+        act.setData(FontChangeMode.SIZEONLY)
         self.__fontButtonMenu.triggered.connect(self.__fontButtonMenuTriggered)
         self.fontButton.setMenu(self.__fontButtonMenu)
 
         self.__allFontsButtonMenu = QMenu()
         act = self.__allFontsButtonMenu.addAction(self.tr("Font"))
-        act.setData(self.FONT)
+        act.setData(FontChangeMode.FONT)
         self.__allFontsButtonMenu.addSeparator()
         act = self.__allFontsButtonMenu.addAction(self.tr("Family and Size only"))
-        act.setData(self.FAMILYANDSIZE)
+        act.setData(FontChangeMode.FAMILYANDSIZE)
         act = self.__allFontsButtonMenu.addAction(self.tr("Family only"))
-        act.setData(self.FAMILYONLY)
+        act.setData(FontChangeMode.FAMILYONLY)
         act = self.__allFontsButtonMenu.addAction(self.tr("Size only"))
-        act.setData(self.SIZEONLY)
+        act.setData(FontChangeMode.SIZEONLY)
         self.__allFontsButtonMenu.triggered.connect(self.__allFontsButtonMenuTriggered)
         self.allFontsButton.setMenu(self.__allFontsButtonMenu)
 
@@ -92,20 +99,42 @@ class EditorHighlightingStylesPage(
         self.lexers = lexers
 
         # set initial values
-        languages = sorted([""] + list(self.lexers.keys()))
-        for language in languages:
-            self.lexerLanguageComboBox.addItem(
-                Lexers.getLanguageIcon(language, False), language
-            )
-        self.on_lexerLanguageComboBox_activated(0)
+        languages = sorted([""] + list(self.lexers))
+        self.__populateLanguages(languages)
+
+    def setMode(self, displayMode):
+        """
+        Public method to perform mode dependent setups.
+
+        @param displayMode mode of the configuration dialog
+        @type ConfigurationMode
+        """
+        from ..ConfigurationDialog import ConfigurationMode
+
+        if displayMode in (ConfigurationMode.SHELLMODE,):
+            self.__populateLanguages(["Python3"])
 
     def save(self):
         """
         Public slot to save the Editor Highlighting Styles configuration.
         """
-        for lexer in list(self.lexers.values()):
+        for lexer in self.lexers.values():
             lexer.writeSettings()
 
+    def __populateLanguages(self, languages):
+        """
+        Private method to populate the language selection box.
+
+        @param languages list of languages to include in the language selector
+        @type list of str
+        """
+        self.lexerLanguageComboBox.clear()
+        for language in languages:
+            self.lexerLanguageComboBox.addItem(
+                Lexers.getLanguageIcon(language, False), language
+            )
+        self.on_lexerLanguageComboBox_activated(0)
+
     @pyqtSlot(int)
     def on_lexerLanguageComboBox_activated(self, index):
         """
@@ -313,9 +342,11 @@ class EditorHighlightingStylesPage(
         Private slot to change the highlighter font.
 
         @param doAll flag indicating to change the font for all styles
-            (boolean)
-        @param familyOnly flag indicating to set the font family only (boolean)
-        @param sizeOnly flag indicating to set the font size only (boolean
+        @type bool
+        @param familyOnly flag indicating to set the font family only
+        @type bool
+        @param sizeOnly flag indicating to set the font size only
+        @type bool
         """
 
         def setFont(font, style, substyle, familyOnly, sizeOnly):
@@ -392,26 +423,34 @@ class EditorHighlightingStylesPage(
         """
         Private slot used to select the font of the selected style and lexer.
 
-        @param act reference to the triggering action (QAction)
+        @param act reference to the triggering action
+        @type QAction
         """
         if act is None:
             return
 
-        familyOnly = act.data() in [self.FAMILYANDSIZE, self.FAMILYONLY]
-        sizeOnly = act.data() in [self.FAMILYANDSIZE, self.SIZEONLY]
+        familyOnly = act.data() in (
+            FontChangeMode.FAMILYANDSIZE,
+            FontChangeMode.FAMILYONLY,
+        )
+        sizeOnly = act.data() in (FontChangeMode.FAMILYANDSIZE, FontChangeMode.SIZEONLY)
         self.__changeFont(False, familyOnly, sizeOnly)
 
     def __allFontsButtonMenuTriggered(self, act):
         """
         Private slot used to change the font of all styles of a selected lexer.
 
-        @param act reference to the triggering action (QAction)
+        @param act reference to the triggering action
+        @type QAction
         """
         if act is None:
             return
 
-        familyOnly = act.data() in [self.FAMILYANDSIZE, self.FAMILYONLY]
-        sizeOnly = act.data() in [self.FAMILYANDSIZE, self.SIZEONLY]
+        familyOnly = act.data() in (
+            FontChangeMode.FAMILYANDSIZE,
+            FontChangeMode.FAMILYONLY,
+        )
+        sizeOnly = act.data() in (FontChangeMode.FAMILYANDSIZE, FontChangeMode.SIZEONLY)
         self.__changeFont(True, familyOnly, sizeOnly)
 
     @pyqtSlot(bool)
@@ -420,7 +459,8 @@ class EditorHighlightingStylesPage(
         Private method used to set the eolfill for the selected style and
         lexer.
 
-        @param on flag indicating enabled or disabled state (boolean)
+        @param on flag indicating enabled or disabled state
+        @type bool
         """
         style, substyle = self.__currentStyles()
         checkState = Qt.CheckState.Checked if on else Qt.CheckState.Unchecked
@@ -548,7 +588,7 @@ class EditorHighlightingStylesPage(
 
         stylesDir = getConfig("ericStylesDir")
 
-        lexerNames = list(self.lexers.keys())
+        lexerNames = list(self.lexers)
         if not exportAll:
             if self.lexer:
                 preselect = [self.lexer.language()]
@@ -616,40 +656,16 @@ class EditorHighlightingStylesPage(
             self,
             self.tr("Import Highlighting Styles"),
             stylesDir,
-            self.tr(
-                "Highlighting Styles File (*.ehj);;"
-                "XML Highlighting Styles File (*.e6h *.e4h)"
-            ),
+            self.tr("Highlighting Styles File (*.ehj)"),
         )
 
         if not fn:
             return
 
-        if fn.endswith(".ehj"):
-            # new JSON based file
-            highlightingStylesFile = HighlightingStylesFile()
-            styles = highlightingStylesFile.readFile(fn)
-            if not styles:
-                return
-        else:
-            # old XML based file
-            f = QFile(fn)
-            if f.open(QIODevice.OpenModeFlag.ReadOnly):
-                reader = HighlightingStylesReader(f, self.lexers)
-                styles = reader.readXML()
-                f.close()
-                if not styles:
-                    return
-            else:
-                EricMessageBox.critical(
-                    self,
-                    self.tr("Import Highlighting Styles"),
-                    self.tr(
-                        "<p>The highlighting styles file <b>{0}</b> could not"
-                        " be read.</p><p>Reason: {1}</p>"
-                    ).format(fn, f.errorString()),
-                )
-                return
+        highlightingStylesFile = HighlightingStylesFile()
+        styles = highlightingStylesFile.readFile(fn)
+        if not styles:
+            return
 
         self.__applyStyles(styles, importAll=importAll)
         self.on_lexerLanguageComboBox_activated(
@@ -708,7 +724,7 @@ class EditorHighlightingStylesPage(
         @return list containing the index of the selected lexer language
             and a tuple containing the index of the parent selected lexer
             entry and the index of the selected entry
-        @rtype list of int and tuple of (int, int)
+        @rtype list of [int, tuple of (int, int)]
         """
         itm = self.styleElementList.currentItem()
         if itm:
@@ -734,6 +750,7 @@ class EditorHighlightingStylesPage(
         Public method to set the state of the widget.
 
         @param state state data generated by saveState
+        @type list of [int, tuple of (int, int)]
         """
         if state:
             self.lexerLanguageComboBox.setCurrentIndex(state[0])
@@ -877,7 +894,9 @@ def create(dlg):
     Module function to create the configuration page.
 
     @param dlg reference to the configuration dialog
-    @return reference to the instantiated page (ConfigurationPageBase)
+    @type ConfigurationDialog
+    @return reference to the instantiated page
+    @rtype ConfigurationPageBase
     """
     page = EditorHighlightingStylesPage(dlg.getLexers())
     return page
