@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -42,12 +42,14 @@ class EditorMouseClickHandlerPage(
         )
 
 
-def create(dlg):
+def create(dlg):  # noqa: U100
     """
     Module function to create the configuration page.
 
     @param dlg reference to the configuration dialog
-    @return reference to the instantiated page (ConfigurationPageBase)
+    @type ConfigurationDialog
+    @return reference to the instantiated page
+    @rtype ConfigurationPageBase
     """
     page = EditorMouseClickHandlerPage()
     return page
