@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,12 +25,13 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Constructor
 
         @param lexers reference to the lexers dictionary
+        @type dict
         """
         super().__init__()
         self.setupUi(self)
         self.setObjectName("EditorPropertiesPage")
 
-        self.languages = sorted(list(lexers.keys())[:])
+        self.languages = sorted(lexers)
 
         # set initial values
         # All
@@ -289,6 +290,37 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             Preferences.getEditor("YAMLFoldComment")
         )
 
+    def setMode(self, displayMode):
+        """
+        Public method to perform mode dependent setups.
+
+        @param displayMode mode of the configuration dialog
+        @type ConfigurationMode
+        """
+        from ..ConfigurationDialog import ConfigurationMode
+
+        if displayMode in (ConfigurationMode.SHELLMODE,):
+            self.bashGroup.hide()
+            self.cppGroup.hide()
+            self.cmakeGroup.hide()
+            self.coffeeScriptGroup.hide()
+            self.cssGroup.hide()
+            self.dGroup.hide()
+            self.gettextGroup.hide()
+            self.htmlGroup.hide()
+            self.jsonGroup.hide()
+            self.pascalGroup.hide()
+            self.perlGroup.hide()
+            self.postscriptGroup.hide()
+            self.povrayGroup.hide()
+            self.propertiesGroup.hide()
+            self.rubyGroup.hide()
+            self.sqlGroup.hide()
+            self.tclGroup.hide()
+            self.texGroup.hide()
+            self.vhdlGroup.hide()
+            self.yamlGroup.hide()
+
     def save(self):
         """
         Public slot to save the Editor Properties (1) configuration.
@@ -560,7 +592,9 @@ def create(dlg):
     Module function to create the configuration page.
 
     @param dlg reference to the configuration dialog
-    @return reference to the instantiated page (ConfigurationPageBase)
+    @type ConfigurationDialog
+    @return reference to the instantiated page
+    @rtype ConfigurationPageBase
     """
     page = EditorPropertiesPage(dlg.getLexers())
     return page
