@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -43,7 +43,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         """
         Constructor
 
-        @param parent The parent widget of this dialog. (QWidget)
+        @param parent The parent widget of this dialog.
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -79,7 +80,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.searchButton:
             self.on_programsSearchButton_clicked()
@@ -98,9 +100,9 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             # 1. do the Qt programs
             # 1a. Translation Converter
             exe = (
-                OSUtilities.isWindowsPlatform()
-                and "{0}.exe".format(QtUtilities.generateQtToolName("lrelease"))
-                or QtUtilities.generateQtToolName("lrelease")
+                "{0}.exe".format(QtUtilities.generateQtToolName("lrelease"))
+                if OSUtilities.isWindowsPlatform()
+                else QtUtilities.generateQtToolName("lrelease")
             )
             exe = os.path.join(QtUtilities.getQtBinariesPath(), exe)
             version = self.__createProgramEntry(
@@ -286,7 +288,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                     version = enchant.__version__
                 except AttributeError:
                     version = self.tr("(unknown)")
-            except (ImportError, AttributeError, OSError):
+            except (AttributeError, ImportError, OSError):
                 text = "enchant"
                 version = ""
             self.__createEntry(self.tr("Spell Checker - PyEnchant"), text, version)
@@ -303,7 +305,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                     version = pygments.__version__
                 except AttributeError:
                     version = self.tr("(unknown)")
-            except (ImportError, AttributeError, OSError):
+            except (AttributeError, ImportError, OSError):
                 text = "pygments"
                 version = ""
             self.__createEntry(self.tr("Source Highlighter - Pygments"), text, version)
@@ -337,6 +339,26 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 "dfu-util",
                 -1,
             )
+            exe = Preferences.getMicroPython("StInfoPath")
+            if not exe:
+                exe = "st-info"
+            self.__createProgramEntry(
+                self.tr("MicroPython - STLink Info"),
+                exe,
+                "--version",
+                "",
+                -1,
+            )
+            exe = Preferences.getMicroPython("StFlashPath")
+            if not exe:
+                exe = "st-flash"
+            self.__createProgramEntry(
+                self.tr("MicroPython - STLink Flasher"),
+                exe,
+                "--version",
+                "",
+                -1,
+            )
 
             # 9. do the jedi related entries
             try:
@@ -350,7 +372,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                     version = jedi.__version__
                 except AttributeError:
                     version = self.tr("(unknown)")
-            except (ImportError, AttributeError, OSError):
+            except (AttributeError, ImportError, OSError):
                 text = "jedi"
                 version = ""
             self.__createEntry(self.tr("Code Assistant - Jedi"), text, version)
@@ -397,23 +419,30 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         """
         Private method to generate a program entry.
 
-        @param description descriptive text (string)
-        @param exe name of the executable program (string)
-        @param versionCommand command line switch to get the version info
-            (str). If this is empty, the given version will be shown.
+        @param description descriptive text
+        @type str
+        @param exe name of the executable program
+        @type str
+        @param versionCommand command line switch to get the version info.
+            If this is empty, the given version will be shown.
+        @type str
         @param versionStartsWith start of line identifying version info
-            (string)
+        @type str
         @param versionPosition index of part containing the version info
-            (integer)
-        @param version version string to show (string)
+        @type int
+        @param version version string to show
+        @type str
         @param versionCleanup tuple of two integers giving string positions
-            start and stop for the version string (tuple of integers)
+            start and stop for the version string
+        @type tuple of (int, int)
         @param versionRe regexp to determine the line identifying version
-            info (string). Takes precedence over versionStartsWith.
+            info. Takes precedence over versionStartsWith.
+        @type str
         @param exeModule list of command line parameters to execute a module
             with the program given in exe (e.g. to execute a Python module)
-            (list of str)
-        @return version string of detected or given version (string)
+        @type list of str
+        @return version string of detected or given version
+        @rtype str
         """
         itmList = self.programsList.findItems(
             description, Qt.MatchFlag.MatchCaseSensitive
@@ -522,9 +551,12 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         """
         Private method to generate a program entry.
 
-        @param description descriptive text (string)
-        @param entryText text to show (string)
-        @param entryVersion version string to show (string).
+        @param description descriptive text
+        @type str
+        @param entryText text to show
+        @type str
+        @param entryVersion version string to show
+        @type str
         """
         itm = QTreeWidgetItem(self.programsList, [description])
         font = itm.font(0)
