@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,8 +21,10 @@ class AddLanguageDialog(QDialog, Ui_AddLanguageDialog):
         """
         Constructor
 
-        @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string)
+        @param parent parent widget of this dialog
+        @type QWidget
+        @param name name of this dialog
+        @type str
         """
         super().__init__(parent)
         if name:
@@ -36,6 +38,7 @@ class AddLanguageDialog(QDialog, Ui_AddLanguageDialog):
         """
         Public method to retrieve the selected language.
 
-        @return the selected language (string)
+        @return the selected language
+        @rtype str
         """
         return self.languageCombo.currentText()
