@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -35,10 +35,9 @@ from .Ui_CreateDialogCodeDialog import Ui_CreateDialogCodeDialog
 
 pyqtSignatureRole = Qt.ItemDataRole.UserRole + 1
 pythonSignatureRole = Qt.ItemDataRole.UserRole + 2
-rubySignatureRole = Qt.ItemDataRole.UserRole + 3
-returnTypeRole = Qt.ItemDataRole.UserRole + 4
-parameterTypesListRole = Qt.ItemDataRole.UserRole + 5
-parameterNamesListRole = Qt.ItemDataRole.UserRole + 6
+returnTypeRole = Qt.ItemDataRole.UserRole + 3
+parameterTypesListRole = Qt.ItemDataRole.UserRole + 4
+parameterNamesListRole = Qt.ItemDataRole.UserRole + 5
 
 
 class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
@@ -61,15 +60,17 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         "QToolBox",
         "QStackedWidget",
     }
-    Separator = 25 * "="
 
     def __init__(self, formName, project, parent=None):
         """
         Constructor
 
-        @param formName name of the file containing the form (string)
+        @param formName name of the file containing the form
+        @type str
         @param project reference to the project object
-        @param parent parent widget if the dialog (QWidget)
+        @type Project
+        @param parent parent widget if the dialog
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -123,16 +124,18 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
 
             classesList = []
             vagueClassesList = []
-            for cls in list(self.__module.classes.values()):
-                if not set(cls.super).isdisjoint(CreateDialogCodeDialog.DialogClasses):
-                    classesList.append(cls.name)
+            for klass in self.__module.classes.values():
+                if not set(klass.super).isdisjoint(
+                    CreateDialogCodeDialog.DialogClasses
+                ):
+                    classesList.append(klass.name)
                 else:
-                    vagueClassesList.append(cls.name)
+                    vagueClassesList.append(klass.name)
             classesList.sort()
             self.classNameCombo.addItems(classesList)
             if vagueClassesList:
                 if classesList:
-                    self.classNameCombo.addItem(CreateDialogCodeDialog.Separator)
+                    self.classNameCombo.insertSeparator(self.classNameCombo.count())
                 self.classNameCombo.addItems(sorted(vagueClassesList))
 
         if (
@@ -158,7 +161,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         """
         Public method to determine, if there was an initialzation error.
 
-        @return flag indicating an initialzation error (boolean)
+        @return flag indicating an initialzation error
+        @rtype bool
         """
         return self.__initError
 
@@ -218,11 +222,20 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         if started and finished:
             output = proc.readAllStandardError()
             outText = str(output, "utf-8", "replace")
-            if "@@eric_start@@" in outText and "@@eric_end@@" in outText:
+            if "@@eric_start@@" in outText:
                 # it is something we sent via UicLoadUi[56].py
-                outText = outText.split("@@eric_start@@")[1].split("@@eric_end@@")[0]
-            if proc.exitCode() == 0:
+                outText = outText.split("@@eric_start@@")[1]
                 ok = True
+            elif "@@eric_error@@" in outText:
+                # it is something we sent via UicLoadUi[56].py
+                outText = outText.split("@@eric_error@@")[1]
+                ok = False
+            else:
+                ok = False
+            if "@@eric_end@@" in outText:
+                # it is something we sent via UicLoadUi[56].py
+                outText = outText.split("@@eric_end@@")[0]
+            if ok:
                 uicText = outText.strip()
             else:
                 EricMessageBox.critical(
@@ -280,7 +293,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         """
         Private slot to get the signatures.
 
-        @return list of signatures (list of strings)
+        @return list of signatures
+        @rtype list of str
         """
         if self.__module is None:
             return []
@@ -289,7 +303,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         clsName = self.classNameCombo.currentText()
         if clsName:
             cls = self.__module.classes[clsName]
-            for meth in list(cls.methods.values()):
+            for meth in cls.methods.values():
                 if meth.name.startswith("on_"):
                     if meth.pyqtSignature is not None:
                         sig = ", ".join(
@@ -308,8 +322,10 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         Private method to map a type as reported by Qt's meta object to the
         correct Python type.
 
-        @param type_ type as reported by Qt (QByteArray)
-        @return mapped Python type (string)
+        @param type_ type as reported by Qt
+        @type QByteArray
+        @return mapped Python type
+        @rtype str
         """
         mapped = bytes(type_).decode()
 
@@ -394,20 +410,6 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                 )
 
     def __generateCode(self):
-        """
-        Private slot to generate the code as requested by the user.
-        """
-        if (
-            self.filenameEdit.text().endswith(".rb")
-            or self.project.getProjectLanguage() == "Ruby"
-        ):
-            # Ruby code generation is not supported
-            pass
-        else:
-            # assume Python (our global default)
-            self.__generatePythonCode()
-
-    def __generatePythonCode(self):
         """
         Private slot to generate Python code as requested by the user.
         """
@@ -618,22 +620,18 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         """
         Private slot to handle the activated signal of the classname combo.
 
-        @param index index of the activated item (integer)
+        @param index index of the activated item
+        @type int
         """
-        if self.classNameCombo.currentText() == CreateDialogCodeDialog.Separator:
-            self.okButton.setEnabled(False)
-            self.filterEdit.clear()
-            self.slotsModel.clear()
-            self.slotsModel.setHorizontalHeaderLabels([""])
-        else:
-            self.okButton.setEnabled(True)
-            self.__updateSlotsModel()
+        self.okButton.setEnabled(True)
+        self.__updateSlotsModel()
 
     def on_filterEdit_textChanged(self, text):
         """
         Private slot called, when thext of the filter edit has changed.
 
-        @param text changed text (string)
+        @param text changed text
+        @type str
         """
         rx = QRegularExpression(
             text, QRegularExpression.PatternOption.CaseInsensitiveOption
@@ -665,7 +663,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         Private slot to handle the buttonBox clicked signal.
 
         @param button reference to the button that was clicked
-            (QAbstractButton)
+        @type QAbstractButton
         """
         if button == self.okButton:
             self.__generateCode()
