@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -24,8 +24,14 @@ from PyQt6.QtWidgets import QAbstractItemView, QApplication, QDialog, QMenu, QTr
 from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
+from eric7.SystemUtilities import FileSystemUtilities
 from eric7.UI.Browser import Browser
-from eric7.UI.BrowserModel import BrowserDirectoryItem, BrowserFileItem
+from eric7.UI.BrowserModel import (
+    BrowserClassItem,
+    BrowserDirectoryItem,
+    BrowserFileItem,
+    BrowserMethodItem,
+)
 from eric7.UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
 from .ProjectBrowserModel import (
@@ -91,6 +97,9 @@ class ProjectBaseBrowser(Browser):
         self._model.rowsInserted.connect(self.__modelRowsInserted)
         self._connectExpandedCollapsed()
 
+        self._initHookMethods()  # perform initialization of the hooks
+        self.hooksMenuEntries = {}
+
         self._createPopupMenus()
 
         self.currentItemName = None
@@ -101,9 +110,6 @@ class ProjectBaseBrowser(Browser):
         self._keyboardSearchTimer = QElapsedTimer()
         self._keyboardSearchTimer.invalidate()
 
-        self._initHookMethods()  # perform initialization of the hooks
-        self.hooksMenuEntries = {}
-
     def _connectExpandedCollapsed(self):
         """
         Protected method to connect the expanded and collapsed signals.
@@ -160,7 +166,8 @@ class ProjectBaseBrowser(Browser):
         """
         Protected slot to show the context menu.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         if not self.project.isOpen():
             return
@@ -180,7 +187,8 @@ class ProjectBaseBrowser(Browser):
         """
         Protected method to select a single item.
 
-        @param index index of item to be selected (QModelIndex)
+        @param index index of item to be selected
+        @type QModelIndex
         """
         if index.isValid():
             self.setCurrentIndex(index)
@@ -194,8 +202,10 @@ class ProjectBaseBrowser(Browser):
         """
         Protected method to set the selection status of an item.
 
-        @param index index of item to set (QModelIndex)
-        @param selected flag giving the new selection status (boolean)
+        @param index index of item to set
+        @type QModelIndex
+        @param selected flag giving the new selection status
+        @type bool
         """
         if index.isValid():
             self.selectionModel().select(
@@ -206,24 +216,30 @@ class ProjectBaseBrowser(Browser):
         """
         Protected method to set the selection status of a range of items.
 
-        @param startIndex start index of range of items to set (QModelIndex)
-        @param endIndex end index of range of items to set (QModelIndex)
-        @param selected flag giving the new selection status (boolean)
+        @param startIndex start index of range of items to set
+        @type QModelIndex
+        @param endIndex end index of range of items to set
+        @type QModelIndex
+        @param selected flag giving the new selection status
+        @type bool
         """
         selection = QItemSelection(startIndex, endIndex)
         self.selectionModel().select(
             selection, selected and self.SelectFlags or self.DeselectFlags
         )
 
-    def __modelRowsInserted(self, parent, start, end):
+    def __modelRowsInserted(self, parent, start, end):  # noqa: U100
         """
         Private slot called after rows have been inserted into the model.
 
-        @param parent parent index of inserted rows (QModelIndex)
-        @param start start row number (integer)
-        @param end end row number (integer)
+        @param parent parent index of inserted rows
+        @type QModelIndex
+        @param start start row number
+        @type int
+        @param end end row number
+        @type int
         """
-        self._resizeColumns(parent)
+        self._resizeColumns()
 
     def _projectClosed(self):
         """
@@ -351,7 +367,8 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to highlight a node given its filename.
 
-        @param fn filename of file to be highlighted (string)
+        @param fn filename of file to be highlighted
+        @type str
         """
         newfn = os.path.abspath(fn)
         newfn = self.project.getRelativePath(newfn)
@@ -366,8 +383,10 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to highlight a node given its filename.
 
-        @param fn filename of file to be highlighted (string)
-        @param lineno one based line number of the item (integer)
+        @param fn filename of file to be highlighted
+        @type str
+        @param lineno one based line number of the item
+        @type int
         """
         newfn = os.path.abspath(fn)
         newfn = self.project.getRelativePath(newfn)
@@ -378,6 +397,31 @@ class ProjectBaseBrowser(Browser):
                 self._selectSingleItem(index)
                 self.scrollTo(index)
 
+    def _showProjectInFileManager(self):
+        """
+        Protected slot to show the path of the project in a file manager application.
+        """
+        if not self.project.isOpen():
+            EricMessageBox.warning(
+                self,
+                self.tr("Show in File Manager"),
+                self.tr("""A project must be opened first."""),
+            )
+            return
+
+        directory = self.project.getProjectPath()
+        ok = FileSystemUtilities.startfile(directory)
+
+        if not ok:
+            EricMessageBox.warning(
+                self,
+                self.tr("Show in File Manager"),
+                self.tr(
+                    "<p>The directory of the current project (<b>{0}</b>) cannot be"
+                    " shown in a file manager application.</p>"
+                ).format(directory),
+            )
+
     def _expandAllDirs(self):
         """
         Protected slot to handle the 'Expand all directories' menu action.
@@ -452,7 +496,8 @@ class ProjectBaseBrowser(Browser):
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the file status.
 
-        @param menu reference to the menu to be shown (QMenu)
+        @param menu reference to the menu to be shown
+        @type QMenu
         """
         if self.project.vcs is None:
             for act in self.menuActions:
@@ -468,7 +513,8 @@ class ProjectBaseBrowser(Browser):
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the files status.
 
-        @param menu reference to the menu to be shown (QMenu)
+        @param menu reference to the menu to be shown
+        @type QMenu
         """
         if self.project.vcs is None:
             for act in self.multiMenuActions:
@@ -483,7 +529,8 @@ class ProjectBaseBrowser(Browser):
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
 
-        @param menu reference to the menu to be shown (QMenu)
+        @param menu reference to the menu to be shown
+        @type QMenu
         """
         if self.project.vcs is None:
             for act in self.dirMenuActions:
@@ -498,7 +545,8 @@ class ProjectBaseBrowser(Browser):
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
 
-        @param menu reference to the menu to be shown (QMenu)
+        @param menu reference to the menu to be shown
+        @type QMenu
         """
         if self.project.vcs is None:
             for act in self.dirMultiMenuActions:
@@ -506,11 +554,12 @@ class ProjectBaseBrowser(Browser):
         else:
             self.vcsHelper.showContextMenuDirMulti(menu, self.dirMultiMenuActions)
 
-    def _showContextMenuBack(self, menu):
+    def _showContextMenuBack(self, menu):  # noqa: U100
         """
         Protected slot called before the context menu is shown.
 
-        @param menu reference to the menu to be shown (QMenu)
+        @param menu reference to the menu to be shown
+        @type QMenu
         """
         # nothing to do for now
         return
@@ -520,8 +569,10 @@ class ProjectBaseBrowser(Browser):
         Protected method to select entries based on their VCS status.
 
         @param local flag indicating local (i.e. non VCS controlled)
-            file/directory entries should be selected (boolean)
+            file/directory entries should be selected
+        @type boolean)
         @param filterList list of classes to check against
+        @type Class
         """
         if self.project.vcs is None:
             return
@@ -605,7 +656,8 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to get the file/directory names of all expanded items.
 
-        @return list of expanded items names (list of string)
+        @return list of expanded items names
+        @rtype list of str
         """
         expandedNames = []
 
@@ -623,7 +675,8 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to expand items given their names.
 
-        @param names list of item names to be expanded (list of string)
+        @param names list of item names to be expanded
+        @type list of str
         """
         model = self.model()
         for name in names:
@@ -640,7 +693,8 @@ class ProjectBaseBrowser(Browser):
         """
         Protected slot to handle the prepareRepopulateItem signal.
 
-        @param name relative name of file item to be repopulated (string)
+        @param name relative name of file item to be repopulated
+        @type str
         """
         itm = self.currentItem()
         if itm is not None:
@@ -666,7 +720,8 @@ class ProjectBaseBrowser(Browser):
         """
         Protected slot to handle the completeRepopulateItem signal.
 
-        @param name relative name of file item to be repopulated (string)
+        @param name relative name of file item to be repopulated
+        @type str
         """
         sindex = self._model.itemIndexByName(name)
         if sindex.isValid():
@@ -702,10 +757,37 @@ class ProjectBaseBrowser(Browser):
         Public method to get a reference to the current item.
 
         @return reference to the current item
+        @rtype BrowserItem
         """
         itm = self.model().item(self.currentIndex())
         return itm
 
+    def currentDirectory(self, relative=False):
+        """
+        Public method to determine the directory of the currently selected entry.
+
+        @param relative flag indicating to return the directory as a relative path
+        @type bool
+        @return directory of the current entry
+        @rtype str
+        """
+        itm = self.model().item(self.currentIndex())
+        if isinstance(
+            itm, (ProjectBrowserFileItem, BrowserClassItem, BrowserMethodItem)
+        ):
+            dn = os.path.dirname(itm.fileName())
+        elif isinstance(
+            itm, (ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem)
+        ):
+            dn = itm.dirName()
+        else:
+            dn = ""
+
+        if relative:
+            dn = self.project.getRelativePath(dn)
+
+        return dn
+
     def _keyboardSearchType(self, item):
         """
         Protected method to check, if the item is of the correct type.
@@ -744,7 +826,8 @@ class ProjectBaseBrowser(Browser):
         """
         Private method to check a hook key.
 
-        @param key key of the hook to check (string)
+        @param key key of the hook to check
+        @type str
         @exception KeyError raised to indicate an invalid hook
         """
         if len(self.hooks) == 0:
@@ -757,8 +840,10 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to add a hook method to the dictionary.
 
-        @param key for the hook method (string)
-        @param method reference to the hook method (method object)
+        @param key for the hook method
+        @type str
+        @param method reference to the hook method
+        @type function
         """
         self.__checkHookKey(key)
         self.hooks[key] = method
@@ -767,9 +852,12 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to add a hook method to the dictionary.
 
-        @param key for the hook method (string)
-        @param method reference to the hook method (method object)
-        @param menuEntry entry to be shown in the context menu (string)
+        @param key for the hook method
+        @type str
+        @param method reference to the hook method
+        @type function
+        @param menuEntry entry to be shown in the context menu
+        @type str
         """
         self.addHookMethod(key, method)
         self.hooksMenuEntries[key] = menuEntry
@@ -778,7 +866,8 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to remove a hook method from the dictionary.
 
-        @param key for the hook method (string)
+        @param key for the hook method
+        @type str
         """
         self.__checkHookKey(key)
         self.hooks[key] = None
