@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -50,6 +50,7 @@ class ProjectBrowser(EricTabWidget):
     @signal designerFile(filename) emitted to open a Qt-Designer file (str)
     @signal linguistFile(filename) emitted to open a Qt-Linguist (*.ts)
         file (str)
+    @signal pdfFile(filename) emitted to open a PDF file (str)
     @signal pixmapEditFile(filename) emitted to edit a pixmap file (str)
     @signal pixmapFile(filename) emitted to open a pixmap file (str)
     @signal preferencesChanged() emitted when the preferences have been changed
@@ -80,6 +81,7 @@ class ProjectBrowser(EricTabWidget):
     closeSourceWindow = pyqtSignal(str)
     designerFile = pyqtSignal(str)
     linguistFile = pyqtSignal(str)
+    pdfFile = pyqtSignal(str)
     pixmapEditFile = pyqtSignal(str)
     pixmapFile = pyqtSignal(str)
     preferencesChanged = pyqtSignal()
@@ -96,7 +98,9 @@ class ProjectBrowser(EricTabWidget):
         Constructor
 
         @param project reference to the project object
-        @param parent parent widget (QWidget)
+        @type Project
+        @param parent parent widget
+        @type QWidget
         """
         EricTabWidget.__init__(self, parent)
         self.project = project
@@ -246,7 +250,7 @@ class ProjectBrowser(EricTabWidget):
         @return list of project browser types
         @rtype list of str
         """
-        return list(self.__browserRepository.keys())
+        return list(self.__browserRepository)
 
     def getProjectBrowserUserStrings(self):
         """
@@ -334,7 +338,8 @@ class ProjectBrowser(EricTabWidget):
         """
         Private slot to handle the currentChanged(int) signal.
 
-        @param index index of the tab (integer)
+        @param index index of the tab
+        @type int
         """
         if index > -1:
             browser = self.widget(index)
@@ -376,7 +381,7 @@ class ProjectBrowser(EricTabWidget):
         browsersList = (
             Preferences.getProjectBrowsers(self.project.getProjectType())
             if self.project.isOpen()
-            else list(self.__browserRepository.keys())
+            else list(self.__browserRepository)
         )
         browsersList = [b for b in browsersList if b in self.__browserRepository]
 
@@ -420,8 +425,10 @@ class ProjectBrowser(EricTabWidget):
         """
         Public slot to handle the editorLineChanged signal.
 
-        @param fn filename of the changed file (string)
-        @param lineno one based line number of the item (integer)
+        @param fn filename of the changed file
+        @type str
+        @param lineno one based line number of the item
+        @type int
         """
         if (
             Preferences.getProject("FollowEditor")
@@ -461,11 +468,12 @@ class ProjectBrowser(EricTabWidget):
         else:
             self.vcsStatusIndicator.setToolTip(self.vcsStatusText[state])
 
-    def __vcsStatusIndicatorClicked(self, pos):
+    def __vcsStatusIndicatorClicked(self, pos):  # noqa: U100
         """
         Private slot to react upon clicks on the VCS indicator LED.
 
-        @param pos position of the click (QPoint)
+        @param pos position of the click
+        @type QPoint
         """
         vcs = self.project.getVcs()
         if vcs:
