@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,19 +15,17 @@ from PyQt6.QtCore import QDir, QFileSystemWatcher, QModelIndex, Qt, pyqtSignal
 from PyQt6.QtGui import QColor
 
 from eric7 import Preferences
-from eric7.EricGui import EricPixmapCache
 from eric7.SystemUtilities import FileSystemUtilities
 from eric7.UI.BrowserModel import (
     BrowserDirectoryItem,
     BrowserFileItem,
     BrowserItem,
+    BrowserItemType,
     BrowserModel,
+    BrowserSimpleDirectoryItem,
 )
 from eric7.Utilities import ModuleParser
-
-ProjectBrowserItemSimpleDirectory = 100
-ProjectBrowserItemDirectory = 101
-ProjectBrowserItemFile = 102
+from eric7.VCS.VersionControl import VersionControlState
 
 
 class ProjectBrowserItemMixin:
@@ -42,7 +40,9 @@ class ProjectBrowserItemMixin:
         Constructor
 
         @param type_ type of file/directory in the project
+        @type str
         @param bold flag indicating a highlighted font
+        @type bool
         """
         self._projectTypes = [type_]
         self.bold = bold
@@ -52,7 +52,8 @@ class ProjectBrowserItemMixin:
         """
         Public method to get the items text color.
 
-        @return text color (QColor)
+        @return text color
+        @rtype QColor
         """
         if self.bold:
             return Preferences.getProjectBrowserColour("Highlighted")
@@ -63,7 +64,8 @@ class ProjectBrowserItemMixin:
         """
         Public method to set the items VCS state.
 
-        @param state VCS state (one of A, C, M, U or " ") (string)
+        @param state VCS state (one of A, C, M, U or " ")
+        @type str
         """
         self.vcsState = state
 
@@ -71,7 +73,8 @@ class ProjectBrowserItemMixin:
         """
         Public method to add the VCS status.
 
-        @param vcsStatus VCS status text (string)
+        @param vcsStatus VCS status text
+        @type str
         """
         self.itemData.append(vcsStatus)
 
@@ -79,7 +82,8 @@ class ProjectBrowserItemMixin:
         """
         Public method to set the VCS status.
 
-        @param vcsStatus VCS status text (string)
+        @param vcsStatus VCS status text
+        @type str
         """
         self.itemData[1] = vcsStatus
 
@@ -88,6 +92,7 @@ class ProjectBrowserItemMixin:
         Public method to get the project type.
 
         @return project type
+        @rtype str
         """
         return self._projectTypes[:]
 
@@ -96,11 +101,14 @@ class ProjectBrowserItemMixin:
         Public method to add a type to the list.
 
         @param type_ type to add to the list
+        @type str
         """
         self._projectTypes.append(type_)
 
 
-class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
+class ProjectBrowserSimpleDirectoryItem(
+    BrowserSimpleDirectoryItem, ProjectBrowserItemMixin
+):
     """
     Class implementing the data structure for project browser simple directory
     items.
@@ -111,65 +119,18 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
         Constructor
 
         @param parent parent item
+        @type BrowserItem
         @param projectType type of file/directory in the project
-        @param text text to be displayed (string)
-        @param path path of the directory (string)
+        @type str
+        @param text text to be displayed
+        @type str
+        @param path path of the directory
+        @type str
         """
-        BrowserItem.__init__(self, parent, text)
+        BrowserSimpleDirectoryItem.__init__(self, parent, text, path=path)
         ProjectBrowserItemMixin.__init__(self, projectType)
 
-        self._dirName = path
-        if not os.path.isdir(self._dirName):
-            self._dirName = os.path.dirname(self._dirName)
-
-        self.type_ = ProjectBrowserItemSimpleDirectory
-        if os.path.lexists(self._dirName) and os.path.islink(self._dirName):
-            self.symlink = True
-            self.icon = EricPixmapCache.getSymlinkIcon("dirClosed")
-        else:
-            self.icon = EricPixmapCache.getIcon("dirClosed")
-
-    def setName(self, dinfo, full=True):
-        """
-        Public method to set the directory name.
-
-        @param dinfo dinfo is the string for the directory (string)
-        @param full flag indicating full pathname should be displayed (boolean)
-        """
-        self._dirName = os.path.abspath(dinfo)
-        self.itemData[0] = os.path.basename(self._dirName)
-
-    def dirName(self):
-        """
-        Public method returning the directory name.
-
-        @return directory name (string)
-        """
-        return self._dirName
-
-    def name(self):
-        """
-        Public method to return the name of the item.
-
-        @return name of the item (string)
-        """
-        return self._dirName
-
-    def lessThan(self, other, column, order):
-        """
-        Public method to check, if the item is less than the other one.
-
-        @param other reference to item to compare against (BrowserItem)
-        @param column column number to use for the comparison (integer)
-        @param order sort order (Qt.SortOrder) (for special sorting)
-        @return true, if this item is less than other (boolean)
-        """
-        if issubclass(other.__class__, BrowserFileItem) and Preferences.getUI(
-            "BrowsersListFoldersFirst"
-        ):
-            return order == Qt.SortOrder.AscendingOrder
-
-        return BrowserItem.lessThan(self, other, column, order)
+        self.type_ = BrowserItemType.PbSimpleDirectory
 
 
 class ProjectBrowserDirectoryItem(BrowserDirectoryItem, ProjectBrowserItemMixin):
@@ -182,15 +143,20 @@ class ProjectBrowserDirectoryItem(BrowserDirectoryItem, ProjectBrowserItemMixin)
         Constructor
 
         @param parent parent item
-        @param dinfo dinfo is the string for the directory (string)
+        @type BrowserItem
+        @param dinfo dinfo is the string for the directory
+        @type str
         @param projectType type of file/directory in the project
-        @param full flag indicating full pathname should be displayed (boolean)
-        @param bold flag indicating a highlighted font (boolean)
+        @type str
+        @param full flag indicating full pathname should be displayed
+        @type bool
+        @param bold flag indicating a highlighted font
+        @type bool
         """
         BrowserDirectoryItem.__init__(self, parent, dinfo, full)
         ProjectBrowserItemMixin.__init__(self, projectType, bold)
 
-        self.type_ = ProjectBrowserItemDirectory
+        self.type_ = BrowserItemType.PbDirectory
 
 
 class ProjectBrowserFileItem(BrowserFileItem, ProjectBrowserItemMixin):
@@ -205,16 +171,22 @@ class ProjectBrowserFileItem(BrowserFileItem, ProjectBrowserItemMixin):
         Constructor
 
         @param parent parent item
-        @param finfo the string for the file (string)
+        @type BrowserItem
+        @param finfo the string for the file
+        @type str
         @param projectType type of file/directory in the project
-        @param full flag indicating full pathname should be displayed (boolean)
-        @param bold flag indicating a highlighted font (boolean)
-        @param sourceLanguage source code language of the project (string)
+        @type str
+        @param full flag indicating full pathname should be displayed
+        @type bool
+        @param bold flag indicating a highlighted font
+        @type bool
+        @param sourceLanguage source code language of the project
+        @type str
         """
         BrowserFileItem.__init__(self, parent, finfo, full, sourceLanguage)
         ProjectBrowserItemMixin.__init__(self, projectType, bold)
 
-        self.type_ = ProjectBrowserItemFile
+        self.type_ = BrowserItemType.PbFile
 
 
 class ProjectBrowserModel(BrowserModel):
@@ -230,7 +202,8 @@ class ProjectBrowserModel(BrowserModel):
         """
         Constructor
 
-        @param parent reference to parent object (Project.Project)
+        @param parent reference to parent object
+        @type Project.Project
         """
         super().__init__(parent, nopopulate=True)
 
@@ -285,9 +258,12 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to get data of an item.
 
-        @param index index of the data to retrieve (QModelIndex)
-        @param role role of data (Qt.ItemDataRole)
+        @param index index of the data to retrieve
+        @type QModelIndex
+        @param role role of data
+        @type Qt.ItemDataRole
         @return requested data
+        @rtype Any
         """
         if not index.isValid():
             return None
@@ -317,13 +293,15 @@ class ProjectBrowserModel(BrowserModel):
         Public method to populate an item's subtree.
 
         @param parentItem reference to the item to be populated
-        @param repopulate flag indicating a repopulation (boolean)
+        @type BrowserItem
+        @param repopulate flag indicating a repopulation
+        @type bool
         """
-        if parentItem.type() == ProjectBrowserItemSimpleDirectory:
+        if parentItem.type() == BrowserItemType.PbSimpleDirectory:
             return  # nothing to do
-        elif parentItem.type() == ProjectBrowserItemDirectory:
+        elif parentItem.type() == BrowserItemType.PbDirectory:
             self.populateProjectDirectoryItem(parentItem, repopulate)
-        elif parentItem.type() == ProjectBrowserItemFile:
+        elif parentItem.type() == BrowserItemType.PbFile:
             self.populateFileItem(parentItem, repopulate)
         else:
             BrowserModel.populateItem(self, parentItem, repopulate)
@@ -333,7 +311,9 @@ class ProjectBrowserModel(BrowserModel):
         Public method to populate a directory item's subtree.
 
         @param parentItem reference to the directory item to be populated
-        @param repopulate flag indicating a repopulation (boolean)
+        @type BrowserItem
+        @param repopulate flag indicating a repopulation
+        @type bool
         """
         self._addWatchedItem(parentItem)
 
@@ -381,7 +361,7 @@ class ProjectBrowserModel(BrowserModel):
                     fname = f.absoluteFilePath()
                     if (
                         states[os.path.normcase(fname)]
-                        == self.project.vcs.canBeCommitted
+                        == VersionControlState.Controlled
                     ):
                         node.addVcsStatus(self.project.vcs.vcsName())
                         self.project.clearStatusMonitorCachedState(f.absoluteFilePath())
@@ -464,7 +444,7 @@ class ProjectBrowserModel(BrowserModel):
                 if self.project.vcs is not None:
                     if (
                         states[os.path.normcase(fname)]
-                        == self.project.vcs.canBeCommitted
+                        == VersionControlState.Controlled
                     ):
                         itm.addVcsStatus(self.project.vcs.vcsName())
                     else:
@@ -483,9 +463,13 @@ class ProjectBrowserModel(BrowserModel):
         don't exist.
 
         @param type_ type of the item
-        @param name name of the item (string)
-        @param dontSplit flag indicating the name should not be split (boolean)
-        @return reference to the item found and the new display name (string)
+        @type str
+        @param name name of the item
+        @type str
+        @param dontSplit flag indicating the name should not be split
+        @type bool
+        @return reference to the item found and the new display name
+        @rtype str
         """
         if dontSplit:
             pathlist = []
@@ -523,10 +507,14 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to find a child item given some text.
 
-        @param text text to search for (string)
-        @param column column to search in (integer)
+        @param text text to search for
+        @type str
+        @param column column to search in
+        @type int
         @param parentItem reference to parent item
+        @type BrowserItem
         @return reference to the item found
+        @rtype BrowserItem
         """
         if parentItem is None:
             parentItem = self.rootItem
@@ -541,9 +529,12 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to add a new item to the model.
 
-        @param typeString string denoting the type of the new item (string)
-        @param name name of the new item (string)
-        @param additionalTypeStrings names of additional types (list of string)
+        @param typeString string denoting the type of the new item
+        @type str
+        @param name name of the new item
+        @type str
+        @param additionalTypeStrings names of additional types
+        @type list of str
         """
         # Show the entry in bold in the others browser to make it more
         # distinguishable
@@ -592,8 +583,10 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to rename an item.
 
-        @param name the old display name (string)
-        @param newFilename new filename of the item (string)
+        @param name the old display name
+        @type str
+        @param newFilename new filename of the item
+        @type str
         """
         itm = self.findItem(name)
         if itm is None:
@@ -608,8 +601,10 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to find an item given its name.
 
-        @param name name of the item (string)
+        @param name name of the item
+        @type str
         @return reference to the item found
+        @rtype BrowserItem
         """
         if QDir.isAbsolutePath(name):
             name = self.project.getRelativePath(name)
@@ -629,8 +624,10 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to find an item's index given its name.
 
-        @param name name of the item (string)
-        @return index of the item found (QModelIndex)
+        @param name name of the item
+        @type str
+        @return index of the item found
+        @rtype QModelIndex
         """
         itm = self.findItem(name)
         index = self.createIndex(itm.row(), 0, itm) if itm else QModelIndex()
@@ -640,9 +637,12 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to find an item's index given its name.
 
-        @param name name of the item (string)
-        @param lineno one based line number of the item (integer)
-        @return index of the item found (QModelIndex)
+        @param name name of the item
+        @type str
+        @param lineno one based line number of the item
+        @type int
+        @return index of the item found
+        @rtype QModelIndex
         """
         index = QModelIndex()
         itm = self.findItem(name)
@@ -687,7 +687,8 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public slot to handle the directoryChanged signal of the watcher.
 
-        @param path path of the directory (string)
+        @param path path of the directory
+        @type str
         """
         if not self.__watcherActive:
             return
@@ -714,7 +715,7 @@ class ProjectBrowserModel(BrowserModel):
             for f in entryInfoList:
                 fpath = FileSystemUtilities.toNativeSeparators(f.absoluteFilePath())
                 childFound = False
-                for child in children:
+                for child in children[:]:
                     if child.name() == fpath:
                         childFound = True
                         children.remove(child)
@@ -742,7 +743,7 @@ class ProjectBrowserModel(BrowserModel):
                 if self.project.vcs is not None:
                     self.project.vcs.clearStatusCache()
                     state = self.project.vcs.vcsRegisteredState(node.name())
-                    if state == self.project.vcs.canBeCommitted:
+                    if state == VersionControlState.Controlled:
                         node.addVcsStatus(self.project.vcs.vcsName())
                     else:
                         node.addVcsStatus(self.tr("local"))
@@ -754,7 +755,7 @@ class ProjectBrowserModel(BrowserModel):
                     child = itm.child(row)
                     childname = FileSystemUtilities.fromNativeSeparators(child.name())
                     entryFound = False
-                    for f in entryInfoList:
+                    for f in entryInfoList[:]:
                         if f.absoluteFilePath() == childname:
                             entryFound = True
                             entryInfoList.remove(f)
@@ -772,12 +773,15 @@ class ProjectBrowserModel(BrowserModel):
         Private method used to set the vcs status of a node.
 
         @param item item to work on
-        @param name filename belonging to this item (string)
+        @type BrowserItem
+        @param name filename belonging to this item
+        @type str
         """
-        if self.project.vcs is not None:
-            state = self.project.vcs.vcsRegisteredState(name)
-            if state == self.project.vcs.canBeCommitted:
-                item.addVcsStatus(self.project.vcs.vcsName())
+        vcs = self.project.vcs
+        if vcs is not None:
+            state = vcs.vcsRegisteredState(name)
+            if state == VersionControlState.Controlled:
+                item.addVcsStatus(vcs.vcsName())
             else:
                 item.addVcsStatus(self.tr("local"))
         else:
@@ -788,14 +792,18 @@ class ProjectBrowserModel(BrowserModel):
         Private method used to update the vcs status of a node.
 
         @param item item to work on
-        @param name filename belonging to this item (string)
-        @param recursive flag indicating a recursive update (boolean)
+        @type BrowserItem
+        @param name filename belonging to this item
+        @type str
+        @param recursive flag indicating a recursive update
+        @type bool
         """
-        if self.project.vcs is not None:
-            self.project.vcs.clearStatusCache()
-            state = self.project.vcs.vcsRegisteredState(name)
-            if state == self.project.vcs.canBeCommitted:
-                item.setVcsStatus(self.project.vcs.vcsName())
+        vcs = self.project.vcs
+        if vcs is not None:
+            vcs.clearStatusCache()
+            state = vcs.vcsRegisteredState(name)
+            if state == VersionControlState.Controlled:
+                item.setVcsStatus(vcs.vcsName())
             else:
                 item.setVcsStatus(self.tr("local"))
             if recursive:
@@ -813,8 +821,10 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method used to update the vcs status of a node.
 
-        @param name filename belonging to this item (string)
-        @param recursive flag indicating a recursive update (boolean)
+        @param name filename belonging to this item
+        @type str
+        @param recursive flag indicating a recursive update
+        @type bool
         """
         item = self.findItem(name)
         if item:
@@ -824,7 +834,8 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to remove a named item.
 
-        @param name file or directory name of the item (string).
+        @param name file or directory name of the item
+        @type str
         """
         fname = os.path.basename(name)
         parentItem = self.findParentItemByName(0, name)[0]
@@ -843,7 +854,8 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to repopulate an item.
 
-        @param name name of the file relative to the project root (string)
+        @param name name of the file relative to the project root
+        @type str
         """
         itm = self.findItem(name)
         if itm is None:
@@ -874,10 +886,9 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public slot to record the (non normal) VCS states.
 
-        @param statesList list of VCS state entries (list of strings) giving
-            the states in the first column and the path relative to the project
-            directory starting with the third column. The allowed status flags
-            are:
+        @param statesList list of VCS state entries giving the states in the
+            first column and the path relative to the project directory starting
+            with the third column. The allowed status flags are:
             <ul>
                 <li>"A" path was added but not yet comitted</li>
                 <li>"M" path has local changes</li>
@@ -887,13 +898,14 @@ class ProjectBrowserModel(BrowserModel):
                 <li>"Z" path contains a conflict</li>
                 <li>" " path is back at normal</li>
             </ul>
+        @type list of str
         """
         statesList.sort()
         lastHead = ""
         itemCache = {}
         if len(statesList) == 1 and statesList[0] == "--RESET--":
             statesList = []
-            for name in list(self.__vcsStatus.keys()):
+            for name in self.__vcsStatus:
                 statesList.append(" {0}".format(name))
 
         for name in statesList:
@@ -917,7 +929,7 @@ class ProjectBrowserModel(BrowserModel):
                     itm.setVcsStatus(self.project.vcs.vcsName())
                     index1 = self.createIndex(itm.row(), 0, itm)
                     index2 = self.createIndex(
-                        itm.row(), self.rootItem.columnCount(), itm
+                        itm.row(), self.rootItem.columnCount() - 1, itm
                     )
                     self.dataChanged.emit(index1, index2)
 
@@ -938,9 +950,11 @@ class ProjectBrowserModel(BrowserModel):
         """
         Private method to recursively change the parents VCS state.
 
-        @param path pathname of parent item (string)
+        @param path pathname of parent item
+        @type str
         @param itemCache reference to the item cache used to store
             references to named items
+        @type dict
         """
         while path:
             try:
@@ -958,7 +972,7 @@ class ProjectBrowserModel(BrowserModel):
                     itm.setVcsState(state)
                     index1 = self.createIndex(itm.row(), 0, itm)
                     index2 = self.createIndex(
-                        itm.row(), self.rootItem.columnCount(), itm
+                        itm.row(), self.rootItem.columnCount() - 1, itm
                     )
                     self.dataChanged.emit(index1, index2)
             path, tail = os.path.split(path)
@@ -967,7 +981,7 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method used to handle a change in preferences.
         """
-        for code in list(self.colorNames.keys()):
+        for code in self.colorNames:
             color = Preferences.getProjectBrowserColour(self.colorNames[code])
             if color.name() == self.itemBackgroundColors[code].name():
                 continue
