@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,7 +29,6 @@ from eric7.UI.NotificationWidget import NotificationTypes
 from .FileCategoryRepositoryItem import FileCategoryRepositoryItem
 from .ProjectBaseBrowser import ProjectBaseBrowser
 from .ProjectBrowserModel import (
-    ProjectBrowserDirectoryItem,
     ProjectBrowserFileItem,
     ProjectBrowserSimpleDirectoryItem,
 )
@@ -213,7 +212,9 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 self.tr("Configure uic Compiler"), self.__configureUicCompiler
             )
             self.menu.addSeparator()
-            self.menu.addAction(self.tr("Open in Qt-Designer"), self.__openFile)
+            self.menu.addAction(
+                self.tr("Open in Qt-Designer"), self.__openFile
+            ).setEnabled(QtUtilities.hasQtDesigner())
             self.menu.addAction(self.tr("Open in Editor"), self.__openFileInEditor)
             self.menu.addSeparator()
             self.menu.addAction(self.tr("Preview form"), self.__UIPreview)
@@ -268,6 +269,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         self.menu.addAction(self.tr("Add forms..."), self.__addFormFiles)
         self.menu.addAction(self.tr("Add forms directory..."), self.__addFormsDirectory)
         self.menu.addSeparator()
+        self.menu.addAction(self.tr("Show in File Manager"), self._showInFileManager)
         self.menu.addAction(self.tr("Copy Path to Clipboard"), self._copyToClipboard)
         self.menu.addSeparator()
         self.menu.addAction(self.tr("Expand all directories"), self._expandAllDirs)
@@ -303,6 +305,10 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             lambda: self.project.addDirectory("FORMS"),
         )
         self.backMenu.addSeparator()
+        self.backMenu.addAction(
+            self.tr("Show in File Manager"), self._showProjectInFileManager
+        )
+        self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Expand all directories"), self._expandAllDirs)
         self.backMenu.addAction(
             self.tr("Collapse all directories"), self._collapseAllDirs
@@ -322,7 +328,9 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 self.tr("Configure uic Compiler"), self.__configureUicCompiler
             )
             self.multiMenu.addSeparator()
-            self.multiMenu.addAction(self.tr("Open in Qt-Designer"), self.__openFile)
+            self.multiMenu.addAction(
+                self.tr("Open in Qt-Designer"), self.__openFile
+            ).setEnabled(QtUtilities.hasQtDesigner())
             self.multiMenu.addAction(self.tr("Open in Editor"), self.__openFileInEditor)
             self.multiMenu.addSeparator()
             self.multiMenu.addAction(self.tr("Preview translations"), self.__TRPreview)
@@ -388,6 +396,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.tr("Add forms directory..."), self.__addFormsDirectory
         )
         self.dirMenu.addSeparator()
+        self.dirMenu.addAction(self.tr("Show in File Manager"), self._showInFileManager)
         self.dirMenu.addAction(self.tr("Copy Path to Clipboard"), self._copyToClipboard)
         self.dirMenu.addSeparator()
         self.dirMenu.addAction(self.tr("Expand all directories"), self._expandAllDirs)
@@ -444,7 +453,8 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         """
         Protected slot to show the context menu.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         if not self.project.isOpen():
             return
@@ -532,31 +542,13 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         """
         Private method to add form files to the project.
         """
-        itm = self.model().item(self.currentIndex())
-        if isinstance(itm, ProjectBrowserFileItem):
-            dn = os.path.dirname(itm.fileName())
-        elif isinstance(
-            itm, (ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem)
-        ):
-            dn = itm.dirName()
-        else:
-            dn = None
-        self.project.addFiles("form", dn)
+        self.project.addFiles("FORMS", self.currentDirectory())
 
     def __addFormsDirectory(self):
         """
         Private method to add form files of a directory to the project.
         """
-        itm = self.model().item(self.currentIndex())
-        if isinstance(itm, ProjectBrowserFileItem):
-            dn = os.path.dirname(itm.fileName())
-        elif isinstance(
-            itm, (ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem)
-        ):
-            dn = itm.dirName()
-        else:
-            dn = None
-        self.project.addDirectory("form", dn)
+        self.project.addDirectory("FORMS", self.currentDirectory())
 
     def __openFile(self):
         """
@@ -649,7 +641,8 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         Private slot to handle the New Form menu action for Qt-related
         projects.
 
-        @param path full directory path for the new form file (string)
+        @param path full directory path for the new form file
+        @type str
         """
         selectedForm, ok = QInputDialog.getItem(
             None,
@@ -818,8 +811,10 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         """
         Private slot to handle the finished signal of the pyuic/rbuic process.
 
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.compileRunning = False
         ericApp().getObject("ViewManager").enableEditorsCheckFocusIn(True)
@@ -872,9 +867,13 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         Private method to compile a .ui file to a .py/.rb file.
 
         @param fn filename of the .ui file to be compiled
+        @type str
         @param noDialog flag indicating silent operations
+        @type bool
         @param progress reference to the progress dialog
-        @return reference to the compile process (QProcess)
+        @type QProgressDialog
+        @return reference to the compile process
+        @rtype QProcess
         """
         self.compileProc = QProcess()
         args = []
@@ -930,9 +929,6 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                             self.project.getProjectData(dataKey="UICPARAMS")["RcSuffix"]
                         )
                     )
-        elif self.project.getProjectLanguage() == "Ruby":
-            self.compiledFile = ofn + ".rb"
-            args.append("-x")
 
         args.append(fn)
         self.compileProc.finished.connect(self.__compileUIDone)
@@ -976,6 +972,9 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
 
             # change environment
             sys.path.insert(0, self.project.getProjectPath())
+            srcDir = self.project.getProjectData("SOURCESDIR")
+            if srcDir:
+                sys.path.insert(1, os.path.join(self.project.getAbsolutePath(srcDir)))
             cwd = os.getcwd()
             os.chdir(os.path.dirname(os.path.abspath(fn)))
             try:
@@ -985,6 +984,8 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             finally:
                 # reset the environment
                 os.chdir(cwd)
+                if srcDir:
+                    del sys.path[1]
                 del sys.path[0]
 
     def __compileForm(self):
@@ -1116,8 +1117,6 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                     if self.project.getProjectLanguage() == "Python3":
                         dirname, filename = os.path.split(os.path.splitext(ifn)[0])
                         ofn = os.path.join(dirname, "Ui_" + filename + ".py")
-                    elif self.project.getProjectLanguage() == "Ruby":
-                        ofn = os.path.splitext(ifn)[0] + ".rb"
                     if (
                         not os.path.exists(ofn)
                         or os.stat(ifn).st_mtime > os.stat(ofn).st_mtime
