@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,8 @@ don't fit the other categories.
 """
 
 import contextlib
-import os
 
-from PyQt6.QtCore import QModelIndex, QUrl, pyqtSignal
+from PyQt6.QtCore import QUrl, pyqtSignal
 from PyQt6.QtGui import QDesktopServices
 from PyQt6.QtWidgets import QDialog, QMenu
 
@@ -114,6 +113,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         self.svgFile.connect(projectBrowser.svgFile)
         self.umlFile.connect(projectBrowser.umlFile)
         self.binaryFile.connect(projectBrowser.binaryFile)
+        self.pdfFile.connect(projectBrowser.pdfFile)
 
     def getIcon(self):
         """
@@ -137,6 +137,9 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         self.openInEditorAct = self.menu.addAction(
             self.tr("Open in Editor"), self._openFileInEditor
         )
+        self.openInPdfViewerAct = self.menu.addAction(
+            self.tr("Open in PDF Viewer"), self._openPdfViewer
+        )
         self.menu.addSeparator()
         self.mimeTypeAct = self.menu.addAction(
             self.tr("Show Mime-Type"), self.__showMimeType
@@ -156,6 +159,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         self.menu.addSeparator()
         self.menu.addAction(self.tr("Refresh"), self.__refreshItem)
         self.menu.addSeparator()
+        self.menu.addAction(self.tr("Show in File Manager"), self._showInFileManager)
         self.menu.addAction(self.tr("Copy Path to Clipboard"), self._copyToClipboard)
         self.menu.addSeparator()
         self.menu.addAction(self.tr("Expand all directories"), self._expandAllDirs)
@@ -176,6 +180,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         self.dirMenu.addAction(self.tr("Add files..."), self.__addOthersFiles)
         self.dirMenu.addAction(self.tr("Add directory..."), self.__addOthersDirectory)
         self.dirMenu.addSeparator()
+        self.dirMenu.addAction(self.tr("Show in File Manager"), self._showInFileManager)
         self.dirMenu.addAction(self.tr("Copy Path to Clipboard"), self._copyToClipboard)
         self.dirMenu.addSeparator()
         self.dirMenu.addAction(self.tr("Expand all directories"), self._expandAllDirs)
@@ -193,6 +198,10 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
             self.tr("Add directory..."), lambda: self.project.addDirectory("OTHERS")
         )
         self.backMenu.addSeparator()
+        self.backMenu.addAction(
+            self.tr("Show in File Manager"), self._showProjectInFileManager
+        )
+        self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Expand all directories"), self._expandAllDirs)
         self.backMenu.addAction(
             self.tr("Collapse all directories"), self._collapseAllDirs
@@ -226,7 +235,8 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         Protected slot to show the context menu.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         if not self.project.isOpen():
             return
@@ -260,6 +270,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
                     if isinstance(itm, ProjectBrowserFileItem):
                         self.editPixmapAct.setVisible(itm.isPixmapFile())
                         self.openInEditorAct.setVisible(itm.isSvgFile())
+                        self.openInPdfViewerAct.setVisible(itm.isPdfFile())
                         self.mimeTypeAct.setVisible(True)
                         self.menu.popup(self.mapToGlobal(coord))
                     elif isinstance(itm, ProjectBrowserDirectoryItem):
@@ -314,7 +325,8 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         It enables/disables the VCS menu entries depending on the overall
         VCS status and the file status.
 
-        @param menu Reference to the popup menu (QPopupMenu)
+        @param menu Reference to the popup menu
+        @type QPopupMenu
         """
         if self.project.vcs is None:
             for act in self.menuActions:
@@ -347,6 +359,16 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
             if isinstance(itm, ProjectBrowserFileItem):
                 self.binaryFile.emit(itm.fileName())
 
+    def _openPdfViewer(self):
+        """
+        Protected slot to handle the open in PDF viewer popup menu entry.
+        """
+        itmList = self.getSelectedItems()
+
+        for itm in itmList:
+            if isinstance(itm, ProjectBrowserFileItem) and itm.isPdfFile():
+                self.pdfFile.emit(itm.fileName())
+
     def _openItem(self):
         """
         Protected slot to handle the open popup menu entry.
@@ -355,7 +377,9 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
 
         for itm in itmList:
             if isinstance(itm, ProjectBrowserFileItem):
-                if itm.isSvgFile():
+                if itm.isPdfFile():
+                    self.pdfFile.emit(itm.fileName())
+                elif itm.isSvgFile():
                     self.svgFile.emit(itm.fileName())
                 elif itm.isPixmapFile():
                     self.pixmapFile.emit(itm.fileName())
@@ -428,31 +452,13 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         Private method to add files to the project.
         """
-        itm = self.model().item(self.currentIndex())
-        if isinstance(itm, ProjectBrowserFileItem):
-            dn = os.path.dirname(itm.fileName())
-        elif isinstance(
-            itm, (ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem)
-        ):
-            dn = itm.dirName()
-        else:
-            dn = None
-        self.project.addFiles("others", dn)
+        self.project.addFiles("OTHERS", self.currentDirectory())
 
     def __addOthersDirectory(self):
         """
         Private method to add files of a directory to the project.
         """
-        itm = self.model().item(self.currentIndex())
-        if isinstance(ProjectBrowserFileItem):
-            dn = os.path.dirname(itm.fileName())
-        elif isinstance(
-            itm, (ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem)
-        ):
-            dn = itm.dirName()
-        else:
-            dn = None
-        self.project.addDirectory("others", dn)
+        self.project.addDirectory("OTHERS", self.currentDirectory())
 
     def __removeItem(self):
         """
@@ -532,4 +538,4 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         else:
             name = ""
 
-        self._resizeColumns(QModelIndex())
+        self._resizeColumns()
