@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -30,7 +30,6 @@ from eric7.UI.NotificationWidget import NotificationTypes
 from .FileCategoryRepositoryItem import FileCategoryRepositoryItem
 from .ProjectBaseBrowser import ProjectBaseBrowser
 from .ProjectBrowserModel import (
-    ProjectBrowserDirectoryItem,
     ProjectBrowserFileItem,
     ProjectBrowserSimpleDirectoryItem,
 )
@@ -199,8 +198,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             )
             self.tsprocMenuActions.append(act)
             self.menu.addSeparator()
-            act = self.menu.addAction(self.tr("Open in Qt-Linguist"), self._openItem)
-            self.tsMenuActions.append(act)
+            self.__qtLinguistAct = self.menu.addAction(
+                self.tr("Open in Qt-Linguist"), self._openItem
+            )
+            self.tsMenuActions.append(self.__qtLinguistAct)
             act = self.menu.addAction(
                 self.tr("Open in Editor"), self.__openFileInEditor
             )
@@ -305,12 +306,13 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.menuActions.append(act)
         self.menu.addSeparator()
         self.__addTranslationAct = self.menu.addAction(
-            self.tr("Add translation..."), self.project.addLanguage
+            self.tr("New translation..."), self.project.addLanguage
         )
         self.menu.addAction(
             self.tr("Add translation files..."), self.__addTranslationFiles
         )
         self.menu.addSeparator()
+        self.menu.addAction(self.tr("Show in File Manager"), self._showInFileManager)
         self.menu.addAction(self.tr("Copy Path to Clipboard"), self._copyToClipboard)
         self.menu.addSeparator()
         self.menu.addAction(self.tr("Configure..."), self._configure)
@@ -380,12 +382,16 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 self.qmprocBackMenuActions.append(act)
         self.backMenu.addSeparator()
         self.__addTranslationBackAct = self.backMenu.addAction(
-            self.tr("Add translation..."), self.project.addLanguage
+            self.tr("New translation..."), self.project.addLanguage
         )
         self.backMenu.addAction(
             self.tr("Add translation files..."), self.__addTranslationFiles
         )
         self.backMenu.addSeparator()
+        self.backMenu.addAction(
+            self.tr("Show in File Manager"), self._showProjectInFileManager
+        )
+        self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Configure..."), self._configure)
         self.backMenu.setEnabled(False)
 
@@ -414,10 +420,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             self.tsMultiMenuActions.append(act)
             self.tsprocMultiMenuActions.append(act)
             self.multiMenu.addSeparator()
-            act = self.multiMenu.addAction(
+            self.__qtLinguistMultiAct = self.multiMenu.addAction(
                 self.tr("Open in Qt-Linguist"), self._openItem
             )
-            self.tsMultiMenuActions.append(act)
+            self.tsMultiMenuActions.append(self.__qtLinguistMultiAct)
             act = self.multiMenu.addAction(
                 self.tr("Open in Editor"), self.__openFileInEditor
             )
@@ -561,12 +567,13 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         self.dirMenuActions.append(act)
         self.dirMenu.addSeparator()
         self.__addTranslationDirAct = self.dirMenu.addAction(
-            self.tr("Add translation..."), self.project.addLanguage
+            self.tr("New translation..."), self.project.addLanguage
         )
         self.dirMenu.addAction(
             self.tr("Add translation files..."), self.__addTranslationFiles
         )
         self.dirMenu.addSeparator()
+        self.dirMenu.addAction(self.tr("Show in File Manager"), self._showInFileManager)
         self.dirMenu.addAction(self.tr("Copy Path to Clipboard"), self._copyToClipboard)
         self.dirMenu.addSeparator()
         self.dirMenu.addAction(self.tr("Configure..."), self._configure)
@@ -583,7 +590,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         Protected slot to show the context menu.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         if not self.project.isOpen():
             return
@@ -647,6 +655,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             elif tsFiles > 0:
                 for act in self.tsMenuActions:
                     act.setEnabled(True)
+                self.__qtLinguistAct.setEnabled(QtUtilities.hasQtLinguist())
+                self.__qtLinguistMultiAct.setEnabled(QtUtilities.hasQtLinguist())
                 for act in self.qmMenuActions:
                     act.setEnabled(False)
             elif qmFiles > 0:
@@ -773,16 +783,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         Private method to add translation files to the project.
         """
-        itm = self.model().item(self.currentIndex())
-        if isinstance(itm, ProjectBrowserFileItem):
-            dn = os.path.dirname(itm.fileName())
-        elif isinstance(
-            itm, (ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem)
-        ):
-            dn = itm.dirName()
-        else:
-            dn = None
-        self.project.addFiles("translation", dn)
+        self.project.addFiles("TRANSLATIONS", self.currentDirectory())
 
     def _openItem(self):
         """
@@ -849,7 +850,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot to handle the Preview translations action.
 
         @param previewAll flag indicating, that all translations
-            should be previewed (boolean)
+            should be previewed
+        @type bool
         """
         fileNames = []
         itmList = self.getSelectedItems()
@@ -895,10 +897,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
 
         @param langs list of languages to include in the process. An empty
             list (default) means that all translations should be included.
-            (list of ProjectBrowserFileItem)
+        @type list of ProjectBrowserFileItem
         @param filterList list of source file extension that should be
-            considered (list of strings)
+            considered
+        @type list of str
         @return flag indicating success
+        @rtype bool
         """
         path, ext = os.path.splitext(self.project.pfile)
         pfile = "{0}_e4x.pro".format(path)
@@ -1017,7 +1021,11 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         @param proc reference to the process
         @type QProcess
         """
-        self.__readStdout(proc, "{0}: ".format(self.pylupdate))
+        out = self.__readStdout(proc, "{0}: ".format(self.pylupdate))
+        for index in range(len(self.__pylupdateProcesses)):
+            if proc is self.__pylupdateProcesses[index][0]:
+                self.__pylupdateProcesses[index][2].append(out)
+                break
 
     def __readStdoutLrelease(self, proc):
         """
@@ -1027,23 +1035,33 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         @param proc reference to the process
         @type QProcess
         """
-        self.__readStdout(proc, "lrelease: ")
+        out = self.__readStdout(proc, "lrelease: ")
+        for index in range(len(self.__lreleaseProcesses)):
+            if proc is self.__lreleaseProcesses[index][0]:
+                self.__lreleaseProcesses[index][1].append(out)
+                break
 
     def __readStdout(self, proc, ps):
         """
         Private method to read from a process' stdout channel.
 
-        @param proc process to read from (QProcess)
-        @param ps prompt string (string)
+        @param proc process to read from
+        @type QProcess
+        @param ps prompt string
+        @type str
+        @return string read from the process
+        @rtype str
         """
         ioEncoding = Preferences.getSystem("IOEncoding")
+        out = ""
 
         proc.setReadChannel(QProcess.ProcessChannel.StandardOutput)
         while proc and proc.canReadLine():
-            s = ps
+            out += ps
             output = str(proc.readLine(), ioEncoding, "replace")
-            s += output
-            self.appendStdout.emit(s)
+            out += output
+
+        return out
 
     def __readStderrLupdate(self, proc):
         """
@@ -1069,8 +1087,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         """
         Private method to read from a process' stderr channel.
 
-        @param proc process to read from (QProcess)
-        @param ps propmt string (string)
+        @param proc process to read from
+        @type QProcess
+        @param ps propmt string
+        @type str
         """
         ioEncoding = Preferences.getSystem("IOEncoding")
 
@@ -1128,13 +1148,18 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             )
 
         for index in range(len(self.__pylupdateProcesses)):
-            if proc == self.__pylupdateProcesses[index][0]:
-                tmpProjectFile = self.__pylupdateProcesses[index][1]
+            if proc is self.__pylupdateProcesses[index][0]:
+                processData = self.__pylupdateProcesses[index]
+                tmpProjectFile = processData[1]
                 if tmpProjectFile:
                     with contextlib.suppress(OSError):
                         self.__tmpProjects.remove(tmpProjectFile)
                         os.remove(tmpProjectFile)
-                del self.__pylupdateProcesses[index]
+
+                if processData[2]:
+                    self.appendStdout.emit("".join(processData[2]))
+
+                self.__pylupdateProcesses.remove(processData)
                 break
 
         if not self.__pylupdateProcesses:
@@ -1152,9 +1177,11 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         pyside6-lupdate to generate the .ts files.
 
         @param noobsolete flag indicating whether obsolete entries should be
-            kept (boolean)
+            kept
+        @type bool
         @param generateAll flag indicating whether all translations should be
-            generated (boolean)
+            generated
+        @type bool
         """
         langs = [] if generateAll else self.getSelectedItems()
 
@@ -1188,14 +1215,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     self.hooks["generateSelectedWithObsolete"](li)
                     return
 
-        # generate a minimal temporary project file suitable for pylupdate
-        self.__tmpProjects = []
-        if self.project.getProjectLanguage() in ["Python", "Python3"]:
-            if self.project.getProjectType() not in ["PyQt6", "PyQt6C", "E7Plugin"]:
-                ok = self.__writeTempProjectFile(langs, [".py"])
-                if not ok:
-                    return
-        else:
+        if self.project.getProjectLanguage() not in ["Python", "Python3"]:
             return
 
         if self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
@@ -1285,7 +1305,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 procStarted = proc.waitForStarted()
                 if procStarted:
                     self.pylupdateProcRunning = True
-                    self.__pylupdateProcesses.append((proc, ""))
+                    self.__pylupdateProcesses.append((proc, "", []))
                 else:
                     with EricOverridenCursor():
                         EricMessageBox.critical(
@@ -1297,6 +1317,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                             ).format(self.pylupdate),
                         )
         else:
+            # generate a minimal temporary project file suitable for pylupdate
+            self.__tmpProjects = []
+            ok = self.__writeTempProjectFile(langs, [".py"])
+            if not ok:
+                return
+
             QGuiApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
             QGuiApplication.processEvents(
                 QEventLoop.ProcessEventsFlag.ExcludeUserInputEvents
@@ -1327,7 +1353,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 procStarted = proc.waitForStarted()
                 if procStarted:
                     self.pylupdateProcRunning = True
-                    self.__pylupdateProcesses.append((proc, tempProjectFile))
+                    self.__pylupdateProcesses.append((proc, tempProjectFile, []))
                 else:
                     with EricOverridenCursor():
                         EricMessageBox.critical(
@@ -1428,8 +1454,12 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             )
 
         for index in range(len(self.__lreleaseProcesses)):
-            if proc == self.__lreleaseProcesses[index]:
-                del self.__lreleaseProcesses[index]
+            if proc is self.__lreleaseProcesses[index][0]:
+                processData = self.__lreleaseProcesses[index]
+                if processData[1]:
+                    self.appendStdout.emit("".join(self.__lreleaseProcesses[index][1]))
+
+                self.__lreleaseProcesses.remove(processData)
                 break
         if not self.__lreleaseProcesses:
             # all done
@@ -1441,7 +1471,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private method to run lrelease to release the translation files (.qm).
 
         @param generateAll flag indicating whether all translations should be
-            released (boolean)
+            released
+        @type bool
         """
         langs = [] if generateAll else self.getSelectedItems()
 
@@ -1525,7 +1556,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         procStarted = proc.waitForStarted()
         if procStarted:
             self.lreleaseProcRunning = True
-            self.__lreleaseProcesses.append(proc)
+            self.__lreleaseProcesses.append((proc, []))
         else:
             EricMessageBox.critical(
                 self,
