@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -51,6 +51,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         self.setupUi(self)
 
         self.dirPicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
+        self.srcDirPicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
         self.mainscriptPicker.setMode(EricPathPickerModes.OPEN_FILE_MODE)
 
         self.makeButton.setIcon(EricPixmapCache.getIcon("makefile"))
@@ -66,17 +67,6 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         self.makePropertiesDlg = None
         self.__fileTypesDict = {}
 
-        patterns = []
-        for pattern, filetype in self.project.getProjectData(
-            dataKey="FILETYPES"
-        ).items():
-            if filetype == "SOURCES":
-                patterns.append(pattern)
-        filters = self.tr("Source Files ({0});;All Files (*)").format(
-            " ".join(sorted(patterns))
-        )
-        self.mainscriptPicker.setFilters(filters)
-
         self.languageComboBox.addItems(project.getProgrammingLanguages())
 
         projectTypes = []
@@ -98,6 +88,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         if not new:
             name = os.path.splitext(self.project.pfile)[0]
             self.nameEdit.setText(os.path.basename(name))
+            self.nameEdit.setReadOnly(True)
             self.languageComboBox.setCurrentIndex(
                 self.languageComboBox.findText(
                     self.project.getProjectData(dataKey="PROGLANGUAGE")
@@ -113,6 +104,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
                 curIndex = self.projectTypeComboBox.findData("PyQt6")
             self.projectTypeComboBox.setCurrentIndex(curIndex)
             self.dirPicker.setText(self.project.ppath)
+            self.srcDirPicker.setText(self.project.getProjectData(dataKey="SOURCESDIR"))
             self.versionEdit.setText(self.project.getProjectData(dataKey="VERSION"))
             self.mainscriptPicker.setText(
                 self.project.getProjectData(dataKey="MAINSCRIPT")
@@ -181,6 +173,8 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         self.__origMixedFlag = self.mixedLanguageCheckBox.isChecked()
         self.__origProjectType = self.getProjectType()
 
+        self.__initFileTypesDict(force=True)
+
         self.languageComboBox.currentTextChanged.connect(self.__initFileTypesDict)
         self.mixedLanguageCheckBox.stateChanged.connect(self.__initFileTypesDict)
         self.projectTypeComboBox.currentIndexChanged.connect(self.__initFileTypesDict)
@@ -190,6 +184,23 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
             and self.dirPicker.text() not in self.__initPaths
         )
 
+    def __setMainScriptPickerFilters(self):
+        """
+        Private method to set the filters for the main script file picker.
+        """
+        patterns = []
+        for pattern, filetype in self.__fileTypesDict.items():
+            if filetype == "SOURCES":
+                patterns.append(pattern)
+        filters = (
+            self.tr("Source Files ({0});;All Files (*)").format(
+                " ".join(sorted(patterns))
+            )
+            if patterns
+            else self.tr("All Files (*)")
+        )
+        self.mainscriptPicker.setFilters(filters)
+
     def __populateLicenseComboBox(self):
         """
         Private method to populate the license selector with the list of trove
@@ -238,13 +249,40 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         """
         Private slot to handle a change of the project directory.
 
-        @param txt name of the project directory (string)
+        @param txt name of the project directory
+        @type str
         """
         self.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setEnabled(
             bool(txt)
             and FileSystemUtilities.fromNativeSeparators(txt) not in self.__initPaths
         )
 
+    @pyqtSlot(str)
+    def on_srcDirPicker_pathSelected(self, srcDir):
+        """
+        Private slot to check the selected sources sub-directory name.
+
+        @param srcDir name of the sources directory name
+        @type str
+        """
+        if srcDir:
+            ppath = self.dirPicker.text()
+            if ppath:
+                ppath = QDir(ppath).absolutePath() + QDir.separator()
+                srcDir = srcDir.replace(ppath, "")
+            self.srcDirPicker.setText(srcDir)
+
+    @pyqtSlot()
+    def on_srcDirPicker_aboutToShowPathPickerDialog(self):
+        """
+        Private slot to perform actions before the sources sub-directory selection
+        dialog is shown.
+        """
+        ppath = self.dirPicker.text()
+        if not ppath:
+            ppath = QDir.currentPath()
+        self.srcDirPicker.setDefaultDirectory(ppath)
+
     @pyqtSlot()
     def on_spellPropertiesButton_clicked(self):
         """
@@ -313,10 +351,10 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         Private slot to perform actions before the main script selection dialog
         is shown.
         """
-        path = self.dirPicker.text()
-        if not path:
-            path = QDir.currentPath()
-        self.mainscriptPicker.setDefaultDirectory(path)
+        ppath = self.dirPicker.text()
+        if not ppath:
+            ppath = QDir.currentPath()
+        self.mainscriptPicker.setDefaultDirectory(ppath)
 
     @pyqtSlot()
     def on_vcsInfoButton_clicked(self):
@@ -336,7 +374,8 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         """
         Public method to get the selected project type.
 
-        @return selected UI type (string)
+        @return selected UI type
+        @rtype str
         """
         return self.projectTypeComboBox.itemData(
             self.projectTypeComboBox.currentIndex()
@@ -346,17 +385,22 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         """
         Public method to get the project path.
 
-        @return data of the project directory edit (string)
+        @return data of the project directory edit
+        @rtype str
         """
         return os.path.abspath(self.dirPicker.text())
 
     @pyqtSlot()
-    def __initFileTypesDict(self):
+    def __initFileTypesDict(self, force=False):
         """
         Private slot to (re-)initialize the filetype dictionary.
+
+        @param force flag indicating to force the initialization (defaults to False)
+        @type bool (optional)
         """
         if (
-            self.__origProgrammingLanguage != self.languageComboBox.currentText()
+            force
+            or self.__origProgrammingLanguage != self.languageComboBox.currentText()
             or self.__origMixedFlag != self.mixedLanguageCheckBox.isChecked()
             or self.__origProjectType != self.getProjectType()
         ):
@@ -370,6 +414,8 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
             # all of the defining data was changed back to original
             self.__fileTypesDict = self.project.getProjectData(dataKey="FILETYPES")
 
+        self.__setMainScriptPickerFilters()
+
     @pyqtSlot()
     def on_filetypesButton_clicked(self):
         """
@@ -397,6 +443,8 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         if dlg.exec() == QDialog.DialogCode.Accepted:
             self.__fileTypesDict = dlg.getData()
 
+        self.__setMainScriptPickerFilters()
+
     def storeData(self):
         """
         Public method to store the entered/modified data.
@@ -405,11 +453,17 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         fn = self.nameEdit.text()
         if fn:
             self.project.name = fn
-            fn = "{0}.epj".format(fn)
+            fn = f"{fn}.epj"
             self.project.pfile = os.path.join(self.project.ppath, fn)
         else:
             self.project.pfile = ""
         self.project.setProjectData(self.versionEdit.text(), dataKey="VERSION")
+        srcDir = self.srcDirPicker.text()
+        if srcDir:
+            srcDir = self.project.getRelativePath(srcDir)
+            self.project.setProjectData(srcDir, dataKey="SOURCESDIR")
+        else:
+            self.project.setProjectData("", dataKey="SOURCESDIR")
         fn = self.mainscriptPicker.text()
         if fn:
             fn = self.project.getRelativePath(fn)
