@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -340,8 +340,10 @@ class PyDocstringGenerator(BaseDocstringGenerator):
         @rtype str
         """
         startLine = cursorPosition[0] - 1
-        endLine = startLine - min(startLine, 20)
+        endLine = startLine - min(startLine, 20) - 1
         # max. 20 lines of definition allowed
+        if endLine < -1:
+            endLine = -1
         isFirstLine = True
         functionTextList = []
 
@@ -681,23 +683,30 @@ class PyFunctionInfo(FunctionInfo):
             self.hasInfo = True
             self.__splitArgumentToNameTypeValue(argumentsList, quote, quoteReplace)
 
-        functionName = (
+        self.functionName = (
             text[: positionArgumentsStart - 1]
             .replace("async def ", "")
             .replace("def ", "")
         )
-        if functionName == "__init__":
+        if self.functionName == "__init__":
             self.functionType = "constructor"
-        elif functionName.startswith("__"):
-            if functionName.endswith("__"):
+        elif self.functionName.startswith("__"):
+            if self.functionName.endswith("__"):
                 self.visibility = "special"
             else:
                 self.visibility = "private"
-        elif functionName.startswith("_"):
+        elif self.functionName.startswith("_"):
             self.visibility = "protected"
         else:
             self.visibility = "public"
 
+        if self.functionName.endswith("Event") or self.functionName in ("eventFilter",):
+            self.eventHandler = True
+            # Qt event handlers are protected
+            self.visibility = "protected"
+        elif self.functionName in ("event",):
+            self.eventHandler = True
+
     def parseBody(self, text):
         """
         Public method to parse the function body text.
