@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -313,7 +313,7 @@ class EditorAssembly(QWidget):
                 self.__membersBoundaries = {}
 
                 self.__globalsCombo.addItem("")
-                index = 0
+                index = 0  # noqa: Y113
 
                 # step 1: add modules
                 items = []
@@ -461,7 +461,3 @@ class EditorAssembly(QWidget):
         )
 
         self.__sourceOutline.setVisible(supported)
-
-
-#
-# eflag: noqa = Y113
