@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2020 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,7 @@ Module implementing an outline widget for source code navigation of the editor.
 import contextlib
 import functools
 
-from PyQt6.QtCore import QCoreApplication, QModelIndex, QPoint, Qt, pyqtSlot
+from PyQt6.QtCore import QCoreApplication, QModelIndex, QPoint, Qt, QTimer, pyqtSlot
 from PyQt6.QtWidgets import QAbstractItemView, QApplication, QDialog, QMenu, QTreeView
 
 from eric7 import Preferences
@@ -71,12 +71,12 @@ class EditorOutlineView(QTreeView):
         self.expanded.connect(self.__resizeColumns)
         self.collapsed.connect(self.__resizeColumns)
 
-        self.__resizeColumns()
-
         self.__expandedNames = []
         self.__currentItemName = ""
         self.__signalsConnected = False
 
+        QTimer.singleShot(0, self.__resizeColumns)
+
     def setActive(self, active):
         """
         Public method to activate or deactivate the outline view.
@@ -200,7 +200,8 @@ class EditorOutlineView(QTreeView):
         Reimplemented to disable expanding/collapsing of items when
         double-clicking. Instead the double-clicked entry is opened.
 
-        @param mouseEvent the mouse event (QMouseEvent)
+        @param mouseEvent the mouse event
+        @type QMouseEvent
         """
         index = self.indexAt(mouseEvent.position().toPoint())
         if index.isValid():
@@ -413,7 +414,8 @@ class EditorOutlineView(QTreeView):
         """
         Private slot to handle the selection of the goto menu.
 
-        @param act reference to the action (EricAction)
+        @param act reference to the action
+        @type EricAction
         """
         lineno = act.data()
         self.__model.editor().gotoLine(lineno)
