@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,6 +22,7 @@ class LexerMarkdown(Lexer, QsciLexerMarkdown):
         Constructor
 
         @param parent parent widget of this lexer
+        @type QWidget
         """
         QsciLexerMarkdown.__init__(self, parent)
         Lexer.__init__(self)
@@ -32,13 +33,15 @@ class LexerMarkdown(Lexer, QsciLexerMarkdown):
         """
         Public method to get the default keywords.
 
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
+        @param kwSet number of the keyword set
+        @type int
+        @return string giving the keywords or None
+        @rtype str
         """
         return QsciLexerMarkdown.keywords(self, kwSet)
 
 
-def createLexer(variant="", parent=None):
+def createLexer(variant="", parent=None):  # noqa: U100
     """
     Function to instantiate a lexer object.
 
