@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -186,9 +186,7 @@ class SubstyledLexer(Lexer):
                 if subStyleStart < 0:
                     continue
 
-                for subStyleIndex, subStyleKey in enumerate(
-                    sorted(subStylesData.keys())
-                ):
+                for subStyleIndex, subStyleKey in enumerate(sorted(subStylesData)):
                     styleNo = subStyleStart + subStyleIndex
                     subStyle = subStylesData[subStyleKey]
                     # set the words
@@ -270,7 +268,7 @@ class SubstyledLexer(Lexer):
             )
             settings.setValue(key, len(self.__subStyles[baseStyle]))
             for subStyleIndex, subStyle in enumerate(
-                sorted(self.__subStyles[baseStyle].keys())
+                sorted(self.__subStyles[baseStyle])
             ):
                 substyleKey = "Scintilla/{0}/style{1}/substyle{2}/".format(
                     self.language(), baseStyle, subStyleIndex
@@ -718,7 +716,7 @@ class SubstyledLexer(Lexer):
         @rtype int
         """
         if style in self.__subStyles:
-            lastSubStyle = sorted(self.__subStyles[style].keys())[-1]
+            lastSubStyle = sorted(self.__subStyles[style])[-1]
             subStyle = lastSubStyle + 1
             self.__subStyles[style][subStyle] = {
                 "Description": "",
