@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -111,7 +111,7 @@ def getSupportedLanguages():
         The first is the display string for the language, the second
         is a dummy file name, which can be used to derive the lexer, and
         the third is the name of an icon file.
-        (string, string, string)
+    @rtype dict of {str: [str, str, str]}
     """
     supportedLanguages = {
         "Bash": [QCoreApplication.translate("Lexers", "Bash"), "dummy.sh", "lexerBash"],
@@ -273,7 +273,7 @@ def getSupportedApiLanguages():
     """
     return [
         lang
-        for lang in getSupportedLanguages().keys()
+        for lang in getSupportedLanguages()
         if lang != "Guessed" and not lang.startswith("Pygments|")
     ]
 
@@ -282,9 +282,12 @@ def getLanguageIcon(language, pixmap):
     """
     Module function to get an icon for a language.
 
-    @param language language of the lexer (string)
-    @param pixmap flag indicating to return a pixmap (boolean)
-    @return icon for the language (QPixmap or QIcon)
+    @param language language of the lexer
+    @type str
+    @param pixmap flag indicating to return a pixmap
+    @type bool
+    @return icon for the language
+    @rtype QPixmap or QIcon
     """
     supportedLanguages = getSupportedLanguages()
     iconFileName = (
@@ -300,10 +303,14 @@ def getLexer(language, parent=None, pyname=""):
     """
     Module function to instantiate a lexer object for a given language.
 
-    @param language language of the lexer (string)
-    @param parent reference to the parent object (QObject)
-    @param pyname name of the pygments lexer to use (string)
-    @return reference to the instantiated lexer object (QsciLexer)
+    @param language language of the lexer
+    @type str
+    @param parent reference to the parent object
+    @type QObject
+    @param pyname name of the pygments lexer to use
+    @type str
+    @return reference to the instantiated lexer object
+    @rtype QsciLexer
     """
     if not pyname:
         languageLexerMapping = {
@@ -372,8 +379,11 @@ def __getPygmentsLexer(parent, name=""):
     Private module function to instantiate a pygments lexer.
 
     @param parent reference to the parent widget
-    @param name name of the pygments lexer to use (string)
-    @return reference to the lexer (LexerPygments) or None
+    @type QWidget
+    @param name name of the pygments lexer to use
+    @type str
+    @return reference to the lexer or None
+    @rtype LexerPygments
     """
     from .LexerPygments import LexerPygments
 
@@ -388,13 +398,15 @@ def getOpenFileFiltersList(includeAll=False, asString=False, withAdditional=True
     """
     Module function to get the file filter list for an open file operation.
 
-    @param includeAll flag indicating the inclusion of the
-        All Files filter (boolean)
-    @param asString flag indicating the list should be returned
-        as a string (boolean)
-    @param withAdditional flag indicating to include additional filters
-        defined by the user (boolean)
-    @return file filter list (list of strings or string)
+    @param includeAll flag indicating the inclusion of the "All Files" filter
+    @type bool
+    @param asString flag indicating the list should be returned as a string
+    @type bool
+    @param withAdditional flag indicating to include additional filters defined
+        by the user
+    @type bool
+    @return file filter list
+    @rtype list of str or str
     """
     openFileFiltersList = [
         QCoreApplication.translate("Lexers", "Python Files (*.py *.py3)"),
@@ -479,13 +491,15 @@ def getSaveFileFiltersList(includeAll=False, asString=False, withAdditional=True
     """
     Module function to get the file filter list for a save file operation.
 
-    @param includeAll flag indicating the inclusion of the
-        All Files filter (boolean)
-    @param asString flag indicating the list should be returned
-        as a string (boolean)
-    @param withAdditional flag indicating to include additional filters
-        defined by the user (boolean)
-    @return file filter list (list of strings or string)
+    @param includeAll flag indicating the inclusion of the "All Files" filter
+    @type bool
+    @param asString flag indicating the list should be returned as a string
+    @type bool
+    @param withAdditional flag indicating to include additional filters defined
+        by the user
+    @type bool
+    @return file filter list
+    @rtype list of str or str
     """
     saveFileFiltersList = [
         QCoreApplication.translate("Lexers", "Python3 Files (*.py)"),
@@ -569,6 +583,7 @@ def getDefaultLexerAssociations():
     Module function to get a dictionary with the default associations.
 
     @return dictionary with the default lexer associations
+    @rtype dict
     """
     assocs = {
         "*.sh": "Bash",
@@ -670,28 +685,6 @@ def getDefaultLexerAssociations():
         "*.m": "Matlab",
         "*.m.matlab": "Matlab",
         "*.m.octave": "Octave",
-        "*.e4c": "XML",
-        "*.e4d": "XML",
-        "*.e4k": "XML",
-        "*.e4m": "XML",
-        "*.e4p": "XML",
-        "*.e4q": "XML",
-        "*.e4s": "XML",
-        "*.e4t": "XML",
-        "*.e5d": "XML",
-        "*.e5k": "XML",
-        "*.e5m": "XML",
-        "*.e5p": "XML",
-        "*.e5q": "XML",
-        "*.e5s": "XML",
-        "*.e5t": "XML",
-        "*.e6d": "XML",
-        "*.e6k": "XML",
-        "*.e6m": "XML",
-        "*.e6p": "XML",
-        "*.e6q": "XML",
-        "*.e6s": "XML",
-        "*.e6t": "XML",
         "*.ecj": "JSON",
         "*.edj": "JSON",
         "*.egj": "JSON",
