@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,15 @@ Module implementing a stand alone shell window.
 import os
 
 from PyQt6.Qsci import QsciScintilla
-from PyQt6.QtCore import QCoreApplication, QPoint, QProcess, QSignalMapper, QSize, Qt
+from PyQt6.QtCore import (
+    QCoreApplication,
+    QPoint,
+    QProcess,
+    QSignalMapper,
+    QSize,
+    Qt,
+    pyqtSlot,
+)
 from PyQt6.QtGui import QAction, QKeySequence
 from PyQt6.QtWidgets import QApplication, QDialog, QVBoxLayout, QWhatsThis, QWidget
 
@@ -28,7 +36,7 @@ from eric7.UI.SearchWidget import SearchWidget
 from eric7.VirtualEnv.VirtualenvManager import VirtualenvManager
 
 from .APIsManager import APIsManager
-from .Shell import Shell
+from .Shell import Shell, ShellHistoryStyle
 
 
 class ShellWindow(EricMainWindow):
@@ -152,7 +160,8 @@ class ShellWindow(EricMainWindow):
         """
         Public method to get a reference to the APIs manager.
 
-        @return the APIs manager object (eric7.QScintilla.APIsManager)
+        @return the APIs manager object
+        @rtype QScintilla.APIsManager
         """
         return self.__apisManager
 
@@ -199,6 +208,7 @@ class ShellWindow(EricMainWindow):
         self.__createViewActions()
         self.__createHelpActions()
         self.__createHistoryActions()
+        self.__createSettingsActions()
 
         # read the keyboard shortcuts and make them identical to the main
         # eric shortcuts
@@ -422,11 +432,7 @@ class ShellWindow(EricMainWindow):
         ####################################################################
 
         self.esm = QSignalMapper(self)
-        try:
-            self.esm.mappedInt.connect(self.__shell.editorCommand)
-        except AttributeError:
-            # pre Qt 5.15
-            self.esm.mapped[int].connect(self.__shell.editorCommand)
+        self.esm.mappedInt.connect(self.__shell.editorCommand)
 
         self.editorActGrp = createActionGroup(self)
 
@@ -1148,6 +1154,30 @@ class ShellWindow(EricMainWindow):
         )
         self.selectHistoryAct.triggered.connect(self.__shell.selectHistory)
 
+    def __createSettingsActions(self):
+        """
+        Private method to create the Settings actions.
+        """
+        self.prefAct = EricAction(
+            self.tr("Preferences"),
+            EricPixmapCache.getIcon("configure"),
+            self.tr("&Preferences..."),
+            0,
+            0,
+            self,
+            "shell_settings_preferences",
+        )
+        self.prefAct.setStatusTip(self.tr("Set the prefered configuration"))
+        self.prefAct.setWhatsThis(
+            self.tr(
+                """<b>Preferences</b>"""
+                """<p>Set the configuration items of the application"""
+                """ with your prefered values.</p>"""
+            )
+        )
+        self.prefAct.triggered.connect(self.__showPreferences)
+        self.prefAct.setMenuRole(QAction.MenuRole.PreferencesRole)
+
     def __createHelpActions(self):
         """
         Private method to create the Help actions.
@@ -1407,6 +1437,10 @@ class ShellWindow(EricMainWindow):
         self.__startMenu.aboutToShow.connect(self.__showStartMenu)
         self.__startMenu.triggered.connect(self.__startShell)
 
+        self.__settingsMenu = self.menuBar().addMenu(self.tr("Se&ttings"))
+        self.__settingsMenu.setTearOffEnabled(True)
+        self.__settingsMenu.addAction(self.prefAct)
+
         self.menuBar().addSeparator()
 
         self.__helpMenu = self.menuBar().addMenu(self.tr("&Help"))
@@ -1428,7 +1462,8 @@ class ShellWindow(EricMainWindow):
         """
         Private slot to start a shell according to the action triggered.
 
-        @param action menu action that was triggered (QAction)
+        @param action menu action that was triggered
+        @type QAction
         """
         venvName = action.text()
         self.__debugServer.startClient(False, venvName=venvName)
@@ -1502,6 +1537,7 @@ class ShellWindow(EricMainWindow):
         self.__sbZoom.valueChanged.connect(self.__zoomTo)
         self.__sbZoom.setValue(0)
 
+    @pyqtSlot(ShellHistoryStyle)
     def __historyStyleChanged(self, historyStyle):
         """
         Private slot to handle a change of the shell history style.
@@ -1512,3 +1548,28 @@ class ShellWindow(EricMainWindow):
         enabled = self.__shell.isHistoryEnabled()
         self.__historyMenu.setEnabled(enabled)
         self.__historyToolbar.setEnabled(enabled)
+
+    @pyqtSlot()
+    def __showPreferences(self):
+        """
+        Private slot to set the preferences.
+        """
+        from eric7.Preferences.ConfigurationDialog import (
+            ConfigurationDialog,
+            ConfigurationMode,
+        )
+
+        dlg = ConfigurationDialog(
+            None,
+            "Configuration",
+            True,
+            fromEric=False,
+            displayMode=ConfigurationMode.SHELLMODE,
+        )
+        dlg.show()
+        dlg.showConfigurationPageByName("0shellPage")
+        dlg.exec()
+        if dlg.result() == QDialog.DialogCode.Accepted:
+            dlg.setPreferences()
+            Preferences.syncPreferences()
+            self.__shell.handlePreferencesChanged()
