@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,10 +29,14 @@ def drawRect(painter, rect, outline, fill=None):
     """
     Module function to draw a rectangle with the given parameters.
 
-    @param painter reference to the painter to be used (QPainter)
-    @param rect rectangle to be drawn (QRect)
-    @param outline color of the outline (QColor)
-    @param fill fill color (QColor)
+    @param painter reference to the painter to be used
+    @type QPainter
+    @param rect rectangle to be drawn
+    @type QRect
+    @param outline color of the outline
+    @type QColor
+    @param fill fill color
+    @type QColor
     """
     clip = QRegion(rect)
     clip = clip.subtracted(QRegion(rect.adjusted(1, 1, -1, -1)))
@@ -70,6 +74,7 @@ class SnapshotRegionGrabber(QWidget):
 
         @param mode region grabber mode (SnapshotRegionGrabber.Rectangle or
             SnapshotRegionGrabber.Ellipse)
+        @type int
         @exception ValueError raised to indicate a bad value for the 'mode'
             parameter
         """
@@ -162,7 +167,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method handling paint events.
 
-        @param evt paint event (QPaintEvent)
+        @param evt paint event
+        @type QPaintEvent
         """
         if self.__grabbing:  # grabWindow() should just get the background
             return
@@ -283,7 +289,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method to handle resize events.
 
-        @param evt resize event (QResizeEvent)
+        @param evt resize event
+        @type QResizeEvent
         """
         if self.__selection.isNull():
             return
@@ -301,7 +308,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method to handle mouse button presses.
 
-        @param evt mouse press event (QMouseEvent)
+        @param evt mouse press event
+        @type QMouseEvent
         """
         self.__showHelp = not self.__helpTextRect.contains(evt.position().toPoint())
         if evt.button() == Qt.MouseButton.LeftButton:
@@ -323,7 +331,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method to handle mouse movements.
 
-        @param evt mouse move event (QMouseEvent)
+        @param evt mouse move event
+        @type QMouseEvent
         """
         shouldShowHelp = not self.__helpTextRect.contains(evt.position().toPoint())
         if shouldShowHelp != self.__showHelp:
@@ -416,7 +425,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method to handle mouse button releases.
 
-        @param evt mouse release event (QMouseEvent)
+        @param evt mouse release event
+        @type QMouseEvent
         """
         self.__mouseDown = False
         self.__newSelection = False
@@ -430,7 +440,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method to handle mouse double clicks.
 
-        @param evt mouse double click event (QMouseEvent)
+        @param evt mouse double click event
+        @type QMouseEvent
         """
         self.__grabRect()
 
@@ -438,7 +449,8 @@ class SnapshotRegionGrabber(QWidget):
         """
         Protected method to handle key presses.
 
-        @param evt key press event (QKeyEvent)
+        @param evt key press event
+        @type QKeyEvent
         """
         if evt.key() == Qt.Key.Key_Escape:
             self.grabbed.emit(QPixmap())
@@ -471,7 +483,9 @@ class SnapshotRegionGrabber(QWidget):
         @param maskType type of the mask to be used
             (SnapshotRegionGrabber.FillMask or
             SnapshotRegionGrabber.StrokeMask)
-        @return calculated mask (QRegion)
+        @type int
+        @return calculated mask
+        @rtype QRegion
         """
         mask = QRegion()
         for rect in self.__handles:
@@ -486,9 +500,12 @@ class SnapshotRegionGrabber(QWidget):
         """
         Private method to limit the given point to the given rectangle.
 
-        @param point point to be limited (QPoint)
-        @param rect rectangle the point shall be limited to (QRect)
-        @return limited point (QPoint)
+        @param point point to be limited
+        @type QPoint
+        @param rect rectangle the point shall be limited to
+        @type QRect
+        @return limited point
+        @rtype QPoint
         """
         q = QPoint()
         if point.x() < rect.x():
@@ -509,8 +526,10 @@ class SnapshotRegionGrabber(QWidget):
         """
         Private method to normalize the given selection.
 
-        @param sel selection to be normalized (QRect)
-        @return normalized selection (QRect)
+        @param sel selection to be normalized
+        @type QRect
+        @return normalized selection
+        @rtype QRect
         """
         rect = QRect(sel)
         if rect.width() <= 0:
