@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,7 +16,7 @@ import os
 import threading
 import time
 
-from PyQt6.QtCore import Qt, QThread, pyqtSignal
+from PyQt6.QtCore import Qt, QThread, pyqtSignal, pyqtSlot
 from PyQt6.QtWidgets import (
     QAbstractItemView,
     QApplication,
@@ -54,8 +54,10 @@ class TaskViewer(QTreeWidget):
         """
         Constructor
 
-        @param parent the parent (QWidget)
+        @param parent the parent
+        @type QWidget
         @param project reference to the project object
+        @type Project
         """
         super().__init__(parent)
 
@@ -214,8 +216,10 @@ class TaskViewer(QTreeWidget):
         """
         Public method to find a parent task by its ID.
 
-        @param parentUid uid of the parent task (string)
-        @return reference to the task (Task)
+        @param parentUid uid of the parent task
+        @type str
+        @return reference to the task
+        @rtype Task
         """
         if not parentUid:
             return None
@@ -259,12 +263,15 @@ class TaskViewer(QTreeWidget):
         self.__resort()
         self.__resizeColumns()
 
+    @pyqtSlot(QTreeWidgetItem, int)
     def __taskItemActivated(self, itm, col):
         """
         Private slot to handle the activation of an item.
 
-        @param itm reference to the activated item (QTreeWidgetItem)
-        @param col column the item was activated in (integer)
+        @param itm reference to the activated item
+        @type QTreeWidgetItem
+        @param col column the item was activated in
+        @type int
         """
         if (
             not self.__activating
@@ -287,7 +294,8 @@ class TaskViewer(QTreeWidget):
         """
         Private slot to show the context menu of the list.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         itm = self.itemAt(coord)
         coord = self.mapToGlobal(coord)
@@ -329,6 +337,7 @@ class TaskViewer(QTreeWidget):
         Public slot to set the project status.
 
         @param o flag indicating the project status
+        @type bool
         """
         self.projectOpen = o
 
@@ -458,7 +467,8 @@ class TaskViewer(QTreeWidget):
         """
         Public method to retrieve all project related tasks.
 
-        @return copy of tasks (list of Task)
+        @return copy of tasks
+        @rtype list of Task
         """
         tasks = [task for task in self.tasks if task.isProjectTask()]
         return tasks[:]
@@ -467,7 +477,8 @@ class TaskViewer(QTreeWidget):
         """
         Public method to retrieve all non project related tasks.
 
-        @return copy of tasks (list of Task)
+        @return copy of tasks
+        @rtype list of Task
         """
         tasks = [task for task in self.tasks if not task.isProjectTask()]
         return tasks[:]
@@ -484,8 +495,8 @@ class TaskViewer(QTreeWidget):
         """
         Public slot to clear project related tasks.
 
-        @param fileOnly flag indicating to clear only file related
-            project tasks (boolean)
+        @param fileOnly flag indicating to clear only file related project tasks
+        @type bool
         """
         for task in reversed(self.tasks[:]):
             if (fileOnly and task.isProjectFileTask()) or (
@@ -506,9 +517,11 @@ class TaskViewer(QTreeWidget):
         """
         Public slot to clear all tasks related to a file.
 
-        @param filename name of the file (string)
+        @param filename name of the file
+        @type str
         @param conditionally flag indicating to clear the tasks of the file
-            checking some conditions (boolean)
+            checking some conditions
+        @type bool
         """
         if conditionally:
             if self.project and self.project.isProjectCategory(filename, "SOURCES"):
@@ -677,7 +690,8 @@ class TaskViewer(QTreeWidget):
         """
         Private method to delete all sub-tasks.
 
-        @param task task to delete sub-tasks of (Task)
+        @param task task to delete sub-tasks of
+        @type Task
         """
         for subtask in task.takeChildren():
             if self.copyTask == subtask:
@@ -735,7 +749,8 @@ class TaskViewer(QTreeWidget):
         """
         Private slot to handle the "Filtered display" context menu entry.
 
-        @param on flag indicating the filter state (boolean)
+        @param on flag indicating the filter state
+        @type bool
         """
         if on and not self.taskFilter.hasActiveFilter():
             res = EricMessageBox.yesNo(
@@ -847,7 +862,7 @@ class TaskViewer(QTreeWidget):
                 try:
                     text, encoding = Utilities.readEncodedFile(fn)
                     lines = text.splitlines()
-                except (UnicodeError, OSError):
+                except (OSError, UnicodeError):
                     count += 1
                     progress.setValue(count)
                     continue
@@ -927,7 +942,8 @@ class ProjectTaskExtractionThread(QThread):
         """
         Constructor
 
-        @param parent reference to the parent object (QObject)
+        @param parent reference to the parent object
+        @type QObject
         """
         super().__init__()
 
@@ -978,7 +994,7 @@ class ProjectTaskExtractionThread(QThread):
             try:
                 text, encoding = Utilities.readEncodedFile(fn)
                 lines = text.splitlines()
-            except (UnicodeError, OSError):
+            except (OSError, UnicodeError):
                 continue
 
             # now search tasks and record them
