@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,8 +21,10 @@ class TemplateSingleVariableDialog(QDialog, Ui_TemplateSingleVariableDialog):
         """
         Constructor
 
-        @param variable template variable name (string)
-        @param parent parent widget of this dialog (QWidget)
+        @param variable template variable name
+        @type str
+        @param parent parent widget of this dialog
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -33,6 +35,7 @@ class TemplateSingleVariableDialog(QDialog, Ui_TemplateSingleVariableDialog):
         """
         Public method to get the value for the variable.
 
-        @return value for the template variable (string)
+        @return value for the template variable
+        @rtype str
         """
         return self.variableEdit.toPlainText()
