@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,14 +12,13 @@ import os
 import pathlib
 import re
 
-from PyQt6.QtCore import QCoreApplication, QFile, QIODevice, Qt
+from PyQt6.QtCore import QCoreApplication, Qt, pyqtSlot
 from PyQt6.QtWidgets import QApplication, QDialog, QMenu, QTreeWidget, QTreeWidgetItem
 
 from eric7 import Globals, Preferences
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets import EricFileDialog, EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
-from eric7.EricXML.TemplatesReader import TemplatesReader
 
 from .TemplatePropertiesDialog import TemplatePropertiesDialog
 from .TemplatesFile import TemplatesFile
@@ -34,9 +33,12 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Constructor
 
-        @param parent parent widget of the template group (QWidget)
-        @param name name of the group (string)
-        @param language programming language for the group (string)
+        @param parent parent widget of the template group
+        @type QWidget
+        @param name name of the group
+        @type str
+        @param language programming language for the group
+        @type str
         """
         self.name = name
         self.language = language
@@ -51,7 +53,8 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to update the name of the group.
 
-        @param name name of the group (string)
+        @param name name of the group
+        @type str
         """
         self.name = name
         self.setText(0, name)
@@ -60,7 +63,8 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to get the name of the group.
 
-        @return name of the group (string)
+        @return name of the group
+        @rtype str
         """
         return self.name
 
@@ -68,7 +72,8 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to update the name of the group.
 
-        @param language programming language for the group (string)
+        @param language programming language for the group
+        @type str
         """
         self.language = language
         if Preferences.getTemplates("ShowTooltip"):
@@ -78,7 +83,8 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to get the name of the group.
 
-        @return language of the group (string)
+        @return language of the group
+        @rtype str
         """
         return self.language
 
@@ -86,10 +92,14 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to add a template entry to this group.
 
-        @param name name of the entry (string)
-        @param description description of the entry to add (string)
-        @param template template text of the entry (string)
-        @param quiet flag indicating quiet operation (boolean)
+        @param name name of the entry
+        @type str
+        @param description description of the entry to add
+        @type str
+        @param template template text of the entry
+        @type str
+        @param quiet flag indicating quiet operation
+        @type bool
         """
         if name in self.entries:
             if not quiet:
@@ -113,7 +123,8 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to remove a template entry from this group.
 
-        @param name name of the entry to be removed (string)
+        @param name name of the entry to be removed
+        @type str
         """
         if name in self.entries:
             index = self.indexOfChild(self.entries[name])
@@ -131,15 +142,17 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to remove all template entries of this group.
         """
-        for name in list(self.entries.keys())[:]:
+        for name in list(self.entries):
             self.removeEntry(name)
 
     def hasEntry(self, name):
         """
         Public method to check, if the group has an entry with the given name.
 
-        @param name name of the entry to check for (string)
-        @return flag indicating existence (boolean)
+        @param name name of the entry to check for
+        @type str
+        @return flag indicating existence
+        @rtype bool
         """
         return name in self.entries
 
@@ -147,8 +160,10 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to get an entry.
 
-        @param name name of the entry to retrieve (string)
-        @return reference to the entry (TemplateEntry)
+        @param name name of the entry to retrieve
+        @type str
+        @return reference to the entry
+        @rtype TemplateEntry
         """
         try:
             return self.entries[name]
@@ -161,8 +176,9 @@ class TemplateGroup(QTreeWidgetItem):
         the given string.
 
         @param beginning string denoting the beginning of the template name
-            (string)
-        @return list of entry names found (list of strings)
+        @type str
+        @return list of entry names found
+        @rtype list of str
         """
         names = []
         for name in self.entries:
@@ -175,7 +191,8 @@ class TemplateGroup(QTreeWidgetItem):
         """
         Public method to retrieve all entries.
 
-        @return list of all entries (list of TemplateEntry)
+        @return list of all entries
+        @rtype list of TemplateEntry
         """
         return list(self.entries.values())
 
@@ -189,10 +206,14 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Constructor
 
-        @param parent parent widget of the template entry (QWidget)
-        @param name name of the entry (string)
-        @param description descriptive text for the template (string)
-        @param templateText text of the template entry (string)
+        @param parent parent widget of the template entry
+        @type QWidget
+        @param name name of the entry
+        @type str
+        @param description descriptive text for the template
+        @type str
+        @param templateText text of the template entry
+        @type str
         """
         self.name = name
         self.description = description
@@ -207,7 +228,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Private method to generate the display text.
 
-        @return display text (string)
+        @return display text
+        @rtype str
         """
         txt = (
             "{0} - {1}".format(self.name, self.description)
@@ -220,7 +242,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to update the name of the entry.
 
-        @param name name of the entry (string)
+        @param name name of the entry
+        @type str
         """
         self.name = name
         self.setText(0, self.__displayText())
@@ -229,7 +252,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to get the name of the entry.
 
-        @return name of the entry (string)
+        @return name of the entry
+        @rtype str
         """
         return self.name
 
@@ -237,7 +261,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to update the description of the entry.
 
-        @param description description of the entry (string)
+        @param description description of the entry
+        @type str
         """
         self.description = description
         self.setText(0, self.__displayText())
@@ -246,7 +271,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to get the description of the entry.
 
-        @return description of the entry (string)
+        @return description of the entry
+        @rtype str
         """
         return self.description
 
@@ -254,7 +280,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to get the name of the group this entry belongs to.
 
-        @return name of the group containing this entry (string)
+        @return name of the group containing this entry
+        @rtype str
         """
         return self.parent().getName()
 
@@ -262,7 +289,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to update the template text.
 
-        @param templateText text of the template entry (string)
+        @param templateText text of the template entry
+        @type str
         """
         self.template = templateText
         self.__extractVariables()
@@ -273,7 +301,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to get the template text.
 
-        @return the template text (string)
+        @return the template text
+        @rtype str
         """
         return self.template
 
@@ -282,14 +311,17 @@ class TemplateEntry(QTreeWidgetItem):
         Public method to get the template text with all variables expanded.
 
         @param varDict dictionary containing the texts of each variable
-            with the variable name as key.
+            with the variable name as key
+        @type dict
         @param indent indentation of the line receiving he expanded
-            template text (string)
-        @return a tuple of the expanded template text (string), the
-            number of lines (integer) and the length of the last line (integer)
+            template text
+        @type str
+        @return a tuple of the expanded template text, the number of lines
+            and the length of the last line
+        @rtype tuple of (str, int, int)
         """
         txt = self.template
-        for var, val in list(varDict.items()):
+        for var, val in varDict.items():
             txt = (
                 self.__expandFormattedVariable(var, val, txt)
                 if var in self.formatedVariables
@@ -313,10 +345,14 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Private method to expand a template variable with special formatting.
 
-        @param var template variable name (string)
-        @param val value of the template variable (string)
-        @param txt template text (string)
-        @return expanded and formatted variable (string)
+        @param var template variable name
+        @type str
+        @param val value of the template variable
+        @type str
+        @param txt template text
+        @type str
+        @return expanded and formatted variable
+        @rtype str
         """
         t = ""
         for line in txt.splitlines():
@@ -349,7 +385,8 @@ class TemplateEntry(QTreeWidgetItem):
         """
         Public method to get the list of variables.
 
-        @return list of variables (list of strings)
+        @return list of variables
+        @rtype list of str
         """
         return self.variables
 
@@ -380,8 +417,10 @@ class TemplateViewer(QTreeWidget):
         """
         Constructor
 
-        @param parent the parent (QWidget)
+        @param parent the parent
+        @type QWidget
         @param viewmanager reference to the viewmanager object
+        @type ViewManager
         """
         super().__init__(parent)
 
@@ -444,12 +483,16 @@ class TemplateViewer(QTreeWidget):
         """
         self.sortItems(self.sortColumn(), self.header().sortIndicatorOrder())
 
+    @pyqtSlot()
+    @pyqtSlot(QTreeWidgetItem, int)
     def __templateItemActivated(self, itm=None, col=0):
         """
         Private slot to handle the activation of an item.
 
-        @param itm reference to the activated item (QTreeWidgetItem)
-        @param col column the item was activated in (integer)
+        @param itm reference to the activated item
+        @type QTreeWidgetItem
+        @param col column the item was activated in
+        @type int
         """
         if not self.__activating:
             self.__activating = True
@@ -462,7 +505,8 @@ class TemplateViewer(QTreeWidget):
         """
         Private slot to show the context menu of the list.
 
-        @param coord the position of the mouse pointer (QPoint)
+        @param coord the position of the mouse pointer
+        @type QPoint
         """
         itm = self.itemAt(coord)
         coord = self.mapToGlobal(coord)
@@ -559,11 +603,7 @@ class TemplateViewer(QTreeWidget):
             self,
             self.tr("Import Templates"),
             "",
-            self.tr(
-                "Templates Files (*.ecj);;"
-                "XML Templates Files (*.e4c);;"
-                "All Files (*)"
-            ),
+            self.tr("Templates Files (*.ecj);;All Files (*)"),
         )
 
         if fn:
@@ -651,10 +691,11 @@ class TemplateViewer(QTreeWidget):
         Private method to return predefined variables.
 
         @return dictionary of predefined variables and their values
+        @rtype dict
         """
         project = ericApp().getObject("Project")
         editor = self.viewmanager.activeWindow()
-        now = datetime.datetime.now()
+        now = datetime.datetime.now()  # noqa: M305
         sepchar = Preferences.getTemplates("SeparatorChar")
         keyfmt = sepchar + "{0}" + sepchar
         varValues = {
@@ -710,7 +751,8 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to apply the template.
 
-        @param itm reference to the template item to apply (TemplateEntry)
+        @param itm reference to the template item to apply
+        @type TemplateEntry
         """
         from .TemplateMultipleVariablesDialog import TemplateMultipleVariablesDialog
         from .TemplateSingleVariableDialog import TemplateSingleVariableDialog
@@ -725,13 +767,12 @@ class TemplateViewer(QTreeWidget):
 
         # Remove predefined variables from list so user doesn't have to fill
         # these values out in the dialog.
-        for v in list(varValues.keys()):
+        for v in varValues:
             if v in variables:
                 variables.remove(v)
 
         if variables:
             if Preferences.getTemplates("SingleDialog"):
-
                 dlg = TemplateMultipleVariablesDialog(variables, self)
                 if dlg.exec() == QDialog.DialogCode.Accepted:
                     varValues.update(dlg.getVariables())
@@ -818,10 +859,11 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to apply a template given a template name.
 
-        @param templateName name of the template item to apply (string)
-        @param groupName name of the group to get the entry from (string).
-            None or empty means to apply the first template found with the
-            given name.
+        @param templateName name of the template item to apply
+        @type str
+        @param groupName name of the group to get the entry from. None or empty means
+            to apply the first template found with the given name.
+        @type str
         """
         if groupName:
             if self.hasGroup(groupName):
@@ -840,11 +882,16 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to add a template entry.
 
-        @param groupName name of the group to add to (string)
-        @param name name of the entry to add (string)
-        @param description description of the entry to add (string)
-        @param template template text of the entry (string)
-        @param quiet flag indicating quiet operation (boolean)
+        @param groupName name of the group to add to
+        @type str
+        @param name name of the entry to add
+        @type str
+        @param description description of the entry to add
+        @type str
+        @param template template text of the entry
+        @type str
+        @param quiet flag indicating quiet operation
+        @type bool
         """
         self.groups[groupName].addEntry(name, description, template, quiet=quiet)
         self.__resort()
@@ -853,8 +900,10 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to check, if a group with the given name exists.
 
-        @param name name of the group to be checked for (string)
-        @return flag indicating an existing group (boolean)
+        @param name name of the group to be checked for
+        @type str
+        @return flag indicating an existing group
+        @rtype bool
         """
         return name in self.groups
 
@@ -862,8 +911,10 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to add a group.
 
-        @param name name of the group to be added (string)
-        @param language programming language for the group (string)
+        @param name name of the group to be added
+        @type str
+        @param language programming language for the group
+        @type str
         """
         if name not in self.groups:
             self.groups[name] = TemplateGroup(self, name, language)
@@ -873,9 +924,12 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to rename a group.
 
-        @param oldname old name of the group (string)
-        @param newname new name of the group (string)
-        @param language programming language for the group (string)
+        @param oldname old name of the group
+        @type str
+        @param newname new name of the group
+        @type str
+        @param language programming language for the group
+        @type str
         """
         if oldname != newname:
             if newname in self.groups:
@@ -900,7 +954,8 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to get all groups.
 
-        @return list of all groups (list of TemplateGroup)
+        @return list of all groups
+        @rtype list of TemplateGroup
         """
         return list(self.groups.values())
 
@@ -908,16 +963,18 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to get all group names.
 
-        @return list of all group names (list of strings)
+        @return list of all group names
+        @rtype list of str
         """
-        groups = sorted(list(self.groups.keys())[:])
+        groups = sorted(self.groups)
         return groups
 
     def removeGroup(self, itm):
         """
         Public method to remove a group.
 
-        @param itm template group to be removed (TemplateGroup)
+        @param itm template group to be removed
+        @type TemplateGroup
         """
         name = itm.getName()
         itm.removeAllEntries()
@@ -929,7 +986,8 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to remove a template entry.
 
-        @param itm template entry to be removed (TemplateEntry)
+        @param itm template entry to be removed
+        @type TemplateEntry
         """
         groupName = itm.getGroupName()
         self.groups[groupName].removeEntry(itm.getName())
@@ -938,12 +996,16 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to change a template entry.
 
-        @param itm template entry to be changed (TemplateEntry)
-        @param name new name for the entry (string)
+        @param itm template entry to be changed
+        @type TemplateEntry
+        @param name new name for the entry
+        @type str
         @param groupName name of the group the entry should belong to
-            (string)
-        @param description description of the entry (string)
-        @param template template text of the entry (string)
+        @type str
+        @param description description of the entry
+        @type str
+        @param template template text of the entry
+        @type str
         """
         if itm.getGroupName() != groupName:
             # move entry to another group
@@ -978,36 +1040,17 @@ class TemplateViewer(QTreeWidget):
 
     def readTemplates(self, filename=None):
         """
-        Public method to read in the templates file (.e4c).
+        Public method to read in the templates file (.ecj).
 
         @param filename name of a templates file to read
         @type str
         """
         if filename is None:
-            # new JSON based file first
             filename = os.path.join(Globals.getConfigDir(), "eric7templates.ecj")
             if not os.path.exists(filename):
-                # old XML based file second
-                filename = os.path.join(Globals.getConfigDir(), "eric7templates.e4c")
-                if not os.path.exists(filename):
-                    return
+                return
 
-        if filename.endswith(".ecj"):
-            self.__templatesFile.readFile(filename)
-        else:
-            f = QFile(filename)
-            if f.open(QIODevice.OpenModeFlag.ReadOnly):
-                reader = TemplatesReader(f, viewer=self)
-                reader.readXML()
-                f.close()
-            else:
-                EricMessageBox.critical(
-                    self,
-                    self.tr("Read Templates"),
-                    self.tr(
-                        "<p>The templates file <b>{0}</b> could not be read.</p>"
-                    ).format(filename),
-                )
+        self.__templatesFile.readFile(filename)
 
     def __configure(self):
         """
@@ -1019,10 +1062,13 @@ class TemplateViewer(QTreeWidget):
         """
         Public method to check, if an entry of the given name exists.
 
-        @param entryName name of the entry to check for (string)
-        @param groupName name of the group to check for the entry (string).
-            None or empty means to check all groups.
-        @return flag indicating the existence (boolean)
+        @param entryName name of the entry to check for
+        @type str
+        @param groupName name of the group to check for the entry. None or empty means
+            to check all groups.
+        @type str
+        @return flag indicating the existence
+        @rtype bool
         """
         if groupName:
             if self.hasGroup(groupName):
@@ -1039,10 +1085,13 @@ class TemplateViewer(QTreeWidget):
         Public method to get the names of templates starting with the
         given string.
 
-        @param start start string of the name (string)
-        @param groupName name of the group to get the entry from (string).
-            None or empty means to look in all groups.
-        @return sorted list of matching template names (list of strings)
+        @param start start string of the name
+        @type str
+        @param groupName name of the group to get the entry from. None or empty
+            means to look in all groups.
+        @type str
+        @return sorted list of matching template names
+        @rtype list of str
         """
         names = []
         if groupName:
