@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2022 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2022 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,6 +20,7 @@ from PyQt6.QtCore import (
     QCoreApplication,
     QModelIndex,
     QPoint,
+    QSortFilterProxyModel,
     Qt,
     pyqtSignal,
     pyqtSlot,
@@ -84,6 +85,7 @@ class TestResultsModel(QAbstractItemModel):
             }
 
         self.__testResults = []
+        self.__testResultsById = {}
 
     def index(self, row, column, parent=QModelIndex()):
         """
@@ -250,6 +252,7 @@ class TestResultsModel(QAbstractItemModel):
         """
         self.beginResetModel()
         self.__testResults.clear()
+        self.__testResultsById.clear()
         self.endResetModel()
 
         self.summary.emit("")
@@ -307,6 +310,9 @@ class TestResultsModel(QAbstractItemModel):
         """
         self.beginResetModel()
         self.__testResults = copy.deepcopy(testResults)
+        self.__testResultsById.clear()
+        for testResult in testResults:
+            self.__testResultsById[testResult.id] = testResult
         self.endResetModel()
 
         self.summary.emit(self.__summary())
@@ -323,6 +329,8 @@ class TestResultsModel(QAbstractItemModel):
         lastRow = firstRow + len(testResults) - 1
         self.beginInsertRows(QModelIndex(), firstRow, lastRow)
         self.__testResults.extend(testResults)
+        for testResult in testResults:
+            self.__testResultsById[testResult.id] = testResult
         self.endInsertRows()
 
         self.summary.emit(self.__summary())
@@ -340,17 +348,18 @@ class TestResultsModel(QAbstractItemModel):
         testResultsToBeAdded = []
 
         for testResult in testResults:
-            for (index, currentResult) in enumerate(self.__testResults):
-                if currentResult.id == testResult.id:
-                    self.__testResults[index] = testResult
-                    if minIndex is None:
-                        minIndex = index
-                        maxIndex = index
-                    else:
-                        minIndex = min(minIndex, index)
-                        maxIndex = max(maxIndex, index)
+            if testResult.id in self.__testResultsById:
+                result = self.__testResultsById[testResult.id]
+                index = self.__testResults.index(result)
+                self.__testResults[index] = testResult
+                self.__testResultsById[testResult.id] = testResult
+                if minIndex is None:
+                    minIndex = index
+                    maxIndex = index
+                else:
+                    minIndex = min(minIndex, index)
+                    maxIndex = max(maxIndex, index)
 
-                    break
             else:
                 # Test result with given id was not found.
                 # Just add it to the list (could be a sub test)
@@ -414,6 +423,62 @@ class TestResultsModel(QAbstractItemModel):
             counts[TestResultCategory.PENDING],
         )
 
+    def getStatusFilterList(self):
+        """
+        Public method to get a list of the unique test result status.
+
+        @return test result status
+        @rtype set of str
+        """
+        return {t.status for t in self.__testResults}
+
+
+class TestResultsFilterModel(QSortFilterProxyModel):
+    """
+    Class implementing a filter model to filter the test results by status.
+    """
+
+    def __init__(self, parent=None):
+        """
+        Constructor
+
+        @param parent reference to the parent object
+        @type QObject
+        """
+        super().__init__(parent)
+
+        self.__statusFilterString = ""
+
+    def filterAcceptsRow(self, sourceRow, sourceParent):
+        """
+        Public method to determine, if the row is acceptable.
+
+        @param sourceRow row number in the source model
+        @type int
+        @param sourceParent index of the source item
+        @type QModelIndex
+        @return flag indicating acceptance
+        @rtype bool
+        """
+        sm = self.sourceModel()
+        idx = sm.index(sourceRow, 0, sourceParent)
+        status = sm.data(idx, Qt.ItemDataRole.DisplayRole)
+        return (
+            sourceParent.isValid()
+            or self.__statusFilterString == ""
+            or status == self.__statusFilterString
+        )
+
+    def setStatusFilterString(self, filterString):
+        """
+        Public method to set the status filter string.
+
+        @param filterString status filter string
+        @type str
+        """
+        self.__statusFilterString = filterString
+        self.invalidateRowsFilter()
+
 
 class TestResultsTreeView(QTreeView):
     """
@@ -444,12 +509,12 @@ class TestResultsTreeView(QTreeView):
         self.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
 
         # connect signals and slots
-        self.doubleClicked.connect(self.__gotoTestDefinition)
+        self.activated.connect(self.__gotoTestDefinition)
         self.customContextMenuRequested.connect(self.__showContextMenu)
 
         self.header().sortIndicatorChanged.connect(self.sortByColumn)
         self.header().sortIndicatorChanged.connect(
-            lambda column, order: self.header().setSortIndicatorShown(True)
+            lambda col, order: self.header().setSortIndicatorShown(True)  # noqa: U100
         )
 
     def reset(self):
@@ -474,7 +539,6 @@ class TestResultsTreeView(QTreeView):
         """
         super().rowsInserted(parent, startRow, endRow)
 
-        self.resizeColumns()
         self.spanFirstColumn(startRow, endRow)
 
     def dataChanged(self, topLeft, bottomRight, roles=[]):
@@ -490,7 +554,6 @@ class TestResultsTreeView(QTreeView):
         """
         super().dataChanged(topLeft, bottomRight, roles)
 
-        self.resizeColumns()
         while topLeft.parent().isValid():
             topLeft = topLeft.parent()
         while bottomRight.parent().isValid():
@@ -553,7 +616,7 @@ class TestResultsTreeView(QTreeView):
         """
         cindex = self.__canonicalIndex(index)
         filename, lineno = self.model().data(cindex, Qt.ItemDataRole.UserRole)
-        if filename is not None:
+        if filename:
             if lineno is None:
                 lineno = 1
             self.goto.emit(filename, lineno)
@@ -597,7 +660,9 @@ class TestResultsTreeView(QTreeView):
         act = menu.addAction(
             self.tr("Show Source"), lambda: self.__gotoTestDefinition(index)
         )
-        act.setEnabled(self.model().data(index, Qt.ItemDataRole.UserRole) is not None)
+        act.setEnabled(
+            self.model().data(index, Qt.ItemDataRole.UserRole)[0] is not None
+        )
         menu.addSeparator()
 
         menu.addAction(self.tr("Collapse All"), self.collapseAll)
