@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2022 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2022 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -18,7 +18,7 @@ def supportedLanguages():
     @return list of supported programming languages
     @rtype list of str
     """
-    return list(FrameworkNames.keys())
+    return list(FrameworkNames)
 
 
 def isLanguageSupported(language):
