@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -139,6 +139,11 @@ class TrayStarter(QSystemTrayIcon):
             self.tr("Icon Editor"),
             self.__startIconEditor,
         )
+        self.__menu.addAction(
+            EricPixmapCache.getIcon("ericPdf"),
+            self.tr("PDF Viewer"),
+            self.__startPdfViewer,
+        )
         self.__menu.addSeparator()
 
         self.__menu.addAction(
@@ -163,6 +168,11 @@ class TrayStarter(QSystemTrayIcon):
             self.tr("Virtual Environments"),
             self.__startVirtualenvManager,
         )
+        self.__menu.addAction(
+            EricPixmapCache.getIcon("pypi"),
+            self.tr("PyPI Package Management"),
+            self.__startPip,
+        )
         self.__menu.addSeparator()
 
         self.__menu.addAction(
@@ -267,7 +277,7 @@ class TrayStarter(QSystemTrayIcon):
         Private slot to handle the activated signal.
 
         @param reason reason code of the signal
-            (QSystemTrayIcon.ActivationReason)
+        @type QSystemTrayIcon.ActivationReason
         """
         if reason in (
             QSystemTrayIcon.ActivationReason.Context,
@@ -296,8 +306,10 @@ class TrayStarter(QSystemTrayIcon):
         """
         Private method to start an eric application.
 
-        @param applName name of the eric application script (string)
+        @param applName name of the eric application script
+        @type str
         @param *applArgs variable list of application arguments
+        @type list of str
         """
         proc = QProcess()
         applPath = os.path.join(os.path.dirname(__file__), "..", applName)
@@ -365,6 +377,12 @@ class TrayStarter(QSystemTrayIcon):
         """
         self.__startProc("eric7_virtualenv.py")
 
+    def __startPip(self):
+        """
+        Private slot to start the eric package manager (PyPI) window.
+        """
+        self.__startProc("eric7_pip.py")
+
     def __startWebBrowser(self):
         """
         Private slot to start the eric web browser.
@@ -461,6 +479,12 @@ class TrayStarter(QSystemTrayIcon):
         """
         self.__startProc("eric7_shell.py")
 
+    def __startPdfViewer(self):
+        """
+        Private slot to start the eric PDF Viewer window.
+        """
+        self.__startProc("eric7_pdf.py")
+
     def __showRecentProjectsMenu(self):
         """
         Private method to set up the recent projects menu.
@@ -523,7 +547,8 @@ class TrayStarter(QSystemTrayIcon):
         Private method to open a project or file from the list of recently
         opened projects or files.
 
-        @param act reference to the action that triggered (QAction)
+        @param act reference to the action that triggered
+        @type QAction
         """
         filename = act.data()
         if filename:
