@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -53,8 +53,10 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Constructor
 
-        @param mode mode of this dialog (string, "bug" or "feature")
-        @param parent parent widget of this dialog (QWidget)
+        @param mode mode of this dialog ("bug" or "feature")
+        @type str
+        @param parent parent widget of this dialog
+        @type QWidget
         """
         super().__init__(parent)
         self.setupUi(self)
@@ -117,7 +119,8 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Protected method to handle the user pressing the escape key.
 
-        @param ev key event (QKeyEvent)
+        @param ev key event
+        @type QKeyEvent
         """
         if ev.key() == Qt.Key.Key_Escape:
             res = EricMessageBox.yesNo(
@@ -132,7 +135,8 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Private slot called by a button of the button box clicked.
 
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.sendButton:
             self.on_sendButton_clicked()
@@ -158,7 +162,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         if self.__helpDialog is None:
             try:
-                from eric7.EricNetwork.EricGoogleMail import (  # __IGNORE_WARNING__
+                from eric7.EricNetwork.EricGoogleMail import (  # noqa: I101
                     GoogleMailHelp,
                 )
 
@@ -206,8 +210,10 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Private method to create a MIMEText message with correct encoding.
 
-        @param txt text to be put into the MIMEText object (string)
+        @param txt text to be put into the MIMEText object
+        @type str
         @return MIMEText object
+        @rtype email.mime.text.MIMEText
         """
         try:
             txt.encode("us-ascii")
@@ -220,8 +226,10 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Private method to create a correctly encoded mail header.
 
-        @param txt header text to encode (string)
-        @return encoded header (email.header.Header)
+        @param txt header text to encode
+        @type str
+        @return encoded header
+        @rtype email.header.Header
         """
         try:
             txt.encode("us-ascii")
@@ -320,8 +328,10 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Private method to actually send the message.
 
-        @param msg the message to be sent (string)
-        @return flag indicating success (boolean)
+        @param msg the message to be sent
+        @type str
+        @return flag indicating success
+        @rtype bool
         """
         try:
             encryption = Preferences.getUser("MailServerEncryption")
@@ -352,7 +362,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
                         return False
                 try:
                     server.login(Preferences.getUser("MailServerUser"), password)
-                except (smtplib.SMTPException, OSError) as e:
+                except (OSError, smtplib.SMTPException) as e:
                     if isinstance(e, smtplib.SMTPResponseException):
                         errorStr = e.smtp_error.decode()
                     elif isinstance(e, OSError):
@@ -377,7 +387,7 @@ class EmailDialog(QDialog, Ui_EmailDialog):
             with EricOverrideCursor():
                 server.sendmail(Preferences.getUser("Email"), self.__toAddress, msg)
                 server.quit()
-        except (smtplib.SMTPException, OSError) as e:
+        except (OSError, smtplib.SMTPException) as e:
             if isinstance(e, smtplib.SMTPResponseException):
                 errorStr = e.smtp_error.decode()
             elif isinstance(e, smtplib.SMTPException):
@@ -464,9 +474,11 @@ class EmailDialog(QDialog, Ui_EmailDialog):
         """
         Public method to add an attachment.
 
-        @param fname name of the file to be attached (string)
+        @param fname name of the file to be attached
+        @type str
         @param deleteFile flag indicating to delete the file after it has
-            been sent (boolean)
+            been sent
+        @type bool
         """
         mimeType = mimetypes.guess_type(fname)[0]
         if not mimeType:
@@ -492,11 +504,13 @@ class EmailDialog(QDialog, Ui_EmailDialog):
             )
             del itm
 
+    @pyqtSlot(str)
     def on_subject_textChanged(self, txt):
         """
         Private slot to handle the textChanged signal of the subject edit.
 
-        @param txt changed text (string)
+        @param txt changed text
+        @type str
         """
         self.sendButton.setEnabled(
             self.subject.text() != "" and self.message.toPlainText() != ""
