@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to search for text in files.
 """
 
+import json
 import os
 import re
 import time
@@ -83,11 +84,15 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         super().__init__(parent)
         self.setupUi(self)
 
+        self.__project = project
+
         self.layout().setContentsMargins(0, 3, 0, 0)
 
         self.caseToolButton.setIcon(EricPixmapCache.getIcon("caseSensitive"))
         self.wordToolButton.setIcon(EricPixmapCache.getIcon("wholeWord"))
+        self.escapeToolButton.setIcon(EricPixmapCache.getIcon("esc-code"))
         self.regexpToolButton.setIcon(EricPixmapCache.getIcon("regexp"))
+        self.filtersConfigButton.setIcon(EricPixmapCache.getIcon("edit"))
 
         self.dirPicker.setMode(EricPathPickerModes.DIRECTORY_MODE)
         self.dirPicker.setInsertPolicy(QComboBox.InsertPolicy.InsertAtTop)
@@ -147,8 +152,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
             )
         )
 
-        self.__project = project
-
+        self.__populateFiltersSelector()
         self.populateFileCategories()
 
         # ensure the file type tab is the current one
@@ -173,6 +177,38 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         self.__replaceMode = True
         self.__toggleReplaceMode()
 
+    def __populateFiltersSelector(self):
+        """
+        Private method to (re-)populate the file filters selector.
+        """
+        currentFilter = self.filterComboBox.currentText()
+        self.filterComboBox.clear()
+
+        # add standard entries
+        self.filterComboBox.addItem("")
+        self.filterComboBox.addItem(self.tr("All Files"), ["*"])
+
+        # add configured entries
+        # FileFilters is a dictionary with the filter name as key and
+        # a list of file name patterns as value
+        self.__filters = json.loads(
+            Preferences.getSettings().value("FindFileWidget/FileFilters", "{}")
+            # noqa: M613
+        )
+        for fileFilter in sorted(self.__filters):
+            self.filterComboBox.addItem(
+                self.tr("{0} ({1})").format(
+                    fileFilter, " ".join(self.__filters[fileFilter])
+                ),
+                self.__filters[fileFilter],
+            )
+
+        # reselect the current entry
+        index = self.filterComboBox.findText(currentFilter)
+        if index == -1:
+            index = 0
+        self.filterComboBox.setCurrentIndex(index)
+
     def populateFileCategories(self):
         """
         Public method to populate the search file categories list.
@@ -345,6 +381,45 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         if self.projectButton.isChecked():
             self.dirButton.setChecked(True)
 
+    @pyqtSlot(bool)
+    def on_escapeToolButton_toggled(self, checked):
+        """
+        Private slot handling a change of the escape selector.
+
+        @param checked state of the escape selector
+        @type bool
+        """
+        if checked:
+            # only one of regexp or escape can be selected
+            self.regexpToolButton.setChecked(False)
+
+    @pyqtSlot(bool)
+    def on_regexpToolButton_toggled(self, checked):
+        """
+        Private slot handling a change of the regexp selector.
+
+        @param checked state of the regexp selector
+        @type bool
+        """
+        if checked:
+            # only one of regexp or escape can be selected
+            self.escapeToolButton.setChecked(False)
+
+    @pyqtSlot()
+    def on_filtersConfigButton_clicked(self):
+        """
+        Private slot to edit the list of defined file filter entries.
+        """
+        from .FindFileFiltersEditDialog import FindFileFiltersEditDialog
+
+        dlg = FindFileFiltersEditDialog(self.__filters, self)
+        if dlg.exec() == QDialog.DialogCode.Accepted:
+            filters = dlg.getFilters()
+            Preferences.getSettings().setValue(
+                "FindFileWidget/FileFilters", json.dumps(filters)
+            )
+            self.__populateFiltersSelector()
+
     @pyqtSlot(str)
     def on_findtextCombo_editTextChanged(self, text):
         """
@@ -352,6 +427,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         text combo.
 
         @param text (ignored)
+        @type str
         """
         self.__enableFindButton()
 
@@ -362,6 +438,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         text combo.
 
         @param text (ignored)
+        @type str
         """
         self.__enableFindButton()
 
@@ -372,6 +449,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         picker.
 
         @param text (ignored)
+        @type str
         """
         self.__enableFindButton()
 
@@ -403,12 +481,13 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         """
         self.__enableFindButton()
 
-    @pyqtSlot(str)
-    def on_filterEdit_textEdited(self, text):
+    @pyqtSlot(int)
+    def on_filterComboBox_currentIndexChanged(self, index):
         """
-        Private slot to handle the textChanged signal of the file filter edit.
+        Private slot to handle the selection of a file filter.
 
-        @param text (ignored)
+        @param index index of the selected entry
+        @type int
         """
         self.__enableFindButton()
 
@@ -426,7 +505,11 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                     or not os.path.exists(os.path.abspath(self.dirPicker.currentText()))
                 )
             )
-            or (self.filterCheckBox.isChecked() and self.filterEdit.text() == "")
+            or (
+                self.filterCheckBox.isChecked()
+                and self.filterComboBox.currentText() == ""
+            )
+            or (self.projectButton.isChecked() and not self.__project.isOpen())
         ):
             self.findButton.setEnabled(False)
         else:
@@ -441,7 +524,21 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         @return text with eol stripped
         @rtype str
         """
-        return txt.replace("\r", "").replace("\n", "")
+        return txt.rstrip("\n\r")
+
+    def __buildReFileFilter(self, fileFilter):
+        """
+        Private method to convert a file filter expression into a valid re search
+        pattern.
+
+        @param fileFilter file filter expression
+        @type str
+        @return re search pattern with dot, question mark and star converted
+        @rtype str
+        """
+        return "^{0}$".format(
+            fileFilter.strip().replace(".", r"\.").replace("*", ".*").replace("?", ".")
+        )
 
     @pyqtSlot()
     def __stopSearch(self):
@@ -464,12 +561,11 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         self.__cancelSearch = False
 
         if self.filterCheckBox.isChecked():
-            fileFilter = self.filterEdit.text()
-            fileFilterList = [
-                "^{0}$".format(filter.replace(".", r"\.").replace("*", ".*"))
-                for filter in fileFilter.split(";")
-            ]
-            filterRe = re.compile("|".join(fileFilterList))
+            fileFilter = self.filterComboBox.currentData()
+            fileFilterPattern = "|".join(
+                self.__buildReFileFilter(filter) for filter in fileFilter
+            )
+            filterRe = re.compile(fileFilterPattern)
 
         if self.projectButton.isChecked():
             if self.filterCheckBox.isChecked():
@@ -500,9 +596,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                         if itm.checkState() == Qt.CheckState.Checked:
                             filters.extend(
                                 [
-                                    "^{0}$".format(
-                                        assoc.replace(".", r"\.").replace("*", ".*")
-                                    )
+                                    self.__buildReFileFilter(assoc)
                                     for assoc in self.__project.getFiletypeAssociations(
                                         itm.data(Qt.ItemDataRole.UserRole)
                                     )
@@ -516,12 +610,8 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                             if fileType == "SOURCES":
                                 filters.extend(
                                     [
-                                        "^{0}$".format(
-                                            assoc.replace(".", r"\.").replace("*", ".*")
-                                        )
-                                        for assoc in list(
-                                            Preferences.getEditorLexerAssocs().keys()
-                                        )
+                                        self.__buildReFileFilter(assoc)
+                                        for assoc in Preferences.getEditorLexerAssocs()
                                         if assoc
                                         not in self.__project.getFileCategoryExtension(
                                             fileType, reverse=True
@@ -531,9 +621,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                             else:
                                 filters.extend(
                                     [
-                                        "^{0}$".format(
-                                            ext.replace(".", r"\.").replace("*", ".*")
-                                        )
+                                        self.__buildReFileFilter(ext)
                                         for ext in self.__project.getFileCategoryExtension(
                                             # __IGNORE_WARNING__
                                             fileType
@@ -558,11 +646,13 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         self.findProgress.setMaximum(len(files))
 
         # retrieve the values
+        esc = self.escapeToolButton.isChecked()
         reg = self.regexpToolButton.isChecked()
         wo = self.wordToolButton.isChecked()
         cs = self.caseToolButton.isChecked()
         ct = self.findtextCombo.currentText()
-        txt = ct if reg else re.escape(ct)
+        txt = Utilities.unslash(ct) if esc else ct
+        txt = txt if reg else re.escape(txt)
         if wo:
             txt = "\\b{0}\\b".format(txt)
         flags = re.UNICODE
@@ -605,6 +695,8 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
             Preferences.getSettings().setValue(
                 "FindFileWidget/ReplaceHistory", self.replaceHistory[:30]
             )
+            if esc:
+                replTxt = Utilities.unslash(replTxt)
 
         if self.dirButton.isChecked():
             searchDir = self.dirPicker.currentText()
@@ -643,7 +735,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
             try:
                 text, encoding, hashStr = Utilities.readEncodedFileWithHash(fn)
                 lines = text.splitlines(True)
-            except (UnicodeError, OSError):
+            except (OSError, UnicodeError):
                 self.findProgress.setValue(progress)
                 continue
 
@@ -663,13 +755,20 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                         rline = search.sub(replTxt, line)
                     else:
                         rline = ""
-                    line = self.__stripEol(line)
+                    line = Utilities.slash(line) if esc else self.__stripEol(line)
                     if len(line) > 1024:
                         line = "{0} ...".format(line[:1024])
                     if self.__replaceMode:
                         if len(rline) > 1024:
                             rline = "{0} ...".format(line[:1024])
-                        line = "- {0}\n+ {1}".format(line, self.__stripEol(rline))
+                        line = "- {0}\n+ {1}".format(
+                            line,
+                            "\n  ".join(
+                                Utilities.slash(rl) for rl in rline.splitlines(True)
+                            )
+                            if esc
+                            else self.__stripEol(rline),
+                        )
                     self.__createItem(file, count, line, start, end, rline, hashStr)
 
                 if time.monotonic() - now > 0.01:
@@ -753,7 +852,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
             self.linguistFile.emit(fileName)
         elif fileExt == ".qm":
             self.trpreview.emit([fileName])
-        elif fileExt in (".egj", ".e5g"):
+        elif fileExt in (".egj",):
             self.umlFile.emit(fileName)
         elif fileExt == ".svg":
             self.svgFile.emit(fileName)
@@ -845,7 +944,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                 try:
                     text, encoding, hashStr = Utilities.readEncodedFileWithHash(fn)
                     lines = text.splitlines(True)
-                except (UnicodeError, OSError) as err:
+                except (OSError, UnicodeError) as err:
                     EricMessageBox.critical(
                         self,
                         self.tr("Replace in Files"),
@@ -884,7 +983,7 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
                 txt = "".join(lines)
                 try:
                     Utilities.writeEncodedFile(fn, txt, encoding)
-                except (OSError, Utilities.CodingError, UnicodeError) as err:
+                except (OSError, UnicodeError, Utilities.CodingError) as err:
                     EricMessageBox.critical(
                         self,
                         self.tr("Replace in Files"),
@@ -911,35 +1010,44 @@ class FindFileWidget(QWidget, Ui_FindFileWidget):
         @param pos position the context menu shall be shown
         @type QPoint
         """
-        menu = QMenu(self)
+        if self.findList.topLevelItemCount() and (
+            self.findList.selectedItems() or self.__replaceMode
+        ):
+            menu = QMenu(self)
 
-        menu.addAction(self.tr("Open"), self.__openFile)
-        menu.addAction(self.tr("Copy Path to Clipboard"), self.__copyToClipboard)
-        if self.__replaceMode:
-            menu.addSeparator()
-            menu.addAction(self.tr("Select All"), self.__selectAll)
-            menu.addAction(self.tr("Deselect All"), self.__deselectAll)
+            if self.findList.selectedItems():
+                menu.addAction(self.tr("Open"), self.__openFile)
+                menu.addAction(
+                    self.tr("Copy Path to Clipboard"), self.__copyToClipboard
+                )
+            if self.__replaceMode:
+                menu.addSeparator()
+                menu.addAction(self.tr("Select All"), self.__selectAll)
+                menu.addAction(self.tr("Deselect All"), self.__deselectAll)
 
-        menu.exec(QCursor.pos())
+            menu.exec(QCursor.pos())
 
     @pyqtSlot()
     def __openFile(self):
         """
         Private slot to open the currently selected entry.
         """
-        itm = self.findList.selectedItems()[0]
-        self.on_findList_itemDoubleClicked(itm, 0)
+        selectedItems = self.findList.selectedItems()
+        if selectedItems:
+            self.on_findList_itemDoubleClicked(selectedItems[0], 0)
 
     @pyqtSlot()
     def __copyToClipboard(self):
         """
         Private slot to copy the path of an entry to the clipboard.
         """
-        itm = self.findList.selectedItems()[0]
-        fn = itm.parent().text(0) if itm.parent() else itm.text(0)
+        selectedItems = self.findList.selectedItems()
+        if selectedItems:
+            itm = selectedItems[0]
+            fn = itm.parent().text(0) if itm.parent() else itm.text(0)
 
-        cb = QApplication.clipboard()
-        cb.setText(fn)
+            cb = QApplication.clipboard()
+            cb.setText(fn)
 
     @pyqtSlot()
     def __deselectAll(self):
