@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a previewer widget for HTML, Markdown and ReST files.
 """
 
-import contextlib
+import importlib.util
 import io
 import os
 import re
@@ -43,7 +43,8 @@ class PreviewerHTML(QWidget):
         """
         Constructor
 
-        @param parent reference to the parent widget (QWidget)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
 
@@ -144,7 +145,8 @@ class PreviewerHTML(QWidget):
         """
         Private slot to enable/disable JavaScript.
 
-        @param checked state of the checkbox (boolean)
+        @param checked state of the checkbox
+        @type bool
         """
         Preferences.setUI("ShowFilePreviewJS", checked)
         self.__setJavaScriptEnabled(checked)
@@ -153,12 +155,13 @@ class PreviewerHTML(QWidget):
         """
         Private method to enable/disable JavaScript.
 
-        @param enable flag indicating the enable state (boolean)
+        @param enable flag indicating the enable state
+        @type bool
         """
         self.jsCheckBox.setChecked(enable)
 
         settings = self.previewView.settings()
-        settings.setAttribute(settings.JavascriptEnabled, enable)
+        settings.setAttribute(settings.WebAttribute.JavascriptEnabled, enable)
 
         self.processEditor()
 
@@ -167,7 +170,8 @@ class PreviewerHTML(QWidget):
         """
         Private slot to enable/disable SSI.
 
-        @param checked state of the checkbox (boolean)
+        @param checked state of the checkbox
+        @type bool
         """
         Preferences.setUI("ShowFilePreviewSSI", checked)
         self.processEditor()
@@ -186,7 +190,8 @@ class PreviewerHTML(QWidget):
         """
         Public slot to process an editor's text.
 
-        @param editor editor to be processed (Editor)
+        @param editor editor to be processed
+        @type Editor
         """
         if not self.__previewAvailable:
             return
@@ -278,7 +283,8 @@ class PreviewerHTML(QWidget):
         """
         Private slot to handle a change of the title.
 
-        @param title new title (string)
+        @param title new title
+        @type str
         """
         if title:
             self.titleLabel.setText(self.tr("Preview - {0}").format(title))
@@ -367,7 +373,8 @@ class PreviewProcessingThread(QThread):
         """
         Constructor
 
-        @param parent reference to the parent object (QObject)
+        @param parent reference to the parent object
+        @type QObject
         """
         super().__init__()
 
@@ -531,11 +538,14 @@ class PreviewProcessingThread(QThread):
 
         Note: Only a limited subset of SSI statements are supported.
 
-        @param txt text to be processed (string)
+        @param txt text to be processed
+        @type str
         @param filename name of the file associated with the given text
-            (string)
-        @param root directory of the document root (string)
-        @return processed HTML (string)
+        @type str
+        @param root directory of the document root
+        @type str
+        @return processed HTML
+        @rtype str
         """
         if not filename:
             return txt
@@ -615,12 +625,15 @@ class PreviewProcessingThread(QThread):
         """
         Private method to convert ReST text into HTML.
 
-        @param text text to be processed (string)
+        @param text text to be processed
+        @type str
         @param useSphinx flag indicating to use Sphinx to generate the
-            ReST preview (boolean)
+            ReST preview
+        @type bool
         @param restDocutilsHtmlFormat HTML format to be generated by docutils
-            (string)
-        @return processed HTML (string)
+        @type str
+        @return processed HTML
+        @rtype str
         """
         if useSphinx:
             return self.__convertReSTSphinx(text)
@@ -631,8 +644,10 @@ class PreviewProcessingThread(QThread):
         """
         Private method to convert ReST text into HTML using 'sphinx'.
 
-        @param text text to be processed (string)
-        @return processed HTML (string)
+        @param text text to be processed
+        @type str
+        @return processed HTML
+        @rtype str
         """
         try:
             from sphinx.application import (  # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
@@ -693,14 +708,17 @@ class PreviewProcessingThread(QThread):
         """
         Private method to convert ReST text into HTML using 'docutils'.
 
-        @param text text to be processed (string)
-        @param htmlFormat HTML format to be generated (string)
-        @return processed HTML (string)
+        @param text text to be processed
+        @type str
+        @param htmlFormat HTML format to be generated
+        @type str
+        @return processed HTML
+        @rtype str
         """
         if "sphinx" in sys.modules:
             # Make sure any Sphinx polution of docutils has been removed.
             unloadKeys = [
-                k for k in sys.modules.keys() if k.startswith(("docutils", "sphinx"))
+                k for k in sys.modules if k.startswith(("docutils", "sphinx"))
             ]
             for key in unloadKeys:
                 sys.modules.pop(key)
@@ -778,26 +796,23 @@ class PreviewProcessingThread(QThread):
             extensions.append("nl2br")
 
         pyMdown = False
-        if usePyMdownExtensions:
-            with contextlib.suppress(ImportError):
-                import pymdownx  # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
+        if usePyMdownExtensions and bool(importlib.util.find_spec("pymdownx")):
+            # PyPI package is 'pymdown-extensions'
 
-                # PyPI package is 'pymdown-extensions'
-
-                extensions.extend(
-                    [
-                        "toc",
-                        "pymdownx.extra",
-                        "pymdownx.caret",
-                        "pymdownx.emoji",
-                        "pymdownx.mark",
-                        "pymdownx.tilde",
-                        "pymdownx.keys",
-                        "pymdownx.tasklist",
-                        "pymdownx.smartsymbols",
-                    ]
-                )
-                pyMdown = True
+            extensions.extend(
+                [
+                    "toc",
+                    "pymdownx.extra",
+                    "pymdownx.caret",
+                    "pymdownx.emoji",
+                    "pymdownx.mark",
+                    "pymdownx.tilde",
+                    "pymdownx.keys",
+                    "pymdownx.tasklist",
+                    "pymdownx.smartsymbols",
+                ]
+            )
+            pyMdown = True
 
         if not pyMdown:
             extensions.extend(["extra", "toc"])
