@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2020 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -175,7 +175,7 @@ class PythonDisViewer(QWidget, Ui_PythonDisViewer):
         if editor and editor is self.__editor:
             self.__loadDIS()
 
-    def __editorLineChanged(self, editor, lineno):
+    def __editorLineChanged(self, editor, lineno):  # noqa: U100
         """
         Private slot to handle a mouse button double click in the editor.
 
