@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -189,12 +189,11 @@ class BackgroundService(QTcpServer):
         @type str
         @exception RuntimeError raised if hashes don't match
         """
+        data = ""
+        fx = ""
+
         connection = self.connections[lang]
         while connection.bytesAvailable():
-            if self.__cancelled:
-                connection.readAll()
-                continue
-
             header = connection.read(struct.calcsize(b"!II"))
             length, datahash = struct.unpack(b"!II", header)
 
@@ -266,32 +265,38 @@ class BackgroundService(QTcpServer):
                         )
                 if res != EricMessageBox.No:
                     self.isWorking = None
-                    self.restartService(lang, True)
+                    self.restartService(lang, forceKill=True)
                     return
             elif data == "Unknown service.":
                 callback = self.services.get((fx, lang))
                 if callback:
                     callback[3](fx, lang, fn, data)
             elif fx.startswith("batch_"):
-                fx = fx.replace("batch_", "")
+                mfx = fx.replace("batch_", "")
                 if data != "__DONE__":
-                    callback = self.services.get((fx, lang))
+                    callback = self.services.get((mfx, lang))
                     if callback:
                         if isinstance(data, (list, tuple)):
                             callback[2](fn, *data)
                         elif isinstance(data, str):
-                            callback[3](fx, lang, fn, data)
+                            callback[3](mfx, lang, fn, data)
                     if data == "Unknown batch service.":
-                        self.batchJobDone.emit(fx, lang)
+                        self.batchJobDone.emit(mfx, lang)
                         self.__cancelled = True
                 else:
-                    self.batchJobDone.emit(fx, lang)
+                    self.batchJobDone.emit(mfx, lang)
                     self.restartService(lang, forceKill=True)
             else:
                 callback = self.services.get((fx, lang))
                 if callback:
                     callback[2](fn, *data)
 
+        if self.__cancelled and data != "__DONE__" and fx.startswith("batch_"):
+            # If it is a canceled batch job perform the batch done logic.
+            fx = fx.replace("batch_", "")
+            self.batchJobDone.emit(fx, lang)
+            self.restartService(lang, forceKill=True)
+
         self.isWorking = None
         self.__processQueue()
 
@@ -380,8 +385,6 @@ class BackgroundService(QTcpServer):
         @param lang language to connect to
         @type str
         """
-        self.__cancelled = True
-
         entriesToRemove = []
         for pendingArg in self.__queue:
             if pendingArg[:2] == [fx, lang]:
@@ -397,6 +400,8 @@ class BackgroundService(QTcpServer):
             connection.write(header)
             connection.write(b"CANCEL")  # 6 character message type
 
+        self.__cancelled = True
+
     def serviceConnect(
         self,
         fx,
@@ -422,7 +427,7 @@ class BackgroundService(QTcpServer):
         @param callback function called on service response
         @type function
         @param onErrorCallback function called, if client isn't available
-            (function)
+        @type function
         @param onBatchDone function called when a batch job is done
         @type function
         """
@@ -521,10 +526,11 @@ class BackgroundService(QTcpServer):
         self.close()
 
         for connection in self.connections.values():
-            connection.readyRead.disconnect()
-            connection.disconnected.disconnect()
-            connection.close()
-            connection.deleteLater()
+            with contextlib.suppress(RuntimeError):
+                connection.readyRead.disconnect()
+                connection.disconnected.disconnect()
+                connection.close()
+                connection.deleteLater()
 
         for process, _interpreter in self.processes.values():
             process.close()
