@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,6 +10,7 @@ Parse enough of a Python file to recognize class and method definitions and
 to find out the superclasses of a class as well as its attributes.
 """
 
+import keyword
 import re
 import sys
 
@@ -70,8 +71,8 @@ _getnext = QRegularExpression(
         ^
         (?P<MethodIndent> [ \t]* )
         (?: async [ \t]+ )? (?: cdef | cpdef | def) [ \t]+
-        (?P<MethodName> \w+ )
-        (?: [ \t]* \[ (?: plain | html ) \] )?
+        (?P<MethodName> [\pL_] \w* )
+        (?: [ \t]* \[ [^\]]+ \] )?
         [ \t]* \(
         (?P<MethodSignature> (?: [^)] | \)[ \t]*,? )*? )
         \) [ \t]*
@@ -84,7 +85,8 @@ _getnext = QRegularExpression(
         (?P<ClassIndent> [ \t]* )
         (?: cdef [ \t]+ )?
         class [ \t]+
-        (?P<ClassName> \w+ )
+        (?P<ClassName> [\pL_] \w* )
+        (?: [ \t]* \[ [^\]]+ \] )?
         [ \t]*
         (?P<ClassSupers> \( [^)]* \) )?
         [ \t]* :
@@ -94,17 +96,32 @@ _getnext = QRegularExpression(
         ^
         (?P<AttributeIndent> [ \t]* )
         self [ \t]* \. [ \t]*
-        (?P<AttributeName> \w+ )
+        (?P<AttributeName> [\pL_] \w* )
         [ \t]* =
     )
 
+|   (?P<TypedAttribute>
+        ^
+        (?P<TypedAttributeIndent> [ \t]* )
+        self [ \t]* \. [ \t]*
+        (?P<TypedAttributeName> [\pL_] \w* )
+        [ \t]* : [ \t]+
+    )
+
 |   (?P<Variable>
         ^
         (?P<VariableIndent> [ \t]* )
-        (?P<VariableName> \w+ )
+        (?P<VariableName> [\pL_] \w* )
         [ \t]* =
     )
 
+|   (?P<TypedVariable>
+        ^
+        (?P<TypedVariableIndent> [ \t]* )
+        (?P<TypedVariableName> [\pL_] \w* )
+        [ \t]* :
+    )
+
 |   (?P<Main>
         ^
         if \s+ __name__ \s* == \s* [^:]+ : $
@@ -173,10 +190,15 @@ class Class(ClbrBaseClasses.Class, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this class
+        @type str
         @param name name of this class
+        @type str
         @param superClasses list of class names this class is inherited from
+        @type list of str
         @param file filename containing this class
+        @type str
         @param lineno linenumber of the class definition
+        @type int
         """
         ClbrBaseClasses.Class.__init__(self, module, name, superClasses, file, lineno)
         VisibilityMixin.__init__(self)
@@ -202,13 +224,21 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this function
+        @type str
         @param name name of this function
+        @type str
         @param file filename containing this class
+        @type str
         @param lineno linenumber of the class definition
+        @type int
         @param signature parameterlist of the method
+        @type str
         @param separator string separating the parameters
+        @type str
         @param modifierType type of the function
+        @type int
         @param annotation return annotation
+        @type str
         """
         ClbrBaseClasses.Function.__init__(
             self,
@@ -234,9 +264,13 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this class
+        @type str
         @param name name of this class
+        @type str
         @param file filename containing this attribute
+        @type str
         @param lineno linenumber of the class definition
+        @type int
         """
         ClbrBaseClasses.Attribute.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
@@ -264,8 +298,10 @@ class Imports:
         """
         Constructor
 
-        @param module name of the module containing the import (string)
-        @param file file name containing the import (string)
+        @param module name of the module containing the import
+        @type str
+        @param file file name containing the import
+        @type str
         """
         self.module = module
         self.name = "import"
@@ -276,9 +312,12 @@ class Imports:
         """
         Public method to add a list of imported names.
 
-        @param moduleName name of the imported module (string)
-        @param names list of names (list of strings)
+        @param moduleName name of the imported module
+        @type str
+        @param names list of names
+        @type list of str
         @param lineno line number of the import
+        @type int
         """
         if moduleName not in self.imports:
             module = ImportedModule(self.module, self.file, moduleName)
@@ -291,8 +330,10 @@ class Imports:
         """
         Public method to get an imported module item.
 
-        @param moduleName name of the imported module (string)
-        @return imported module item (ImportedModule) or None
+        @param moduleName name of the imported module
+        @type str
+        @return imported module item
+        @rtype ImportedModule
         """
         if moduleName in self.imports:
             return self.imports[moduleName]
@@ -305,6 +346,7 @@ class Imports:
 
         @return dictionary of imported module names with name as key and list
             of line numbers of imports as value
+        @rtype dict
         """
         return self.imports
 
@@ -318,9 +360,12 @@ class ImportedModule:
         """
         Constructor
 
-        @param module name of the module containing the import (string)
-        @param file file name containing the import (string)
-        @param importedModule name of the imported module (string)
+        @param module name of the module containing the import
+        @type str
+        @param file file name containing the import
+        @type str
+        @param importedModule name of the imported module
+        @type str
         """
         self.module = module
         self.name = "import"
@@ -336,7 +381,9 @@ class ImportedModule:
         Public method to add a list of imported names.
 
         @param lineno line number of the import
-        @param importedNames list of imported names (list of strings)
+        @type int
+        @param importedNames list of imported names
+        @type list of str
         """
         if lineno not in self.linenos:
             self.linenos.append(lineno)
@@ -381,7 +428,7 @@ def readmodule_ex(module, path=None, isTypeFile=False):
 
     try:
         src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, OSError):
+    except (OSError, UnicodeError):
         # can't do anything with this module
         return {}
 
@@ -454,11 +501,11 @@ def scan(src, file, module):
             break
         start, i = m.capturedStart(), m.capturedEnd()
 
-        if m.hasCaptured("MethodModifier"):
+        if m.captured("MethodModifier"):
             modifierIndent = _indent(m.captured("MethodModifierIndent"))
             modifierType = m.captured("MethodModifierType")
 
-        elif m.hasCaptured("Method"):
+        elif m.captured("Method"):
             # found a method definition or function
             thisindent = _indent(m.captured("MethodIndent"))
             meth_name = m.captured("MethodName")
@@ -495,7 +542,7 @@ def scan(src, file, module):
                     deltaindentcalculated = False
             # close all classes indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                del classstack[-1]
+                classstack.pop()
             if classstack:
                 # it's a class method
                 cur_class = classstack[-1][0]
@@ -539,15 +586,15 @@ def scan(src, file, module):
             modifierType = ClbrBaseClasses.Function.General
             modifierIndent = -1
 
-        elif m.hasCaptured("String"):
+        elif m.captured("String"):
             pass
 
-        elif m.hasCaptured("Class"):
+        elif m.captured("Class"):
             # we found a class definition
             thisindent = _indent(m.captured("ClassIndent"))
             # close all classes indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                del classstack[-1]
+                classstack.pop()
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
             class_name = m.captured("ClassName")
@@ -606,7 +653,11 @@ def scan(src, file, module):
                 classstack[-1][0]._addclass(class_name, cur_class)
             classstack.append((cur_class, thisindent))
 
-        elif m.hasCaptured("Attribute"):
+        elif m.captured("Attribute") or m.captured("TypedAttribute"):
+            if m.captured("Attribute"):
+                attribute_name = m.captured("AttributeName")
+            else:
+                attribute_name = m.captured("TypedAttributeName")
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
             index = -1
@@ -614,21 +665,28 @@ def scan(src, file, module):
                 if classstack[index][0] is not None and not isinstance(
                     classstack[index][0], Function
                 ):
-                    attr = Attribute(module, m.captured("AttributeName"), file, lineno)
+                    attr = Attribute(module, attribute_name, file, lineno)
                     classstack[index][0]._addattribute(attr)
                     break
                 else:
                     index -= 1
 
-        elif m.hasCaptured("Main"):
+        elif m.captured("Main"):
             # 'main' part of the script, reset class stack
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
             classstack = []
 
-        elif m.hasCaptured("Variable"):
-            thisindent = _indent(m.captured("VariableIndent"))
-            variable_name = m.captured("VariableName")
+        elif m.captured("Variable") or m.captured("TypedVariable"):
+            if m.captured("Variable"):
+                thisindent = _indent(m.captured("VariableIndent"))
+                variable_name = m.captured("VariableName")
+            else:
+                thisindent = _indent(m.captured("TypedVariableIndent"))
+                variable_name = m.captured("TypedVariableName")
+                if keyword.iskeyword(variable_name):
+                    # only if the determined name is not a keyword (e.g. else, except)
+                    continue
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
             if thisindent == 0 or not classstack:
@@ -652,9 +710,13 @@ def scan(src, file, module):
                             classstack[index][0]._addglobal(
                                 Attribute(module, variable_name, file, lineno)
                             )
+                        elif isinstance(classstack[index][0], Function):
+                            classstack[index][0]._addattribute(
+                                Attribute(module, variable_name, file, lineno)
+                            )
                         break
 
-        elif m.hasCaptured("Publics"):
+        elif m.captured("Publics"):
             idents = m.captured("Identifiers")
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
@@ -669,7 +731,7 @@ def scan(src, file, module):
             )
             dictionary["__all__"] = pubs
 
-        elif m.hasCaptured("Import"):
+        elif m.captured("Import"):
             # - import module
             names = [
                 n.strip()
@@ -684,7 +746,7 @@ def scan(src, file, module):
             for name in names:
                 dictionary["@@Import@@"].addImport(name, [], lineno)
 
-        elif m.hasCaptured("ImportFrom"):
+        elif m.captured("ImportFrom"):
             # - from module import stuff
             mod = m.captured("ImportFromPath")
             namesLines = (
@@ -703,7 +765,7 @@ def scan(src, file, module):
                 dictionary["@@Import@@"] = Imports(module, file)
             dictionary["@@Import@@"].addImport(mod, names, lineno)
 
-        elif m.hasCaptured("ConditionalDefine"):
+        elif m.captured("ConditionalDefine"):
             # a conditional function/method definition
             thisindent = _indent(m.captured("ConditionalDefineIndent"))
             while conditionalsstack and conditionalsstack[-1] >= thisindent:
@@ -713,7 +775,7 @@ def scan(src, file, module):
             conditionalsstack.append(thisindent)
             deltaindentcalculated = False
 
-        elif m.hasCaptured("CodingLine"):
+        elif m.captured("CodingLine"):
             # a coding statement
             coding = m.captured("Coding")
             lineno += src.count("\n", last_lineno_pos, start)
@@ -742,7 +804,9 @@ def _indent(ws):
     """
     Module function to return the indentation depth.
 
-    @param ws the whitespace to be checked (string)
-    @return length of the whitespace string (integer)
+    @param ws the whitespace to be checked
+    @type str
+    @return length of the whitespace string
+    @rtype int
     """
     return len(ws.expandtabs(TABWIDTH))
