@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -190,10 +190,15 @@ class Class(ClbrBaseClasses.Class, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this class
+        @type str
         @param name name of this class
+        @type str
         @param superClasses list of class names this class is inherited from
+        @type list of str
         @param file filename containing this class
+        @type str
         @param lineno linenumber of the class definition
+        @type int
         """
         ClbrBaseClasses.Class.__init__(self, module, name, superClasses, file, lineno)
         VisibilityMixin.__init__(self)
@@ -209,9 +214,13 @@ class Module(ClbrBaseClasses.Module, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this class
+        @type str
         @param name name of this class
+        @type str
         @param file filename containing this class
+        @type str
         @param lineno linenumber of the class definition
+        @type int
         """
         ClbrBaseClasses.Module.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
@@ -227,11 +236,17 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this function
+        @type str
         @param name name of this function
+        @type str
         @param file filename containing this class
+        @type str
         @param lineno linenumber of the class definition
-        @param signature parameterlist of the method
+        @type int
+        @param signature parameter list of the method
+        @type str
         @param separator string separating the parameters
+        @type str
         """
         ClbrBaseClasses.Function.__init__(
             self, module, name, file, lineno, signature, separator
@@ -249,16 +264,20 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         Constructor
 
         @param module name of the module containing this class
+        @type str
         @param name name of this class
+        @type str
         @param file filename containing this attribute
+        @type str
         @param lineno linenumber of the class definition
+        @type int
         """
         ClbrBaseClasses.Attribute.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
         self.setPrivate()
 
 
-def readmodule_ex(module, path=None, isTypeFile=False):
+def readmodule_ex(module, path=None, isTypeFile=False):  # noqa: U100
     """
     Read a Ruby file and return a dictionary of classes, functions and modules.
 
@@ -283,7 +302,7 @@ def readmodule_ex(module, path=None, isTypeFile=False):
 
     try:
         src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, OSError):
+    except (OSError, UnicodeError):
         # can't do anything with this module
         return {}
 
@@ -323,7 +342,7 @@ def scan(src, file, module):
             break
         start, i = m.capturedStart(), m.capturedEnd()
 
-        if m.hasCaptured("Method"):
+        if m.captured("Method"):
             # found a method definition or function
             thisindent = indent
             indent += 1
@@ -387,14 +406,14 @@ def scan(src, file, module):
             classstack.append((f, thisindent))  # Marker for nested fns
 
         elif (
-            m.hasCaptured("String")
-            or m.hasCaptured("Comment")
-            or m.hasCaptured("ClassIgnored")
-            or m.hasCaptured("BeginEnd")
+            m.captured("String")
+            or m.captured("Comment")
+            or m.captured("ClassIgnored")
+            or m.captured("BeginEnd")
         ):
             pass
 
-        elif m.hasCaptured("Class"):
+        elif m.captured("Class"):
             # we found a class definition
             thisindent = indent
             indent += 1
@@ -438,7 +457,7 @@ def scan(src, file, module):
             acstack.append(["public", thisindent])
             # default access control is 'public'
 
-        elif m.hasCaptured("Module"):
+        elif m.captured("Module"):
             # we found a module definition
             thisindent = indent
             indent += 1
@@ -477,7 +496,7 @@ def scan(src, file, module):
             acstack.append(["public", thisindent])
             # default access control is 'public'
 
-        elif m.hasCaptured("AccessControl"):
+        elif m.captured("AccessControl"):
             aclist = m.captured("AccessControlList")
             if not aclist:
                 index = -1
@@ -520,7 +539,7 @@ def scan(src, file, module):
                     else:
                         index -= 1
 
-        elif m.hasCaptured("Attribute"):
+        elif m.captured("Attribute"):
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
             index = -1
@@ -539,7 +558,7 @@ def scan(src, file, module):
                         lastGlobalEntry.setEndLine(lineno - 1)
                     lastGlobalEntry = None
 
-        elif m.hasCaptured("Attr"):
+        elif m.captured("Attr"):
             lineno += src.count("\n", last_lineno_pos, start)
             last_lineno_pos = start
             index = -1
@@ -586,11 +605,11 @@ def scan(src, file, module):
                 else:
                     index -= 1
 
-        elif m.hasCaptured("Begin"):
+        elif m.captured("Begin"):
             # a begin of a block we are not interested in
             indent += 1
 
-        elif m.hasCaptured("End"):
+        elif m.captured("End"):
             # an end of a block
             indent -= 1
             if indent < 0:
@@ -601,7 +620,7 @@ def scan(src, file, module):
                 else:
                     indent = 0
 
-        elif m.hasCaptured("CodingLine"):
+        elif m.captured("CodingLine"):
             # a coding statement
             coding = m.captured("Coding")
             lineno += src.count("\n", last_lineno_pos, start)
