@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,6 +10,7 @@ Package implementing various functions/classes needed everywhere within eric.
 import codecs
 import contextlib
 import glob
+import importlib.util
 import json
 import os
 import re
@@ -34,92 +35,29 @@ from PyQt6.QtCore import (
 
 from eric7 import Preferences
 from eric7.EricWidgets.EricApplication import ericApp
-
-# TODO: remove these with release 23.4
-# imports from eric7.SystemUtilities are for backward compatibility
-from eric7.Globals import (  # __IGNORE_FLAKES_WARNING__
-    desktopName,
-    getConfig,
-    getConfigDir,
-    getPythonExecutable,
-    getPythonLibraryDirectory,
-    getPythonScriptsDirectory,
-    sessionType,
-    setConfigDir,
-    toBool,
-)
-from eric7.SystemUtilities import DesktopUtilities
-from eric7.SystemUtilities.FileSystemUtilities import (  # __IGNORE_FLAKES_WARNING__
-    absolutePath,
-    absoluteUniversalPath,
-    compactPath,
-    direntries,
-    findVolume,
-    fromNativeSeparators,
-    getDirs,
-    getExecutablePath,
-    getExecutablePaths,
-    getWindowsExecutablePath,
-    isDrive,
-    isExecutable,
-    isinpath,
-    joinext,
-    normabsjoinpath,
-    normcaseabspath,
-    normcasepath,
-    normjoinpath,
-    relativeUniversalPath,
-    samefilepath,
-    samepath,
-    splitPath,
-    startswithPath,
-    toNativeSeparators,
-)
-from eric7.SystemUtilities.OSUtilities import (  # __IGNORE_FLAKES_WARNING__
-    getEnvironmentEntry,
-    hasEnvironmentEntry,
-    getHomeDir,
-    getRealName,
-    getUserName,
-    getRealName,
-    isLinuxPlatform,
-    isMacPlatform,
-    isWindowsPlatform,
-    win32_getRealName,
-    win32_GetUserName,
-    win32_Kill,
-)
-from eric7.SystemUtilities.PythonUtilities import (  # __IGNORE_FLAKES_WARNING__
-    determinePythonVersion,
-    getPythonLibPath,
-    getPythonVersion,
-)
-from eric7.SystemUtilities.QtUtilities import (  # __IGNORE_FLAKES_WARNING__
-    checkPyside,
-    generatePyQtToolPath,
-    generatePySideToolPath,
-    generateQtToolName,
-    getPyQt6ModulesDirectory,
-    getPyQtToolsPath,
-    getQtBinariesPath,
-    getQtMacBundle,
-    prepareQtMacBundle,
-    qVersionTuple,
-)
+from eric7.SystemUtilities import DesktopUtilities, OSUtilities
 from eric7.UI.Info import Program, Version
 
 
-def __showwarning(message, category, filename, lineno, file=None, line=""):
+def __showwarning(
+    message, category, filename, lineno, file=None, line=""  # noqa: U100
+):
     """
     Module function to raise a SyntaxError for a SyntaxWarning.
 
     @param message warning object
+    @type Class
     @param category type object of the warning
-    @param filename name of the file causing the warning (string)
-    @param lineno line number causing the warning (integer)
+    @type SyntaxWarning
+    @param filename name of the file causing the warning
+    @type str
+    @param lineno line number causing the warning
+    @type int
     @param file file to write the warning message to (ignored)
+    @type file
     @param line line causing the warning (ignored)
-    @raise err exception of type SyntaxError
+    @type int
+    @exception err exception of type SyntaxError
     """
     if category is SyntaxWarning:
         err = SyntaxError(str(message))
@@ -130,8 +68,6 @@ def __showwarning(message, category, filename, lineno, file=None, line=""):
 
 warnings.showwarning = __showwarning
 
-configDir = None
-
 codingBytes_regexps = [
     (5, re.compile(rb"""coding[:=]\s*([-\w_.]+)""")),
     (1, re.compile(rb"""<\?xml.*\bencoding\s*=\s*['"]([-\w_.]+)['"]\?>""")),
@@ -141,7 +77,7 @@ coding_regexps = [
     (1, re.compile(r"""<\?xml.*\bencoding\s*=\s*['"]([-\w_.]+)['"]\?>""")),
 ]
 
-supportedCodecs = [
+supportedCodecs = [  # noqa: U200
     "utf-8",
     "iso-8859-1",
     "iso-8859-2",
@@ -242,7 +178,8 @@ class CodingError(Exception):
         """
         Constructor
 
-        @param coding coding to include in the message (string)
+        @param coding coding to include in the message
+        @type str
         """
         self.errorMessage = QCoreApplication.translate(
             "CodingError", "The coding '{0}' is wrong for the given text."
@@ -253,6 +190,7 @@ class CodingError(Exception):
         Special method returning a representation of the exception.
 
         @return string representing the error message
+        @rtype str
         """
         return str(self.errorMessage)
 
@@ -261,6 +199,7 @@ class CodingError(Exception):
         Special method returning a string representation of the exception.
 
         @return string representing the error message
+        @rtype str
         """
         return str(self.errorMessage)
 
@@ -269,8 +208,10 @@ def get_codingBytes(text):
     """
     Function to get the coding of a bytes text.
 
-    @param text bytes text to inspect (bytes)
+    @param text bytes text to inspect
+    @type bytes
     @return coding string
+    @rtype str
     """
     lines = text.splitlines()
     for coding in codingBytes_regexps:
@@ -287,8 +228,10 @@ def get_coding(text):
     """
     Function to get the coding of a text.
 
-    @param text text to inspect (string)
+    @param text text to inspect
+    @type str
     @return coding string
+    @rtype str
     """
     lines = text.splitlines()
     for coding in coding_regexps:
@@ -305,8 +248,10 @@ def readEncodedFile(filename):
     """
     Function to read a file and decode its contents into proper text.
 
-    @param filename name of the file to read (string)
-    @return tuple of decoded text and encoding (string, string)
+    @param filename name of the file to read
+    @type str
+    @return tuple of decoded text and encoding
+    @rtype tuple of (str, str)
     """
     with open(filename, "rb") as f:
         text = f.read()
@@ -318,9 +263,10 @@ def readEncodedFileWithHash(filename):
     Function to read a file, calculate a hash value and decode its contents
     into proper text.
 
-    @param filename name of the file to read (string)
-    @return tuple of decoded text, encoding and hash value (string, string,
-        string)
+    @param filename name of the file to read
+    @type str
+    @return tuple of decoded text, encoding and hash value
+    @rtype tuple of (str, str, str)
     """
     with open(filename, "rb") as f:
         text = f.read()
@@ -337,8 +283,10 @@ def decode(text):
     """
     Function to decode some byte text into a string.
 
-    @param text byte text to decode (bytes)
-    @return tuple of decoded text and encoding (string, string)
+    @param text byte text to decode
+    @type bytes
+    @return tuple of decoded text and encoding
+    @rtype tuple of (str, str)
     """
     with contextlib.suppress(UnicodeError, LookupError):
         if text.startswith(BOM_UTF8):
@@ -366,7 +314,7 @@ def decode(text):
             if guess and guess["confidence"] > 0.95 and guess["encoding"] is not None:
                 codec = guess["encoding"].lower()
                 return str(text, codec), "{0}-guessed".format(codec)
-        except (UnicodeError, LookupError):
+        except (LookupError, UnicodeError):
             pass
         except ImportError:
             pass
@@ -394,9 +342,12 @@ def readEncodedFileWithEncoding(filename, encoding):
     """
     Function to read a file and decode its contents into proper text.
 
-    @param filename name of the file to read (string)
-    @param encoding encoding to be used to read the file (string)
-    @return tuple of decoded text and encoding (string, string)
+    @param filename name of the file to read
+    @type str
+    @param encoding encoding to be used to read the file
+    @type str
+    @return tuple of decoded text and encoding
+    @rtype tuple of (str, str)
     """
     with open(filename, "rb") as f:
         text = f.read()
@@ -463,7 +414,7 @@ def encode(text, origEncoding, forcedEncoding=""):
         if coding:
             try:
                 etext, encoding = text.encode(coding), coding
-            except (UnicodeError, LookupError):
+            except (LookupError, UnicodeError):
                 # Error: Declared encoding is incorrect
                 raise CodingError(coding)
         else:
@@ -508,8 +459,10 @@ def decodeString(text):
     """
     Function to decode a string containing Unicode encoded characters.
 
-    @param text text containing encoded chars (string)
-    @return decoded text (string)
+    @param text text containing encoded chars
+    @type str
+    @return decoded text
+    @rtype str
     """
     buf = b""
     index = 0
@@ -529,8 +482,10 @@ def decodeBytes(buffer):
     """
     Function to decode some byte text into a string.
 
-    @param buffer byte buffer to decode (bytes)
-    @return decoded text (string)
+    @param buffer byte buffer to decode
+    @type bytes
+    @return decoded text
+    @rtype str
     """
     # try UTF with BOM
     with contextlib.suppress(UnicodeError, LookupError):
@@ -554,7 +509,7 @@ def decodeBytes(buffer):
         if guess and guess["encoding"] is not None:
             codec = guess["encoding"].lower()
             return str(buffer, encoding=codec)
-    except (UnicodeError, LookupError):
+    except (LookupError, UnicodeError):
         pass
     except ImportError:
         pass
@@ -566,8 +521,10 @@ def readStringFromStream(stream):
     """
     Module function to read a string from the given stream.
 
-    @param stream data stream opened for reading (QDataStream)
-    @return string read from the stream (string)
+    @param stream data stream opened for reading
+    @type QDataStream
+    @return string read from the stream
+    @rtype str
     """
     data = stream.readString()
     if data is None:
@@ -579,8 +536,10 @@ def normalizeCode(codestring):
     """
     Function to normalize the given code.
 
-    @param codestring code to be normalized (string)
-    @return normalized code (string)
+    @param codestring code to be normalized
+    @type str
+    @return normalized code
+    @rtype str
     """
     codestring = codestring.replace("\r\n", "\n").replace("\r", "\n")
 
@@ -606,8 +565,11 @@ def escape_entities(m, escmap=_escape_map):
     Function to encode html entities.
 
     @param m the match object
+    @type re.Match
     @param escmap the map of entities to encode
-    @return the converted text (string)
+    @type dict
+    @return the converted text
+    @rtype str
     """
     char = m.group()
     text = escmap.get(char)
@@ -620,9 +582,12 @@ def html_encode(text, pattern=_escape):
     """
     Function to correctly encode a text for html.
 
-    @param text text to be encoded (string)
-    @param pattern search pattern for text to be encoded (string)
-    @return the encoded text (string)
+    @param text text to be encoded
+    @type str
+    @param pattern search pattern for text to be encoded
+    @type str
+    @return the encoded text
+    @rtype str
     """
     if not text:
         return ""
@@ -638,7 +603,9 @@ def escape_uentities(m):
     Function to encode html entities.
 
     @param m the match object
-    @return the converted text (string)
+    @type re.Match
+    @return the converted text
+    @rtype str
     """
     char = m.group()
     text = "&#{0:d};".format(ord(char))
@@ -649,9 +616,12 @@ def html_uencode(text, pattern=_uescape):
     """
     Function to correctly encode a unicode text for html.
 
-    @param text text to be encoded (string)
-    @param pattern search pattern for text to be encoded (string)
-    @return the encoded text (string)
+    @param text text to be encoded
+    @type str
+    @param pattern search pattern for text to be encoded
+    @type str
+    @return the encoded text
+    @rtype str
     """
     if not text:
         return ""
@@ -667,7 +637,9 @@ def unescape_uentities(m):
     Function to decode html entities.
 
     @param m the match object
-    @return the converted text (string)
+    @type re.Match
+    @return the converted text
+    @rtype str
     """
     char = m.group()
     ordinal = int(char[2:-1])
@@ -678,9 +650,12 @@ def html_udecode(text, pattern=_uunescape):
     """
     Function to correctly decode a html text to a unicode text.
 
-    @param text text to be decoded (string)
-    @param pattern search pattern for text to be decoded (string)
-    @return the decoded text (string)
+    @param text text to be decoded
+    @type str
+    @param pattern search pattern for text to be decoded
+    @type str
+    @return the decoded text
+    @rtype str
     """
     if not text:
         return ""
@@ -692,19 +667,22 @@ def convertLineEnds(text, eol):
     """
     Function to convert the end of line characters.
 
-    @param text text to be converted (string)
-    @param eol new eol setting (string)
-    @return text with converted eols (string)
+    @param text text to be converted
+    @type str
+    @param eol new eol setting
+    @type str
+    @return text with converted eols
+    @rtype str
     """
     if eol == "\r\n":
         regexp = re.compile(r"""(\r(?!\n)|(?<!\r)\n)""")
-        return regexp.sub(lambda m, eol="\r\n": eol, text)
+        return regexp.sub("\r\n", text)
     elif eol == "\n":
         regexp = re.compile(r"""(\r\n|\r)""")
-        return regexp.sub(lambda m, eol="\n": eol, text)
+        return regexp.sub("\n", text)
     elif eol == "\r":
         regexp = re.compile(r"""(\r\n|\n)""")
-        return regexp.sub(lambda m, eol="\r": eol, text)
+        return regexp.sub("\r", text)
     else:
         return text
 
@@ -713,7 +691,8 @@ def linesep():
     """
     Function to return the line separator used by the editor.
 
-    @return line separator used by the editor (string)
+    @return line separator used by the editor
+    @rtype str
     """
     eolMode = Preferences.getEditor("EOLMode")
     if eolMode == QsciScintilla.EolMode.EolUnix:
@@ -736,8 +715,10 @@ def extractFlags(text):
     at the very end of a file. The search is ended, if a line without
     the 'eflag:' marker is found.
 
-    @param text text to be scanned (string)
+    @param text text to be scanned
+    @type str
     @return dictionary of string, boolean, complex, float and int
+    @rtype dict
     """
     flags = {}
     lines = text.rstrip().splitlines() if isinstance(text, str) else text
@@ -783,12 +764,14 @@ def extractFlagsFromFile(filename):
     """
     Function to extract eric specific flags out of the given file.
 
-    @param filename name of the file to be scanned (string)
+    @param filename name of the file to be scanned
+    @type str
     @return dictionary of string, boolean, complex, float and int
+    @rtype dict
     """
     try:
         source, encoding = readEncodedFile(filename)
-    except (UnicodeError, OSError):
+    except (OSError, UnicodeError):
         return {}
 
     return extractFlags(source)
@@ -799,11 +782,16 @@ def extractLineFlags(line, startComment="#", endComment="", flagsLine=False):
     Function to extract flags starting and ending with '__' from a line
     comment.
 
-    @param line line to extract flags from (string)
-    @param startComment string identifying the start of the comment (string)
-    @param endComment string identifying the end of a comment (string)
-    @param flagsLine flag indicating to check for a flags only line (bool)
-    @return list containing the extracted flags (list of strings)
+    @param line line to extract flags from
+    @type str
+    @param startComment string identifying the start of the comment
+    @type str
+    @param endComment string identifying the end of a comment
+    @type str
+    @param flagsLine flag indicating to check for a flags only line
+    @type bool
+    @return list containing the extracted flags
+    @rtype list of str
     """
     flags = []
 
@@ -1015,7 +1003,7 @@ def getPercentReplacement(code):
         return fn
     elif code in ["H", "%H"]:
         # home directory
-        return getHomeDir()
+        return OSUtilities.getHomeDir()
     elif code in ["L", "%L"]:
         # line of the cursor of the current editor
         aw = ericApp().getObject("ViewManager").activeWindow()
@@ -1040,7 +1028,7 @@ def getPercentReplacement(code):
         return text
     elif code in ["U", "%U"]:
         # username
-        un = getUserName()
+        un = OSUtilities.getUserName()
         if un is None:
             return code
         else:
@@ -1057,7 +1045,8 @@ def getPercentReplacementHelp():
     """
     Function to get the help text for the supported %-codes.
 
-    @returns help text (string)
+    @return help text
+    @rtype str
     """
     return QCoreApplication.translate(
         "Utilities",
@@ -1099,6 +1088,100 @@ def rxIndex(rx, txt):
         return match.start()
 
 
+def unslash(txt):
+    """
+    Function to convert a string containing escape codes to an escaped string.
+
+    @param txt string to be converted
+    @type str
+    @return converted string containing escape codes
+    @rtype str
+    """
+    s = []
+    index = 0
+    while index < len(txt):
+        c = txt[index]
+        if c == "\\" and index + 1 < len(txt):
+            index += 1
+            c = txt[index]
+            if c == "a":
+                o = "\a"
+            elif c == "b":
+                o = "\b"
+            elif c == "f":
+                o = "\f"
+            elif c == "n":
+                o = "\n"
+            elif c == "r":
+                o = "\r"
+            elif c == "t":
+                o = "\t"
+            elif c == "v":
+                o = "\v"
+            elif c in "01234567":
+                # octal
+                oc = c
+                if index + 1 < len(txt) and txt[index + 1] in "01234567":
+                    index += 1
+                    oc += txt[index]
+                    if index + 1 < len(txt) and txt[index + 1] in "01234567":
+                        index += 1
+                        oc += txt[index]
+                o = chr(int(oc, base=8))
+            elif c.lower() == "x":
+                val = 0
+                if index + 1 < len(txt) and txt[index + 1] in "0123456789abcdefABCDEF":
+                    index += 1
+                    hx = txt[index]
+                    if (
+                        index + 1 < len(txt)
+                        and txt[index + 1] in "0123456789abcdefABCDEF"
+                    ):
+                        index += 1
+                        hx += txt[index]
+                    val = int(hx, base=16)
+                o = chr(val)
+            else:
+                o = c
+        else:
+            o = c
+
+        s.append(o)
+        index += 1
+
+    return "".join(s)
+
+
+_slashmap = {i: hex(i).replace("0x", "\\x") for i in range(7)}
+_slashmap.update(
+    {
+        7: "\\a",
+        8: "\\b",
+        9: "\\t",
+        10: "\\n",
+        11: "\\v",
+        12: "\\f",
+        13: "\\r",
+    }
+)
+_slashmap.update({i: hex(i).replace("0x", "\\x") for i in range(14, 32)})
+_slashmap.update({i: hex(i).replace("0x", "\\x") for i in range(127, 160)})
+
+
+def slash(txt):
+    """
+    Function to convert an escaped string to a string containing escape codes.
+
+    Note: This is the reverse of 'unslash()'.
+
+    @param txt string to be converted
+    @type str
+    @return converted string containing escaped escape codes
+    @rtype str
+    """
+    return txt.translate(_slashmap)
+
+
 ###############################################################################
 ## Other utility functions below
 ###############################################################################
@@ -1126,25 +1209,23 @@ def generateVersionInfo(linesep="\n"):
     info.append("  Qt {0}".format(qVersion()))
     info.append("  PyQt6 {0}".format(PYQT_VERSION_STR))
     try:
-        from PyQt6 import QtCharts  # __IGNORE_WARNING_I10__
+        from PyQt6 import QtCharts  # noqa: I101, I102
 
         info.append("  PyQt6-Charts {0}".format(QtCharts.PYQT_CHART_VERSION_STR))
-    except (ImportError, AttributeError):
+    except (AttributeError, ImportError):
         info.append("  PyQt6-Charts not installed")
     try:
-        from PyQt6 import QtWebEngineCore  # __IGNORE_WARNING_I10__
+        from PyQt6 import QtWebEngineCore  # noqa: I101, I102
 
         info.append(
             "  PyQt6-WebEngine {0}".format(QtWebEngineCore.PYQT_WEBENGINE_VERSION_STR)
         )
-    except (ImportError, AttributeError):
+    except (AttributeError, ImportError):
         info.append("  PyQt6-WebEngine not installed")
     info.append("  PyQt6-QScintilla {0}".format(QSCINTILLA_VERSION_STR))
     info.append("  sip {0}".format(sip_version_str))
-    with contextlib.suppress(ImportError):
-        from PyQt6 import QtWebEngineWidgets  # __IGNORE_WARNING__
-
-        from eric7.WebBrowser.Tools import WebBrowserTools  # __IGNORE_WARNING_I101__
+    if bool(importlib.util.find_spec("PyQt6.QtWebEngineWidgets")):
+        from eric7.WebBrowser.Tools import WebBrowserTools  # noqa: I101
 
         (
             chromiumVersion,
@@ -1190,7 +1271,7 @@ def generatePluginsVersionInfo(linesep="\n"):
                 versions[pinfo["module_name"]] = pinfo["version"]
 
             info.append("Plugins Version Numbers:")
-            for pluginModuleName in sorted(versions.keys()):
+            for pluginModuleName in sorted(versions):
                 info.append(
                     "  {0} {1}".format(pluginModuleName, versions[pluginModuleName])
                 )
@@ -1208,7 +1289,7 @@ def generateDistroInfo(linesep="\n"):
     @rtype str
     """
     info = []
-    if isLinuxPlatform():
+    if OSUtilities.isLinuxPlatform() or OSUtilities.isFreeBsdPlatform():
         releaseList = glob.glob("/etc/*-release")
         if releaseList:
             info.append("Distribution Info:")
