@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -35,9 +35,13 @@ class VcsProjectHelper(QObject):
         Constructor
 
         @param vcsObject reference to the vcs object
+        @type VersionControl
         @param projectObject reference to the project object
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @type Project
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         super().__init__(parent)
         if name:
@@ -57,7 +61,9 @@ class VcsProjectHelper(QObject):
         Public method to set references to the vcs and project objects.
 
         @param vcsObject reference to the vcs object
+        @type VersionControl
         @param projectObject reference to the project object
+        @type Project
         """
         self.vcs = vcsObject
         self.project = projectObject
@@ -146,7 +152,8 @@ class VcsProjectHelper(QObject):
         """
         Public method to generate the VCS menu.
 
-        @param menu reference to the menu to be populated (QMenu)
+        @param menu reference to the menu to be populated
+        @type QMenu
         """
         menu.clear()
 
@@ -156,14 +163,16 @@ class VcsProjectHelper(QObject):
         menu.addAction(self.vcsAddAct)
         menu.addSeparator()
 
-    def initToolbar(self, ui, toolbarManager):
+    def initToolbar(self, ui, toolbarManager):  # noqa: U100
         """
         Public slot to initialize the VCS toolbar.
 
-        @param ui reference to the main window (UserInterface)
+        @param ui reference to the main window
+        @type UserInterface
         @param toolbarManager reference to a toolbar manager object
-            (EricToolBarManager)
-        @return the toolbar generated (QToolBar)
+        @type EricToolBarManager
+        @return the toolbar generated
+        @rtype QToolBar
         """
         return None  # __IGNORE_WARNING_M831__
 
@@ -171,10 +180,12 @@ class VcsProjectHelper(QObject):
         """
         Public slot to initialize the basic VCS toolbar.
 
-        @param ui reference to the main window (UserInterface)
+        @param ui reference to the main window
+        @type UserInterface
         @param toolbarManager reference to a toolbar manager object
-            (EricToolBarManager)
-        @return the toolbar generated (QToolBar)
+        @type EricToolBarManager
+        @return the toolbar generated
+        @rtype QToolBar
         """
         tb = QToolBar(QCoreApplication.translate("VcsProjectHelper", "VCS"), ui)
         tb.setObjectName("VersionControlToolbar")
@@ -202,7 +213,8 @@ class VcsProjectHelper(QObject):
         Protected slot used to create a local project from the repository.
 
         @param export flag indicating whether an export or a checkout
-                should be performed
+            should be performed
+        @type bool
         """
         if not self.project or not self.project.checkDirty():
             return
@@ -217,8 +229,7 @@ class VcsProjectHelper(QObject):
             return
 
         vcsSystemsDisplay = []
-        keys = sorted(vcsSystemsDict.keys())
-        for key in keys:
+        for key in sorted(vcsSystemsDict):
             vcsSystemsDisplay.append(vcsSystemsDict[key])
         vcsSelected, ok = QInputDialog.getItem(
             None,
@@ -234,7 +245,7 @@ class VcsProjectHelper(QObject):
             return
 
         selectedVcsSystem = None
-        for vcsSystem, vcsSystemDisplay in list(vcsSystemsDict.items()):
+        for vcsSystem, vcsSystemDisplay in vcsSystemsDict.items():
             if vcsSystemDisplay == vcsSelected:
                 selectedVcsSystem = vcsSystem
                 break
@@ -293,11 +304,7 @@ class VcsProjectHelper(QObject):
                 if ok:
                     projectdir = os.path.normpath(projectdir)
                     dpath = pathlib.Path(projectdir)
-                    # look for JSON style project file first
                     plist = list(dpath.glob("*.epj"))
-                    if not plist:
-                        # look for XML style project file second
-                        plist = list(dpath.glob("*.e4p"))
                     if plist:
                         if len(plist) == 1:
                             self.project.openProject(str(plist[0].resolve()))
@@ -447,8 +454,7 @@ class VcsProjectHelper(QObject):
             return
 
         vcsSystemsDisplay = []
-        keys = sorted(vcsSystemsDict.keys())
-        for key in keys:
+        for key in sorted(vcsSystemsDict):
             vcsSystemsDisplay.append(vcsSystemsDict[key])
         vcsSelected, ok = QInputDialog.getItem(
             None,
@@ -464,7 +470,7 @@ class VcsProjectHelper(QObject):
             return
 
         selectedVcsSystem = None
-        for vcsSystem, vcsSystemDisplay in list(vcsSystemsDict.items()):
+        for vcsSystem, vcsSystemDisplay in vcsSystemsDict.items():
             if vcsSystemDisplay == vcsSelected:
                 selectedVcsSystem = vcsSystem
                 break
@@ -579,7 +585,7 @@ class VcsProjectHelper(QObject):
                 ppath = self.project.ppath
                 self.setDirty(False)
                 self.project.closeProject()
-                shutil.rmtree(ppath, True)
+                shutil.rmtree(ppath, ignore_errors=True)
 
     def _vcsCommandOptions(self):
         """
