@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2021 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -62,15 +62,19 @@ class StatusWidget(QWidget):
         self.__layout = QVBoxLayout()
         self.__layout.setObjectName("MainLayout")
         self.__layout.setContentsMargins(0, 3, 0, 0)
-        self.__topLayout = QHBoxLayout()
-        self.__topLayout.setObjectName("topLayout")
 
-        # Create the top area
+        # Create the info label part
         self.__infoLabel = QLabel(self)
         self.__infoLabel.setSizePolicy(
             QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Preferred
         )
-        self.__topLayout.addWidget(self.__infoLabel)
+        self.__layout.addWidget(self.__infoLabel)
+
+        # Create the top area
+        self.__topLayout = QHBoxLayout()
+        self.__topLayout.setObjectName("topLayout")
+
+        self.__topLayout.addStretch()
 
         self.__commitToggleButton = QToolButton(self)
         self.__commitToggleButton.setIcon(EricPixmapCache.getIcon("check"))
@@ -108,6 +112,8 @@ class StatusWidget(QWidget):
         self.__actionsButton.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
         self.__topLayout.addWidget(self.__actionsButton)
 
+        self.__topLayout.addStretch()
+
         self.__layout.addLayout(self.__topLayout)
         ###################################################################
 
@@ -168,6 +174,8 @@ class StatusWidget(QWidget):
         self.__quickCommitButton.clicked.connect(self.__quickCommit)
         self.__quickCommitLayout2.addWidget(self.__quickCommitButton)
 
+        self.__quickCommitLayout2.addStretch()
+
         self.__quickCommitLayout.addLayout(self.__quickCommitLayout2)
         self.__quickCommitGroup.setLayout(self.__quickCommitLayout)
         self.__layout.addWidget(self.__quickCommitGroup)
