@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,6 +9,7 @@ VCS interfaces.
 """
 
 import contextlib
+import enum
 import json
 import os
 
@@ -29,6 +30,15 @@ from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
 
 
+class VersionControlState(enum.Enum):
+    """
+    Class defining the global VCS states of files and directories.
+    """
+
+    Controlled = 0
+    Uncontrolled = 1
+
+
 class VersionControl(QObject):
     """
     Class implementing an abstract base class to be subclassed by all specific
@@ -56,9 +66,6 @@ class VersionControl(QObject):
     vcsStatusMonitorInfo = pyqtSignal(str)
     vcsStatusChanged = pyqtSignal()
 
-    canBeCommitted = 1  # Indicates that a file/directory is in the vcs.
-    canBeAdded = 2  # Indicates that a file/directory is not in vcs.
-
     commitHistoryLock = "commitHistory.lock"
     commitHistoryData = "commitHistory.json"
 
@@ -66,8 +73,10 @@ class VersionControl(QObject):
         """
         Constructor
 
-        @param parent parent widget (QWidget)
-        @param name name of this object (string)
+        @param parent parent widget
+        @type QWidget
+        @param name name of this object
+        @type str
         """
         super().__init__(parent)
         if name:
@@ -98,21 +107,22 @@ class VersionControl(QObject):
         """
         Public method used to shutdown the vcs interface.
 
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsExists(self):
         """
         Public method used to test for the presence of the vcs.
 
-        @return tuple of flag indicating the existence and a string
-            giving an error message in case of failure
-        @exception RuntimeError to indicate that this method must be
+        @return tuple of flag indicating the existence and an error message
+            in case of failure
+        @rtype tuple of (bool, str)
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return (False, "")
 
@@ -120,13 +130,16 @@ class VersionControl(QObject):
         """
         Public method used to initialize the vcs.
 
-        @param vcsDir name of the VCS directory (string)
-        @param noDialog flag indicating quiet operations (boolean)
-        @return flag indicating success (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @param vcsDir name of the VCS directory
+        @type str
+        @param noDialog flag indicating quiet operations
+        @type bool
+        @return flag indicating success
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -141,10 +154,10 @@ class VersionControl(QObject):
         @type Project
         @param addAll flag indicating to add all files to the repository
         @type bool
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsImport(self, vcsDataDict, projectDir, noDialog=False, addAll=True):
         """
@@ -152,7 +165,7 @@ class VersionControl(QObject):
 
         @param vcsDataDict dictionary of data required for the import
         @type dict
-        @param projectDir project directory (string)
+        @param projectDir project directory
         @type str
         @param noDialog flag indicating quiet operations
         @type bool
@@ -161,10 +174,10 @@ class VersionControl(QObject):
         @return tuple containing a flag indicating an execution without errors
             and a flag indicating the version control status
         @rtype tuple of (bool, bool)
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return (False, False)
 
@@ -173,13 +186,17 @@ class VersionControl(QObject):
         Public method used to check the project out of the vcs.
 
         @param vcsDataDict dictionary of data required for the checkout
-        @param projectDir project directory to create (string)
+        @type dict
+        @param projectDir project directory to create
+        @type str
         @param noDialog flag indicating quiet operations
-        @return flag indicating an execution without errors (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @type bool
+        @return flag indicating an execution without errors
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -188,12 +205,15 @@ class VersionControl(QObject):
         Public method used to export a directory from the vcs.
 
         @param vcsDataDict dictionary of data required for the export
-        @param projectDir project directory to create (string)
-        @return flag indicating an execution without errors (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @type dict
+        @param projectDir project directory to create
+        @type str
+        @return flag indicating an execution without errors
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -202,14 +222,18 @@ class VersionControl(QObject):
         Public method used to make the change of a file/directory permanent in
         the vcs.
 
-        @param name file/directory name to be committed (string)
-        @param message message for this operation (string)
-        @param noDialog flag indicating quiet operations (boolean)
-        @return flag indicating success (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to be committed
+        @type str
+        @param message message for this operation
+        @type str
+        @param noDialog flag indicating quiet operations
+        @type bool
+        @return flag indicating success
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -219,10 +243,10 @@ class VersionControl(QObject):
 
         @return list of saved commit messages
         @rtype list of str
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return []
 
@@ -251,10 +275,10 @@ class VersionControl(QObject):
 
         @param message message to be added
         @type str
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def _vcsAddProjectCommitMessage(self, message):
         """
@@ -280,7 +304,7 @@ class VersionControl(QObject):
                 del messages[noMessages:]
 
                 with contextlib.suppress(TypeError, OSError):
-                    jsonString = json.dumps(messages, indent=2)
+                    jsonString = json.dumps(messages, indent=2) + "\n"
                     with open(
                         os.path.join(projectMgmtDir, VersionControl.commitHistoryData),
                         "w",
@@ -295,10 +319,10 @@ class VersionControl(QObject):
         """
         Public method to clear the list of saved messages.
 
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def _vcsClearProjectCommitMessages(self):
         """
@@ -314,7 +338,7 @@ class VersionControl(QObject):
             )
             if lockFile.lock():
                 with contextlib.suppress(TypeError, OSError):
-                    jsonString = json.dumps([], indent=2)
+                    jsonString = json.dumps([], indent=2) + "\n"
                     with open(
                         os.path.join(projectMgmtDir, VersionControl.commitHistoryData),
                         "w",
@@ -329,14 +353,17 @@ class VersionControl(QObject):
         """
         Public method used to update a file/directory in the vcs.
 
-        @param name file/directory name to be updated (string)
-        @param noDialog flag indicating quiet operations (boolean)
+        @param name file/directory name to be updated
+        @type str
+        @param noDialog flag indicating quiet operations
+        @type bool
         @return flag indicating, that the update contained an add
-            or delete (boolean)
-        @exception RuntimeError to indicate that this method must be
+            or delete
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -344,47 +371,57 @@ class VersionControl(QObject):
         """
         Public method used to add a file/directory in the vcs.
 
-        @param name file/directory name to be added (string)
-        @param isDir flag indicating name is a directory (boolean)
-        @param noDialog flag indicating quiet operations (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to be added
+        @type str
+        @param isDir flag indicating name is a directory
+        @type bool
+        @param noDialog flag indicating quiet operations
+        @type bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsAddBinary(self, name, isDir=False):
         """
         Public method used to add a file/directory in binary mode in the vcs.
 
-        @param name file/directory name to be added (string)
-        @param isDir flag indicating name is a directory (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to be added
+        @type str
+        @param isDir flag indicating name is a directory
+        @type bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsAddTree(self, path):
         """
         Public method to add a directory tree rooted at path in the vcs.
 
-        @param path root directory of the tree to be added (string)
-        @exception RuntimeError to indicate that this method must be
+        @param path root directory of the tree to be added
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsRemove(self, name, project=False, noDialog=False):
         """
         Public method used to add a file/directory in the vcs.
 
-        @param name file/directory name to be removed (string)
-        @param project flag indicating deletion of a project tree (boolean)
+        @param name file/directory name to be removed
+        @type str
+        @param project flag indicating deletion of a project tree
+        @type bool
         @param noDialog flag indicating quiet operations
-        @return flag indicating success (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @type bool
+        @return flag indicating success
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -392,15 +429,20 @@ class VersionControl(QObject):
         """
         Public method used to move a file/directory.
 
-        @param name file/directory name to be moved (string)
+        @param name file/directory name to be moved
+        @type str
         @param project reference to the project object
-        @param target new name of the file/directory (string)
+        @type Project
+        @param target new name of the file/directory
+        @type str
         @param noDialog flag indicating quiet operations
-        @return flag indicating successfull operation (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @type bool
+        @return flag indicating successfull operation
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -409,23 +451,25 @@ class VersionControl(QObject):
         Public method used to view the log of a file/directory in the vcs
         with a log browser dialog.
 
-        @param name file/directory name to show the log for (string)
+        @param name file/directory name to show the log for
+        @type str
         @param isFile flag indicating log for a file is to be shown
-            (boolean)
-        @exception RuntimeError to indicate that this method must be
+        @type bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsDiff(self, name):
         """
         Public method used to view the diff of a file/directory in the vcs.
 
-        @param name file/directory name to be diffed (string)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to be diffed
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsSbsDiff(self, name, extended=False, revisions=None):
         """
@@ -438,30 +482,32 @@ class VersionControl(QObject):
         @type bool
         @param revisions tuple of two revisions
         @type tuple of two str
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsStatus(self, name):
         """
         Public method used to view the status of a file/directory in the vcs.
 
-        @param name file/directory name to show the status for (string)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to show the status for
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsTag(self, name):
         """
         Public method used to set the tag of a file/directory in the vcs.
 
-        @param name file/directory name to be tagged (string)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to be tagged
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsRevert(self, name):
         """
@@ -472,10 +518,10 @@ class VersionControl(QObject):
         @return flag indicating, that the update contained an add
             or delete
         @rtype bool
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -485,22 +531,24 @@ class VersionControl(QObject):
 
         @param name file/directory name to be removed
         @type str or list of str
-        @exception RuntimeError to indicate that this method must be
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsSwitch(self, name):
         """
         Public method used to switch a directory to a different tag/branch.
 
-        @param name directory name to be switched (string)
+        @param name directory name to be switched
+        @type str
         @return flag indicating, that the switch contained an add
-            or delete (boolean)
-        @exception RuntimeError to indicate that this method must be
+            or delete
+        @rtype bool
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return False
 
@@ -508,23 +556,25 @@ class VersionControl(QObject):
         """
         Public method used to merge a tag/branch into the local project.
 
-        @param name file/directory name to be merged (string)
-        @exception RuntimeError to indicate that this method must be
+        @param name file/directory name to be merged
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsRegisteredState(self, name):
         """
         Public method used to get the registered state of a file in the vcs.
 
-        @param name filename to check (string)
-        @return a combination of canBeCommited and canBeAdded or
-            0 in order to signal an error
-        @exception RuntimeError to indicate that this method must be
+        @param name filename to check
+        @type str
+        @return registered state
+        @rtype VersionControlState
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return 0
 
@@ -534,13 +584,16 @@ class VersionControl(QObject):
         in the vcs.
 
         @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @return the received dictionary completed with a combination of
-            canBeCommited and canBeAdded or None in order to signal an error
-        @exception RuntimeError to indicate that this method must be
+        @type dict
+        @param dname directory to check in
+        @type str
+        @return the received dictionary completed with the VCS state or None in
+            order to signal an error
+        @rtype dict
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return {}
 
@@ -548,11 +601,12 @@ class VersionControl(QObject):
         """
         Public method returning the name of the vcs.
 
-        @return name of the vcs (string)
-        @exception RuntimeError to indicate that this method must be
+        @return name of the vcs
+        @rtype str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return ""
 
@@ -560,57 +614,65 @@ class VersionControl(QObject):
         """
         Public method used to cleanup the local copy.
 
-        @param name directory name to be cleaned up (string)
-        @exception RuntimeError to indicate that this method must be
+        @param name directory name to be cleaned up
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsCommandLine(self, name):
         """
         Public method used to execute arbitrary vcs commands.
 
-        @param name directory name of the working directory (string)
-        @exception RuntimeError to indicate that this method must be
+        @param name directory name of the working directory
+        @type str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsOptionsDialog(self, project, archive, editable=False, parent=None):
         """
         Public method to get a dialog to enter repository info.
 
         @param project reference to the project object
-        @param archive name of the project in the repository (string)
+        @type Project
+        @param archive name of the project in the repository
+        @type str
         @param editable flag indicating that the project name is editable
-            (boolean)
-        @param parent parent widget (QWidget)
-        @exception RuntimeError to indicate that this method must be
+        @type bool
+        @param parent parent widget
+        @type QWidget
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsNewProjectOptionsDialog(self, parent=None):
         """
         Public method to get a dialog to enter repository info for getting a
         new project.
 
-        @param parent parent widget (QWidget)
-        @exception RuntimeError to indicate that this method must be
+        @param parent parent widget
+        @type QWidget
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
     def vcsRepositoryInfos(self, ppath):
         """
         Public method to retrieve information about the repository.
 
-        @param ppath local path to get the repository infos (string)
-        @return string with ready formated info for display (string)
-        @exception RuntimeError to indicate that this method must be
+        @param ppath local path to get the repository infos
+        @type str
+        @return string with ready formated info for display
+        @rtype str
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return ""
 
@@ -620,14 +682,18 @@ class VersionControl(QObject):
         project browsers.
 
         @param browser reference to the project browser object
+        @type ProjectBaseBrowser
         @param project reference to the project object
+        @type Project
         @param isTranslationsBrowser flag indicating, the helper is requested
             for the translations browser (this needs some special treatment)
+        @type bool
         @return the project browser helper object
-        @exception RuntimeError to indicate that this method must be
+        @rtype VcsProjectBrowserHelper
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return None  # __IGNORE_WARNING_M831__
 
@@ -636,11 +702,13 @@ class VersionControl(QObject):
         Public method to instanciate a helper object for the project.
 
         @param project reference to the project object
+        @type Project
         @return the project helper object
-        @exception RuntimeError to indicate that this method must be
+        @rtype VcsProjectHelper
+        @exception NotImplementedError to indicate that this method must be
             implemented by a subclass
         """
-        raise RuntimeError("Not implemented")
+        raise NotImplementedError("Not implemented")
 
         return None  # __IGNORE_WARNING_M831__
 
@@ -661,7 +729,8 @@ class VersionControl(QObject):
         This method could ensure, that certain files or directories are
         exclude from being version controlled.
 
-        @param project reference to the project (Project)
+        @param project reference to the project
+        @type Project
         """
         pass
 
@@ -670,7 +739,7 @@ class VersionControl(QObject):
         Public method to signal the support of user settable command options.
 
         @return flag indicating the support  of user settable command options
-            (boolean)
+        @rtype bool
         """
         return True
 
@@ -679,7 +748,8 @@ class VersionControl(QObject):
         Public method used to set the options for the vcs.
 
         @param options a dictionary of option strings with keys as
-                defined by the default options
+            defined by the default options
+        @type dict
         """
         if self.vcsSupportCommandOptions():
             for key in options:
@@ -692,6 +762,7 @@ class VersionControl(QObject):
 
         @return a dictionary of option strings that can be passed to
             vcsSetOptions.
+        @rtype dict
         """
         if self.vcsSupportCommandOptions():
             return self.options
@@ -703,6 +774,7 @@ class VersionControl(QObject):
         Public method used to set vcs specific data.
 
         @param data a dictionary of vcs specific data
+        @type dict
         """
         for key in data:
             with contextlib.suppress(KeyError):
@@ -713,6 +785,7 @@ class VersionControl(QObject):
         Public method used to retrieve vcs specific data.
 
         @return a dictionary of vcs specific data
+        @rtype dict
         """
         return self.otherData
 
@@ -720,8 +793,10 @@ class VersionControl(QObject):
         """
         Public method used to set an entry in the otherData dictionary.
 
-        @param key the key of the data (string)
+        @param key the key of the data
+        @type str
         @param value the value of the data
+        @type Any
         """
         if key in self.interestingDataKeys:
             self.otherData[key] = value
@@ -731,12 +806,13 @@ class VersionControl(QObject):
         Public method used to set entries in the otherData dictionary.
 
         @param dictionary dictionary to pick entries from
+        @type dict
         """
         for key in self.interestingDataKeys:
             if key in dictionary:
                 self.otherData[key] = dictionary[key]
 
-    def vcsResolved(self, name):
+    def vcsResolved(self, name):  # noqa: U100
         """
         Public method used to resolve conflicts of a file/directory.
 
@@ -757,11 +833,16 @@ class VersionControl(QObject):
         This method starts a process and waits
         for its end while still serving the Qt event loop.
 
-        @param proc process to start (QProcess)
-        @param program path of the executable to start (string)
-        @param arguments list of arguments for the process (list of strings)
-        @param workingDir working directory for the process (string)
-        @return flag indicating normal exit (boolean)
+        @param proc process to start
+        @type QProcess
+        @param program path of the executable to start
+        @type str
+        @param arguments list of arguments for the process
+        @type list of str
+        @param workingDir working directory for the process
+        @type str
+        @return flag indicating normal exit
+        @rtype bool
         """
         if proc is None:
             return False
@@ -795,8 +876,10 @@ class VersionControl(QObject):
         """
         Public method splitting name into a directory part and a file part.
 
-        @param name path name (string)
-        @return a tuple of 2 strings (dirname, filename).
+        @param name path name
+        @type str
+        @return tuple containing the directory name and the file name
+        @rtype tuple of (str, str)
         """
         if os.path.isdir(name):
             dn = os.path.abspath(name)
@@ -810,8 +893,10 @@ class VersionControl(QObject):
         Public method splitting the list of names into a common directory part
         and a file list.
 
-        @param names list of paths (list of strings)
-        @return a tuple of string and list of strings (dirname, filenamelist)
+        @param names list of paths
+        @type list of str
+        @return tuple containing the directory name and the file name list
+        @rtype tuple of (str, list of str)
         """
         dname = os.path.commonprefix(names)
         if dname:
@@ -828,8 +913,10 @@ class VersionControl(QObject):
         Public method to add an argument list to the already present
         arguments.
 
-        @param args current arguments list (list of strings)
-        @param argslist list of arguments (list of strings)
+        @param args current arguments list
+        @type list of str
+        @param argslist list of arguments
+        @type list of str
         """
         for arg in argslist:
             if arg != "":
@@ -894,7 +981,9 @@ class VersionControl(QObject):
         Public method to start the VCS status monitor thread.
 
         @param project reference to the project object
-        @return reference to the monitor thread (QThread)
+        @type Project
+        @return reference to the monitor thread
+        @rtype QThread
         """
         vcsStatusMonitorInterval = (
             project.pudata["VCSSTATUSMONITORINTERVAL"]
@@ -960,8 +1049,10 @@ class VersionControl(QObject):
         """
         Public method to change the monitor interval.
 
-        @param interval new interval in seconds (integer)
+        @param interval new interval in seconds
+        @type int
         @param project reference to the project object
+        @type Project
         """
         if self.statusMonitorThread is not None:
             if interval == 0:
@@ -975,7 +1066,8 @@ class VersionControl(QObject):
         """
         Public method to get the monitor interval.
 
-        @return interval in seconds (integer)
+        @return interval in seconds
+        @rtype int
         """
         if self.statusMonitorThread is not None:
             return self.statusMonitorThread.getInterval()
@@ -986,7 +1078,8 @@ class VersionControl(QObject):
         """
         Public method to enable the auto update function.
 
-        @param auto status of the auto update function (boolean)
+        @param auto status of the auto update function
+        @type bool
         """
         if self.statusMonitorThread is not None:
             self.statusMonitorThread.setAutoUpdate(auto)
@@ -995,7 +1088,8 @@ class VersionControl(QObject):
         """
         Public method to retrieve the status of the auto update function.
 
-        @return status of the auto update function (boolean)
+        @return status of the auto update function
+        @rtype bool
         """
         if self.statusMonitorThread is not None:
             return self.statusMonitorThread.getAutoUpdate()
@@ -1015,12 +1109,13 @@ class VersionControl(QObject):
         """
         Public method to clear the cached VCS state of a file/directory.
 
-        @param name name of the entry to be cleared (string)
+        @param name name of the entry to be cleared
+        @type str
         """
         if self.statusMonitorThread is not None:
             self.statusMonitorThread.clearCachedState(name)
 
-    def _createStatusMonitorThread(self, interval, project):
+    def _createStatusMonitorThread(self, interval, project):  # noqa: U100
         """
         Protected method to create an instance of the VCS status monitor
         thread.
@@ -1029,8 +1124,10 @@ class VersionControl(QObject):
         support VCS status monitoring.
 
         @param interval check interval for the monitor thread in seconds
-            (integer)
+        @type int
         @param project reference to the project object
-        @return reference to the monitor thread (QThread)
+        @type Project
+        @return reference to the monitor thread
+        @rtype QThread
         """
         return None  # __IGNORE_WARNING_M831__
