@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -51,10 +51,14 @@ class AdBlockSubscription(QObject):
         """
         Constructor
 
-        @param url AdBlock URL for the subscription (QUrl)
-        @param custom flag indicating a custom subscription (boolean)
-        @param parent reference to the parent object (QObject)
-        @param default flag indicating a default subscription (boolean)
+        @param url AdBlock URL for the subscription
+        @type QUrl
+        @param custom flag indicating a custom subscription
+        @type bool
+        @param parent reference to the parent object
+        @type QObject
+        @param default flag indicating a default subscription
+        @type bool
         """
         super().__init__(parent)
 
