@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,6 +8,7 @@ Module implementing the bookmarks manager.
 """
 
 import contextlib
+import enum
 import os
 import pathlib
 
@@ -29,14 +30,20 @@ from eric7 import Globals
 from eric7.EricWidgets import EricFileDialog, EricMessageBox
 from eric7.Utilities.AutoSaver import AutoSaver
 
-from .BookmarkNode import BookmarkNode
+from .BookmarkNode import BookmarkNode, BookmarkNodeType, BookmarkTimestampType
 
 BOOKMARKBAR = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Bar")
 BOOKMARKMENU = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Menu")
 
-StartRoot = 0
-StartMenu = 1
-StartToolBar = 2
+
+class BookmarkSearchStart(enum.Enum):
+    """
+    Class defining the start points for bookmark searches.
+    """
+
+    Root = 0
+    Menu = 1
+    ToolBar = 2
 
 
 class BookmarksManager(QObject):
@@ -63,7 +70,8 @@ class BookmarksManager(QObject):
         """
         Constructor
 
-        @param parent reference to the parent object (QObject)
+        @param parent reference to the parent object
+        @type QObject
         """
         super().__init__(parent)
 
@@ -90,7 +98,8 @@ class BookmarksManager(QObject):
         """
         Class method to get the file name of the bookmark file.
 
-        @return name of the bookmark file (string)
+        @return name of the bookmark file
+        @rtype str
         """
         return os.path.join(Globals.getConfigDir(), "web_browser", "bookmarks.xbel")
 
@@ -104,7 +113,8 @@ class BookmarksManager(QObject):
         """
         Public method to get a reference to the undo stack.
 
-        @return reference to the undo stack (QUndoStack)
+        @return reference to the undo stack
+        @rtype QUndoStack
         """
         return self.__commands
 
@@ -160,7 +170,7 @@ class BookmarksManager(QObject):
         others = []
         for index in range(len(self.__bookmarkRootNode.children()) - 1, -1, -1):
             node = self.__bookmarkRootNode.children()[index]
-            if node.type() == BookmarkNode.Folder:
+            if node.type() == BookmarkNodeType.Folder:
                 if (
                     node.title == self.tr("Toolbar Bookmarks")
                     or node.title == BOOKMARKBAR
@@ -181,13 +191,15 @@ class BookmarksManager(QObject):
             raise RuntimeError("Error loading bookmarks.")
 
         if self.__toolbar is None:
-            self.__toolbar = BookmarkNode(BookmarkNode.Folder, self.__bookmarkRootNode)
+            self.__toolbar = BookmarkNode(
+                BookmarkNodeType.Folder, self.__bookmarkRootNode
+            )
             self.__toolbar.title = self.tr(BOOKMARKBAR)
         else:
             self.__bookmarkRootNode.add(self.__toolbar)
 
         if self.__menu is None:
-            self.__menu = BookmarkNode(BookmarkNode.Folder, self.__bookmarkRootNode)
+            self.__menu = BookmarkNode(BookmarkNodeType.Folder, self.__bookmarkRootNode)
             self.__menu.title = self.tr(BOOKMARKMENU)
         else:
             self.__bookmarkRootNode.add(self.__menu)
@@ -229,14 +241,19 @@ class BookmarksManager(QObject):
         """
         Public method to add a bookmark.
 
-        @param parent reference to the node to add to (BookmarkNode)
-        @param node reference to the node to add (BookmarkNode)
-        @param row row number (integer)
+        @param parent reference to the node to add to
+        @type BookmarkNode
+        @param node reference to the node to add
+        @type BookmarkNode
+        @param row row number
+        @type int
         """
         if not self.__loaded:
             return
 
-        self.setTimestamp(node, BookmarkNode.TsAdded, QDateTime.currentDateTime())
+        self.setTimestamp(
+            node, BookmarkTimestampType.Added, QDateTime.currentDateTime()
+        )
 
         command = InsertBookmarksCommand(self, parent, node, row)
         self.__commands.push(command)
@@ -245,7 +262,8 @@ class BookmarksManager(QObject):
         """
         Public method to remove a bookmark.
 
-        @param node reference to the node to be removed (BookmarkNode)
+        @param node reference to the node to be removed
+        @type BookmarkNode
         """
         if not self.__loaded:
             return
@@ -259,8 +277,10 @@ class BookmarksManager(QObject):
         """
         Public method to set the title of a bookmark.
 
-        @param node reference to the node to be changed (BookmarkNode)
-        @param newTitle title to be set (string)
+        @param node reference to the node to be changed
+        @type BookmarkNode
+        @param newTitle title to be set
+        @type str
         """
         if not self.__loaded:
             return
@@ -272,8 +292,10 @@ class BookmarksManager(QObject):
         """
         Public method to set the URL of a bookmark.
 
-        @param node reference to the node to be changed (BookmarkNode)
-        @param newUrl URL to be set (string)
+        @param node reference to the node to be changed
+        @type BookmarkNode
+        @param newUrl URL to be set
+        @type str
         """
         if not self.__loaded:
             return
@@ -281,12 +303,10 @@ class BookmarksManager(QObject):
         command = ChangeBookmarkCommand(self, node, newUrl, False)
         self.__commands.push(command)
 
-    def setNodeChanged(self, node):
+    def setNodeChanged(self):
         """
         Public method to signal changes of bookmarks other than title, URL
         or timestamp.
-
-        @param node reference to the bookmark (BookmarkNode)
         """
         self.__saveTimer.changeOccurred()
 
@@ -294,20 +314,21 @@ class BookmarksManager(QObject):
         """
         Public method to set the URL of a bookmark.
 
-        @param node reference to the node to be changed (BookmarkNode)
+        @param node reference to the node to be changed
+        @type BookmarkNode
         @param timestampType type of the timestamp to set
-            (BookmarkNode.TsAdded, BookmarkNode.TsModified,
-            BookmarkNode.TsVisited)
-        @param timestamp timestamp to set (QDateTime)
+        @type BookmarkTimestampType
+        @param timestamp timestamp to set
+        @type QDateTime
         """
         if not self.__loaded:
             return
 
-        if timestampType == BookmarkNode.TsAdded:
+        if timestampType == BookmarkTimestampType.Added:
             node.added = timestamp
-        elif timestampType == BookmarkNode.TsModified:
+        elif timestampType == BookmarkTimestampType.Modified:
             node.modified = timestamp
-        elif timestampType == BookmarkNode.TsVisited:
+        elif timestampType == BookmarkTimestampType.Visited:
             node.visited = timestamp
         self.__saveTimer.changeOccurred()
 
@@ -315,7 +336,8 @@ class BookmarksManager(QObject):
         """
         Public method to increment the visit count of a bookmark.
 
-        @param node reference to the node to be changed (BookmarkNode)
+        @param node reference to the node to be changed
+        @type BookmarkNode
         """
         if not self.__loaded:
             return
@@ -328,8 +350,10 @@ class BookmarksManager(QObject):
         """
         Public method to set the visit count of a bookmark.
 
-        @param node reference to the node to be changed (BookmarkNode)
-        @param count visit count to be set (int or str)
+        @param node reference to the node to be changed
+        @type BookmarkNode
+        @param count visit count to be set
+        @type int or str
         """
         with contextlib.suppress(ValueError):
             node.visitCount = int(count)
@@ -339,7 +363,8 @@ class BookmarksManager(QObject):
         """
         Public method to get a reference to the root bookmark node.
 
-        @return reference to the root bookmark node (BookmarkNode)
+        @return reference to the root bookmark node
+        @rtype BookmarkNode
         """
         if not self.__loaded:
             self.load()
@@ -350,7 +375,8 @@ class BookmarksManager(QObject):
         """
         Public method to get a reference to the bookmarks menu node.
 
-        @return reference to the bookmarks menu node (BookmarkNode)
+        @return reference to the bookmarks menu node
+        @rtype BookmarkNode
         """
         if not self.__loaded:
             self.load()
@@ -361,7 +387,8 @@ class BookmarksManager(QObject):
         """
         Public method to get a reference to the bookmarks toolbar node.
 
-        @return reference to the bookmarks toolbar node (BookmarkNode)
+        @return reference to the bookmarks toolbar node
+        @rtype BookmarkNode
         """
         if not self.__loaded:
             self.load()
@@ -372,7 +399,8 @@ class BookmarksManager(QObject):
         """
         Public method to get a reference to the bookmarks model.
 
-        @return reference to the bookmarks model (BookmarksModel)
+        @return reference to the bookmarks model
+        @rtype BookmarksModel
         """
         from .BookmarksModel import BookmarksModel
 
@@ -434,7 +462,8 @@ class BookmarksManager(QObject):
         """
         Public slot to update the icon image for an URL.
 
-        @param url URL of the icon to update (QUrl or string)
+        @param url URL of the icon to update
+        @type QUrl or str
         """
         if isinstance(url, QUrl):
             url = url.toString()
@@ -442,18 +471,20 @@ class BookmarksManager(QObject):
         for node in nodes:
             self.bookmarksModel().entryChanged(node)
 
-    def bookmarkForUrl(self, url, start=StartRoot):
+    def bookmarkForUrl(self, url, start=BookmarkSearchStart.Root):
         """
         Public method to get a bookmark node for a given URL.
 
-        @param url URL of the bookmark to search for (QUrl or string)
+        @param url URL of the bookmark to search for
+        @type QUrl or str
         @param start indicator for the start of the search
-            (StartRoot, StartMenu, StartToolBar)
-        @return bookmark node for the given url (BookmarkNode)
+        @type BookmarkSearchStart
+        @return bookmark node for the given url
+        @rtype BookmarkNode
         """
-        if start == StartMenu:
+        if start == BookmarkSearchStart.Menu:
             startNode = self.__menu
-        elif start == StartToolBar:
+        elif start == BookmarkSearchStart.ToolBar:
             startNode = self.__toolbar
         else:
             startNode = self.__bookmarkRootNode
@@ -469,33 +500,37 @@ class BookmarksManager(QObject):
         """
         Private method get a bookmark node for a given URL.
 
-        @param url URL of the bookmark to search for (string)
+        @param url URL of the bookmark to search for
+        @type str
         @param startNode reference to the node to start searching
-            (BookmarkNode)
-        @return bookmark node for the given url (BookmarkNode)
+        @type BookmarkNode
+        @return bookmark node for the given url
+        @rtype BookmarkNode
         """
         bm = None
         for node in startNode.children():
-            if node.type() == BookmarkNode.Folder:
+            if node.type() == BookmarkNodeType.Folder:
                 bm = self.__searchBookmark(url, node)
-            elif node.type() == BookmarkNode.Bookmark and node.url == url:
+            elif node.type() == BookmarkNodeType.Bookmark and node.url == url:
                 bm = node
             if bm is not None:
                 return bm
         return None
 
-    def bookmarksForUrl(self, url, start=StartRoot):
+    def bookmarksForUrl(self, url, start=BookmarkSearchStart.Root):
         """
         Public method to get a list of bookmark nodes for a given URL.
 
-        @param url URL of the bookmarks to search for (QUrl or string)
+        @param url URL of the bookmarks to search for
+        @type QUrl or str
         @param start indicator for the start of the search
-            (StartRoot, StartMenu, StartToolBar)
-        @return list of bookmark nodes for the given url (list of BookmarkNode)
+        @type BookmarkSearchStart
+        @return list of bookmark nodes for the given url
+        @rtype list of BookmarkNode
         """
-        if start == StartMenu:
+        if start == BookmarkSearchStart.Menu:
             startNode = self.__menu
-        elif start == StartToolBar:
+        elif start == BookmarkSearchStart.ToolBar:
             startNode = self.__toolbar
         else:
             startNode = self.__bookmarkRootNode
@@ -511,16 +546,18 @@ class BookmarksManager(QObject):
         """
         Private method get a list of bookmark nodes for a given URL.
 
-        @param url URL of the bookmarks to search for (string)
+        @param url URL of the bookmarks to search for
+        @type str
         @param startNode reference to the node to start searching
-            (BookmarkNode)
-        @return list of bookmark nodes for the given url (list of BookmarkNode)
+        @type BookmarkNode
+        @return list of bookmark nodes for the given url
+        @rtype list of BookmarkNode
         """
         bm = []
         for node in startNode.children():
-            if node.type() == BookmarkNode.Folder:
+            if node.type() == BookmarkNodeType.Folder:
                 bm.extend(self.__searchBookmarks(url, node))
-            elif node.type() == BookmarkNode.Bookmark and node.url == url:
+            elif node.type() == BookmarkNodeType.Bookmark and node.url == url:
                 bm.append(node)
         return bm
 
@@ -535,9 +572,11 @@ class RemoveBookmarksCommand(QUndoCommand):
         Constructor
 
         @param bookmarksManager reference to the bookmarks manager
-            (BookmarksManager)
-        @param parent reference to the parent node (BookmarkNode)
-        @param row row number of bookmark (integer)
+        @type BookmarksManager
+        @param parent reference to the parent node
+        @type BookmarkNode
+        @param row row number of bookmark
+        @type int
         """
         super().__init__(
             QCoreApplication.translate("BookmarksManager", "Remove Bookmark")
@@ -576,10 +615,13 @@ class InsertBookmarksCommand(RemoveBookmarksCommand):
         Constructor
 
         @param bookmarksManager reference to the bookmarks manager
-            (BookmarksManager)
-        @param parent reference to the parent node (BookmarkNode)
-        @param node reference to the node to be inserted (BookmarkNode)
-        @param row row number of bookmark (integer)
+        @type BookmarksManager
+        @param parent reference to the parent node
+        @type BookmarkNode
+        @param node reference to the node to be inserted
+        @type BookmarkNode
+        @param row row number of bookmark
+        @type int
         """
         RemoveBookmarksCommand.__init__(self, bookmarksManager, parent, row)
         self.setText(QCoreApplication.translate("BookmarksManager", "Insert Bookmark"))
@@ -608,11 +650,14 @@ class ChangeBookmarkCommand(QUndoCommand):
         Constructor
 
         @param bookmarksManager reference to the bookmarks manager
-            (BookmarksManager)
-        @param node reference to the node to be changed (BookmarkNode)
-        @param newValue new value to be set (string)
+        @type BookmarksManager
+        @param node reference to the node to be changed
+        @type BookmarkNode
+        @param newValue new value to be set
+        @type str
         @param title flag indicating a change of the title (True) or
-            the URL (False) (boolean)
+            the URL (False)
+        @type bool
         """
         super().__init__()
 
