@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,8 +23,9 @@ class OpenSearchEngineAction(QAction):
         Constructor
 
         @param engine reference to the open search engine object
-            (OpenSearchEngine)
-        @param parent reference to the parent object (QObject)
+        @type OpenSearchEngine
+        @param parent reference to the parent object
+        @type QObject
         """
         super().__init__(parent)
 
