@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -36,18 +36,28 @@ class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
     DocumentationDirRole = Qt.ItemDataRole.UserRole + 2
     LocalesRole = Qt.ItemDataRole.UserRole + 3
 
-    def __init__(self, writeableDirectories, parent=None):
+    def __init__(
+        self,
+        writeableDirectories,
+        enforceUnencryptedDownloads=False,
+        parent=None,
+    ):
         """
         Constructor
 
         @param writeableDirectories list of writable directories
         @type list of str
-        @param parent reference to the parent widget
-        @type QWidget
+        @param enforceUnencryptedDownloads flag indicating to perform unencrypted
+            downloads (defaults to False)
+        @type bool (optional)
+        @param parent reference to the parent widget (defaults to None)
+        @type QWidget (optional)
         """
         super().__init__(parent)
         self.setupUi(self)
 
+        self.__enforceUnencryptedDownloads = enforceUnencryptedDownloads
+
         self.__refreshButton = self.buttonBox.addButton(
             self.tr("Refresh"), QDialogButtonBox.ButtonRole.ActionRole
         )
@@ -154,7 +164,8 @@ class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
         Private slot to set the read only status of the dictionaries URL line
         edit.
 
-        @param checked state of the push button (boolean)
+        @param checked state of the push button
+        @type bool
         """
         self.dictionariesUrlEdit.setReadOnly(not checked)
 
@@ -176,6 +187,10 @@ class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
         self.downloadProgress.setValue(0)
 
         url = self.dictionariesUrlEdit.text()
+        if self.__enforceUnencryptedDownloads or Preferences.getWebBrowser(
+            "ForceHttpDictionaryDownload"
+        ):
+            url = url.replace("https://", "http://")
 
         if self.__online:
             self.__refreshButton.setEnabled(False)
@@ -371,6 +386,10 @@ class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
         if self.__online:
             if self.__dictionariesToDownload:
                 url = self.__dictionariesToDownload.pop(0)
+                if self.__enforceUnencryptedDownloads or Preferences.getWebBrowser(
+                    "ForceHttpDictionaryDownload"
+                ):
+                    url = url.replace("https://", "http://")
                 self.statusLabel.setText(url)
 
                 self.__downloadCancelled = False
@@ -471,7 +490,9 @@ class ManageDictionariesDialog(QDialog, Ui_ManageDictionariesDialog):
         ]
         for itm in itemsToDelete:
             documentationDir = itm.data(ManageDictionariesDialog.DocumentationDirRole)
-            shutil.rmtree(os.path.join(installLocation, documentationDir), True)
+            shutil.rmtree(
+                os.path.join(installLocation, documentationDir), ignore_errors=True
+            )
 
             locales = itm.data(ManageDictionariesDialog.LocalesRole)
             for locale in locales:
