@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,6 +13,7 @@ Module implementing a window for managing the web browser tabs.
 #
 
 import collections
+import enum
 import os
 
 from PyQt6.QtCore import QPoint, QRect, Qt, QTimer, pyqtSignal, pyqtSlot
@@ -33,21 +34,31 @@ from eric7.EricWidgets.EricApplication import ericApp
 from eric7.EricWidgets.EricClickableLabel import EricClickableLabel
 
 
+class TabGroupByType(enum.Enum):
+    """
+    Class defining the supported "Group By" types.
+    """
+
+    Window = 0
+    Domain = 1
+    Host = 2
+
+
+TabGroupByDefaultType = TabGroupByType.Window
+
+
 class TabManagerWidget(QWidget):
     """
     Class implementing a window for managing the web browser tabs.
 
-    @signal groupTypeChanged(int) emitted when the 'Group By' value was changed
+    @signal groupTypeChanged(TabGroupByType) emitted when the 'Group By' value
+        was changed
     """
 
-    GroupByWindow = 0
-    GroupByDomain = 1
-    GroupByHost = 2
-
     WebBrowserRole = Qt.ItemDataRole.UserRole + 1
     WebWindowRole = Qt.ItemDataRole.UserRole + 2
 
-    groupTypeChanged = pyqtSignal(int)
+    groupTypeChanged = pyqtSignal(TabGroupByType)
 
     _tldExtractor = None
 
@@ -82,7 +93,13 @@ class TabManagerWidget(QWidget):
         self.__refreshBlocked = False
         self.__waitForRefresh = False
         self.__isDefaultWidget = defaultWidget
-        self.__groupType = Preferences.getWebBrowser("TabManagerGroupByType")
+        try:
+            self.__groupType = TabGroupByType(
+                Preferences.getWebBrowser("TabManagerGroupByType")
+            )
+        except ValueError:
+            # use default
+            self.__groupType = TabGroupByDefaultType
 
         if TabManagerWidget._tldExtractor is None:
             TabManagerWidget._tldExtractor = EricTldExtractor.instance()
@@ -122,7 +139,7 @@ class TabManagerWidget(QWidget):
             as value
         """
         from ..Bookmarks.AddBookmarkDialog import AddBookmarkDialog
-        from ..Bookmarks.BookmarkNode import BookmarkNode
+        from ..Bookmarks.BookmarkNode import BookmarkNode, BookmarkNodeType
 
         if not browsersDict:
             return
@@ -139,7 +156,7 @@ class TabManagerWidget(QWidget):
         for mainWin in browsersDict:
             for browser in browsersDict[mainWin]:
                 if not browser.url().isEmpty() and browser.url().scheme() != "eric":
-                    bookmark = BookmarkNode(BookmarkNode.Bookmark)
+                    bookmark = BookmarkNode(BookmarkNodeType.Bookmark)
                     bookmark.url = bytes(browser.url().toEncoded()).decode()
                     bookmark.title = browser.title()
 
@@ -153,7 +170,7 @@ class TabManagerWidget(QWidget):
         @type int (0 - 2)
         """
         self.__groupType = groupType
-        Preferences.setWebBrowser("TabManagerGroupByType", groupType)
+        Preferences.setWebBrowser("TabManagerGroupByType", groupType.value)
 
     def domainFromUrl(self, url, useHostName=False):
         """
@@ -380,13 +397,13 @@ class TabManagerWidget(QWidget):
 
         self.__tree.clear()
 
-        if self.__groupType == TabManagerWidget.GroupByHost:
+        if self.__groupType == TabGroupByType.Host:
             self.__groupByDomainName(True)
-        elif self.__groupType == TabManagerWidget.GroupByDomain:
+        elif self.__groupType == TabGroupByType.Domain:
             self.__groupByDomainName()
         else:
             # default is group by window
-            self.__setGroupType(TabManagerWidget.GroupByWindow)
+            self.__setGroupType(TabGroupByType.Window)
             self.__groupByWindow()
 
         # restore selected items
@@ -504,19 +521,19 @@ class TabManagerWidget(QWidget):
         menu = QMenu()
         groupTypeSubMenu = QMenu(self.tr("Group by"))
         act = groupTypeSubMenu.addAction(self.tr("&Window"))
-        act.setData(TabManagerWidget.GroupByWindow)
+        act.setData(TabGroupByType.Window)
         act.setCheckable(True)
-        act.setChecked(self.__groupType == TabManagerWidget.GroupByWindow)
+        act.setChecked(self.__groupType == TabGroupByType.Window)
 
         act = groupTypeSubMenu.addAction(self.tr("&Domain"))
-        act.setData(TabManagerWidget.GroupByDomain)
+        act.setData(TabGroupByType.Domain)
         act.setCheckable(True)
-        act.setChecked(self.__groupType == TabManagerWidget.GroupByDomain)
+        act.setChecked(self.__groupType == TabGroupByType.Domain)
 
         act = groupTypeSubMenu.addAction(self.tr("&Host"))
-        act.setData(TabManagerWidget.GroupByHost)
+        act.setData(TabGroupByType.Host)
         act.setCheckable(True)
-        act.setChecked(self.__groupType == TabManagerWidget.GroupByHost)
+        act.setChecked(self.__groupType == TabGroupByType.Host)
         groupTypeSubMenu.triggered.connect(self.changeGroupType)
 
         menu.addMenu(groupTypeSubMenu)
@@ -537,14 +554,12 @@ class TabManagerWidget(QWidget):
 
         menu.exec(self.__tree.viewport().mapToGlobal(pos))
 
-    def mainWindowCreated(self, mainWin, refresh=True):
+    def mainWindowCreated(self, mainWin):
         """
         Public method to act on the creation of a new web browser window.
 
         @param mainWin reference to the web browser window
         @type WebBrowserWindow
-        @param refresh flag indicating to refresh the widget
-        @type bool
         """
         mainWin.webBrowserWindowClosed.connect(self.delayedRefreshTree)
         mainWin.webBrowserWindowOpened.connect(self.mainWindowCreated)
