@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2020 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -24,7 +24,8 @@ class SslLabel(EricClickableLabel):
         """
         Constructor
 
-        @param parent reference to the parent widget (QWidget)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent)
 
@@ -34,7 +35,8 @@ class SslLabel(EricClickableLabel):
         """
         Public method to set the validity indication.
 
-        @param valid flag indicating the certificate validity (boolean)
+        @param valid flag indicating the certificate validity
+        @type bool
         """
         if valid:
             self.setStyleSheet(SslLabel.okStyle)
