@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -115,7 +115,7 @@ class WebBrowserPage(QWebEnginePage):
         the page.
 
         @return reference to the WebBrowserView associated with the page
-        r@type WebBrowserView
+        @rtype WebBrowserView
         """
         return self.__view
 
@@ -255,8 +255,10 @@ class WebBrowserPage(QWebEnginePage):
         Class method to get the global user agent setting.
 
         @param resolveEmpty flag indicating to resolve an empty
-            user agent (boolean)
-        @return user agent string (string)
+            user agent
+        @type bool
+        @return user agent string
+        @rtype str
         """
         agent = Preferences.getWebBrowser("UserAgent")
         if agent == "" and resolveEmpty:
@@ -268,7 +270,8 @@ class WebBrowserPage(QWebEnginePage):
         """
         Class method to set the global user agent string.
 
-        @param agent new current user agent string (string)
+        @param agent new current user agent string
+        @type str
         """
         Preferences.setWebBrowser("UserAgent", agent)
 
@@ -277,8 +280,10 @@ class WebBrowserPage(QWebEnginePage):
         """
         Class method to determine the user agent for the given URL.
 
-        @param url URL to determine user agent for (QUrl)
-        @return user agent string (string)
+        @param url URL to determine user agent for
+        @type QUrl
+        @return user agent string
+        @rtype str
         """
         agent = WebBrowserWindow.userAgentsManager().userAgentForUrl(url)
         if agent == "":
@@ -463,38 +468,13 @@ class WebBrowserPage(QWebEnginePage):
         else:
             request.reject()
 
-    def execPrintPage(self, printer, timeout=1000):
-        """
-        Public method to execute a synchronous print.
-
-        @param printer reference to the printer object
-        @type QPrinter
-        @param timeout timeout value in milliseconds
-        @type int
-        @return flag indicating a successful print job
-        @rtype bool
-        """
-        loop = QEventLoop()
-        resultDict = {"res": None}
-        QTimer.singleShot(timeout, loop.quit)
-
-        def printCallback(res, resDict=resultDict):
-            if loop and loop.isRunning():
-                resDict["res"] = res
-                loop.quit()
-
-        self.print(printer, printCallback)
-
-        loop.exec()
-        return resultDict["res"]
-
-    def __contentsSizeChanged(self, size):
+    def __contentsSizeChanged(self, size):  # noqa: U100
         """
         Private slot to work around QWebEnginePage not scrolling to anchors
         when opened in a background tab.
 
         @param size changed contents size (unused)
-        @type QSize
+        @type QSizeF
         """
         fragment = self.url().fragment()
         self.runJavaScript(Scripts.scrollToAnchor(fragment))
