@@ -1,59 +1,32 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the central widget showing the web pages.
 """
 
-import os
-
-from PyQt6.QtCore import QMarginsF, Qt, QUrl, pyqtSignal, pyqtSlot
-from PyQt6.QtGui import QIcon, QPageLayout, QPainter, QPixmap
-from PyQt6.QtPrintSupport import (
-    QAbstractPrintDialog,
-    QPrintDialog,
-    QPrinter,
-    QPrintPreviewDialog,
-)
-from PyQt6.QtWidgets import QDialog, QHBoxLayout, QMenu, QToolButton, QWidget
+from PyQt6.QtCore import Qt, QUrl, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QIcon, QPainter, QPixmap
+from PyQt6.QtWidgets import QHBoxLayout, QMenu, QToolButton, QWidget
 
 from eric7 import Preferences
 from eric7.EricGui import EricPixmapCache
-from eric7.EricGui.EricOverrideCursor import EricOverrideCursor
 from eric7.EricWidgets import EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
 from eric7.EricWidgets.EricTabWidget import EricTabWidget
-from eric7.SystemUtilities import FileSystemUtilities, OSUtilities
+from eric7.SystemUtilities import FileSystemUtilities
 from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 
 from . import WebInspector
 from .ClosedTabsManager import ClosedTabsManager
-from .Tools import WebBrowserTools
 from .UrlBar.StackedUrlBar import StackedUrlBar
 from .WebBrowserPage import WebBrowserPage
 from .WebBrowserTabBar import WebBrowserTabBar
 from .WebBrowserView import WebBrowserView
 
 
-def isCupsAvailable():
-    """
-    Static method to test the availability of CUPS.
-
-    @return flag indicating the availability of CUPS
-    @rtype bool
-    """
-    if OSUtilities.isMacPlatform():
-        # OS X/MacOS always have CUPS
-        return True
-    elif OSUtilities.isLinuxPlatform():
-        testPrinter = QPrinter()
-        return testPrinter.supportsMultipleCopies()
-    else:
-        return False
-
-
 class WebBrowserTabWidget(EricTabWidget):
     """
     Class implementing the central widget showing the web pages.
@@ -84,7 +57,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Constructor
 
-        @param parent reference to the parent widget (QWidget)
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super().__init__(parent, dnd=True)
 
@@ -254,8 +228,10 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private slot to show the tab context menu.
 
-        @param coord the position of the mouse pointer (QPoint)
-        @param index index of the tab the menu is requested for (integer)
+        @param coord the position of the mouse pointer
+        @type QPoint
+        @param index index of the tab the menu is requested for
+        @type int
         """
         coord = self.mapToGlobal(coord)
         if index == -1:
@@ -500,10 +476,12 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to create a new web browser tab after a given one.
 
-        @param browser reference to the browser to add after (WebBrowserView)
-        @param link link to be shown (string or QUrl)
-        @param background flag indicating to open the tab in the
-            background (bool)
+        @param browser reference to the browser to add after
+        @type WebBrowserView
+        @param link link to be shown
+        @type str or QUrl
+        @param background flag indicating to open the tab in the background
+        @type bool
         @return reference to the new browser
         @rtype WebBrowserView
         """
@@ -525,7 +503,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private slot called to handle the navigation button menu selection.
 
-        @param act reference to the selected action (QAction)
+        @param act reference to the selected action
+        @type QAction
         """
         index = act.data()
         if index is not None:
@@ -616,7 +595,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to get a reference to the current browser.
 
-        @return reference to the current browser (WebBrowserView)
+        @return reference to the current browser
+        @rtype WebBrowserView
         """
         return self.currentWidget()
 
@@ -624,8 +604,10 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to get a reference to the browser with the given index.
 
-        @param index index of the browser to get (integer)
-        @return reference to the indexed browser (WebBrowserView)
+        @param index index of the browser to get
+        @type int
+        @return reference to the indexed browser
+        @rtype WebBrowserView
         """
         return self.widget(index)
 
@@ -633,7 +615,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to get a list of references to all browsers.
 
-        @return list of references to browsers (list of WebBrowserView)
+        @return list of references to browsers
+        @rtype list of WebBrowserView
         """
         li = []
         for index in range(self.count()):
@@ -645,186 +628,42 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public slot called to print the displayed page.
 
-        @param browser reference to the browser to be printed (WebBrowserView)
+        @param browser reference to the browser to be printed
+        @type WebBrowserView
         """
         if browser is None:
             browser = self.currentBrowser()
 
-        printer = QPrinter(mode=QPrinter.PrinterMode.HighResolution)
-        if Preferences.getPrinter("ColorMode"):
-            printer.setColorMode(QPrinter.ColorMode.Color)
-        else:
-            printer.setColorMode(QPrinter.ColorMode.GrayScale)
-        if Preferences.getPrinter("FirstPageFirst"):
-            printer.setPageOrder(QPrinter.PageOrder.FirstPageFirst)
-        else:
-            printer.setPageOrder(QPrinter.PageOrder.LastPageFirst)
-        printer.setPageMargins(
-            QMarginsF(
-                Preferences.getPrinter("LeftMargin") * 10,
-                Preferences.getPrinter("TopMargin") * 10,
-                Preferences.getPrinter("RightMargin") * 10,
-                Preferences.getPrinter("BottomMargin") * 10,
-            ),
-            QPageLayout.Unit.Millimeter,
-        )
-        printerName = Preferences.getPrinter("PrinterName")
-        if printerName:
-            printer.setPrinterName(printerName)
-        printer.setResolution(Preferences.getPrinter("Resolution"))
-        documentName = WebBrowserTools.getFileNameFromUrl(browser.url())
-        printer.setDocName(documentName)
-
-        printDialog = QPrintDialog(printer, self)
-        printDialog.setOptions(
-            QAbstractPrintDialog.PrintDialogOption.PrintToFile
-            | QAbstractPrintDialog.PrintDialogOption.PrintShowPageSize
-        )
-        if not OSUtilities.isWindowsPlatform():
-            if isCupsAvailable():
-                printDialog.setOption(
-                    QAbstractPrintDialog.PrintDialogOption.PrintCollateCopies
-                )
-            printDialog.setOption(QAbstractPrintDialog.PrintDialogOption.PrintPageRange)
-        if printDialog.exec() == QDialog.DialogCode.Accepted:
-            browser.page().execPrintPage(printer, 10 * 1000)
+        if browser is not None:
+            browser.printPage()
 
     @pyqtSlot()
     def printBrowserPdf(self, browser=None):
         """
         Public slot called to print the displayed page to PDF.
 
-        @param browser reference to the browser to be printed (HelpBrowser)
+        @param browser reference to the browser to be printed
+        @type WebBrowserView
         """
-        from .Tools.PrintToPdfDialog import PrintToPdfDialog
-
         if browser is None:
             browser = self.currentBrowser()
 
-        name = WebBrowserTools.getFileNameFromUrl(browser.url())
-        if name:
-            name = name.rsplit(".", 1)[0]
-            name += ".pdf"
-        if hasattr(browser.page(), "printToPdf"):
-            if not name:
-                name = "printout.pdf"
-            dlg = PrintToPdfDialog(name, self)
-            if dlg.exec() == QDialog.DialogCode.Accepted:
-                filePath, pageLayout = dlg.getData()
-                if filePath:
-                    if os.path.exists(filePath):
-                        res = EricMessageBox.warning(
-                            self,
-                            self.tr("Print to PDF"),
-                            self.tr(
-                                """<p>The file <b>{0}</b> exists"""
-                                """ already. Shall it be"""
-                                """ overwritten?</p>"""
-                            ).format(filePath),
-                            EricMessageBox.No | EricMessageBox.Yes,
-                            EricMessageBox.No,
-                        )
-                        if res == EricMessageBox.No:
-                            return
-                    browser.page().printToPdf(
-                        lambda pdf: self.__pdfGeneratedForSave(filePath, pdf),
-                        pageLayout,
-                    )
-        elif OSUtilities.isLinuxPlatform():
-            printer = QPrinter(mode=QPrinter.PrinterMode.HighResolution)
-            if Preferences.getPrinter("ColorMode"):
-                printer.setColorMode(QPrinter.ColorMode.Color)
-            else:
-                printer.setColorMode(QPrinter.ColorMode.GrayScale)
-            printerName = Preferences.getPrinter("PrinterName")
-            if printerName:
-                printer.setPrinterName(printerName)
-            printer.setOutputFormat(QPrinter.OutputFormat.PdfFormat)
-            if name:
-                printer.setOutputFileName(name)
-            printer.setResolution(Preferences.getPrinter("Resolution"))
-
-            printDialog = QPrintDialog(printer, self)
-            if printDialog.exec() == QDialog.DialogCode.Accepted:
-                browser.render(printer)
-
-    def __pdfGeneratedForSave(self, filePath, pdfData):
-        """
-        Private slot to save the generated PDF data to a file.
-
-        @param filePath path to save the PDF to
-        @type str
-        @param pdfData generated PDF document
-        @type QByteArray
-        """
-        if pdfData.size() == 0:
-            return
-
-        try:
-            with open(filePath, "wb") as f:
-                f.write(pdfData)
-        except OSError as err:
-            EricMessageBox.critical(
-                self,
-                self.tr("Print to PDF"),
-                self.tr(
-                    """<p>The PDF could not be written to file <b>{0}"""
-                    """</b>.</p><p><b>Error:</b> {1}</p>"""
-                ).format(filePath, str(err)),
-                EricMessageBox.Ok,
-            )
+        if browser is not None:
+            browser.printPageToPdf()
 
     @pyqtSlot()
     def printPreviewBrowser(self, browser=None):
         """
         Public slot called to show a print preview of the displayed file.
 
-        @param browser reference to the browser to be printed (WebBrowserView)
+        @param browser reference to the browser to be printed
+        @type WebBrowserView
         """
         if browser is None:
             browser = self.currentBrowser()
 
-        printer = QPrinter(mode=QPrinter.PrinterMode.HighResolution)
-        if Preferences.getPrinter("ColorMode"):
-            printer.setColorMode(QPrinter.ColorMode.Color)
-        else:
-            printer.setColorMode(QPrinter.ColorMode.GrayScale)
-        if Preferences.getPrinter("FirstPageFirst"):
-            printer.setPageOrder(QPrinter.PageOrder.FirstPageFirst)
-        else:
-            printer.setPageOrder(QPrinter.PageOrder.LastPageFirst)
-        printer.setPageMargins(
-            QMarginsF(
-                Preferences.getPrinter("LeftMargin") * 10,
-                Preferences.getPrinter("TopMargin") * 10,
-                Preferences.getPrinter("RightMargin") * 10,
-                Preferences.getPrinter("BottomMargin") * 10,
-            ),
-            QPageLayout.Unit.Millimeter,
-        )
-        printerName = Preferences.getPrinter("PrinterName")
-        if printerName:
-            printer.setPrinterName(printerName)
-        printer.setResolution(Preferences.getPrinter("Resolution"))
-
-        preview = QPrintPreviewDialog(printer, self)
-        preview.resize(800, 750)
-        preview.paintRequested.connect(
-            lambda p: self.__printPreviewRequested(p, browser)
-        )
-        preview.exec()
-
-    def __printPreviewRequested(self, printer, browser):
-        """
-        Private slot to generate the print preview.
-
-        @param printer reference to the printer object
-        @type QPrinter
-        @param browser reference to the browser to be printed
-        @type WebBrowserView
-        """
-        with EricOverrideCursor():
-            browser.page().execPrintPage(printer, 10 * 1000)
+        if browser is not None:
+            browser.printPreviewPage()
 
     def __sourceChanged(self, url, browser):
         """
@@ -862,10 +701,14 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private method to elide some text.
 
-        @param txt text to be elided (string)
-        @param mode elide mode (Qt.TextElideMode)
-        @param length amount of characters to be used (integer)
-        @return the elided text (string)
+        @param txt text to be elided
+        @type str
+        @param mode elide mode
+        @type Qt.TextElideMode
+        @param length amount of characters to be used
+        @type int
+        @return the elided text
+        @rtype str
         """
         if mode == Qt.TextElideMode.ElideNone or len(txt) < length:
             return txt
@@ -889,7 +732,7 @@ class WebBrowserTabWidget(EricTabWidget):
         for urlbar in self.__stackedUrlBar.urlBars():
             urlbar.preferencesChanged()
 
-    def __loadFinished(self, ok, browser):
+    def __loadFinished(self, ok, browser):  # noqa: U100
         """
         Private method to handle the loadFinished signal.
 
@@ -950,6 +793,7 @@ class WebBrowserTabWidget(EricTabWidget):
         Public method to get a list of all opened Qt help files.
 
         @return dictionary with tab id as key and host/namespace as value
+        @rtype dict
         """
         sourceList = {}
         for i in range(self.count()):
@@ -963,7 +807,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to check, if the application should be shut down.
 
-        @return flag indicating a shut down (boolean)
+        @return flag indicating a shut down
+        @rtype bool
         """
         if self.count() > 1 and Preferences.getWebBrowser("WarnOnMultipleClose"):
             mb = EricMessageBox.EricMessageBox(
@@ -999,7 +844,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to get a reference to the stacked url bar.
 
-        @return reference to the stacked url bar (StackedUrlBar)
+        @return reference to the stacked url bar
+        @rtype StackedUrlBar
         """
         return self.__stackedUrlBar
 
@@ -1007,7 +853,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to get a reference to the current url bar.
 
-        @return reference to the current url bar (UrlBar)
+        @return reference to the current url bar
+        @rtype UrlBar
         """
         return self.__stackedUrlBar.currentWidget()
 
@@ -1045,7 +892,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private slot called when a URL is selected from the completer.
 
-        @param path path to be shown (string)
+        @param path path to be shown
+        @type str
         """
         url = self.__guessUrlFromPath(path)
         self.currentBrowser().setSource(url)
@@ -1054,8 +902,10 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private method to guess an URL given a path string.
 
-        @param path path string to guess an URL for (string)
-        @return guessed URL (QUrl)
+        @param path path string to guess an URL for
+        @type str
+        @return guessed URL
+        @rtype QUrl
         """
         manager = self.__mainWindow.openSearchManager()
         path = FileSystemUtilities.fromNativeSeparators(path)
@@ -1086,7 +936,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private slot to handle an index change.
 
-        @param index new index (integer)
+        @param index new index
+        @type int
         """
         self.__stackedUrlBar.setCurrentIndex(index)
 
@@ -1115,7 +966,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public method to check, if closed tabs can be restored.
 
-        @return flag indicating that closed tabs can be restored (boolean)
+        @return flag indicating that closed tabs can be restored
+        @rtype bool
         """
         return self.__closedTabsManager.isClosedTabAvailable()
 
@@ -1161,7 +1013,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Public slot to get a reference to the closed tabs manager.
 
-        @return reference to the closed tabs manager (ClosedTabsManager)
+        @return reference to the closed tabs manager
+        @rtype ClosedTabsManager
         """
         return self.__closedTabsManager
 
@@ -1169,7 +1022,8 @@ class WebBrowserTabWidget(EricTabWidget):
         """
         Private slot to handle changes of the availability of closed tabs.
 
-        @param avail flag indicating the availability of closed tabs (boolean)
+        @param avail flag indicating the availability of closed tabs
+        @type bool
         """
         self.__closedTabsButton.setEnabled(avail)
         self.__restoreClosedTabAct.setEnabled(avail)
