@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2024 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the uninstall script for the eric debug client.
 #
@@ -10,15 +10,14 @@
 Unnstallation script for the eric debug clients.
 """
 
+import argparse
 import contextlib
-import getopt
 import os
 import shutil
 import sys
 import sysconfig
 
 # Define the globals.
-progName = None
 currDir = os.getcwd()
 modDir = None
 pyModDir = None
@@ -29,7 +28,8 @@ def exit(rcode=0):
     """
     Exit the install script.
 
-    @param rcode result code to report back (integer)
+    @param rcode result code to report back
+    @type int
     """
     global currDir
 
@@ -42,22 +42,6 @@ def exit(rcode=0):
     sys.exit(rcode)
 
 
-def usage(rcode=2):
-    """
-    Display a usage message and exit.
-
-    @param rcode return code passed back to the calling process (integer)
-    """
-    global progName
-
-    print("Usage:")
-    print("    {0} [-h]".format(progName))
-    print("where:")
-    print("    -h             display this help message")
-
-    exit(rcode)
-
-
 def initGlobals():
     """
     Module function to set the values of globals that need more than a
@@ -66,6 +50,15 @@ def initGlobals():
     global modDir, pyModDir
 
     modDir = sysconfig.get_path("platlib")
+    if not os.access(modDir, os.W_OK):
+        # can't write to the standard path, use the 'user' path instead
+        if sys.platform.startswith(("win", "cygwin")):
+            scheme = "nt_user"
+        elif sys.platform == "darwin":
+            scheme = "osx_framework_user"
+        else:
+            scheme = "posix_user"
+        modDir = sysconfig.get_path("platlib", scheme)
     pyModDir = modDir
 
 
@@ -79,32 +72,31 @@ def uninstallEricDebugClients():
         # Cleanup the install directories
         dirname = os.path.join(pyModDir, installPackage)
         if os.path.exists(dirname):
-            shutil.rmtree(dirname, True)
+            shutil.rmtree(dirname, ignore_errors=True)
     except OSError as msg:
         sys.stderr.write("Error: {0}\nTry uninstall with admin rights.\n".format(msg))
         exit(7)
 
 
-def main(argv):
+def createArgumentParser():
+    """
+    Function to create an argument parser.
+
+    @return created argument parser object
+    @rtype argparse.ArgumentParser
+    """
+    parser = argparse.ArgumentParser(description="Uninstall eric7 debug client.")
+    return parser
+
+
+def main():
     """
     The main function of the script.
-
-    @param argv the list of command line arguments.
     """
     initGlobals()
 
-    # Parse the command line.
-    global progName
-    progName = os.path.basename(argv[0])
-
-    try:
-        optlist, args = getopt.getopt(argv[1:], "hy")
-    except getopt.GetoptError:
-        usage()
-
-    for opt, _arg in optlist:
-        if opt in ["-h", "--help"]:
-            usage(0)
+    parser = createArgumentParser()
+    parser.parse_args()
 
     print("\nUninstalling eric debug clients ...")
     uninstallEricDebugClients()
@@ -116,7 +108,7 @@ def main(argv):
 
 if __name__ == "__main__":
     try:
-        main(sys.argv)
+        main()
     except SystemExit:
         raise
     except Exception:
